  #include <sys/utsname.h>
  #include <unistd.h>
  #include <fcntl.h>

#include "pxll.h"

static int lookup_field (int tag, int label);

static
inline
pxll_int
get_typecode (object * ob)
{
  if (IMMEDIATE(ob)) {
    if (IS_INTEGER(ob)) {
      return TC_INT;
    } else {
      return (pxll_int)ob & 0xff;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case (object * ob)
{
  if (is_immediate (ob)) {
    if (is_int (ob)) {
      return TC_INT;
    } else {
      return (pxll_int) ob;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_noint (object * ob)
{
  if (is_immediate (ob)) {
    return (pxll_int) ob;
  } else {
    return (pxll_int) * ((pxll_int*) ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_imm (object * ob)
{
  return (pxll_int)ob;
}

static
inline
pxll_int
get_case_tup (object * ob)
{
  return (pxll_int)*((pxll_int *)ob) & 0xff;
}

static
inline
pxll_int
get_imm_payload (object * ob)
{
  return ((pxll_int) ob) >> 8;
}

static
pxll_int
get_tuple_size (object * ob)
{
  header * h = (header *) ob;
  return (*h)>>8;
}

static
void
indent (int n)
{
  while (n--) {
    fprintf (stdout, "  ");
  }
}

void print_string (object * ob, int quoted);
void print_list (pxll_pair * l);

// this is kinda lame, it's part pretty-printer, part not.
static
object *
dump_object (object * ob, int depth)
{
  // indent (depth);
  if (depth > 100) {
    fprintf (stdout , "...");
    return (object *) PXLL_UNDEFINED;
  }
  if (!ob) {
    fprintf (stdout, "<null>");
  } else if (is_int (ob)) {
    // integer
    fprintf (stdout, "%zd", unbox (ob));
  } else {
    int tc = is_immediate (ob);
    switch (tc) {
    case TC_CHAR:
      if ((pxll_int)ob>>8 == 257) {
	// deliberately out-of-range character
	fprintf (stdout, "#\\eof");
      } else {
	char ch = ((char)((pxll_int)ob>>8));
	switch (ch) {
	case '\000': fprintf (stdout, "#\\nul"); break;
	case ' '   : fprintf (stdout, "#\\space"); break;
	case '\n'  : fprintf (stdout, "#\\newline"); break;
	case '\r'  : fprintf (stdout, "#\\return"); break;
	case '\t'  : fprintf (stdout, "#\\tab"); break;
	default    : fprintf (stdout, "#\\%c", ch);
	}
      }
      break;
    case TC_BOOL:
      fprintf (stdout, ((pxll_int)ob >> 8) & 0xff ? "#t" : "#f");
      break;
    case TC_NIL:
      fprintf (stdout, "()");
      break;
    case TC_UNDEFINED:
      fprintf (stdout, "#u");
      break;
    case TC_EMPTY_VECTOR:
      fprintf (stdout, "#()");
      break;
    case 0: {
      // structure
      header h = (header) (ob[0]);
      int tc = h & 0xff;
      switch (tc) {
      case TC_SAVE: {
	// XXX fix me - now holds saved registers
        pxll_save * s = (pxll_save* ) ob;
        fprintf (stdout, "<save pc=%p\n", s->pc);
        dump_object ((object *) s->lenv, depth+1); fprintf (stdout, "\n");
        dump_object ((object *) s->next, depth+1); fprintf (stdout, ">");
      }
        break;
      case TC_CLOSURE: {
        pxll_closure * c = (pxll_closure *) ob;
        //fprintf (stdout, "<closure pc=%p\n", c->pc);
        //dump_object ((object *) c->lenv, depth+1); fprintf (stdout, ">\n");
	fprintf (stdout, "<closure pc=%p lenv=%p>", c->pc, c->lenv);
      }
        break;
      case TC_TUPLE: {
        pxll_tuple * t = (pxll_tuple *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "<tuple\n");
        for (i=0; i < n-1; i++) {
          dump_object ((object *) t->val[i], depth + 1); fprintf (stdout, "\n");
        }
        dump_object ((object *) t->next, depth + 1);
        fprintf (stdout, ">");
      }
	break;
      case TC_VECTOR: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "#(");
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_VEC16: {
        pxll_vec16 * t = (pxll_vec16 *) ob;
        pxll_int n = t->len;
        int i;
	fprintf (stdout, "#16(");
        for (i=0; i < n; i++) {
	  fprintf (stdout, "%d", t->data[i]);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_PAIR:
	print_list ((pxll_pair *) ob);
        break;
      case TC_STRING:
	print_string (ob, 1);
	break;
      case TC_BUFFER: {
	pxll_int n = get_tuple_size (ob);
	fprintf (stdout, "<buffer %" PRIuPTR " words %" PRIuPTR " bytes>", n, n * (sizeof(pxll_int)));
	break;
      }
      case TC_SYMBOL:
	print_string (ob[1], 0);
	break;
      default: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "{u%d ", (tc - TC_USEROBJ)>>2);
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, "}");
      }
      }
    }
      break;
    case TC_USERIMM:
      // a user immediate unit-type...
      fprintf (stdout, "<u%" PRIuPTR ">", (((pxll_int)ob)>>8));
    }
  }
  return (object *) PXLL_UNDEFINED;
}

// for gdb...
void
DO (object * x)
{
  dump_object (x, 0);
  fprintf (stdout, "\n");
  fflush (stdout);
}

// for debugging
void
stack_depth_indent (object * k)
{
  while (k != PXLL_NIL) {
    k = k[1];
    fprintf (stderr, "  ");
  }
}

void
print_string (object * ob, int quoted)
{
  pxll_string * s = (pxll_string *) ob;
  char * ps = s->data;
  int i;
  //fprintf (stderr, "<printing string of len=%d (tuple-len=%d)>\n", s->len, get_tuple_size (ob));
  if (quoted) {
    fputc ('"', stdout);
  }
  for (i=0; i < (s->len); i++, ps++) {
    if (*ps == '"') {
      fputc ('\\', stdout);
      fputc ('"', stdout);
    } else {
      if (isprint(*ps)) {
	fputc (*ps, stdout);
      } else {
	fprintf (stdout, "\\0x%02x", *ps);
      }
    }
    if (i > 50) {
      fprintf (stdout, "...");
      break;
    }
  }
  if (quoted) {
    fputc ('"', stdout);
  }
}

void
print_list (pxll_pair * l)
{
  fprintf (stdout, "(");
  while (1) {
    object * car = l->car;
    object * cdr = l->cdr;
    dump_object (car, 0);
    if (cdr == PXLL_NIL) {
      fprintf (stdout, ")");
      break;
    } else if (!is_immediate (cdr) && GET_TYPECODE (*cdr) == TC_PAIR) {
      fprintf (stdout, " ");
      l = (pxll_pair *) cdr;
    } else {
      fprintf (stdout, " . ");
      dump_object (cdr, 0);
      fprintf (stdout, ")");
      break;
    }
  }
}

int
read_header (FILE * file)
{
  int depth = 0;
  // tiny lisp 'skipper' (as opposed to 'reader')
  do {
    char ch = fgetc (file);
    switch (ch) {
    case '(':
      depth++;
      break;
    case ')':
      depth--;
      break;
    case '"':
      while (fgetc (file) != '"') {
        // empty body
      }
      break;
    default:
      break;
    }
  } while (depth);
  // read terminating newline
  fgetc (file);
  return 0;
}

#ifndef NO_RANGE_CHECK
// used to check array references.  some day we might try to teach
//   the compiler when/how to skip doing this...
static
void
inline
range_check (unsigned int length, unsigned int index)
{
  if (index >= length) {
    fprintf (stderr, "array/string reference out of range: %d[%d]\n", length, index);
    abort();
  }
}
#else
static
void
inline
range_check (unsigned int length, unsigned int index)
{
}
#endif

pxll_int verbose_gc = 1;
pxll_int clear_fromspace = 0;
pxll_int clear_tospace = 0;

pxll_int vm (int argc, char * argv[]);

#include "rdtsc.h"

unsigned long long gc_ticks = 0;

static
void
clear_space (object * p, pxll_int n)
{
  while (n--) {
    *p++ = PXLL_NIL;
  }
}

int
main (int argc, char * argv[])
{
  heap0 = malloc (sizeof (object) * heap_size);
  heap1 = malloc (sizeof (object) * heap_size);
  if (!heap0 || !heap1) {
    fprintf (stderr, "unable to allocate heap\n");
    return -1;
  } else {
    unsigned long long t0, t1;
    pxll_int result;
    if (clear_tospace) {
      clear_space (heap0, heap_size);
    }
    t0 = rdtsc();
    result = vm (argc, argv);
    t1 = rdtsc();
    dump_object ((object *) result, 0);
    fprintf (stdout, "\n");
    fprintf (stderr, "{total ticks: %lld gc ticks: %lld}\n", t1 - t0, gc_ticks);
    return (int) result;
  }
}

// CONSTRUCTED LITERALS //
pxll_string constructed_0 = {STRING_HEADER(8), 8, "system: " };
pxll_string constructed_1 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_2 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_3 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_4 = {STRING_HEADER(6), 6, ".c -o " };
pxll_string constructed_5 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_6 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_7 = {STRING_HEADER(2), 2, "-O" };
pxll_string constructed_8 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_9 = {STRING_HEADER(19), 19, " -fnested-functions" };
pxll_string constructed_10 = {STRING_HEADER(6), 6, "Darwin" };
pxll_string constructed_11 = {STRING_HEADER(3), 3, "gcc" };
pxll_string constructed_12 = {STRING_HEADER(7), 7, "-I. -g " };
pxll_string constructed_13 = {STRING_HEADER(6), 6, "CFLAGS" };
pxll_string constructed_14 = {STRING_HEADER(3), 3, "gcc" };
pxll_string constructed_15 = {STRING_HEADER(2), 2, "CC" };
pxll_string constructed_16 = {STRING_HEADER(13), 13, "compiling...\n" };
pxll_string constructed_17 = {STRING_HEADER(6), 6, "done.\n" };
pxll_string constructed_18 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_19 = {STRING_HEADER(10), 10, "  } break;" };
pxll_string constructed_20 = {STRING_HEADER(10), 10, "     case " };
pxll_string constructed_21 = {STRING_HEADER(9), 9, ": return " };
pxll_string constructed_22 = {STRING_HEADER(8), 8, "; break;" };
pxll_string constructed_23 = {STRING_HEADER(18), 18, "  switch (label) {" };
pxll_string constructed_24 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_25 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_26 = {STRING_HEADER(16), 16, "{ switch (tag) {" };
pxll_string constructed_27 = {STRING_HEADER(44), 44, "static int lookup_field (int tag, int label)" };
pxll_string constructed_28 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_29 = {STRING_HEADER(25), 25, "return (pxll_int) result;" };
pxll_string constructed_30 = {STRING_HEADER(8), 8, "Lreturn:" };
pxll_string constructed_31 = {STRING_HEADER(37), 37, "abcdefghijklmnopqrstuvwxyz_0123456789" };
pxll_string constructed_32 = {STRING_HEADER(5), 5, "_bang" };
pxll_string constructed_33 = {STRING_HEADER(6), 6, "_splat" };
pxll_string constructed_34 = {STRING_HEADER(9), 9, "_question" };
pxll_string constructed_35 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_36 = {STRING_HEADER(5), 5, "_plus" };
pxll_string constructed_37 = {STRING_HEADER(8), 8, "_percent" };
pxll_int constructed_38[] = {UPTR(38,21),UOHEAD(3,1),9474,UPTR0(37),UITAG(0),UOHEAD(3,1),11010,UPTR0(36),UPTR(38,1),UOHEAD(3,1),11522,UPTR0(35),UPTR(38,5),UOHEAD(3,1),16130,UPTR0(34),UPTR(38,9),UOHEAD(3,1),10754,UPTR0(33),UPTR(38,13),UOHEAD(3,1),8450,UPTR0(32),UPTR(38,17)};
pxll_string constructed_39 = {STRING_HEADER(5), 5, "minus" };
pxll_string constructed_40 = {STRING_HEADER(1), 1, "_" };
pxll_int constructed_41[] = {TC_NIL};
pxll_int constructed_42[] = {TC_NIL};
pxll_string constructed_43 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_44 = {STRING_HEADER(20), 20, "(pxll_int)PXLL_FALSE" };
pxll_string constructed_45 = {STRING_HEADER(5), 5, "false" };
// symbol false
pxll_int constructed_46[] = {UPTR(46,1), SYMBOL_HEADER, UPTR0(45), INTCON(0)};
pxll_string constructed_47 = {STRING_HEADER(19), 19, "(pxll_int)PXLL_TRUE" };
pxll_string constructed_48 = {STRING_HEADER(4), 4, "true" };
// symbol true
pxll_int constructed_49[] = {UPTR(49,1), SYMBOL_HEADER, UPTR0(48), INTCON(1)};
pxll_string constructed_50 = {STRING_HEADER(4), 4, "bool" };
// symbol bool
pxll_int constructed_51[] = {UPTR(51,1), SYMBOL_HEADER, UPTR0(50), INTCON(2)};
pxll_string constructed_52 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_53 = {STRING_HEADER(3), 3, "nil" };
// symbol nil
pxll_int constructed_54[] = {UPTR(54,1), SYMBOL_HEADER, UPTR0(53), INTCON(3)};
pxll_string constructed_55 = {STRING_HEADER(4), 4, "list" };
// symbol list
pxll_int constructed_56[] = {UPTR(56,1), SYMBOL_HEADER, UPTR0(55), INTCON(4)};
pxll_string constructed_57 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_58 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_59 = {STRING_HEADER(9), 9, "TC_SYMBOL" };
pxll_string constructed_60 = {STRING_HEADER(1), 1, "t" };
// symbol t
pxll_int constructed_61[] = {UPTR(61,1), SYMBOL_HEADER, UPTR0(60), INTCON(5)};
pxll_string constructed_62 = {STRING_HEADER(6), 6, "symbol" };
// symbol symbol
pxll_int constructed_63[] = {UPTR(63,1), SYMBOL_HEADER, UPTR0(62), INTCON(6)};
pxll_string constructed_64 = {STRING_HEADER(7), 7, "TC_PAIR" };
pxll_string constructed_65 = {STRING_HEADER(4), 4, "cons" };
// symbol cons
pxll_int constructed_66[] = {UPTR(66,1), SYMBOL_HEADER, UPTR0(65), INTCON(7)};
pxll_string constructed_67 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_68 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_69[] = {TC_NIL};
pxll_string constructed_70 = {STRING_HEADER(3), 3, "..." };
// symbol ...
pxll_int constructed_71[] = {UPTR(71,1), SYMBOL_HEADER, UPTR0(70), INTCON(8)};
pxll_string constructed_72 = {STRING_HEADER(79), 79, "Why, sometimes I've believed as many as six impossible things before breakfast." };
pxll_string constructed_73 = {STRING_HEADER(29), 29, "\n***\nRuntime Error, halting: " };
pxll_string constructed_74 = {STRING_HEADER(4), 4, "FUN_" };
pxll_string constructed_75 = {STRING_HEADER(12), 12, "PXLL_RETURN(" };
pxll_string constructed_76 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_77 = {STRING_HEADER(14), 14, " = (object *) " };
pxll_string constructed_78 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_79 = {STRING_HEADER(8), 8, "// dead " };
pxll_string constructed_80 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_81 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_82 = {STRING_HEADER(26), 26, " = (object*) &constructed_" };
pxll_string constructed_83 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_84 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_85 = {STRING_HEADER(26), 26, " = (object *) constructed_" };
pxll_string constructed_86 = {STRING_HEADER(4), 4, "[0];" };
pxll_string constructed_87 = {STRING_HEADER(6), 6, "string" };
// symbol string
pxll_int constructed_88[] = {UPTR(88,1), SYMBOL_HEADER, UPTR0(87), INTCON(9)};
pxll_string constructed_89 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_90 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_91 = {STRING_HEADER(17), 17, "if PXLL_IS_TRUE(r" };
pxll_string constructed_92 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_93 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_94 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_95 = {STRING_HEADER(16), 16, "if PXLL_IS_TRUE(" };
pxll_string constructed_96 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_97 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_98 = {STRING_HEADER(5), 5, "arrow" };
// symbol arrow
pxll_int constructed_99[] = {UPTR(99,1), SYMBOL_HEADER, UPTR0(98), INTCON(10)};
pxll_string constructed_100 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_101 = {STRING_HEADER(2), 2, "=r" };
pxll_string constructed_102 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_103 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_104 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_105 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_106 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_107 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_108 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_109 = {STRING_HEADER(8), 8, "[1] = &&" };
pxll_string constructed_110 = {STRING_HEADER(3), 3, "; r" };
pxll_string constructed_111 = {STRING_HEADER(11), 11, "[2] = lenv;" };
pxll_string constructed_112 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_113 = {STRING_HEADER(28), 28, " = allocate (TC_CLOSURE, 2);" };
pxll_string constructed_114 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_115 = {STRING_HEADER(15), 15, "check_heap (0);" };
pxll_string constructed_116 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_117 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_118 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_119 = {STRING_HEADER(7), 7, "// def " };
pxll_string constructed_120 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_121 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_122 = {STRING_HEADER(4), 4, "top[" };
pxll_string constructed_123 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_124 = {STRING_HEADER(9), 9, "((object*" };
pxll_string constructed_125 = {STRING_HEADER(8), 8, ") lenv) " };
pxll_string constructed_126 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_127 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_128 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_129 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_130 = {STRING_HEADER(4), 4, "top[" };
pxll_string constructed_131 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_132 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_133 = {STRING_HEADER(9), 9, "((object*" };
pxll_string constructed_134 = {STRING_HEADER(8), 8, ") lenv) " };
pxll_string constructed_135 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_136 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_137 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_138 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_139 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_140 = {STRING_HEADER(7), 7, "top = r" };
pxll_string constructed_141 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_142 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_143 = {STRING_HEADER(23), 23, " = allocate (TC_TUPLE, " };
pxll_string constructed_144 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_145 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_146 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_147 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_148 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_149 = {STRING_HEADER(13), 13, " = allocate (" };
pxll_string constructed_150 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_151 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_152 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_153 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_154 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_155 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_156 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_157 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_158 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_159 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_160 = {STRING_HEADER(10), 10, " = result;" };
pxll_string constructed_161 = {STRING_HEADER(24), 24, "; lenv = k[2]; k = k[1];" };
pxll_string constructed_162 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_163 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_164 = {STRING_HEADER(5), 5, " = k[" };
pxll_string constructed_165 = {STRING_HEADER(1), 1, "]" };
pxll_string constructed_166 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_167 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_168 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_169 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_170 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_171 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_172 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_173 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_174 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_175 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_176 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_177 = {STRING_HEADER(32), 32, "t[1] = k; t[2] = lenv; t[3] = &&" };
pxll_string constructed_178 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_179 = {STRING_HEADER(8), 8, "; k = t;" };
pxll_string constructed_180 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_181 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_182 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_183 = {STRING_HEADER(23), 23, "t = allocate (TC_SAVE, " };
pxll_string constructed_184 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_185 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_186 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_187 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_188 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_189 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_190 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_191 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_192 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_193 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_194 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_195 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_196 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_197 = {STRING_HEADER(5), 5, "lenv[" };
pxll_string constructed_198 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_199 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_200 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_201 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_202 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_203 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_204 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_205 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_206 = {STRING_HEADER(20), 20, "[1] = lenv; lenv = r" };
pxll_string constructed_207 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_208 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_209 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_210 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_211 = {STRING_HEADER(15), 15, "lenv = lenv[1];" };
pxll_string constructed_212 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_213 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_214 = {STRING_HEADER(3), 3, "(((" };
pxll_string constructed_215 = {STRING_HEADER(15), 15, "*)((pxll_int*)r" };
pxll_string constructed_216 = {STRING_HEADER(5), 5, ")+1)[" };
pxll_string constructed_217 = {STRING_HEADER(2), 2, "])" };
pxll_string constructed_218 = {STRING_HEADER(2), 2, "((" };
pxll_string constructed_219 = {STRING_HEADER(7), 7, ")unbox(" };
pxll_string constructed_220 = {STRING_HEADER(2), 2, "))" };
pxll_string constructed_221 = {STRING_HEADER(37), 37, "lookup-cast: can't cast from int to: " };
pxll_string constructed_222 = {STRING_HEADER(3), 3, "int" };
// symbol int
pxll_int constructed_223[] = {UPTR(223,1), SYMBOL_HEADER, UPTR0(222), INTCON(11)};
pxll_string constructed_224 = {STRING_HEADER(43), 43, "lookup-cast: unable to cast between types: " };
pxll_string constructed_225 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_226 = {STRING_HEADER(6), 6, "primop" };
pxll_string constructed_227 = {STRING_HEADER(5), 5, "%cset" };
// symbol %cset
pxll_int constructed_228[] = {UPTR(228,1), SYMBOL_HEADER, UPTR0(227), INTCON(12)};
pxll_string constructed_229 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_230 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_231 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_232 = {STRING_HEADER(3), 3, "(((" };
pxll_string constructed_233 = {STRING_HEADER(15), 15, "*)((pxll_int*)r" };
pxll_string constructed_234 = {STRING_HEADER(5), 5, ")+1)[" };
pxll_string constructed_235 = {STRING_HEADER(2), 2, "])" };
pxll_string constructed_236 = {STRING_HEADER(5), 5, "%cget" };
// symbol %cget
pxll_int constructed_237[] = {UPTR(237,1), SYMBOL_HEADER, UPTR0(236), INTCON(13)};
pxll_string constructed_238 = {STRING_HEADER(24), 24, "PXLL_UNDEFINED; result=r" };
pxll_string constructed_239 = {STRING_HEADER(15), 15, "; goto Lreturn;" };
pxll_string constructed_240 = {STRING_HEADER(5), 5, "%exit" };
// symbol %exit
pxll_int constructed_241[] = {UPTR(241,1), SYMBOL_HEADER, UPTR0(240), INTCON(14)};
pxll_string constructed_242 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_243 = {STRING_HEADER(48), 48, " = alloc_no_clear (TC_BUFFER, HOW_MANY (sizeof (" };
pxll_string constructed_244 = {STRING_HEADER(11), 11, ") * unbox(r" };
pxll_string constructed_245 = {STRING_HEADER(21), 21, "), sizeof (object)));" };
pxll_string constructed_246 = {STRING_HEADER(24), 24, "%callocate: dead target?" };
pxll_string constructed_247 = {STRING_HEADER(10), 10, "%callocate" };
// symbol %callocate
pxll_int constructed_248[] = {UPTR(248,1), SYMBOL_HEADER, UPTR0(247), INTCON(15)};
pxll_string constructed_249 = {STRING_HEADER(13), 13, "ensure_heap (" };
pxll_string constructed_250 = {STRING_HEADER(9), 9, ", unbox(r" };
pxll_string constructed_251 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_252 = {STRING_HEADER(12), 12, "%ensure-heap" };
// symbol %ensure-heap
pxll_int constructed_253[] = {UPTR(253,1), SYMBOL_HEADER, UPTR0(252), INTCON(16)};
pxll_string constructed_254 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_255 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_256 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_257 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_258 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_259 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_260 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_261 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_262 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_263 = {STRING_HEADER(11), 11, "%record-set" };
// symbol %record-set
pxll_int constructed_264[] = {UPTR(264,1), SYMBOL_HEADER, UPTR0(263), INTCON(17)};
pxll_string constructed_265 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_266 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_267 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_268 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_269 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_270 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_271 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_272 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_273 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_274 = {STRING_HEADER(11), 11, "%record-get" };
// symbol %record-get
pxll_int constructed_275[] = {UPTR(275,1), SYMBOL_HEADER, UPTR0(274), INTCON(18)};
pxll_string constructed_276 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_277 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_278 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_279 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_280 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_281 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_282 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_283 = {STRING_HEADER(10), 10, "%array-set" };
// symbol %array-set
pxll_int constructed_284[] = {UPTR(284,1), SYMBOL_HEADER, UPTR0(283), INTCON(19)};
pxll_string constructed_285 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_286 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_287 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_288 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_289 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_290 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_291 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_292 = {STRING_HEADER(10), 10, "%array-ref" };
// symbol %array-ref
pxll_int constructed_293[] = {UPTR(293,1), SYMBOL_HEADER, UPTR0(292), INTCON(20)};
pxll_string constructed_294 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_295 = {STRING_HEADER(3), 3, "  r" };
pxll_string constructed_296 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_297 = {STRING_HEADER(21), 21, "  for (i=0; i<unbox(r" };
pxll_string constructed_298 = {STRING_HEADER(20), 20, "); i++) { t[i+1] = r" };
pxll_string constructed_299 = {STRING_HEADER(3), 3, "; }" };
pxll_string constructed_300 = {STRING_HEADER(40), 40, "  t = alloc_no_clear (TC_VECTOR, unbox(r" };
pxll_string constructed_301 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_302 = {STRING_HEADER(11), 11, "if (unbox(r" };
pxll_string constructed_303 = {STRING_HEADER(11), 11, ") == 0) { r" };
pxll_string constructed_304 = {STRING_HEADER(39), 39, " = (object *) TC_EMPTY_VECTOR; } else {" };
pxll_string constructed_305 = {STRING_HEADER(12), 12, "%make-vector" };
// symbol %make-vector
pxll_int constructed_306[] = {UPTR(306,1), SYMBOL_HEADER, UPTR0(305), INTCON(21)};
pxll_string constructed_307 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_308 = {STRING_HEADER(13), 13, " = UOBJ_GET(r" };
pxll_string constructed_309 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_310 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_311 = {STRING_HEADER(6), 6, "%nvget" };
// symbol %nvget
pxll_int constructed_312[] = {UPTR(312,1), SYMBOL_HEADER, UPTR0(311), INTCON(22)};
pxll_string constructed_313 = {STRING_HEADER(29), 29, "emit-primop: no such datatype" };
pxll_string constructed_314 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_315 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_316 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_317 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_318 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_319 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_320 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_321 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_322 = {STRING_HEADER(20), 20, "t = alloc_no_clear (" };
pxll_string constructed_323 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_324 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_325 = {STRING_HEADER(6), 6, "%dtcon" };
// symbol %dtcon
pxll_int constructed_326[] = {UPTR(326,1), SYMBOL_HEADER, UPTR0(325), INTCON(23)};
pxll_string constructed_327 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_328 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_329 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_330 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_331 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_332 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_333 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_334 = {STRING_HEADER(8), 8, "_over: ;" };
pxll_string constructed_335 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_336 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_337 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_338 = {STRING_HEADER(6), 6, "_over;" };
pxll_string constructed_339 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_340 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_341 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_342 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_343 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_344 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_345 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_346 = {STRING_HEADER(11), 11, "emit-nvcase" };
pxll_string constructed_347 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_348 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_349 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_350 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_351 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_352 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_353 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_354 = {STRING_HEADER(8), 8, "switch (" };
pxll_string constructed_355 = {STRING_HEADER(3), 3, " (r" };
pxll_string constructed_356 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_357 = {STRING_HEADER(8), 8, "get_case" };
pxll_string constructed_358 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_359 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_360 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_361 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_362 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_363 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_364 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_365 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_366 = {STRING_HEADER(32), 32, "variant constructor never called" };
pxll_string constructed_367 = {STRING_HEADER(25), 25, "switch (get_case_noint (r" };
pxll_string constructed_368 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_369 = {STRING_HEADER(22), 22, "pvcase else-clause NYI" };
pxll_string constructed_370 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_371 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_372 = {STRING_HEADER(3), 3, ": r" };
pxll_string constructed_373 = {STRING_HEADER(9), 9, " = heap0[" };
pxll_string constructed_374 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_375 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_376 = {STRING_HEADER(26), 26, "void gc_regs_out (int n) {" };
pxll_string constructed_377 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_378 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_379 = {STRING_HEADER(8), 8, ": heap1[" };
pxll_string constructed_380 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_381 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_382 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_383 = {STRING_HEADER(25), 25, "void gc_regs_in (int n) {" };
pxll_string constructed_384 = {STRING_HEADER(19), 19, "register object * r" };
pxll_string constructed_385 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_386 = {STRING_HEADER(37), 37, "pxll_int pxll_internal_symbols[] = {(" };
pxll_string constructed_387 = {STRING_HEADER(16), 16, "<<8)|TC_VECTOR, " };
pxll_string constructed_388 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_389 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_390 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_391 = {STRING_HEADER(3), 3, ",1)" };
pxll_int constructed_392[] = {TC_NIL};
pxll_string constructed_393 = {STRING_HEADER(24), 24, "pxll_string constructed_" };
pxll_string constructed_394 = {STRING_HEADER(18), 18, " = {STRING_HEADER(" };
pxll_string constructed_395 = {STRING_HEADER(3), 3, "), " };
pxll_string constructed_396 = {STRING_HEADER(3), 3, ", \"" };
pxll_string constructed_397 = {STRING_HEADER(4), 4, "\" };" };
pxll_int constructed_398[] = {TC_NIL};
pxll_string constructed_399 = {STRING_HEADER(2), 2, "\\\"" };
pxll_string constructed_400 = {STRING_HEADER(2), 2, "\\\\" };
pxll_string constructed_401 = {STRING_HEADER(2), 2, "\\t" };
pxll_string constructed_402 = {STRING_HEADER(2), 2, "\\n" };
pxll_string constructed_403 = {STRING_HEADER(2), 2, "\\r" };
pxll_string constructed_404 = {STRING_HEADER(1), 1, "0" };
pxll_string constructed_405 = {STRING_HEADER(2), 2, "00" };
pxll_string constructed_406 = {STRING_HEADER(3), 3, "000" };
pxll_string constructed_407 = {STRING_HEADER(30), 30, "unable to oct-encode character" };
pxll_int constructed_408[] = {TC_NIL};
pxll_string constructed_409 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_410 = {STRING_HEADER(11), 11, "[] = {UPTR(" };
pxll_string constructed_411 = {STRING_HEADER(26), 26, ",1), SYMBOL_HEADER, UPTR0(" };
pxll_string constructed_412 = {STRING_HEADER(10), 10, "), INTCON(" };
pxll_string constructed_413 = {STRING_HEADER(3), 3, ")};" };
pxll_string constructed_414 = {STRING_HEADER(10), 10, "// symbol " };
pxll_string constructed_415 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_416 = {STRING_HEADER(6), 6, "[] = {" };
pxll_string constructed_417 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_418 = {STRING_HEADER(1), 1, "," };
pxll_int constructed_419[] = {TC_NIL};
pxll_string constructed_420 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_421 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_422 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_423 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_424 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_425 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_426 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_427 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_428 = {STRING_HEADER(14), 14, "<<8)|TC_VECTOR" };
pxll_string constructed_429 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_430 = {STRING_HEADER(3), 3, ",1)" };
pxll_string constructed_431 = {STRING_HEADER(15), 15, "unknown symbol?" };
pxll_string constructed_432 = {STRING_HEADER(6), 6, "UPTR0(" };
pxll_string constructed_433 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_434 = {STRING_HEADER(29), 29, "emit-constructed: lost string" };
pxll_string constructed_435 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_436 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_437 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_438 = {STRING_HEADER(11), 11, "CONS_HEADER" };
pxll_string constructed_439 = {STRING_HEADER(7), 7, "UOHEAD(" };
pxll_string constructed_440 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_441 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_442[] = {TC_NIL};
pxll_string constructed_443 = {STRING_HEADER(39), 39, "template strings not found in header.c?" };
pxll_int constructed_444[] = {TC_NIL};
pxll_string constructed_445 = {STRING_HEADER(8), 8, "header.c" };
pxll_string constructed_446 = {STRING_HEADER(10), 10, "#include <" };
pxll_string constructed_447 = {STRING_HEADER(1), 1, ">" };
pxll_string constructed_448 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_449 = {STRING_HEADER(16), 16, "\n-- C output --\n" };
pxll_string constructed_450 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_451 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_452 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_453 = {STRING_HEADER(22), 22, "\n-- variant labels --\n" };
pxll_string constructed_454 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_455 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_456 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_457 = {STRING_HEADER(15), 15, "\n-- symbols --\n" };
pxll_string constructed_458 = {STRING_HEADER(15), 15, "\n-- records --\n" };
pxll_string constructed_459 = {STRING_HEADER(14), 14, "\n-- labels --\n" };
pxll_string constructed_460 = {STRING_HEADER(17), 17, "\n-- datatypes --\n" };
pxll_string constructed_461 = {STRING_HEADER(11), 11, "\n-- RTL --\n" };
pxll_string constructed_462 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_463 = {STRING_HEADER(2), 2, "  " };
pxll_int constructed_464[] = {TC_NIL};
pxll_int constructed_465[] = {TC_NIL};
pxll_string constructed_466 = {STRING_HEADER(16), 16, "unbound variable" };
pxll_string constructed_467 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_string constructed_468 = {STRING_HEADER(6), 6, "vector" };
// symbol vector
pxll_int constructed_469[] = {UPTR(469,1), SYMBOL_HEADER, UPTR0(468), INTCON(24)};
pxll_string constructed_470 = {STRING_HEADER(11), 11, "constructor" };
// symbol constructor
pxll_int constructed_471[] = {UPTR(471,1), SYMBOL_HEADER, UPTR0(470), INTCON(25)};
pxll_string constructed_472 = {STRING_HEADER(13), 13, "c-conditional" };
pxll_string constructed_473 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_474[] = {TC_NIL};
pxll_string constructed_475 = {STRING_HEADER(28), 28, "c-call function in register?" };
pxll_string constructed_476 = {STRING_HEADER(20), 20, "c-call: no function?" };
pxll_string constructed_477 = {STRING_HEADER(6), 6, "buffer" };
// symbol buffer
pxll_int constructed_478[] = {UPTR(478,1), SYMBOL_HEADER, UPTR0(477), INTCON(26)};
pxll_string constructed_479 = {STRING_HEADER(5), 5, "%rset" };
// symbol %rset
pxll_int constructed_480[] = {UPTR(480,1), SYMBOL_HEADER, UPTR0(479), INTCON(27)};
pxll_string constructed_481 = {STRING_HEADER(8), 8, "%raccess" };
// symbol %raccess
pxll_int constructed_482[] = {UPTR(482,1), SYMBOL_HEADER, UPTR0(481), INTCON(28)};
pxll_int constructed_483[] = {TC_NIL};
pxll_string constructed_484 = {STRING_HEADER(6), 6, "%rmake" };
// symbol %rmake
pxll_int constructed_485[] = {UPTR(485,1), SYMBOL_HEADER, UPTR0(484), INTCON(29)};
pxll_string constructed_486 = {STRING_HEADER(18), 18, "malformed %rextend" };
pxll_string constructed_487 = {STRING_HEADER(8), 8, "%rextend" };
// symbol %rextend
pxll_int constructed_488[] = {UPTR(488,1), SYMBOL_HEADER, UPTR0(487), INTCON(30)};
pxll_string constructed_489 = {STRING_HEADER(23), 23, "c-record-extension: NYI" };
pxll_string constructed_490 = {STRING_HEADER(22), 22, "unknown variant label?" };
pxll_string constructed_491 = {STRING_HEADER(16), 16, "bad %vcon params" };
pxll_string constructed_492 = {STRING_HEADER(5), 5, "%vcon" };
// symbol %vcon
pxll_int constructed_493[] = {UPTR(493,1), SYMBOL_HEADER, UPTR0(492), INTCON(31)};
pxll_string constructed_494 = {STRING_HEADER(7), 7, "%fatbar" };
// symbol %fatbar
pxll_int constructed_495[] = {UPTR(495,1), SYMBOL_HEADER, UPTR0(494), INTCON(32)};
pxll_string constructed_496 = {STRING_HEADER(21), 21, "%fail without fatbar?" };
pxll_string constructed_497 = {STRING_HEADER(5), 5, "%fail" };
// symbol %fail
pxll_int constructed_498[] = {UPTR(498,1), SYMBOL_HEADER, UPTR0(497), INTCON(33)};
pxll_string constructed_499 = {STRING_HEADER(12), 12, "%match-error" };
// symbol %match-error
pxll_int constructed_500[] = {UPTR(500,1), SYMBOL_HEADER, UPTR0(499), INTCON(34)};
pxll_string constructed_501 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_502 = {STRING_HEADER(16), 16, "incomplete match" };
pxll_int constructed_503[] = {TC_NIL};
pxll_string constructed_504 = {STRING_HEADER(13), 13, "add-free-regs" };
pxll_string constructed_505 = {STRING_HEADER(3), 3, "top" };
// symbol top
pxll_int constructed_506[] = {UPTR(506,1), SYMBOL_HEADER, UPTR0(505), INTCON(35)};
pxll_int constructed_507[] = {UPTR(507,1),CONS_HEADER,UPTR(506,1),TC_NIL};
pxll_string constructed_508 = {STRING_HEADER(20), 20, "\n-- after typing --\n" };
pxll_int constructed_509[] = {TC_NIL};
pxll_string constructed_510 = {STRING_HEADER(28), 28, "apply-tenv: unbound variable" };
pxll_string constructed_511 = {STRING_HEADER(3), 3, "raw" };
// symbol raw
pxll_int constructed_512[] = {UPTR(512,1), SYMBOL_HEADER, UPTR0(511), INTCON(36)};
pxll_string constructed_513 = {STRING_HEADER(26), 26, "strange constructor scheme" };
pxll_string constructed_514 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_515 = {STRING_HEADER(28), 28, "wrong number of args to cexp" };
pxll_string constructed_516 = {STRING_HEADER(20), 20, "malformed arrow type" };
pxll_string constructed_517 = {STRING_HEADER(21), 21, "malformed conditional" };
pxll_string constructed_518 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_int constructed_519[] = {TC_NIL};
pxll_int constructed_520[] = {TC_NIL};
pxll_string constructed_521 = {STRING_HEADER(11), 11, "empty call?" };
pxll_int constructed_522[] = {TC_NIL};
pxll_int constructed_523[] = {TC_NIL};
pxll_int constructed_524[] = {TC_NIL};
pxll_int constructed_525[] = {TC_NIL};
pxll_int constructed_526[] = {TC_NIL};
pxll_int constructed_527[] = {TC_NIL};
pxll_int constructed_528[] = {TC_NIL};
pxll_int constructed_529[] = {TC_NIL};
pxll_int constructed_530[] = {TC_NIL};
pxll_string constructed_531 = {STRING_HEADER(31), 31, "wrong number of args to primapp" };
pxll_string constructed_532 = {STRING_HEADER(15), 15, "type-of-primapp" };
pxll_int constructed_533[] = {TC_NIL};
pxll_string constructed_534 = {STRING_HEADER(4), 4, "rsum" };
// symbol rsum
pxll_int constructed_535[] = {UPTR(535,1), SYMBOL_HEADER, UPTR0(534), INTCON(37)};
pxll_string constructed_536 = {STRING_HEADER(3), 3, "pre" };
// symbol pre
pxll_int constructed_537[] = {UPTR(537,1), SYMBOL_HEADER, UPTR0(536), INTCON(38)};
pxll_string constructed_538 = {STRING_HEADER(7), 7, "product" };
// symbol product
pxll_int constructed_539[] = {UPTR(539,1), SYMBOL_HEADER, UPTR0(538), INTCON(39)};
pxll_int constructed_540[] = {TC_NIL};
pxll_string constructed_541 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_542 = {STRING_HEADER(24), 24, "bad parameters to primop" };
pxll_int constructed_543[] = {TC_NIL};
pxll_int constructed_544[] = {TC_NIL};
pxll_string constructed_545 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_546 = {STRING_HEADER(8), 8, "rproduct" };
// symbol rproduct
pxll_int constructed_547[] = {UPTR(547,1), SYMBOL_HEADER, UPTR0(546), INTCON(40)};
pxll_int constructed_548[] = {TC_NIL};
pxll_int constructed_549[] = {TC_NIL};
pxll_string constructed_550 = {STRING_HEADER(8), 8, "rdefault" };
// symbol rdefault
pxll_int constructed_551[] = {UPTR(551,1), SYMBOL_HEADER, UPTR0(550), INTCON(41)};
pxll_int constructed_552[] = {TC_NIL};
pxll_string constructed_553 = {STRING_HEADER(3), 3, "abs" };
// symbol abs
pxll_int constructed_554[] = {UPTR(554,1), SYMBOL_HEADER, UPTR0(553), INTCON(42)};
pxll_int constructed_555[] = {TC_NIL};
pxll_int constructed_556[] = {TC_NIL};
pxll_int constructed_557[] = {TC_NIL};
pxll_string constructed_558 = {STRING_HEADER(14), 14, "lookup-primapp" };
pxll_string constructed_559 = {STRING_HEADER(16), 16, "malformed pvcase" };
pxll_string constructed_560 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_561 = {STRING_HEADER(10), 10, "typing NYI" };
pxll_int constructed_562[] = {TC_NIL};
pxll_string constructed_563 = {STRING_HEADER(23), 23, "instantiate-type-scheme" };
pxll_string constructed_564 = {STRING_HEADER(10), 10, "typing...\n" };
pxll_int constructed_565[] = {TC_NIL};
pxll_string constructed_566 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_567[] = {TC_NIL};
pxll_int constructed_568[] = {TC_NIL};
pxll_int constructed_569[] = {TC_NIL};
pxll_int constructed_570[] = {TC_NIL};
pxll_int constructed_571[] = {TC_NIL};
pxll_int constructed_572[] = {TC_NIL};
pxll_string constructed_573 = {STRING_HEADER(31), 31, "strongly-connected components:\n" };
pxll_string constructed_574 = {STRING_HEADER(20), 20, "after second round:\n" };
pxll_int constructed_575[] = {TC_NIL};
pxll_string constructed_576 = {STRING_HEADER(7), 7, "lambda_" };
pxll_string constructed_577 = {STRING_HEADER(6), 6, "lambda" };
// symbol lambda
pxll_int constructed_578[] = {UPTR(578,1), SYMBOL_HEADER, UPTR0(577), INTCON(43)};
pxll_int constructed_579[] = {TC_NIL};
pxll_int constructed_580[] = {TC_NIL};
pxll_string constructed_581 = {STRING_HEADER(2), 2, ".c" };
pxll_string constructed_582 = {STRING_HEADER(9), 9, "find-base" };
pxll_string constructed_583 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_584 = {STRING_HEADER(3), 3, "scm" };
pxll_string constructed_585 = {STRING_HEADER(2), 2, "if" };
// symbol if
pxll_int constructed_586[] = {UPTR(586,1), SYMBOL_HEADER, UPTR0(585), INTCON(44)};
pxll_string constructed_587 = {STRING_HEADER(4), 4, "set!" };
// symbol set!
pxll_int constructed_588[] = {UPTR(588,1), SYMBOL_HEADER, UPTR0(587), INTCON(45)};
pxll_string constructed_589 = {STRING_HEADER(5), 5, "begin" };
// symbol begin
pxll_int constructed_590[] = {UPTR(590,1), SYMBOL_HEADER, UPTR0(589), INTCON(46)};
pxll_string constructed_591 = {STRING_HEADER(8), 8, "function" };
// symbol function
pxll_int constructed_592[] = {UPTR(592,1), SYMBOL_HEADER, UPTR0(591), INTCON(47)};
pxll_string constructed_593 = {STRING_HEADER(5), 5, "vcase" };
// symbol vcase
pxll_int constructed_594[] = {UPTR(594,1), SYMBOL_HEADER, UPTR0(593), INTCON(48)};
pxll_string constructed_595 = {STRING_HEADER(9), 9, "let-splat" };
// symbol let-splat
pxll_int constructed_596[] = {UPTR(596,1), SYMBOL_HEADER, UPTR0(595), INTCON(49)};
pxll_string constructed_597 = {STRING_HEADER(5), 5, "match" };
// symbol match
pxll_int constructed_598[] = {UPTR(598,1), SYMBOL_HEADER, UPTR0(597), INTCON(50)};
pxll_string constructed_599 = {STRING_HEADER(8), 8, "cinclude" };
// symbol cinclude
pxll_int constructed_600[] = {UPTR(600,1), SYMBOL_HEADER, UPTR0(599), INTCON(51)};
pxll_string constructed_601 = {STRING_HEADER(7), 7, "%nvcase" };
// symbol %nvcase
pxll_int constructed_602[] = {UPTR(602,1), SYMBOL_HEADER, UPTR0(601), INTCON(52)};
pxll_string constructed_603 = {STRING_HEADER(6), 6, "%%cexp" };
// symbol %%cexp
pxll_int constructed_604[] = {UPTR(604,1), SYMBOL_HEADER, UPTR0(603), INTCON(53)};
pxll_string constructed_605 = {STRING_HEADER(16), 16, "malformed %%cexp" };
pxll_string constructed_606 = {STRING_HEADER(20), 20, "malformed <cinclude>" };
pxll_int constructed_607[] = {TC_NIL};
pxll_int constructed_608[] = {TC_NIL};
pxll_string constructed_609 = {STRING_HEADER(3), 3, "let" };
// symbol let
pxll_int constructed_610[] = {UPTR(610,1), SYMBOL_HEADER, UPTR0(609), INTCON(54)};
pxll_string constructed_611 = {STRING_HEADER(4), 4, "with" };
// symbol with
pxll_int constructed_612[] = {UPTR(612,1), SYMBOL_HEADER, UPTR0(611), INTCON(55)};
pxll_string constructed_613 = {STRING_HEADER(26), 26, "malformed match expression" };
pxll_string constructed_614 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_615 = {STRING_HEADER(3), 3, "arg" };
pxll_string constructed_616 = {STRING_HEADER(1), 1, ":" };
pxll_int constructed_617[] = {TC_NIL};
pxll_int constructed_618[] = {TC_NIL};
pxll_int constructed_619[] = {TC_NIL};
pxll_int constructed_620[] = {TC_NIL};
pxll_int constructed_621[] = {TC_NIL};
pxll_string constructed_622 = {STRING_HEADER(4), 4, "else" };
// symbol else
pxll_int constructed_623[] = {UPTR(623,1), SYMBOL_HEADER, UPTR0(622), INTCON(56)};
pxll_string constructed_624 = {STRING_HEADER(10), 10, "split-alts" };
pxll_int constructed_625[] = {TC_NIL};
pxll_string constructed_626 = {STRING_HEADER(1), 1, "_" };
// symbol _
pxll_int constructed_627[] = {UPTR(627,1), SYMBOL_HEADER, UPTR0(626), INTCON(57)};
pxll_int constructed_628[] = {TC_NIL};
pxll_int constructed_629[] = {TC_NIL};
pxll_string constructed_630 = {STRING_HEADER(12), 12, "expand-vcase" };
pxll_string constructed_631 = {STRING_HEADER(18), 18, "malformed FUNCTION" };
pxll_string constructed_632 = {STRING_HEADER(16), 16, "malformed LAMBDA" };
pxll_string constructed_633 = {STRING_HEADER(30), 30, "malformed binding in LET-SPLAT" };
pxll_string constructed_634 = {STRING_HEADER(19), 19, "malformed LET-SPLAT" };
pxll_string constructed_635 = {STRING_HEADER(11), 11, "empty BEGIN" };
pxll_string constructed_636 = {STRING_HEADER(14), 14, "malformed set!" };
pxll_string constructed_637 = {STRING_HEADER(14), 14, "malformed <if>" };
pxll_int constructed_638[] = {TC_NIL};
pxll_string constructed_639 = {STRING_HEADER(1), 1, "o" };
// symbol o
pxll_int constructed_640[] = {UPTR(640,1), SYMBOL_HEADER, UPTR0(639), INTCON(58)};
pxll_string constructed_641 = {STRING_HEADER(7), 7, "%method" };
// symbol %method
pxll_int constructed_642[] = {UPTR(642,1), SYMBOL_HEADER, UPTR0(641), INTCON(59)};
pxll_int constructed_643[] = {TC_NIL};
pxll_int constructed_644[] = {TC_NIL};
pxll_int constructed_645[] = {TC_NIL};
pxll_string constructed_646 = {STRING_HEADER(20), 20, "malformed definition" };
pxll_string constructed_647 = {STRING_HEADER(2), 2, "->" };
// symbol ->
pxll_int constructed_648[] = {UPTR(648,1), SYMBOL_HEADER, UPTR0(647), INTCON(60)};
pxll_string constructed_649 = {STRING_HEADER(18), 18, "malformed <define>" };
pxll_string constructed_650 = {STRING_HEADER(6), 6, "define" };
// symbol define
pxll_int constructed_651[] = {UPTR(651,1), SYMBOL_HEADER, UPTR0(650), INTCON(61)};
pxll_int constructed_652[] = {TC_NIL};
pxll_string constructed_653 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_654 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_655 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_656 = {STRING_HEADER(3), 3, ">\n\t" };
pxll_string constructed_657 = {STRING_HEADER(8), 8, "(macro <" };
pxll_string constructed_658 = {STRING_HEADER(28), 28, "no matching clause for macro" };
pxll_int constructed_659[] = {TC_NIL};
pxll_string constructed_660 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_661 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_662 = {STRING_HEADER(8), 8, "defmacro" };
// symbol defmacro
pxll_int constructed_663[] = {UPTR(663,1), SYMBOL_HEADER, UPTR0(662), INTCON(62)};
pxll_string constructed_664 = {STRING_HEADER(25), 25, "malformed alt in datatype" };
pxll_string constructed_665 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_666 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_667 = {STRING_HEADER(18), 18, "malformed datatype" };
pxll_string constructed_668 = {STRING_HEADER(8), 8, "datatype" };
// symbol datatype
pxll_int constructed_669[] = {UPTR(669,1), SYMBOL_HEADER, UPTR0(668), INTCON(63)};
pxll_int constructed_670[] = {TC_NIL};
pxll_int constructed_671[] = {TC_NIL};
pxll_string constructed_672 = {STRING_HEADER(3), 3, "fix" };
// symbol fix
pxll_int constructed_673[] = {UPTR(673,1), SYMBOL_HEADER, UPTR0(672), INTCON(64)};
pxll_int constructed_674[] = {TC_NIL};
pxll_string constructed_675 = {STRING_HEADER(39), 39, "unexpected s-expression in transformer:" };
pxll_string constructed_676 = {STRING_HEADER(2), 2, "-O" };
pxll_string constructed_677 = {STRING_HEADER(2), 2, "-f" };
pxll_string constructed_678 = {STRING_HEADER(2), 2, "-v" };
pxll_string constructed_679 = {STRING_HEADER(2), 2, "-c" };
pxll_string constructed_680 = {STRING_HEADER(16), 16, "self/selfmac.scm" };
pxll_int constructed_681[] = {TC_NIL};
pxll_int constructed_682[] = {TC_NIL};
pxll_string constructed_683 = {STRING_HEADER(0), 0, "" };
pxll_int constructed_684[] = {TC_NIL};
pxll_int constructed_685[] = {TC_NIL};
pxll_int constructed_686[] = {TC_NIL};
pxll_string constructed_687 = {STRING_HEADER(31), 31, "Usage: compile <irken-src-file>" };
pxll_string constructed_688 = {STRING_HEADER(28), 28, "// REGISTER_DECLARATIONS //\n" };
pxll_string constructed_689 = {STRING_HEADER(27), 27, "// CONSTRUCTED LITERALS //\n" };
pxll_string constructed_690 = {STRING_HEADER(95), 95, "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~ " };
pxll_string constructed_691 = {STRING_HEADER(7), 7, "uint8_t" };
// symbol uint8_t
pxll_int constructed_692[] = {UPTR(692,1), SYMBOL_HEADER, UPTR0(691), INTCON(65)};
pxll_string constructed_693 = {STRING_HEADER(8), 8, "uint16_t" };
// symbol uint16_t
pxll_int constructed_694[] = {UPTR(694,1), SYMBOL_HEADER, UPTR0(693), INTCON(66)};
pxll_string constructed_695 = {STRING_HEADER(8), 8, "uint32_t" };
// symbol uint32_t
pxll_int constructed_696[] = {UPTR(696,1), SYMBOL_HEADER, UPTR0(695), INTCON(67)};
pxll_string constructed_697 = {STRING_HEADER(8), 8, "uint64_t" };
// symbol uint64_t
pxll_int constructed_698[] = {UPTR(698,1), SYMBOL_HEADER, UPTR0(697), INTCON(68)};
pxll_string constructed_699 = {STRING_HEADER(6), 6, "int8_t" };
// symbol int8_t
pxll_int constructed_700[] = {UPTR(700,1), SYMBOL_HEADER, UPTR0(699), INTCON(69)};
pxll_string constructed_701 = {STRING_HEADER(7), 7, "int16_t" };
// symbol int16_t
pxll_int constructed_702[] = {UPTR(702,1), SYMBOL_HEADER, UPTR0(701), INTCON(70)};
pxll_string constructed_703 = {STRING_HEADER(7), 7, "int32_t" };
// symbol int32_t
pxll_int constructed_704[] = {UPTR(704,1), SYMBOL_HEADER, UPTR0(703), INTCON(71)};
pxll_string constructed_705 = {STRING_HEADER(7), 7, "int64_t" };
// symbol int64_t
pxll_int constructed_706[] = {UPTR(706,1), SYMBOL_HEADER, UPTR0(705), INTCON(72)};
pxll_int constructed_707[] = {UPTR(707,22),CONS_HEADER,UPTR(706,1),TC_NIL,CONS_HEADER,UPTR(704,1),UPTR(707,1),CONS_HEADER,UPTR(702,1),UPTR(707,4),CONS_HEADER,UPTR(700,1),UPTR(707,7),CONS_HEADER,UPTR(698,1),UPTR(707,10),CONS_HEADER,UPTR(696,1),UPTR(707,13),CONS_HEADER,UPTR(694,1),UPTR(707,16),CONS_HEADER,UPTR(692,1),UPTR(707,19)};
pxll_string constructed_708 = {STRING_HEADER(1), 1, "L" };
pxll_int constructed_709[] = {TC_NIL};
pxll_string constructed_710 = {STRING_HEADER(26), 26, "key already present in map" };
pxll_int constructed_711[] = {TC_NIL};
pxll_int constructed_712[] = {TC_NIL};
pxll_int constructed_713[] = {TC_NIL};
pxll_int constructed_714[] = {TC_NIL};
pxll_string constructed_715 = {STRING_HEADER(1), 1, "?" };
// symbol ?
pxll_int constructed_716[] = {UPTR(716,1), SYMBOL_HEADER, UPTR0(715), INTCON(73)};
pxll_string constructed_717 = {STRING_HEADER(4), 4, "char" };
// symbol char
pxll_int constructed_718[] = {UPTR(718,1), SYMBOL_HEADER, UPTR0(717), INTCON(74)};
pxll_string constructed_719 = {STRING_HEADER(9), 9, "undefined" };
// symbol undefined
pxll_int constructed_720[] = {UPTR(720,1), SYMBOL_HEADER, UPTR0(719), INTCON(75)};
pxll_int constructed_721[] = {TC_NIL};
pxll_int constructed_722[] = {TC_NIL};
pxll_int constructed_723[] = {TC_NIL};
pxll_int constructed_724[] = {TC_NIL};
pxll_int constructed_725[] = {TC_NIL};
pxll_int constructed_726[] = {TC_NIL};
pxll_int constructed_727[] = {UPTR(727,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(727,1),CONS_HEADER,2306,UPTR(727,4),CONS_HEADER,8194,UPTR(727,7)};
pxll_string constructed_728 = {STRING_HEADER(10), 10, "0123456789" };
pxll_string constructed_729 = {STRING_HEADER(52), 52, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" };
pxll_string constructed_730 = {STRING_HEADER(7), 7, "()[]{}:" };
pxll_int constructed_731[] = {UPTR(731,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(731,1),CONS_HEADER,2306,UPTR(731,4),CONS_HEADER,8194,UPTR(731,7)};
pxll_int constructed_732[] = {UPTR(732,29),UOHEAD(3,1),14082,15,UITAG(0),UOHEAD(3,1),13826,13,UPTR(732,1),UOHEAD(3,1),13570,11,UPTR(732,5),UOHEAD(3,1),13314,9,UPTR(732,9),UOHEAD(3,1),13058,7,UPTR(732,13),UOHEAD(3,1),12802,5,UPTR(732,17),UOHEAD(3,1),12546,3,UPTR(732,21),UOHEAD(3,1),12290,1,UPTR(732,25)};
pxll_int constructed_733[] = {UPTR(733,37),UOHEAD(3,1),14594,19,UITAG(0),UOHEAD(3,1),14338,17,UPTR(733,1),UOHEAD(3,1),14082,15,UPTR(733,5),UOHEAD(3,1),13826,13,UPTR(733,9),UOHEAD(3,1),13570,11,UPTR(733,13),UOHEAD(3,1),13314,9,UPTR(733,17),UOHEAD(3,1),13058,7,UPTR(733,21),UOHEAD(3,1),12802,5,UPTR(733,25),UOHEAD(3,1),12546,3,UPTR(733,29),UOHEAD(3,1),12290,1,UPTR(733,33)};
pxll_int constructed_734[] = {UPTR(734,85),UOHEAD(3,1),17922,31,UITAG(0),UOHEAD(3,1),17666,29,UPTR(734,1),UOHEAD(3,1),17410,27,UPTR(734,5),UOHEAD(3,1),17154,25,UPTR(734,9),UOHEAD(3,1),16898,23,UPTR(734,13),UOHEAD(3,1),16642,21,UPTR(734,17),UOHEAD(3,1),26114,31,UPTR(734,21),UOHEAD(3,1),25858,29,UPTR(734,25),UOHEAD(3,1),25602,27,UPTR(734,29),UOHEAD(3,1),25346,25,UPTR(734,33),UOHEAD(3,1),25090,23,UPTR(734,37),UOHEAD(3,1),24834,21,UPTR(734,41),UOHEAD(3,1),14594,19,UPTR(734,45),UOHEAD(3,1),14338,17,UPTR(734,49),UOHEAD(3,1),14082,15,UPTR(734,53),UOHEAD(3,1),13826,13,UPTR(734,57),UOHEAD(3,1),13570,11,UPTR(734,61),UOHEAD(3,1),13314,9,UPTR(734,65),UOHEAD(3,1),13058,7,UPTR(734,69),UOHEAD(3,1),12802,5,UPTR(734,73),UOHEAD(3,1),12546,3,UPTR(734,77),UOHEAD(3,1),12290,1,UPTR(734,81)};
pxll_string constructed_735 = {STRING_HEADER(0), 0, "" };
pxll_int constructed_736[] = {UPTR(736,1),(16<<8)|TC_VECTOR,12290,12546,12802,13058,13314,13570,13826,14082,14338,14594,24834,25090,25346,25602,25858,26114};
pxll_string constructed_737 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_738 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_739 = {STRING_HEADER(1), 1, "%" };
pxll_string constructed_740 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_741 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_742 = {STRING_HEADER(9), 9, "(object*)" };
pxll_string constructed_743 = {STRING_HEADER(3), 3, "ptr" };
// symbol ptr
pxll_int constructed_744[] = {UPTR(744,1), SYMBOL_HEADER, UPTR0(743), INTCON(76)};
pxll_string constructed_745 = {STRING_HEADER(9), 9, "(object*)" };
pxll_string constructed_746 = {STRING_HEADER(7), 7, "cstring" };
// symbol cstring
pxll_int constructed_747[] = {UPTR(747,1), SYMBOL_HEADER, UPTR0(746), INTCON(77)};
pxll_string constructed_748 = {STRING_HEADER(10), 10, "PXLL_TEST(" };
pxll_string constructed_749 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_750 = {STRING_HEADER(14), 14, "box((pxll_int)" };
pxll_string constructed_751 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_752 = {STRING_HEADER(14), 14, "box((pxll_int)" };
pxll_string constructed_753 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_754 = {STRING_HEADER(7), 7, "struct " };
pxll_string constructed_755 = {STRING_HEADER(6), 6, "struct" };
// symbol struct
pxll_int constructed_756[] = {UPTR(756,1), SYMBOL_HEADER, UPTR0(755), INTCON(78)};
pxll_string constructed_757 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_758 = {STRING_HEADER(2), 2, "*)" };
pxll_string constructed_759 = {STRING_HEADER(15), 15, "malformed ctype" };
pxll_string constructed_760 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_761 = {STRING_HEADER(2), 2, "))" };
pxll_string constructed_762 = {STRING_HEADER(25), 25, "unknown raw type in %cexp" };
pxll_string constructed_763 = {STRING_HEADER(12), 12, "continuation" };
// symbol continuation
pxll_int constructed_764[] = {UPTR(764,1), SYMBOL_HEADER, UPTR0(763), INTCON(79)};
pxll_string constructed_765 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_766 = {STRING_HEADER(16), 16, "(((pxll_vector*)" };
pxll_string constructed_767 = {STRING_HEADER(5), 5, ")+1))" };
pxll_string constructed_768 = {STRING_HEADER(7), 7, "(char*)" };
pxll_string constructed_769 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_770 = {STRING_HEADER(8), 8, "))->data" };
pxll_string constructed_771 = {STRING_HEADER(6), 6, "unbox(" };
pxll_string constructed_772 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_773 = {STRING_HEADER(6), 6, "unbox(" };
pxll_string constructed_774 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_775 = {STRING_HEADER(8), 8, "wrap-in:" };
pxll_string constructed_776 = {STRING_HEADER(27), 27, "expected immediate literal " };
pxll_string constructed_777 = {STRING_HEADER(17), 17, "inline: bad arity" };
pxll_int constructed_778[] = {TC_NIL};
pxll_string constructed_779 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_780[] = {TC_NIL};
pxll_int constructed_781[] = {TC_NIL};
pxll_int constructed_782[] = {TC_NIL};
pxll_int constructed_783[] = {TC_NIL};
pxll_string constructed_784 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_785[] = {TC_NIL};
pxll_string constructed_786 = {STRING_HEADER(43), 43, "inline-application - inlining non-function?" };
pxll_int constructed_787[] = {TC_NIL};
pxll_int constructed_788[] = {TC_NIL};
pxll_int constructed_789[] = {TC_NIL};
pxll_int constructed_790[] = {TC_NIL};
pxll_int constructed_791[] = {TC_NIL};
pxll_int constructed_792[] = {TC_NIL};
pxll_int constructed_793[] = {TC_NIL};
pxll_string constructed_794 = {STRING_HEADER(33), 33, "find-escaping-funs: failed lookup" };
pxll_int constructed_795[] = {TC_NIL};
pxll_int constructed_796[] = {TC_NIL};
pxll_int constructed_797[] = {TC_NIL};
pxll_string constructed_798 = {STRING_HEADER(11), 11, "simpleopt: " };
pxll_string constructed_799 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_800[] = {TC_NIL};
pxll_int constructed_801[] = {TC_NIL};
pxll_string constructed_802 = {STRING_HEADER(3), 3, "moo" };
// symbol moo
pxll_int constructed_803[] = {UPTR(803,1), SYMBOL_HEADER, UPTR0(802), INTCON(80)};
pxll_string constructed_804 = {STRING_HEADER(6), 6, "rlabel" };
// symbol rlabel
pxll_int constructed_805[] = {UPTR(805,1), SYMBOL_HEADER, UPTR0(804), INTCON(81)};
pxll_string constructed_806 = {STRING_HEADER(10), 10, "type error" };
pxll_string constructed_807 = {STRING_HEADER(14), 14, "\nType Error:\n\t" };
pxll_string constructed_808 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_809 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_810 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_811 = {STRING_HEADER(5), 5, "- ret" };
pxll_string constructed_812 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_813 = {STRING_HEADER(4), 4, "tail" };
pxll_string constructed_814 = {STRING_HEADER(6), 6, "trcall" };
pxll_string constructed_815 = {STRING_HEADER(3), 3, "lit" };
pxll_string constructed_816 = {STRING_HEADER(6), 6, "litcon" };
pxll_string constructed_817 = {STRING_HEADER(4), 4, "cexp" };
pxll_string constructed_818 = {STRING_HEADER(4), 4, "test" };
pxll_string constructed_819 = {STRING_HEADER(3), 3, "jmp" };
pxll_string constructed_820 = {STRING_HEADER(5), 5, "close" };
pxll_string constructed_821 = {STRING_HEADER(3), 3, "ref" };
pxll_string constructed_822 = {STRING_HEADER(3), 3, "set" };
pxll_string constructed_823 = {STRING_HEADER(4), 4, "stor" };
pxll_string constructed_824 = {STRING_HEADER(6), 6, "invoke" };
pxll_string constructed_825 = {STRING_HEADER(3), 3, "env" };
pxll_string constructed_826 = {STRING_HEADER(5), 5, "alloc" };
pxll_string constructed_827 = {STRING_HEADER(4), 4, "push" };
pxll_string constructed_828 = {STRING_HEADER(3), 3, "pop" };
pxll_string constructed_829 = {STRING_HEADER(6), 6, "primop" };
pxll_string constructed_830 = {STRING_HEADER(4), 4, "move" };
pxll_string constructed_831 = {STRING_HEADER(6), 6, "fatbar" };
pxll_string constructed_832 = {STRING_HEADER(4), 4, "fail" };
pxll_string constructed_833 = {STRING_HEADER(8), 8, "testcexp" };
pxll_string constructed_834 = {STRING_HEADER(6), 6, "nvcase" };
pxll_string constructed_835 = {STRING_HEADER(6), 6, "pvcase" };
pxll_string constructed_836 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_837 = {STRING_HEADER(1), 1, "-" };
pxll_string constructed_838 = {STRING_HEADER(2), 2, "- " };
pxll_string constructed_839 = {STRING_HEADER(8), 8, "k/target" };
pxll_string constructed_840 = {STRING_HEADER(6), 6, "k/free" };
pxll_int constructed_841[] = {TC_NIL};
pxll_int constructed_842[] = {TC_NIL};
pxll_string constructed_843 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_844 = {STRING_HEADER(22), 22, "unhandled literal type" };
pxll_int constructed_845[] = {TC_NIL};
pxll_int constructed_846[] = {TC_NIL};
pxll_int constructed_847[] = {TC_NIL};
pxll_string constructed_848 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_849 = {STRING_HEADER(9), 9, "let_subst" };
// symbol let_subst
pxll_int constructed_850[] = {UPTR(850,1), SYMBOL_HEADER, UPTR0(849), INTCON(82)};
pxll_string constructed_851 = {STRING_HEADER(6), 6, "letrec" };
// symbol letrec
pxll_int constructed_852[] = {UPTR(852,1), SYMBOL_HEADER, UPTR0(851), INTCON(83)};
pxll_string constructed_853 = {STRING_HEADER(7), 7, "literal" };
// symbol literal
pxll_int constructed_854[] = {UPTR(854,1), SYMBOL_HEADER, UPTR0(853), INTCON(84)};
pxll_string constructed_855 = {STRING_HEADER(5), 5, "quote" };
// symbol quote
pxll_int constructed_856[] = {UPTR(856,1), SYMBOL_HEADER, UPTR0(855), INTCON(85)};
pxll_string constructed_857 = {STRING_HEADER(28), 28, "null primapp missing params?" };
pxll_string constructed_858 = {STRING_HEADER(14), 14, "syntax error: " };
pxll_string constructed_859 = {STRING_HEADER(16), 16, "syntax error 2: " };
pxll_int constructed_860[] = {TC_NIL};
pxll_int constructed_861[] = {TC_NIL};
pxll_int constructed_862[] = {TC_NIL};
pxll_int constructed_863[] = {TC_NIL};
pxll_int constructed_864[] = {TC_NIL};
pxll_int constructed_865[] = {TC_NIL};
pxll_string constructed_866 = {STRING_HEADER(15), 15, "unpack-bindings" };
pxll_int constructed_867[] = {TC_NIL};
pxll_string constructed_868 = {STRING_HEADER(16), 16, "malformed formal" };
pxll_string constructed_869 = {STRING_HEADER(7), 7, "varref " };
pxll_string constructed_870 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_871 = {STRING_HEADER(7), 7, "varset " };
pxll_string constructed_872 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_873 = {STRING_HEADER(8), 8, "literal " };
pxll_string constructed_874 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_875 = {STRING_HEADER(5), 5, "cexp " };
pxll_string constructed_876 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_877 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_878 = {STRING_HEADER(11), 11, "sequence : " };
pxll_string constructed_879 = {STRING_HEADER(14), 14, "conditional : " };
pxll_string constructed_880 = {STRING_HEADER(7), 7, "call : " };
pxll_string constructed_881 = {STRING_HEADER(9), 9, "function " };
pxll_string constructed_882 = {STRING_HEADER(2), 2, " (" };
pxll_string constructed_883 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_884 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_885 = {STRING_HEADER(5), 5, "fix (" };
pxll_string constructed_886 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_887 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_888 = {STRING_HEADER(7), 7, "nvcase " };
pxll_string constructed_889 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_890 = {STRING_HEADER(3), 3, ") (" };
pxll_string constructed_891 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_892 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_893 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_894 = {STRING_HEADER(6), 6, "subst " };
pxll_string constructed_895 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_896 = {STRING_HEADER(8), 8, "primapp " };
pxll_string constructed_897 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_898 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_899 = {STRING_HEADER(5), 5, "let (" };
pxll_string constructed_900 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_901 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_902 = {STRING_HEADER(1), 1, " " };
pxll_int constructed_903[] = {TC_NIL};
pxll_string constructed_904 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_905 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_906 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_907 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_908 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_909 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_910 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_911 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_912 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_913 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_914 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_915 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_916 = {STRING_HEADER(20), 20, "unpack-fix: no body?" };
pxll_string constructed_917 = {STRING_HEADER(12), 12, "varref->name" };
pxll_string constructed_918 = {STRING_HEADER(4), 4, "  )\n" };
pxll_string constructed_919 = {STRING_HEADER(4), 4, "  (:" };
pxll_string constructed_920 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_921 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_922 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_923 = {STRING_HEADER(10), 10, "(datatype " };
pxll_int constructed_924[] = {TC_NIL};
pxll_int constructed_925[] = {TC_NIL};
pxll_int constructed_926[] = {TC_NIL};
pxll_int constructed_927[] = {TC_NIL};
pxll_int constructed_928[] = {TC_NIL};
pxll_string constructed_929 = {STRING_HEADER(1), 1, "." };
// symbol .
pxll_int constructed_930[] = {UPTR(930,1), SYMBOL_HEADER, UPTR0(929), INTCON(86)};
pxll_string constructed_931 = {STRING_HEADER(17), 17, "malformed pattern" };
pxll_int constructed_932[] = {TC_NIL};
pxll_string constructed_933 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_934 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_935 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_936 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_string constructed_937 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_int constructed_938[] = {TC_NIL};
pxll_string constructed_939 = {STRING_HEADER(21), 21, "not a literal pattern" };
pxll_string constructed_940 = {STRING_HEADER(20), 20, "not a record pattern" };
pxll_string constructed_941 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_942 = {STRING_HEADER(40), 40, "record pattern with different label sigs" };
pxll_string constructed_943 = {STRING_HEADER(6), 6, "record" };
// symbol record
pxll_int constructed_944[] = {UPTR(944,1), SYMBOL_HEADER, UPTR0(943), INTCON(87)};
pxll_string constructed_945 = {STRING_HEADER(33), 33, "arity mismatch in variant pattern" };
pxll_int constructed_946[] = {TC_NIL};
pxll_int constructed_947[] = {TC_NIL};
pxll_string constructed_948 = {STRING_HEADER(39), 39, "more than one datatype in pattern match" };
pxll_string constructed_949 = {STRING_HEADER(8), 8, "variable" };
// symbol variable
pxll_int constructed_950[] = {UPTR(950,1), SYMBOL_HEADER, UPTR0(949), INTCON(88)};
pxll_string constructed_951 = {STRING_HEADER(8), 8, "string=?" };
// symbol string=?
pxll_int constructed_952[] = {UPTR(952,1), SYMBOL_HEADER, UPTR0(951), INTCON(89)};
pxll_string constructed_953 = {STRING_HEADER(3), 3, "eq?" };
// symbol eq?
pxll_int constructed_954[] = {UPTR(954,1), SYMBOL_HEADER, UPTR0(953), INTCON(90)};
pxll_string constructed_955 = {STRING_HEADER(19), 19, "empty pattern list?" };
pxll_string constructed_956 = {STRING_HEADER(29), 29, "remove-first-pat: empty pats?" };
pxll_string constructed_957 = {STRING_HEADER(1), 1, "m" };
pxll_int constructed_958[] = {TC_NIL};
pxll_int constructed_959[] = {TC_NIL};
pxll_string constructed_960 = {STRING_HEADER(14), 14, "bad record sig" };
pxll_string constructed_961 = {STRING_HEADER(26), 26, "unable to get record sig: " };
pxll_string constructed_962 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_963[] = {TC_NIL};
pxll_string constructed_964 = {STRING_HEADER(8), 8, "bad type" };
pxll_string constructed_965 = {STRING_HEADER(15), 15, "malformed type?" };
pxll_int constructed_966[] = {TC_NIL};
pxll_string constructed_967 = {STRING_HEADER(14), 14, "bad arrow type" };
pxll_string constructed_968 = {STRING_HEADER(19), 19, "malformed predicate" };
pxll_string constructed_969 = {STRING_HEADER(1), 1, "t" };
pxll_string constructed_970 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_971 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_972 = {STRING_HEADER(3), 3, ")->" };
pxll_string constructed_973 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_974 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_975 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_976 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_977 = {STRING_HEADER(18), 18, "expected sexp:list" };
pxll_string constructed_978 = {STRING_HEADER(13), 13, "expected list" };
pxll_int constructed_979[] = {TC_NIL};
pxll_int constructed_980[] = {TC_NIL};
pxll_int constructed_981[] = {TC_NIL};
pxll_string constructed_982 = {STRING_HEADER(36), 36, "unexpected args to ellipsis-sub-envs" };
pxll_int constructed_983[] = {TC_NIL};
pxll_int constructed_984[] = {TC_NIL};
pxll_string constructed_985 = {STRING_HEADER(2), 2, "()" };
pxll_string constructed_986 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_987 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_988 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_989 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_990 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_991 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_992 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_993 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_994 = {STRING_HEADER(2), 2, "#\\" };
pxll_string constructed_995 = {STRING_HEADER(2), 2, "#t" };
pxll_string constructed_996 = {STRING_HEADER(2), 2, "#f" };
pxll_string constructed_997 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_998 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_999 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1000 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1001 = {STRING_HEADER(1), 1, "{" };
pxll_string constructed_1002 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_1003 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1004 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_1005 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_1006 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_1007 = {STRING_HEADER(3), 3, "..." };
pxll_string constructed_1008 = {STRING_HEADER(1), 1, "=" };
pxll_string constructed_1009 = {STRING_HEADER(9), 9, "sexp->int" };
pxll_string constructed_1010 = {STRING_HEADER(12), 12, "sexp->symbol" };
pxll_int constructed_1011[] = {TC_NIL};
pxll_string constructed_1012 = {STRING_HEADER(7), 7, "include" };
// symbol include
pxll_int constructed_1013[] = {UPTR(1013,1), SYMBOL_HEADER, UPTR0(1012), INTCON(91)};
pxll_int constructed_1014[] = {TC_NIL};
pxll_string constructed_1015 = {STRING_HEADER(13), 13, "bad hex digit" };
pxll_string constructed_1016 = {STRING_HEADER(12), 12, "colon syntax" };
pxll_string constructed_1017 = {STRING_HEADER(30), 30, "expected closing ]/} character" };
pxll_string constructed_1018 = {STRING_HEADER(22), 22, "unexpected close-paren" };
pxll_string constructed_1019 = {STRING_HEADER(3), 3, "nul" };
pxll_string constructed_1020 = {STRING_HEADER(3), 3, "eof" };
pxll_string constructed_1021 = {STRING_HEADER(3), 3, "tab" };
pxll_string constructed_1022 = {STRING_HEADER(6), 6, "return" };
pxll_string constructed_1023 = {STRING_HEADER(5), 5, "space" };
pxll_string constructed_1024 = {STRING_HEADER(7), 7, "newline" };
pxll_string constructed_1025 = {STRING_HEADER(22), 22, "bad character constant" };
pxll_string constructed_1026 = {STRING_HEADER(12), 12, "syntax error" };
pxll_string constructed_1027 = {STRING_HEADER(15), 15, "expected symbol" };
pxll_string constructed_1028 = {STRING_HEADER(36), 36, "no dots allowed in constructor names" };
pxll_string constructed_1029 = {STRING_HEADER(5), 5, "comma" };
// symbol comma
pxll_int constructed_1030[] = {UPTR(1030,1), SYMBOL_HEADER, UPTR0(1029), INTCON(92)};
pxll_int constructed_1031[] = {TC_NIL};
pxll_string constructed_1032 = {STRING_HEADER(30), 30, "bad backslash escape in string" };
pxll_int constructed_1033[] = {TC_NIL};
pxll_string constructed_1034 = {STRING_HEADER(30), 30, "expected '=' in record literal" };
pxll_int constructed_1035[] = {TC_NIL};
pxll_string constructed_1036 = {STRING_HEADER(22), 22, "unexpected end of file" };
pxll_string constructed_1037 = {STRING_HEADER(18), 18, "bad decimal digit?" };
pxll_int constructed_1038[] = {TC_NIL};
pxll_string constructed_1039 = {STRING_HEADER(22), 22, "unexpected end-of-file" };
pxll_string constructed_1040 = {STRING_HEADER(13), 13, "reading file " };
pxll_int constructed_1041[] = {TC_NIL};
pxll_int constructed_1042[] = {TC_NIL};
pxll_string constructed_1043 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_1044 = {STRING_HEADER(13), 13, "open() failed" };
pxll_int constructed_1045[] = {TC_NIL};
pxll_int constructed_1046[] = {TC_NIL};
pxll_int constructed_1047[] = {TC_NIL};
pxll_int constructed_1048[] = {TC_NIL};
pxll_int constructed_1049[] = {TC_NIL};
pxll_int constructed_1050[] = {TC_NIL};
pxll_int constructed_1051[] = {UPTR(1051,1),(0<<8)|TC_VECTOR};
pxll_int constructed_1052[] = {TC_NIL};
pxll_string constructed_1053 = {STRING_HEADER(29), 29, "every2?: unequal-length lists" };
pxll_string constructed_1054 = {STRING_HEADER(31), 31, "for-each2: unequal-length lists" };
pxll_int constructed_1055[] = {TC_NIL};
pxll_int constructed_1056[] = {TC_NIL};
pxll_string constructed_1057 = {STRING_HEADER(26), 26, "map2: unequal-length lists" };
pxll_int constructed_1058[] = {TC_NIL};
pxll_int constructed_1059[] = {TC_NIL};
pxll_int constructed_1060[] = {TC_NIL};
pxll_string constructed_1061 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_string constructed_1062 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_int constructed_1063[] = {TC_NIL};
pxll_string constructed_1064 = {STRING_HEADER(4), 4, "last" };
pxll_string constructed_1065 = {STRING_HEADER(3), 3, "cdr" };
pxll_string constructed_1066 = {STRING_HEADER(3), 3, "car" };
pxll_string constructed_1067 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1068 = {STRING_HEADER(17), 17, "lookup-label-code" };
pxll_string constructed_1069 = {STRING_HEADER(25), 25, "vars-get-var: no such var" };
pxll_string constructed_1070 = {STRING_HEADER(2), 2, "}\n" };
pxll_string constructed_1071 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_1072 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_1073 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_1074 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_1075 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_1076 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_1077 = {STRING_HEADER(4), 4, "name" };
pxll_string constructed_1078 = {STRING_HEADER(5), 5, "flags" };
pxll_string constructed_1079 = {STRING_HEADER(4), 4, "mult" };
pxll_string constructed_1080 = {STRING_HEADER(5), 5, "calls" };
pxll_string constructed_1081 = {STRING_HEADER(4), 4, "sets" };
pxll_string constructed_1082 = {STRING_HEADER(4), 4, "refs" };
pxll_string constructed_1083 = {STRING_HEADER(9), 9, "vars = {\n" };
pxll_int pxll_internal_symbols[] = {(93<<8)|TC_VECTOR, UPTR(46,1), UPTR(49,1), UPTR(51,1), UPTR(54,1), UPTR(56,1), UPTR(61,1), UPTR(63,1), UPTR(66,1), UPTR(71,1), UPTR(88,1), UPTR(99,1), UPTR(223,1), UPTR(228,1), UPTR(237,1), UPTR(241,1), UPTR(248,1), UPTR(253,1), UPTR(264,1), UPTR(275,1), UPTR(284,1), UPTR(293,1), UPTR(306,1), UPTR(312,1), UPTR(326,1), UPTR(469,1), UPTR(471,1), UPTR(478,1), UPTR(480,1), UPTR(482,1), UPTR(485,1), UPTR(488,1), UPTR(493,1), UPTR(495,1), UPTR(498,1), UPTR(500,1), UPTR(506,1), UPTR(512,1), UPTR(535,1), UPTR(537,1), UPTR(539,1), UPTR(547,1), UPTR(551,1), UPTR(554,1), UPTR(578,1), UPTR(586,1), UPTR(588,1), UPTR(590,1), UPTR(592,1), UPTR(594,1), UPTR(596,1), UPTR(598,1), UPTR(600,1), UPTR(602,1), UPTR(604,1), UPTR(610,1), UPTR(612,1), UPTR(623,1), UPTR(627,1), UPTR(640,1), UPTR(642,1), UPTR(648,1), UPTR(651,1), UPTR(663,1), UPTR(669,1), UPTR(673,1), UPTR(692,1), UPTR(694,1), UPTR(696,1), UPTR(698,1), UPTR(700,1), UPTR(702,1), UPTR(704,1), UPTR(706,1), UPTR(716,1), UPTR(718,1), UPTR(720,1), UPTR(744,1), UPTR(747,1), UPTR(756,1), UPTR(764,1), UPTR(803,1), UPTR(805,1), UPTR(850,1), UPTR(852,1), UPTR(854,1), UPTR(856,1), UPTR(930,1), UPTR(944,1), UPTR(950,1), UPTR(952,1), UPTR(954,1), UPTR(1013,1), UPTR(1030,1)};

pxll_int
vm (int argc, char * argv[])
{
  register object * lenv = PXLL_NIL;
  register object * k = PXLL_NIL;
// REGISTER_DECLARATIONS //
  register object * r0;
  register object * r1;
  register object * r2;
  register object * r3;
  register object * r4;
  register object * r5;
  register object * r6;
  register object * r7;
  void gc_regs_in (int n) {
    switch (n) {
    case 8: heap1[10] = r7;
    case 7: heap1[9] = r6;
    case 6: heap1[8] = r5;
    case 5: heap1[7] = r4;
    case 4: heap1[6] = r3;
    case 3: heap1[5] = r2;
    case 2: heap1[4] = r1;
    case 1: heap1[3] = r0;
  }}
  void gc_regs_out (int n) {
    switch (n) {
    case 8: r7 = heap0[10];
    case 7: r6 = heap0[9];
    case 6: r5 = heap0[8];
    case 5: r4 = heap0[7];
    case 4: r3 = heap0[6];
    case 3: r2 = heap0[5];
    case 2: r1 = heap0[4];
    case 1: r0 = heap0[3];
  }}
  object * top = PXLL_NIL; // top-level (i.e. 'global') environment
  object * t = 0; // temp - for swaps & building tuples
  object * result;
  object * limit = heap0 + (heap_size - head_room);
  object * freep = heap0;
  int i; // loop counter
  
#define PXLL_RETURN(d)	result = r##d; goto *k[3]

#include "gc.c"

  // check heap is called at the top of each allocating function.
  //  [by locating the check at the top, we avoid considering any
  //   registers as roots of the gc...]
  void check_heap (int nfree) {
    if (freep >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  void ensure_heap (int nfree, pxll_int size) {
    if (freep + size + 1 >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  object * allocate (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
#if 1
    // at least on the g5, this technique is considerably faster than using memset
    //   in gc_flip() to 'pre-clear' the heap... probably a cache effect...
    while (size--) {
      // this keeps gc from being confused by partially-filled objects.
      *(++freep) = PXLL_NIL;
    }
    ++freep;
#else
    // if you use this version, be sure to set <clear_tospace>!
    freep += size + 1;
#endif
    return save;  
  }

  // this is emitted by the backend for %make-tuple
  object * alloc_no_clear (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
    freep += size + 1;
    return save;  
  }

  // gcc inlines/unrolls these nicely, they allow more compact code
  // Note: I'm not using these any longer, because there's a huge
  //   impact on compile times - 11m vs 50m when I tested it.
  inline object * varref (pxll_int depth, pxll_int index)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    return walk[index+2];
  }

  inline void varset (pxll_int depth, pxll_int index, object * val)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    walk[index+2] = val;
  }

  
  // these could probably be written in irken...
  pxll_int dump_image (char * filename, object * closure) {
    FILE * dump_file = fopen (filename, "wb");
    pxll_int offset;
    pxll_int size;
    object * start;
    // do a gc for a compact dump
    closure = gc_dump (closure);
    // for now, start at the front of the heap
    start = heap0;
    size = freep - start;
    offset = (pxll_int) heap0;
    // XXX add endian indicator...
    fprintf (dump_file, "(pxll image %" PRIuPTR " %p)\n", sizeof (pxll_int), start);
    fwrite (&offset, sizeof(pxll_int), 1, dump_file);
    fwrite (&size, sizeof(pxll_int), 1, dump_file);
    fwrite (start, sizeof(pxll_int), size, dump_file);
    fclose (dump_file);
    return size;
  }

  object * load_image (char * filename) {
    FILE * load_file = fopen (filename, "rb");
    if (!load_file) {
      abort();
    } else {
      object * start, * thunk;
      pxll_int size;
      read_header (load_file);	// XXX verify header...
      fread (&start, sizeof(pxll_int), 1, load_file);
      fread (&size, sizeof(pxll_int), 1, load_file);
      fread (heap1, sizeof(pxll_int), size, load_file);
      fprintf (stderr, "size=%d\n", (int) size);
      // relocate heap0
      gc_relocate (4, heap1, heap1 + size, start - heap1);
      // replace roots
      lenv  = (object *) heap1[0];
      k     = (object *) heap1[1];
      top   = (object *) heap1[2];
      thunk = (object *) heap1[3];
      freep = heap1 + size;
      // swap heaps
      { object * temp = heap0; heap0 = heap1; heap1 = temp; }
      return thunk;
    }
  }

  k = allocate (TC_SAVE, 3);
  k[1] = (object *) PXLL_NIL; // top of stack
  k[2] = (object *) PXLL_NIL; // null environment
  k[3] = &&Lreturn; // continuation that will return from this function.
  // --- BEGIN USER PROGRAM ---
  r0 = allocate (TC_TUPLE, 204);
  top = r0;
  r0[1] = lenv; lenv = r0;
  // def list:cons_3
  goto L0;
  FUN_list_3acons_3:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L0:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list_3acons_3; r1[2] = lenv;
  r0[2] = r1;
  // def sexp:symbol_18
  goto L1;
  FUN_sexp_3asymbol_18:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3asymbol_18; r1[2] = lenv;
  r0[3] = r1;
  // def sexp:int_22
  goto L2;
  FUN_sexp_3aint_22:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3aint_22; r1[2] = lenv;
  r0[4] = r1;
  // def vars-get-var_257
  goto L3;
  FUN_vars_get_var_257:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[15];
    r1[2] = r2;
    r2 = top[80];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L4; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L4:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = top[156];
        r2 = (object *) 5;
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        r0[2] = r1;
        r0 = (object*) &constructed_1083;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_1083;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 16);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_1082;
        r3[3] = r4;
        r4 = top[59];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L5; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L5:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_1081;
        r3[3] = r4;
        r4 = top[59];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L6; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L6:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_1080;
        r3[3] = r4;
        r4 = top[59];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L7; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L7:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_1079;
        r3[3] = r4;
        r4 = top[59];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L8; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L8:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[5] = r3;
        r3 = allocate (TC_TUPLE, 4);
        r4 = ((object***) lenv) [1][1][2];
        r3[2] = r4;
        r4 = (object*) &constructed_1078;
        r3[3] = r4;
        r4 = (object *) 262;
        r3[4] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L9; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
        L9:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[6] = r3;
        r3 = allocate (TC_TUPLE, 4);
        r4 = (object *) 61;
        r3[2] = r4;
        r4 = (object*) &constructed_1077;
        r3[3] = r4;
        r4 = (object *) 6;
        r3[4] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L10; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
        L10:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[7] = r3;
        r3 = (object*)TC_NIL;
        r2[8] = r3;
        r3 = ((object*) lenv) [8];
        r4 = (object*) &constructed_1076;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = ((object*) lenv) [9];
        r4 = ((object*) lenv) [7];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = ((object*) lenv) [10];
        r4 = (object*) &constructed_1075;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r3 = ((object*) lenv) [11];
        r4 = ((object*) lenv) [6];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[12] = r3;
        r3 = ((object*) lenv) [12];
        r4 = ((object*) lenv) [5];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[13] = r3;
        r3 = ((object*) lenv) [13];
        r4 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[14] = r3;
        r3 = ((object*) lenv) [14];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[15] = r3;
        r3 = ((object*) lenv) [15];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[16] = r3;
        r2 = ((object*) lenv) [16];
        r3 = (object*) &constructed_1074;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L11; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L11:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = ((object*) lenv) [2];
        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_844_i12
        goto L12;
        FUN_lambda_844_i12:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 22);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object***) lenv) [1][1][3];
          r4 = ((pxll_vector*)r4)->val[3];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L13; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L13:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = ((object*) lenv) [2];
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L14; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L14:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object***) lenv) [1][1][3];
          r4 = ((pxll_vector*)r4)->val[4];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L15; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L15:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = ((object*) lenv) [4];
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L16; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L16:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[5] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object***) lenv) [1][1][3];
          r4 = ((pxll_vector*)r4)->val[0];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L17; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L17:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[6] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = ((object*) lenv) [6];
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L18; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L18:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[7] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object***) lenv) [1][1][3];
          r4 = ((pxll_vector*)r4)->val[2];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L19; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L19:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[8] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = ((object*) lenv) [8];
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L20; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L20:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[9] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object***) lenv) [1][1][3];
          r4 = ((pxll_vector*)r4)->val[1];
          r3[2] = r4;
          r4 = top[125];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L21; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_flags_repr_512;
          L21:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[10] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = ((object****) lenv) [1][1][1][2];
          r3[2] = r4;
          r4 = ((object*) lenv) [10];
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L22; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L22:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[11] = r3;
          r3 = ((object***) lenv) [1][1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object****) lenv) [1][1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[12] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 61;
          r3[2] = r4;
          r4 = ((object*) lenv) [12];
          r3[3] = r4;
          r4 = (object *) 6;
          r3[4] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L23; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L23:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[13] = r3;
          r3 = (object*)TC_NIL;
          r2[14] = r3;
          r3 = ((object*) lenv) [14];
          r4 = (object*) &constructed_1073;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[15] = r3;
          r3 = ((object*) lenv) [15];
          r4 = ((object*) lenv) [13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[16] = r3;
          r3 = ((object*) lenv) [16];
          r4 = (object*) &constructed_1072;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[17] = r3;
          r3 = ((object*) lenv) [17];
          r4 = ((object*) lenv) [11];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[18] = r3;
          r3 = ((object*) lenv) [18];
          r4 = ((object*) lenv) [9];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[19] = r3;
          r3 = ((object*) lenv) [19];
          r4 = ((object*) lenv) [7];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[20] = r3;
          r3 = ((object*) lenv) [20];
          r4 = ((object*) lenv) [5];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[21] = r3;
          r3 = ((object*) lenv) [21];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[22] = r3;
          r2 = ((object*) lenv) [22];
          r3 = (object*) &constructed_1071;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L24; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L24:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L12:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_844_i12; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[15];
        r0[3] = r1;
        r1 = top[73];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L25; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L25:
        ; lenv = k[2]; k = k[1];
        r0 = (object*) &constructed_1070;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_1070;
        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_1069;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L3:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_get_var_257; r1[2] = lenv;
  r0[5] = r1;
  // def vars-set-flag!_259
  goto L26;
  FUN_vars_set_flag_bang_259:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L27; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
    L27:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[2] = r1;
    r0 = ((object***) lenv) [1][1][4];
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
    lenv = lenv[1];
    r0 = r0;
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[1] = r0;
    PXLL_RETURN(0);
  L26:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_set_flag_bang_259; r1[2] = lenv;
  r0[6] = r1;
  // def add-var_261
  goto L28;
  FUN_add_var_261:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][3];
    r2 = ((pxll_vector*)r2)->val[15];
    r1[2] = r2;
    r2 = top[80];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L29; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L29:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][3];
        r1 = ((pxll_vector*)r1)->val[15];
        r0[2] = r1;
        r1 = top[80];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[4] = r1;
        r1 = allocate (UOTAG(25), 5);
        r2 = (object *) 1;
        r1[1] = r2;
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = (object *) 1;
        r1[4] = r2;
        r2 = (object *) 1;
        r1[5] = r2;
        r0[5] = r1;
        r1 = top[71];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L30; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L30:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object**) lenv) [1][3];
        ((pxll_vector*)r1)->val[15] = r0;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L28:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_var_261; r1[2] = lenv;
  r0[7] = r1;
  // def add-vars_262
  goto L31;
  FUN_add_vars_262:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def add_669
    goto L32;
    FUN_add_669:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][3];
      r0[3] = r1;
      r1 = top[7];
      r0[1] = r1[2]; lenv = r0; goto FUN_add_var_261;
    L32:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_669; r1[2] = lenv;
    r0[2] = r1;
    // def search_670
    goto L33;
    FUN_search_670:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L34; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L34:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L35; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L35:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L36; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L36:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r1 = top[7];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L37; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_add_var_261;
          L37:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_416;
        }
      }
      r0=r0;
      goto fatbar_416_over;
      fatbar_416:
      r0 = (object *) 14;
      r0=r0;
      fatbar_416_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L33:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_670; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_search_670;
  L31:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_vars_262; r1[2] = lenv;
  r0[8] = r1;
  // def lookup-label-code_264
  goto L38;
  FUN_lookup_label_code_264:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_682
    goto L39;
    FUN_loop_682:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_1068;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[3] = r1;
          r1 = top[14];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object*) lenv) [3];
                PXLL_RETURN(0);
              } else {
                r0 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_682;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L39:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_682; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_682;
  L38:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lookup_label_code_264; r1[2] = lenv;
  r0[9] = r1;
  // def =_272
  goto L40;
  FUN__3d_272:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    PXLL_RETURN(0);
  L40:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3d_272; r1[2] = lenv;
  r0[10] = r1;
  // def <_274
  goto L41;
  FUN__3c_274:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L41:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3c_274; r1[2] = lenv;
  r0[11] = r1;
  // def +_280
  goto L42;
  FUN__plus_280:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
  L42:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__plus_280; r1[2] = lenv;
  r0[12] = r1;
  // def eq?_296
  goto L43;
  FUN_eq_question_296:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
  L43:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_eq_question_296; r1[2] = lenv;
  r0[13] = r1;
  // def error1_304
  goto L44;
  FUN_error1_304:
    r0 = (object *) 2562;
    box((pxll_int)fputc (GET_CHAR(r0), stdout));
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1067;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_1067;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = ((object*) lenv) [3];
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
  L44:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_error1_304; r1[2] = lenv;
  r0[14] = r1;
  // def id_307
  goto L45;
  FUN_id_307:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L45:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_id_307; r1[2] = lenv;
  r0[15] = r1;
  // def ^call/cc_308
  goto L46;
  FUN__5ecall_2fcc_308:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = k;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_1120
    goto L47;
    FUN_lambda_1120:
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][2];
      r0 = (k=r1, r0);
      PXLL_RETURN(0);
    L47:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_1120; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L46:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__5ecall_2fcc_308; r1[2] = lenv;
  r0[16] = r1;
  // def pair->first_311
  goto L48;
  FUN_pair__3efirst_311:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L48:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3efirst_311; r1[2] = lenv;
  r0[17] = r1;
  // def pair->second_312
  goto L49;
  FUN_pair__3esecond_312:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L49:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3esecond_312; r1[2] = lenv;
  r0[18] = r1;
  // def car_319
  goto L50;
  FUN_car_319:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1066;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1066;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L50:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_car_319; r1[2] = lenv;
  r0[19] = r1;
  // def cdr_320
  goto L51;
  FUN_cdr_320:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1065;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1065;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L51:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cdr_320; r1[2] = lenv;
  r0[20] = r1;
  // def reverse-onto_321
  goto L52;
  FUN_reverse_onto_321:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } break;
    }
    PXLL_RETURN(0);
  L52:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reverse_onto_321; r1[2] = lenv;
  r0[21] = r1;
  // def length_324
  goto L53;
  FUN_length_324:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def fun_794
    goto L54;
    FUN_fun_794:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_fun_794;
        } break;
      }
      PXLL_RETURN(0);
    L54:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fun_794; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_fun_794;
  L53:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_length_324; r1[2] = lenv;
  r0[22] = r1;
  // def last_327
  goto L55;
  FUN_last_327:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1064;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1064;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_415;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_415_over;
        fatbar_415:
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_last_327;
        fatbar_415_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L55:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_last_327; r1[2] = lenv;
  r0[23] = r1;
  // def member?_328
  goto L56;
  FUN_member_question_328:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L57; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L57:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[4] = r1;
          r1 = top[24];
          r0[1] = r1[2]; lenv = r0; goto FUN_member_question_328;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L56:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_question_328; r1[2] = lenv;
  r0[24] = r1;
  // def member-eq?_329
  goto L58;
  FUN_member_eq_question_329:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[25];
          r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L58:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_eq_question_329; r1[2] = lenv;
  r0[25] = r1;
  // def remove-eq_330
  goto L59;
  FUN_remove_eq_330:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1063[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[26];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L60; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_remove_eq_330;
          L60:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L59:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_remove_eq_330; r1[2] = lenv;
  r0[26] = r1;
  // def nth_331
  goto L61;
  FUN_nth_331:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1062;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1062;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } else {
          goto fatbar_414;
        }
        PXLL_RETURN(0);
        goto fatbar_414_over;
        fatbar_414:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        r0[3] = r1;
        r1 = top[27];
        r0[1] = r1[2]; lenv = r0; goto FUN_nth_331;
        fatbar_414_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L61:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_nth_331; r1[2] = lenv;
  r0[27] = r1;
  // def index-eq_332
  goto L62;
  FUN_index_eq_332:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_823
    goto L63;
    FUN_loop_823:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object*) &constructed_73;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1061;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1061;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object****) lenv) [1][1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object**) lenv) [1][2];
            PXLL_RETURN(0);
          } else {
            r0 = (object *) 3;
            r1 = ((object**) lenv) [1][2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            r1 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            lenv[3] = r1;
            goto FUN_loop_823;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L63:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_823; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_823;
  L62:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_index_eq_332; r1[2] = lenv;
  r0[28] = r1;
  // def slice_333
  goto L64;
  FUN_slice_333:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) constructed_1059[0];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_831
      goto L65;
      FUN_loop_831:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][3];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L66; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
          L66:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r2 = ((object*) lenv) [4];
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_831;
        } else {
          r0 = ((object***) lenv) [1][1][4];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[19];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L67; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
            L67:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object**) lenv) [1][4];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = ((object*) lenv) [3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[20];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L68; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_320;
            L68:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv[2] = r2;
            lenv[3] = r1;
            lenv[4] = r0;
            goto FUN_loop_831;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = (object *) constructed_41[0];
            r0[3] = r1;
            r1 = top[21];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L65:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_831; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) constructed_1060[0];
      r0[4] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_831;
    }
    PXLL_RETURN(0);
  L64:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_slice_333; r1[2] = lenv;
  r0[29] = r1;
  // def range_334
  goto L69;
  FUN_range_334:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_836
    goto L70;
    FUN_loop_836:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_836;
      }
      PXLL_RETURN(0);
    L70:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_836; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 3;
    r2 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_836;
  L69:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_range_334; r1[2] = lenv;
  r0[30] = r1;
  // def n-of_335
  goto L71;
  FUN_n_of_335:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_841
    goto L72;
    FUN_loop_841:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<=unbox(r0))) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object***) lenv) [1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_841;
      }
      PXLL_RETURN(0);
    L72:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_841; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_841;
  L71:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_n_of_335; r1[2] = lenv;
  r0[31] = r1;
  // def map_336
  goto L73;
  FUN_map_336:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1058[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L74; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L74:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L75; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L75:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L73:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map_336; r1[2] = lenv;
  r0[32] = r1;
  // def map2_337
  goto L76;
  FUN_map2_337:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) constructed_1056[0];
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_413;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L77; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L77:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            r1[4] = r2;
            r2 = top[33];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L78; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map2_337;
            L78:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = ((object*) lenv) [5];
            r1 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_413;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_413_over;
    fatbar_413:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1057;
    r0[2] = r1;
    r1 = allocate (UOTAG(1), 2);
    r2 = ((object*) lenv) [3];
    r1[1] = r2;
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_413_over: ;
    PXLL_RETURN(0);
  L76:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map2_337; r1[2] = lenv;
  r0[33] = r1;
  // def filter_338
  goto L79;
  FUN_filter_338:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1055[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L80; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L80:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L81; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_filter_338;
          L81:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[34];
          r0[1] = r1[2]; lenv = r0; goto FUN_filter_338;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L79:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_filter_338; r1[2] = lenv;
  r0[34] = r1;
  // def for-each_339
  goto L82;
  FUN_for_each_339:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L83; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L83:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[35];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      } break;
    }
    PXLL_RETURN(0);
  L82:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each_339; r1[2] = lenv;
  r0[35] = r1;
  // def for-each2_340
  goto L84;
  FUN_for_each2_340:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_412;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L85; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L85:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object***) lenv) [1][1][2];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            r0[4] = r1;
            r1 = top[36];
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_340;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_412;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_412_over;
    fatbar_412:
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1054;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_1054;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_412_over: ;
    PXLL_RETURN(0);
  L84:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each2_340; r1[2] = lenv;
  r0[36] = r1;
  // def fold_341
  goto L86;
  FUN_fold_341:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L87; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L87:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*) lenv) [3];
        r2 = ((object**) lenv) [1][2];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_fold_341;
      } break;
    }
    PXLL_RETURN(0);
  L86:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_fold_341; r1[2] = lenv;
  r0[37] = r1;
  // def foldr_342
  goto L88;
  FUN_foldr_342:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r1[4] = r2;
        r2 = top[38];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L89; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_foldr_342;
        L89:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
    }
    PXLL_RETURN(0);
  L88:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_foldr_342; r1[2] = lenv;
  r0[38] = r1;
  // def some?_343
  goto L90;
  FUN_some_question_343:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L91; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L91:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[39];
          r0[1] = r1[2]; lenv = r0; goto FUN_some_question_343;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L90:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_some_question_343; r1[2] = lenv;
  r0[39] = r1;
  // def every?_344
  goto L92;
  FUN_every_question_344:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L93; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L93:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[40];
          r0[1] = r1[2]; lenv = r0; goto FUN_every_question_344;
        } else {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L92:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every_question_344; r1[2] = lenv;
  r0[40] = r1;
  // def every2?_345
  goto L94;
  FUN_every2_question_345:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_411;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L95; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L95:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r0[4] = r1;
              r1 = top[41];
              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_345;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_411;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_411_over;
    fatbar_411:
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1053;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_1053;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_411_over: ;
    PXLL_RETURN(0);
  L94:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every2_question_345; r1[2] = lenv;
  r0[41] = r1;
  // def pack_347
  goto L96;
  FUN_pack_347:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def pack2_902
    goto L97;
    FUN_pack2_902:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L98; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L98:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L99; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L99:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_pack2_902;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][3];
            r1[2] = r2;
            r2 = (object *) constructed_41[0];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L100; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L100:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = (object*)TC_NIL;
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            r3 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[4] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L101; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pack2_902;
            L101:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L97:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pack2_902; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1052[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_pack2_902;
      } break;
    }
    PXLL_RETURN(0);
  L96:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pack_347; r1[2] = lenv;
  r0[42] = r1;
  // def list->vector_349
  goto L102;
  FUN_list__3evector_349:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_915
    goto L103;
    FUN_recur_915:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][2];
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_915;
        } break;
      }
      PXLL_RETURN(0);
    L103:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_915; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1051[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L104; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L104:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        ensure_heap (1, unbox(r1));
        r1 = ((object*) lenv) [2];
        r2 = ((object*) lenv) [3];
        if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
          t = alloc_no_clear (TC_VECTOR, unbox(r2));
          for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
          r1 = t;
        }
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = (object *) 1;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_recur_915;
      } break;
    }
    PXLL_RETURN(0);
  L102:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3evector_349; r1[2] = lenv;
  r0[43] = r1;
  // def sort_350
  goto L105;
  FUN_sort_350:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def halve_927
    goto L106;
    FUN_halve_927:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(1), 2);
          r1 = ((object*) lenv) [2];
          r0[1] = r1;
          r1 = (object *) constructed_1049[0];
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object**) lenv) [1][2];
              r0[1] = r1;
              r1 = (object *) constructed_1050[0];
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_410;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_410_over;
          fatbar_410:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L107; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_halve_927;
          L107:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object*) lenv) [3];
              r2 = ((object***) lenv) [1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[1] = r1;
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
          fatbar_410_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L106:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_halve_927; r1[2] = lenv;
    r0[2] = r1;
    // def merge-sort_928
    goto L108;
    FUN_merge_sort_928:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_409;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_409_over;
      fatbar_409:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L109; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_halve_927;
      L109:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L110; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_928;
          L110:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L111; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_928;
          L111:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_931_i162
          goto L112;
          FUN_loop_931_i162:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = ((object*) lenv) [3];
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = ((object**) lenv) [1][2];
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object**) lenv) [1][2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[3] = r1;
                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L113; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L113:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    if PXLL_IS_TRUE(r0) {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object***) lenv) [1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = ((object*****) lenv) [1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L114; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_931_i162;
                      L114:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object***) lenv) [1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object***) lenv) [1][1][3];
                      r3 = ((object***) lenv) [1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r1[3] = r2;
                      r2 = ((object*****) lenv) [1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L115; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_931_i162;
                      L115:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    }
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L112:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_931_i162; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][4];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_931_i162;
        } break;
      }
      PXLL_RETURN(0);
      fatbar_409_over: ;
      PXLL_RETURN(0);
    L108:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_merge_sort_928; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_merge_sort_928;
  L105:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_350; r1[2] = lenv;
  r0[44] = r1;
  // def substring_355
  goto L116;
  FUN_substring_355:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][3];
    r1 = (object *) 1;
    r2 = ((object**) lenv) [1][2];
    r3 = ((object*) lenv) [2];
    r4 = ((object*) lenv) [3];
    (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
  L116:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_substring_355; r1[2] = lenv;
  r0[45] = r1;
  // def char->string_358
  goto L117;
  FUN_char__3estring_358:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 3;
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 3;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
    r0 = (object *) 1;
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L117:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char__3estring_358; r1[2] = lenv;
  r0[46] = r1;
  // def string-concat_362
  goto L118;
  FUN_string_concat_362:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_976
    goto L119;
    FUN_loop_976:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object***) lenv) [1][1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_976;
        } break;
      }
      PXLL_RETURN(0);
    L119:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_976; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object***) lenv) [1][1][2];
    r1[2] = r2;
    r2 = (object *) 1;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L120; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_976;
    L120:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_983
    goto L121;
    FUN_loop_983:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object***) lenv) [1][1][3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object**) lenv) [1][2];
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][3];
          r0 = (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object***) lenv) [1][1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_983;
        } break;
      }
      PXLL_RETURN(0);
    L121:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_983; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_983;
  L118:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_concat_362; r1[2] = lenv;
  r0[47] = r1;
  // def string-join_363
  goto L122;
  FUN_string_join_363:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sj_990
    goto L123;
    FUN_sj_990:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L124; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L124:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_41[0];
              r1[3] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L125; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
              L125:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = top[47];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
            } break;
            default: {
              goto fatbar_408;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_408_over;
          fatbar_408:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_sj_990;
          fatbar_408_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L123:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sj_990; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = top[47];
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = (object *) constructed_1048[0];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_sj_990;
    }
    PXLL_RETURN(0);
  L122:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_join_363; r1[2] = lenv;
  r0[48] = r1;
  // def string-split_364
  goto L126;
  FUN_string_split_364:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_997
    goto L127;
    FUN_loop_997:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = box((pxll_int)((pxll_string*)(r1))->len);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object****) lenv) [1][1][1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[4] = r2;
        r2 = top[45];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L128; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
        L128:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_41[0];
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r2 = ((object****) lenv) [1][1][1][2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = ((object**) lenv) [1][2];
        r2 = ((object****) lenv) [1][1][1][2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[4] = r2;
          r2 = top[45];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L129; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
          L129:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object**) lenv) [1][4];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = (object *) 3;
          r2 = ((object*) lenv) [2];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r2 = (object *) 3;
          r3 = ((object*) lenv) [2];
          r2 = box((pxll_int)unbox(r3)+unbox(r2));
          lenv[2] = r2;
          lenv[3] = r1;
          lenv[4] = r0;
          goto FUN_loop_997;
        } else {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [4];
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_997;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L127:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_997; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = (object *) constructed_1047[0];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_997;
  L126:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_split_364; r1[2] = lenv;
  r0[49] = r1;
  // def string-compare_365
  goto L130;
  FUN_string_compare_365:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = ((object*) lenv) [2];
      r1=r1;
    } else {
      r1 = ((object*) lenv) [3];
      r1=r1;
    }
    r2 = ((object**) lenv) [1][3];
    r3 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)memcmp (((pxll_string*)(r3))->data, ((pxll_string*)(r2))->data, unbox(r1)));
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [4];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) -1;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L130:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_compare_365; r1[2] = lenv;
  r0[50] = r1;
  // def string-find_366
  goto L131;
  FUN_string_find_366:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object*) lenv) [3];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = (object *) -1;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1010
      goto L132;
      FUN_loop_1010:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)-unbox(r0));
          PXLL_RETURN(0);
        } else {
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) -1;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*****) lenv) [1][1][1][1][2];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r1 = ((object*) lenv) [3];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1010;
            } else {
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              r1 = (object *) 1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1010;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L132:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1010; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1010;
    }
    PXLL_RETURN(0);
  L131:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_find_366; r1[2] = lenv;
  r0[51] = r1;
  // def string<?_368
  goto L133;
  FUN_string_3c_question_368:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[50];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L134; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
    L134:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L133:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_3c_question_368; r1[2] = lenv;
  r0[52] = r1;
  // def zero-terminate_370
  goto L135;
  FUN_zero_terminate_370:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = (object *) 3;
    r2 = ((object*) lenv) [2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][2];
    range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][2];
    r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
    r0[4] = r1;
    r0 = (object *) 2;
    r1 = ((object*) lenv) [4];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = box((pxll_int)((pxll_string*)(r1))->len);
      r0[2] = r1;
      r1 = (object *) 3;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r1 = ((object*) lenv) [3];
      r1 = box((pxll_int)string_tuple_length (unbox(r1)));
      ensure_heap (1, unbox(r1));
      r1 = ((object*) lenv) [3];
      r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
      r0[4] = r1;
      r0 = (object *) 1;
      r1 = (object *) 1;
      r2 = ((object**) lenv) [1][2];
      r3 = ((object*) lenv) [2];
      r4 = ((object*) lenv) [4];
      (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
      r0 = ((object*) lenv) [2];
      r1 = ((object*) lenv) [4];
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = ((object*) lenv) [2];
      r1 = (object *) 2;
      r2 = ((object*) lenv) [4];
      (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L135:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_zero_terminate_370; r1[2] = lenv;
  r0[53] = r1;
  // def list->string_371
  goto L136;
  FUN_list__3estring_371:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L137; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L137:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1024
    goto L138;
    FUN_loop_1024:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object***) lenv) [1][1][3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object****) lenv) [1][1][1][3];
          range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          r2 = ((object****) lenv) [1][1][1][3];
          (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1024;
        } break;
      }
      PXLL_RETURN(0);
    L138:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1024; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1024;
  L136:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3estring_371; r1[2] = lenv;
  r0[54] = r1;
  // def string->list_372
  goto L139;
  FUN_string__3elist_372:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1030
    goto L140;
    FUN_loop_1030:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r0;
        lenv[3] = r1;
        goto FUN_loop_1030;
      }
      PXLL_RETURN(0);
    L140:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1030; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1030;
  L139:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3elist_372; r1[2] = lenv;
  r0[55] = r1;
  // def int->string_374
  goto L141;
  FUN_int__3estring_374:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r1 = (object *) 1;
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 12290;
      r0[2] = r1;
      r1 = top[46];
      r0[1] = r1[2]; lenv = r0; goto FUN_char__3estring_358;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1039
      goto L142;
      FUN_loop_1039:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        r1 = (object *) 1;
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r2 = ((object***) lenv) [1][1][2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
            r1 = ((object*) lenv) [3];
            r2 = (object *) 11522;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r1=r1;
          } else {
            r1 = ((object*) lenv) [3];
            r1=r1;
          }
          r0[2] = r1;
          r1 = top[54];
          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 21;
          r2 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)unbox(r2) % unbox(r1));
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r2 = (object *) 97;
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r1 = TO_CHAR(unbox(r1));
          r0[4] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = (object *) 21;
          r2 = ((object*) lenv) [2];
          r1 = box((pxll_int)unbox(r2)/unbox(r1));
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1039;
        }
        PXLL_RETURN(0);
      L142:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1039; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r2 = ((object**) lenv) [1][2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
        r1 = ((object**) lenv) [1][2];
        r2 = (object *) 1;
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        r1=r1;
      } else {
        r1 = ((object**) lenv) [1][2];
        r1=r1;
      }
      r0[2] = r1;
      r1 = (object *) constructed_1046[0];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1039;
    }
    PXLL_RETURN(0);
  L141:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3estring_374; r1[2] = lenv;
  r0[56] = r1;
  // def int->hex-string_375
  goto L143;
  FUN_int__3ehex_string_375:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1043
    goto L144;
    FUN_loop_1043:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r1 = (object *) 1;
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r2 = ((object***) lenv) [1][1][2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
          r1 = ((object*) lenv) [3];
          r2 = (object *) 11522;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r1=r1;
        } else {
          r1 = ((object*) lenv) [3];
          r1=r1;
        }
        r0[2] = r1;
        r1 = top[54];
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 31;
        r2 = ((object**) lenv) [1][2];
        r1 = box((pxll_int)unbox(r2)&unbox(r1));
        r2 = top[157];
        range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
        r1 = ((pxll_vector*)r2)->val[unbox(r1)];
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 9;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)>>unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_1043;
      }
      PXLL_RETURN(0);
    L144:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1043; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r2 = ((object**) lenv) [1][2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = ((object**) lenv) [1][2];
      r2 = (object *) 1;
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r1=r1;
    } else {
      r1 = ((object**) lenv) [1][2];
      r1=r1;
    }
    r0[2] = r1;
    r1 = (object *) constructed_1045[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1043;
  L143:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3ehex_string_375; r1[2] = lenv;
  r0[57] = r1;
  // def pad_377
  goto L145;
  FUN_pad_377:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
      r0 = ((object**) lenv) [1][3];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r2 = ((object***) lenv) [1][1][2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][4];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = top[31];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L146; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_335;
        L146:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = top[54];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L147; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_371;
        L147:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object****) lenv) [1][1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = top[31];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L148; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_335;
        L148:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = top[54];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L149; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_371;
        L149:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = ((object****) lenv) [1][1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L145:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pad_377; r1[2] = lenv;
  r0[58] = r1;
  // def cpad_380
  goto L150;
  FUN_cpad_380:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[3] = r1;
    r1 = (object *) 5;
    r2 = ((object*) lenv) [3];
    r1 = box((pxll_int)unbox(r2)/unbox(r1));
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r2 = ((object*) lenv) [2];
    r1 = box((pxll_int)unbox(r2)+unbox(r1));
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object*) lenv) [5];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = (object *) 262;
    r1[4] = r2;
    r2 = top[58];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L151; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pad_377;
    L151:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [6];
    r0[3] = r1;
    r1 = (object *) 6;
    r0[4] = r1;
    r1 = top[58];
    r0[1] = r1[2]; lenv = r0; goto FUN_pad_377;
  L150:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cpad_380; r1[2] = lenv;
  r0[59] = r1;
  // def copy-cstring_382
  goto L152;
  FUN_copy_cstring_382:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)strlen((char*)r1));
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [2];
    r2 = ((object*) lenv) [3];
    (memcpy (((pxll_string*)(r2))->data, (char*)r0, unbox(r1)), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
  L152:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_copy_cstring_382; r1[2] = lenv;
  r0[60] = r1;
  // def open_383
  goto L153;
  FUN_open_383:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[53];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L154; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
    L154:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r2 = ((object**) lenv) [1][3];
    r3 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)open (((pxll_string*)(r1))->data, unbox(r2), unbox(r3)));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>=unbox(r0))) {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_1044;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[53];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L155; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
      L155:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    }
    PXLL_RETURN(0);
  L153:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_open_383; r1[2] = lenv;
  r0[61] = r1;
  // def file/open-read_390
  goto L156;
  FUN_file_2fopen_read_390:
    check_heap (0);
    r0 = allocate (UOTAG(24), 4);
    r1 = (object *) 32769;
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 32769;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[158];
    r1[3] = r2;
    r2 = (object *) 1;
    r1[4] = r2;
    r2 = top[61];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L157; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_open_383;
    L157:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = (object *) 1;
    r0[4] = r1;
    PXLL_RETURN(0);
  L156:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fopen_read_390; r1[2] = lenv;
  r0[62] = r1;
  // def file/fill-buffer_395
  goto L158;
  FUN_file_2ffill_buffer_395:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[4] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    r1 = box((pxll_int)read (unbox(r3), ((pxll_string*)(r1))->data, unbox(r2)));
    r0[5] = r1;
    r1 = ((object*) lenv) [5];
    r0[6] = r1;
    r0 = ((object*) lenv) [6];
    r1 = ((object**) lenv) [1][2];
    ((pxll_vector*)r1)->val[1] = r0;
    r0 = (object *) 1;
    r1 = ((object**) lenv) [1][2];
    ((pxll_vector*)r1)->val[3] = r0;
    r0 = ((object*) lenv) [6];
    PXLL_RETURN(0);
  L158:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2ffill_buffer_395; r1[2] = lenv;
  r0[63] = r1;
  // def file/read-buffer_396
  goto L159;
  FUN_file_2fread_buffer_396:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      r0 = ((pxll_vector*)r0)->val[1];
      r1 = ((object**) lenv) [1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r0[4] = r1;
      r1 = top[45];
      r0[1] = r1[2]; lenv = r0; goto FUN_substring_355;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[63];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L160; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_395;
      L160:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object*) &constructed_1043;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[1];
        r1[4] = r2;
        r2 = top[45];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L161; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
        L161:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L159:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_buffer_396; r1[2] = lenv;
  r0[64] = r1;
  // def file/read-char_397
  goto L162;
  FUN_file_2fread_char_397:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = (object *) 3;
      r2 = ((object*) lenv) [3];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[4] = r1;
      r0 = ((object*) lenv) [4];
      r1 = ((object*) lenv) [2];
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = ((object*) lenv) [4];
      r1 = ((object*) lenv) [2];
      r0 = TO_CHAR(((unsigned char *)((pxll_string*)(r1))->data)[unbox(r0)]);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[63];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L163; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_395;
      L163:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 65794;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[65];
        r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_397;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L162:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_char_397; r1[2] = lenv;
  r0[65] = r1;
  // def alist/lookup_405
  goto L164;
  FUN_alist_2flookup_405:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[66];
          r0[1] = r1[2]; lenv = r0; goto FUN_alist_2flookup_405;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L164:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flookup_405; r1[2] = lenv;
  r0[66] = r1;
  // def alist/get_407
  goto L165;
  FUN_alist_2fget_407:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[66];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L166; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L166:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
    }
    PXLL_RETURN(0);
  L165:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fget_407; r1[2] = lenv;
  r0[67] = r1;
  // def alist/iterate_408
  goto L167;
  FUN_alist_2fiterate_408:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L168; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L168:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = top[68];
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      } break;
    }
    PXLL_RETURN(0);
  L167:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fiterate_408; r1[2] = lenv;
  r0[68] = r1;
  // def alist->keys_410
  goto L169;
  FUN_alist__3ekeys_410:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[69];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L170; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_410;
        L170:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L169:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist__3ekeys_410; r1[2] = lenv;
  r0[69] = r1;
  // def alist/length_412
  goto L171;
  FUN_alist_2flength_412:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[70];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L172; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flength_412;
        L172:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L171:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flength_412; r1[2] = lenv;
  r0[70] = r1;
  // def tree/insert_414
  goto L173;
  FUN_tree_2finsert_414:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def ins_1194
    goto L174;
    FUN_ins_1194:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(2)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = (object*)UITAG(2);
          r0[2] = r1;
          r1 = (object*)UITAG(2);
          r0[3] = r1;
          r0 = ((object****) lenv) [1][1][1][5];
          r1 = ((object*) lenv) [3];
          r2 = ((object****) lenv) [1][1][1][4];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L175; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L175:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L176; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_ins_1194;
            L176:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object**) lenv) [1][5];
            r1 = ((object**) lenv) [1][3];
            r2 = ((object**) lenv) [1][4];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),4);
            t[1] = r3;
            t[2] = r1;
            t[3] = r2;
            t[4] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L177; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L177:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L178; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_ins_1194;
              L178:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object**) lenv) [1][5];
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][4];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(0),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L179; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L179:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L180; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_ins_1194;
            L180:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 5);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,2);
                r0[4] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,3);
                r0[5] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 7);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,2);
                    r0[4] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,3);
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [3];
                    r3 = ((object*) lenv) [4];
                    r4 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object****) lenv) [1][1][1][5];
                    r2 = ((object****) lenv) [1][1][1][3];
                    r3 = ((object****) lenv) [1][1][1][4];
                    r4 = ((object**) lenv) [1][3];
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r0 = ((object**) lenv) [1][5];
                    r1 = ((object*) lenv) [7];
                    r2 = ((object**) lenv) [1][4];
                    r3 = ((object*) lenv) [6];
                    t = alloc_no_clear (UOTAG(0),4);
                    t[1] = r3;
                    t[2] = r1;
                    t[3] = r2;
                    t[4] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_405;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_405_over;
                fatbar_405:
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 7);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,2);
                    r0[4] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,3);
                    r0[5] = r1;
                    r1 = ((object**) lenv) [1][5];
                    r2 = ((object*) lenv) [2];
                    r3 = ((object**) lenv) [1][4];
                    r4 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object****) lenv) [1][1][1][5];
                    r2 = ((object****) lenv) [1][1][1][3];
                    r3 = ((object****) lenv) [1][1][1][4];
                    r4 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r0 = ((object*) lenv) [5];
                    r1 = ((object*) lenv) [7];
                    r2 = ((object*) lenv) [4];
                    r3 = ((object*) lenv) [6];
                    t = alloc_no_clear (UOTAG(0),4);
                    t[1] = r3;
                    t[2] = r1;
                    t[3] = r2;
                    t[4] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_404;
                  }
                }
                PXLL_RETURN(0);
                fatbar_405_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_404;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_404_over;
            fatbar_404:
            r0 = ((object**) lenv) [1][5];
            r1 = ((object**) lenv) [1][3];
            r2 = ((object**) lenv) [1][4];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(1),4);
            t[1] = r3;
            t[2] = r1;
            t[3] = r2;
            t[4] = r0;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_404_over: ;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L181; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L181:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L182; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_ins_1194;
              L182:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 5);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,2);
                  r0[4] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,3);
                  r0[5] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,2);
                      r0[4] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,3);
                      r0[5] = r1;
                      r1 = ((object****) lenv) [1][1][1][5];
                      r2 = ((object*) lenv) [2];
                      r3 = ((object****) lenv) [1][1][1][4];
                      r4 = ((object****) lenv) [1][1][1][2];
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[6] = r1;
                      r1 = ((object**) lenv) [1][5];
                      r2 = ((object**) lenv) [1][3];
                      r3 = ((object**) lenv) [1][4];
                      r4 = ((object*) lenv) [3];
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[7] = r1;
                      r0 = ((object*) lenv) [5];
                      r1 = ((object*) lenv) [7];
                      r2 = ((object*) lenv) [4];
                      r3 = ((object*) lenv) [6];
                      t = alloc_no_clear (UOTAG(0),4);
                      t[1] = r3;
                      t[2] = r1;
                      t[3] = r2;
                      t[4] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_407;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_407_over;
                  fatbar_407:
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,2);
                      r0[4] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,3);
                      r0[5] = r1;
                      r1 = ((object****) lenv) [1][1][1][5];
                      r2 = ((object**) lenv) [1][2];
                      r3 = ((object****) lenv) [1][1][1][4];
                      r4 = ((object****) lenv) [1][1][1][2];
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[6] = r1;
                      r1 = ((object*) lenv) [5];
                      r2 = ((object*) lenv) [3];
                      r3 = ((object*) lenv) [4];
                      r4 = ((object*) lenv) [2];
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[7] = r1;
                      r0 = ((object**) lenv) [1][5];
                      r1 = ((object*) lenv) [7];
                      r2 = ((object**) lenv) [1][4];
                      r3 = ((object*) lenv) [6];
                      t = alloc_no_clear (UOTAG(0),4);
                      t[1] = r3;
                      t[2] = r1;
                      t[3] = r2;
                      t[4] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_406;
                    }
                  }
                  PXLL_RETURN(0);
                  fatbar_407_over: ;
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_406;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_406_over;
              fatbar_406:
              r0 = ((object**) lenv) [1][5];
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][4];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(1),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
              fatbar_406_over: ;
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L174:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_ins_1194; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object***) lenv) [1][1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L183; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_ins_1194;
    L183:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        r1 = ((object*) lenv) [3];
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),4);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        t[4] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_403;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_403_over;
    fatbar_403:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_403_over: ;
    PXLL_RETURN(0);
  L173:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finsert_414; r1[2] = lenv;
  r0[71] = r1;
  // def tree/member_415
  goto L184;
  FUN_tree_2fmember_415:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def member0_1244
    goto L185;
    FUN_member0_1244:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(2)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L186; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L186:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [2];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_member0_1244;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L187; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L187:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_member0_1244;
            } else {
              r0 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L188; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L188:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [2];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_member0_1244;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L189; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L189:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_member0_1244;
            } else {
              r0 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L185:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_member0_1244; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_member0_1244;
  L184:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fmember_415; r1[2] = lenv;
  r0[72] = r1;
  // def tree/inorder_416
  goto L190;
  FUN_tree_2finorder_416:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(2)): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[73];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L191; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L191:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L192; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L192:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[73];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L193; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L193:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[73];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L194; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L194:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L195; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L195:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[73];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L196; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L196:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L190:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finorder_416; r1[2] = lenv;
  r0[73] = r1;
  // def tree/reverse_417
  goto L197;
  FUN_tree_2freverse_417:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(2)): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L198; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
        L198:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L199; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L199:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L200; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
        L200:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L201; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
        L201:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L202; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L202:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L203; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
        L203:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L197:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2freverse_417; r1[2] = lenv;
  r0[74] = r1;
  // def tree/keys_419
  goto L204;
  FUN_tree_2fkeys_419:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_1042[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_4635
    goto L205;
    FUN_lambda_4635:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r0 = r0;
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L205:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_4635; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[74];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L206; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
    L206:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L204:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fkeys_419; r1[2] = lenv;
  r0[75] = r1;
  // def tree/values_420
  goto L207;
  FUN_tree_2fvalues_420:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_1041[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_4652
    goto L208;
    FUN_lambda_4652:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r0 = r0;
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L208:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_4652; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[74];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L209; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
    L209:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L207:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fvalues_420; r1[2] = lenv;
  r0[76] = r1;
  // def symbol->string_422
  goto L210;
  FUN_symbol__3estring_422:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L210:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol__3estring_422; r1[2] = lenv;
  r0[77] = r1;
  // def intern-symbol_424
  goto L211;
  FUN_intern_symbol_424:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = top[164];
    r0[2] = r1;
    r1 = top[52];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[71];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L212; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
    L212:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    top[164] = r0;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = top[163];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = (object *) 3;
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    top[163] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L211:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_intern_symbol_424; r1[2] = lenv;
  r0[78] = r1;
  // def string->symbol_425
  goto L213;
  FUN_string__3esymbol_425:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = top[164];
    r1[2] = r2;
    r2 = top[52];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L214; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L214:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = top[163];
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_SYMBOL,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[78];
        r0[1] = r1[2]; lenv = r0; goto FUN_intern_symbol_424;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L213:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3esymbol_425; r1[2] = lenv;
  r0[79] = r1;
  // def symbol<?_426
  goto L215;
  FUN_symbol_3c_question_426:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][3];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[50];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L216; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
    L216:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [4];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L215:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_3c_question_426; r1[2] = lenv;
  r0[80] = r1;
  // def symbol-index<?_427
  goto L217;
  FUN_symbol_index_3c_question_427:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][2];
    r2 = UOBJ_GET(r2,1);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][3];
    r2 = UOBJ_GET(r2,1);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L217:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_index_3c_question_427; r1[2] = lenv;
  r0[81] = r1;
  // def char-class_429
  goto L218;
  FUN_char_class_429:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 513;
    ensure_heap (1, unbox(r1));
    r1 = (object *) 6;
    r2 = (object *) 513;
    if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
      t = alloc_no_clear (TC_VECTOR, unbox(r2));
      for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
      r1 = t;
    }
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def in-class?_1311
    goto L219;
    FUN_in_class_question_1311:
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)GET_CHAR(r0));
      r1 = ((object***) lenv) [1][1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r0));
      r0 = ((pxll_vector*)r1)->val[unbox(r0)];
      PXLL_RETURN(0);
    L219:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_in_class_question_1311; r1[2] = lenv;
    r0[2] = r1;
    // def loop_1313
    goto L220;
    FUN_loop_1313:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object**) lenv) [1][2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)GET_CHAR(r0));
          r1 = (object *) 262;
          r2 = ((object****) lenv) [1][1][1][2];
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_1313;
        } break;
      }
      PXLL_RETURN(0);
    L220:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1313; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1313;
  L218:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char_class_429; r1[2] = lenv;
  r0[82] = r1;
  // def reader_430
  goto L221;
  FUN_reader_430:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 65794;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1323
    goto L222;
    FUN_skip_whitespace_1323:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1344
      goto L223;
      FUN_loop_1344:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1342_i346
            goto L224;
            FUN_loop_1342_i346:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_401;
              }
              PXLL_RETURN(0);
              goto fatbar_401_over;
              fatbar_401:
              r0 = (object *) 3330;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_402;
              }
              PXLL_RETURN(0);
              goto fatbar_402_over;
              fatbar_402:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L225; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L225:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L226; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L226:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              lenv[2] = r0;
              goto FUN_loop_1342_i346;
              fatbar_402_over: ;
              PXLL_RETURN(0);
              fatbar_401_over: ;
              PXLL_RETURN(0);
            L224:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1342_i346; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            r1[2] = r2;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L227; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L227:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object******) lenv) [1][1][1][1][1][2] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L228; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_loop_1342_i346;
            L228:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*****) lenv) [1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L229; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L229:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object****) lenv) [1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object****) lenv) [1][1][1][2];
            lenv[2] = r0;
            goto FUN_loop_1344;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = top[173];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L230; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L230:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L231; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L231:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*****) lenv) [1][1][1][1][2] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*****) lenv) [1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L232; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L232:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object****) lenv) [1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object****) lenv) [1][1][1][2];
              lenv[2] = r0;
              goto FUN_loop_1344;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L223:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1344; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L233; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L233:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1344;
    L222:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1323; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1324
    goto L234;
    FUN_read_atom_1324:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1349
      goto L235;
      FUN_loop_1349:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L236; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L236:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][2] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = ((object*****) lenv) [1][1][1][1][2];
        ((object***) lenv) [1][1][4] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L237; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L237:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = (object *) 7;
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_397;
        }
        r0=r0;
        goto fatbar_397_over;
        fatbar_397:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L238; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L238:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L239; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L239:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_398;
        }
        r0=r0;
        goto fatbar_398_over;
        fatbar_398:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L240; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L240:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L241; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L241:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_399;
        }
        r0=r0;
        goto fatbar_399_over;
        fatbar_399:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L242; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L242:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][4];
                r0[2] = r1;
                r1 = top[174];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L243; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L243:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                  r0=r0;
                } else {
                  r0 = (object *) 7;
                  r0=r0;
                }
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_400;
        }
        r0=r0;
        goto fatbar_400_over;
        fatbar_400:
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_72;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_72;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        r0=r0;
        fatbar_400_over: ;
        r0=r0;
        fatbar_399_over: ;
        r0=r0;
        fatbar_398_over: ;
        r0=r0;
        fatbar_397_over: ;
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L244; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L244:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object******) lenv) [1][1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          lenv[2] = r0;
          goto FUN_loop_1349;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_1039;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_1039;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L245; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L245:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              ((object******) lenv) [1][1][1][1][1][2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              ((object*) lenv) [2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(0), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L246; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L246:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = top[54];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L247; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L247:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L248; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L248:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L235:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1349; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1038[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1349;
    L234:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1324; r1[2] = lenv;
    r0[3] = r1;
    // def read_1328
    goto L249;
    FUN_read_1328:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L250; t[4] = r0; k = t;
      lenv = r1[2]; goto FUN_skip_whitespace_1323;
      L250:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object*****) lenv) [1][1][1][1][2];
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = ((object*) lenv) [2];
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      r2 = r2;
      if PXLL_IS_TRUE(r2) {
        r2 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L251; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L251:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        ((object****) lenv) [1][1][1][2] = r2;
      } else {
        r2 = (object *) 14;
      }
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_73;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1018;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1018;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_357;
      }
      r1=r1;
      goto fatbar_357_over;
      fatbar_357:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L252; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L252:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L253; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L253:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object****) lenv) [1][1][1][2] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object****) lenv) [1][1][1][2];
        ((object*) lenv) [2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][7];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L254; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_list_1333;
          L254:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_359;
        }
        r1=r1;
        goto fatbar_359_over;
        fatbar_359:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L255; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L255:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_360;
        }
        r1=r1;
        goto fatbar_360_over;
        fatbar_360:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L256; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L256:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_361;
        }
        r1=r1;
        goto fatbar_361_over;
        fatbar_361:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L257; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L257:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_362;
        }
        r1=r1;
        goto fatbar_362_over;
        fatbar_362:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L258; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L258:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_363;
        }
        r1=r1;
        goto fatbar_363_over;
        fatbar_363:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L259; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L259:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_364;
        }
        r1=r1;
        goto fatbar_364_over;
        fatbar_364:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L260; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L260:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_365;
        }
        r1=r1;
        goto fatbar_365_over;
        fatbar_365:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L261; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L261:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L262; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1338;
          L262:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_366;
        }
        r1=r1;
        goto fatbar_366_over;
        fatbar_366:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L263; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L263:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L264; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1338;
          L264:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_367;
        }
        r1=r1;
        goto fatbar_367_over;
        fatbar_367:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L265; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L265:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L266; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1337;
          L266:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_368;
        }
        r1=r1;
        goto fatbar_368_over;
        fatbar_368:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L267; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L267:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L268; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1337;
          L268:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_369;
        }
        r1=r1;
        goto fatbar_369_over;
        fatbar_369:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L269; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L269:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L270; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_atom_1324;
          L270:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case_noint (r1)) {
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_372;
              }
              r1=r1;
              goto fatbar_372_over;
              fatbar_372:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1019;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L271; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L271:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_373;
              }
              r1=r1;
              goto fatbar_373_over;
              fatbar_373:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1020;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L272; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L272:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_374;
              }
              r1=r1;
              goto fatbar_374_over;
              fatbar_374:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1021;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L273; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L273:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_375;
              }
              r1=r1;
              goto fatbar_375_over;
              fatbar_375:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1022;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L274; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L274:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_376;
              }
              r1=r1;
              goto fatbar_376_over;
              fatbar_376:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1023;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L275; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L275:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_377;
              }
              r1=r1;
              goto fatbar_377_over;
              fatbar_377:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1024;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L276; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L276:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_371;
              }
              r1=r1;
              fatbar_377_over: ;
              r1=r1;
              fatbar_376_over: ;
              r1=r1;
              fatbar_375_over: ;
              r1=r1;
              fatbar_374_over: ;
              r1=r1;
              fatbar_373_over: ;
              r1=r1;
              fatbar_372_over: ;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r1=r1;
          goto fatbar_371_over;
          fatbar_371:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_1025;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L277; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L277:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_371_over: ;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_370;
        }
        r1=r1;
        goto fatbar_370_over;
        fatbar_370:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_1026;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[14];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L278; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
        L278:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_370_over: ;
        r1=r1;
        fatbar_369_over: ;
        r1=r1;
        fatbar_368_over: ;
        r1=r1;
        fatbar_367_over: ;
        r1=r1;
        fatbar_366_over: ;
        r1=r1;
        fatbar_365_over: ;
        r1=r1;
        fatbar_364_over: ;
        r1=r1;
        fatbar_363_over: ;
        r1=r1;
        fatbar_362_over: ;
        r1=r1;
        fatbar_361_over: ;
        r1=r1;
        fatbar_360_over: ;
        r1=r1;
        fatbar_359_over: ;
        r1=r1;
      } else {
        goto fatbar_358;
      }
      r1=r1;
      goto fatbar_358_over;
      fatbar_358:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L279; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L279:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L280; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_atom_1324;
        L280:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = ((object*) lenv) [3];
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1027;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[14];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L281; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                L281:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = ((object*) lenv) [4];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*) lenv) [2];
                  r2[2] = r3;
                  r3 = top[79];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L282; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                  L282:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r2=r2;
                } else {
                  goto fatbar_379;
                }
                r2=r2;
                goto fatbar_379_over;
                fatbar_379:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1028;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[14];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L283; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                L283:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
                fatbar_379_over: ;
                r2=r2;
              } break;
            }
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
          } break;
        }
        r1[3] = r2;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_54[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_378;
      }
      r1=r1;
      goto fatbar_378_over;
      fatbar_378:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L284; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L284:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_1030[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L285; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1328;
        L285:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_380;
      }
      r1=r1;
      goto fatbar_380_over;
      fatbar_380:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L286; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L286:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_856[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L287; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1328;
        L287:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_381;
      }
      r1=r1;
      goto fatbar_381_over;
      fatbar_381:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L288; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L288:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1384_i455_i529
        goto L289;
        FUN_loop_1384_i455_i529:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L290; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L290:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L291; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L291:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = r0;
            ((object*) lenv) [2] = r0;
            r0 = (object *) 23554;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L292; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L292:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_384;
            }
            PXLL_RETURN(0);
            goto fatbar_384_over;
            fatbar_384:
            r0 = (object *) 8706;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L293; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L293:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_385;
            }
            PXLL_RETURN(0);
            goto fatbar_385_over;
            fatbar_385:
            r0 = (object *) 29698;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L294; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L294:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_386;
            }
            PXLL_RETURN(0);
            goto fatbar_386_over;
            fatbar_386:
            r0 = (object *) 28162;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L295; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L295:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_387;
            }
            PXLL_RETURN(0);
            goto fatbar_387_over;
            fatbar_387:
            r0 = (object *) 29186;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L296; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L296:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3330;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_388;
            }
            PXLL_RETURN(0);
            goto fatbar_388_over;
            fatbar_388:
            r0 = (object *) 22530;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L297; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L297:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L298; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1331;
              L298:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_389;
            }
            PXLL_RETURN(0);
            goto fatbar_389_over;
            fatbar_389:
            r0 = (object *) 30722;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L299; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L299:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L300; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1331;
              L300:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529;
            } else {
              goto fatbar_390;
            }
            PXLL_RETURN(0);
            goto fatbar_390_over;
            fatbar_390:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_1032;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            fatbar_390_over: ;
            PXLL_RETURN(0);
            fatbar_389_over: ;
            PXLL_RETURN(0);
            fatbar_388_over: ;
            PXLL_RETURN(0);
            fatbar_387_over: ;
            PXLL_RETURN(0);
            fatbar_386_over: ;
            PXLL_RETURN(0);
            fatbar_385_over: ;
            PXLL_RETURN(0);
            fatbar_384_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_383;
          }
          PXLL_RETURN(0);
          goto fatbar_383_over;
          fatbar_383:
          r0 = (object *) 8706;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L301; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L301:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L302; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L302:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[54];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L303; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L303:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_391;
          }
          PXLL_RETURN(0);
          goto fatbar_391_over;
          fatbar_391:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L304; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L304:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L305; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L305:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object******) lenv) [1][1][1][1][1][2] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = ((object******) lenv) [1][1][1][1][1][2];
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1384_i455_i529;
          fatbar_391_over: ;
          PXLL_RETURN(0);
          fatbar_383_over: ;
          PXLL_RETURN(0);
        L289:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1384_i455_i529; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object******) lenv) [1][1][1][1][1][2];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L306; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L306:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*****) lenv) [1][1][1][1][2] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r2 = (object *) constructed_1031[0];
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L307; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1384_i455_i529;
        L307:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_382;
      }
      r1=r1;
      goto fatbar_382_over;
      fatbar_382:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L308; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L308:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1391_i489_i529
        goto L309;
        FUN_loop_1391_i489_i529:
          check_heap (0);
          r0 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L310; ; k = t;
          lenv = r0[2]; goto FUN_skip_whitespace_1323;
          L310:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L311; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L311:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r1;
          } else {
            r1 = (object *) 14;
          }
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L312; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L312:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = (object *) constructed_41[0];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L313; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L313:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1396_i496_i529
            goto L314;
            FUN_loop_1396_i496_i529:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = top[176];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L315; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L315:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
                r0=r0;
              } else {
                r0 = (object *) 11778;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
                r0=r0;
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L316; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L316:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L317; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L317:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1396_i496_i529;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_41[0];
                r2[3] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L318; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                L318:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = top[54];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L319; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
                L319:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = top[79];
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
              }
              PXLL_RETURN(0);
            L314:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1396_i496_i529; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_1035[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = ((object*) lenv) [2];
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            r2 = r2;
            if PXLL_IS_TRUE(r2) {
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L320; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L320:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r2;
            } else {
              r2 = (object *) 14;
            }
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L321; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_loop_1396_i496_i529;
            L321:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r0 = (object *) constructed_71[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1391_i489_i529;
            } else {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L322; ; k = t;
              lenv = r0[2]; goto FUN_skip_whitespace_1323;
              L322:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L323; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L323:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r1;
              } else {
                r1 = (object *) 14;
              }
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_1034;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L324; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L324:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L325; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_read_1328;
                L325:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1391_i489_i529;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L309:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1391_i489_i529; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_1033[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L326; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1391_i489_i529;
        L326:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_392;
      }
      r1=r1;
      goto fatbar_392_over;
      fatbar_392:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][7];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L327; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_list_1333;
        L327:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_393;
      }
      r1=r1;
      goto fatbar_393_over;
      fatbar_393:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_73;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1036;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1036;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_394;
      }
      r1=r1;
      goto fatbar_394_over;
      fatbar_394:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L328; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto FUN_read_atom_1324;
      L328:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
                r2=r2;
              } else {
                r2 = (object *) 1;
                r2=r2;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1404_i517_i529
              goto L329;
              FUN_loop_1404_i517_i529:
                check_heap (0);
                r0 = ((object****) lenv) [1][1][1][4];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = ((object***) lenv) [1][1][3];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [3];
                    r1 = (object *) 1;
                    r0 = box((pxll_int)unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[166];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = top[66];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L330; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                  L330:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_1037;
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][2];
                      r0[3] = r1;
                      r1 = top[14];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = ((object****) lenv) [1][1][1][3];
                      r1 = box((pxll_int)unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][2];
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      r1 = (object *) 3;
                      r2 = ((object***) lenv) [1][1][2];
                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1404_i517_i529;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L329:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1404_i517_i529; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L331; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_loop_1404_i517_i529;
              L331:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[5] = r2;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [5];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[79];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L332; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                L332:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_395;
              }
              r1=r1;
              goto fatbar_395_over;
              fatbar_395:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][5];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[79];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L333; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                L333:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1353_i528_i529
                goto L334;
                FUN_loop_1353_i528_i529:
                  check_heap (0);
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[79];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L335; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
                          L335:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_396;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_396_over;
                      fatbar_396:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = ((object****) lenv) [1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L336; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_1353_i528_i529;
                      L336:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[79];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L337; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
                      L337:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      r1 = ((object*) lenv) [2];
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_396_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_73;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_73;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_72;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_72;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L334:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1353_i528_i529; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = ((object***) lenv) [1][1][2];
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = top[49];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L338; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_364;
                L338:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_41[0];
                r2[3] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L339; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                L339:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L340; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_loop_1353_i528_i529;
                L340:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              }
              r1=r1;
              fatbar_395_over: ;
              r1=r1;
            } break;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      fatbar_394_over: ;
      r1=r1;
      fatbar_393_over: ;
      r1=r1;
      fatbar_392_over: ;
      r1=r1;
      fatbar_382_over: ;
      r1=r1;
      fatbar_381_over: ;
      r1=r1;
      fatbar_380_over: ;
      r1=r1;
      fatbar_378_over: ;
      r1=r1;
      fatbar_358_over: ;
      r1=r1;
      fatbar_357_over: ;
      lenv = lenv[1];
      r1 = r1;
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L341; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1323;
      L341:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L342; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L342:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r0 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L343; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L343:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object*****) lenv) [1][1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L344; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1328;
        L344:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_354;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_354;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_354_over;
        fatbar_354:
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_54[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_642[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = ((object*) lenv) [6];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = ((object*) lenv) [7];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_355;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_355;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_355_over;
        fatbar_355:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_1016;
        r0[2] = r1;
        r1 = allocate (UOTAG(1), 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[1] = r2;
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_355_over: ;
        PXLL_RETURN(0);
        fatbar_354_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_353;
      }
      PXLL_RETURN(0);
      goto fatbar_353_over;
      fatbar_353:
      r0 = (object *) 23298;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L345; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L345:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object******) lenv) [1][1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L346; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1328;
        L346:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L347; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_skip_whitespace_1323;
        L347:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L348; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L348:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L349; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L349:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = ((object*) lenv) [2];
          r1=r1;
        } else {
          r1 = (object*) &constructed_73;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_1017;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_1017;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
          r1=r1;
        }
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = (object *) constructed_293[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = ((object*) lenv) [8];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = ((object*) lenv) [9];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_356;
      }
      PXLL_RETURN(0);
      goto fatbar_356_over;
      fatbar_356:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
      fatbar_356_over: ;
      PXLL_RETURN(0);
      fatbar_353_over: ;
      PXLL_RETURN(0);
    L249:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1328; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1330
    goto L350;
    FUN_read_hex_digit_1330:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[165];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[66];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L351; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L351:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_73;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1015;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1015;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L350:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1330; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1331
    goto L352;
    FUN_read_hex_code_1331:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][2];
      r2[2] = r3;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L353; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L353:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][2] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L354; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1330;
      L354:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][2];
      r2[2] = r3;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L355; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L355:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][2] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L356; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1330;
      L356:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r2 = ((object*) lenv) [4];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L352:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1331; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1333
    goto L357;
    FUN_read_list_1333:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object****) lenv) [1][1][1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L358; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L358:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object***) lenv) [1][1][2] = r0;
      r0 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1387
      goto L359;
      FUN_loop_1387:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L360; ; k = t;
        lenv = r0[2]; goto FUN_skip_whitespace_1323;
        L360:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L361; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L361:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L362; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L362:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object******) lenv) [1][1][1][1][1][2] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L363; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_read_1328;
          L363:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1387;
        }
        PXLL_RETURN(0);
      L359:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1387; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1014[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1387;
    L357:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1333; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1337
    goto L364;
    FUN_read_hex_int_1337:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L365; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L365:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L366; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L366:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1410
      goto L367;
      FUN_loop_1410:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[165];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L368; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L368:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L369; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L369:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L370; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L370:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1410;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L367:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1410; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L371; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L371:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1410;
    L364:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1337; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1338
    goto L372;
    FUN_read_oct_int_1338:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L373; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L373:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L374; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L374:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1416
      goto L375;
      FUN_loop_1416:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[167];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L376; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L376:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L377; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L377:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L378; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L378:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1416;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L375:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1416; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L379; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L379:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1416;
    L372:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1338; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1423_i665
    goto L380;
    FUN_loop_1423_i665:
      check_heap (0);
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L381; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1323;
      L381:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L382; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L382:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = (object *) constructed_41[0];
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L383; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1328;
        L383:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_1013[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[84];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L384; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_431;
                                  L384:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L385; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L385:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L386; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L386:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  r0[3] = r1;
                                  r1 = top[21];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L387; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                                  L387:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1423_i665;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_352;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_352;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_352;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_352;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_352;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_352;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_352;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_352_over;
        fatbar_352:
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1423_i665;
        fatbar_352_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L380:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1423_i665; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_1011[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [10];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1423_i665;
  L221:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reader_430; r1[2] = lenv;
  r0[83] = r1;
  // def read-file_431
  goto L388;
  FUN_read_file_431:
    check_heap (0);
    r0 = (object*) &constructed_1040;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_1040;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [2];
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[62];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L389; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_390;
    L389:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    // def lambda_6513
    goto L390;
    FUN_lambda_6513:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = top[65];
      r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_397;
    L390:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_6513; r1[2] = lenv;
    r0[3] = r1;
    r1 = (object *) 65794;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1323_i0
    goto L391;
    FUN_skip_whitespace_1323_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1344_i0
      goto L392;
      FUN_loop_1344_i0:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1342_i346_i0
            goto L393;
            FUN_loop_1342_i346_i0:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_350;
              }
              PXLL_RETURN(0);
              goto fatbar_350_over;
              fatbar_350:
              r0 = (object *) 3330;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_351;
              }
              PXLL_RETURN(0);
              goto fatbar_351_over;
              fatbar_351:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L394; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L394:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L395; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L395:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              lenv[2] = r0;
              goto FUN_loop_1342_i346_i0;
              fatbar_351_over: ;
              PXLL_RETURN(0);
              fatbar_350_over: ;
              PXLL_RETURN(0);
            L393:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1342_i346_i0; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object******) lenv) [1][1][1][1][1][4];
            r1[2] = r2;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L396; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L396:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object******) lenv) [1][1][1][1][1][4] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L397; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L397:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object****) lenv) [1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L398; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L398:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object****) lenv) [1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object****) lenv) [1][1][1][4];
            lenv[2] = r0;
            goto FUN_loop_1344_i0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = top[173];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L399; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L399:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][4];
              r0[2] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L400; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L400:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*****) lenv) [1][1][1][1][4] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object****) lenv) [1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L401; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L401:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object****) lenv) [1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object****) lenv) [1][1][1][4];
              lenv[2] = r0;
              goto FUN_loop_1344_i0;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L392:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1344_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L402; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L402:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L391:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1323_i0; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1324_i0
    goto L403;
    FUN_read_atom_1324_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1349_i0
      goto L404;
      FUN_loop_1349_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L405; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L405:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][4] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = ((object*****) lenv) [1][1][1][1][4];
        ((object***) lenv) [1][1][4] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L406; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L406:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = (object *) 7;
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_346;
        }
        r0=r0;
        goto fatbar_346_over;
        fatbar_346:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L407; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L407:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L408; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L408:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_347;
        }
        r0=r0;
        goto fatbar_347_over;
        fatbar_347:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[174];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L409; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L409:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L410; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L410:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_348;
        }
        r0=r0;
        goto fatbar_348_over;
        fatbar_348:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[175];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L411; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L411:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][4];
                r0[2] = r1;
                r1 = top[174];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L412; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L412:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                  r0=r0;
                } else {
                  r0 = (object *) 7;
                  r0=r0;
                }
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_349;
        }
        r0=r0;
        goto fatbar_349_over;
        fatbar_349:
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_72;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_72;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        r0=r0;
        fatbar_349_over: ;
        r0=r0;
        fatbar_348_over: ;
        r0=r0;
        fatbar_347_over: ;
        r0=r0;
        fatbar_346_over: ;
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][4];
          r0[2] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L413; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L413:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object******) lenv) [1][1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          lenv[2] = r0;
          goto FUN_loop_1349_i0;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_1039;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_1039;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][4];
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][3];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L414; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L414:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              ((object******) lenv) [1][1][1][1][1][4] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              ((object*) lenv) [2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(0), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L415; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L415:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = top[54];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L416; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L416:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L417; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L417:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L404:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1349_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1038[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L403:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1324_i0; r1[2] = lenv;
    r0[3] = r1;
    // def read_1328_i0
    goto L418;
    FUN_read_1328_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L419; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L419:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object*****) lenv) [1][1][1][1][4];
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = ((object*) lenv) [2];
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      r2 = r2;
      if PXLL_IS_TRUE(r2) {
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L420; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L420:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        ((object****) lenv) [1][1][1][4] = r2;
      } else {
        r2 = (object *) 14;
      }
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_73;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1018;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1018;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_306;
      }
      r1=r1;
      goto fatbar_306_over;
      fatbar_306:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L421; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L421:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L422; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L422:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object****) lenv) [1][1][1][4] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object****) lenv) [1][1][1][4];
        ((object*) lenv) [2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][7];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L423; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L423:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_308;
        }
        r1=r1;
        goto fatbar_308_over;
        fatbar_308:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L424; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L424:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_309;
        }
        r1=r1;
        goto fatbar_309_over;
        fatbar_309:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L425; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L425:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_310;
        }
        r1=r1;
        goto fatbar_310_over;
        fatbar_310:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L426; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L426:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_311;
        }
        r1=r1;
        goto fatbar_311_over;
        fatbar_311:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L427; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L427:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_312;
        }
        r1=r1;
        goto fatbar_312_over;
        fatbar_312:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L428; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L428:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_313;
        }
        r1=r1;
        goto fatbar_313_over;
        fatbar_313:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L429; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L429:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_314;
        }
        r1=r1;
        goto fatbar_314_over;
        fatbar_314:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L430; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L430:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L431; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L431:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_315;
        }
        r1=r1;
        goto fatbar_315_over;
        fatbar_315:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L432; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L432:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L433; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L433:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_316;
        }
        r1=r1;
        goto fatbar_316_over;
        fatbar_316:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L434; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L434:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L435; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L435:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_317;
        }
        r1=r1;
        goto fatbar_317_over;
        fatbar_317:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L436; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L436:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L437; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L437:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_318;
        }
        r1=r1;
        goto fatbar_318_over;
        fatbar_318:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L438; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L438:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L439; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L439:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case_noint (r1)) {
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_321;
              }
              r1=r1;
              goto fatbar_321_over;
              fatbar_321:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1019;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L440; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L440:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_322;
              }
              r1=r1;
              goto fatbar_322_over;
              fatbar_322:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1020;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L441; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L441:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_323;
              }
              r1=r1;
              goto fatbar_323_over;
              fatbar_323:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1021;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L442; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L442:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_324;
              }
              r1=r1;
              goto fatbar_324_over;
              fatbar_324:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1022;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L443; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L443:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_325;
              }
              r1=r1;
              goto fatbar_325_over;
              fatbar_325:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1023;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L444; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L444:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_326;
              }
              r1=r1;
              goto fatbar_326_over;
              fatbar_326:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1024;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L445; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L445:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_320;
              }
              r1=r1;
              fatbar_326_over: ;
              r1=r1;
              fatbar_325_over: ;
              r1=r1;
              fatbar_324_over: ;
              r1=r1;
              fatbar_323_over: ;
              r1=r1;
              fatbar_322_over: ;
              r1=r1;
              fatbar_321_over: ;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r1=r1;
          goto fatbar_320_over;
          fatbar_320:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_1025;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L446; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L446:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_320_over: ;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_319;
        }
        r1=r1;
        goto fatbar_319_over;
        fatbar_319:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_1026;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[14];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L447; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
        L447:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_319_over: ;
        r1=r1;
        fatbar_318_over: ;
        r1=r1;
        fatbar_317_over: ;
        r1=r1;
        fatbar_316_over: ;
        r1=r1;
        fatbar_315_over: ;
        r1=r1;
        fatbar_314_over: ;
        r1=r1;
        fatbar_313_over: ;
        r1=r1;
        fatbar_312_over: ;
        r1=r1;
        fatbar_311_over: ;
        r1=r1;
        fatbar_310_over: ;
        r1=r1;
        fatbar_309_over: ;
        r1=r1;
        fatbar_308_over: ;
        r1=r1;
      } else {
        goto fatbar_307;
      }
      r1=r1;
      goto fatbar_307_over;
      fatbar_307:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L448; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L448:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L449; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L449:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = ((object*) lenv) [3];
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1027;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[14];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L450; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                L450:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = ((object*) lenv) [4];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*) lenv) [2];
                  r2[2] = r3;
                  r3 = top[79];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L451; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                  L451:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r2=r2;
                } else {
                  goto fatbar_328;
                }
                r2=r2;
                goto fatbar_328_over;
                fatbar_328:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1028;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[14];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L452; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                L452:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
                fatbar_328_over: ;
                r2=r2;
              } break;
            }
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
          } break;
        }
        r1[3] = r2;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_54[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_327;
      }
      r1=r1;
      goto fatbar_327_over;
      fatbar_327:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L453; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L453:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_1030[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L454; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L454:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_329;
      }
      r1=r1;
      goto fatbar_329_over;
      fatbar_329:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L455; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L455:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_856[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L456; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L456:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_330;
      }
      r1=r1;
      goto fatbar_330_over;
      fatbar_330:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L457; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L457:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1384_i455_i529_i0
        goto L458;
        FUN_loop_1384_i455_i529_i0:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L459; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L459:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L460; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L460:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = r0;
            ((object*) lenv) [2] = r0;
            r0 = (object *) 23554;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L461; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L461:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_333;
            }
            PXLL_RETURN(0);
            goto fatbar_333_over;
            fatbar_333:
            r0 = (object *) 8706;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L462; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L462:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_334;
            }
            PXLL_RETURN(0);
            goto fatbar_334_over;
            fatbar_334:
            r0 = (object *) 29698;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L463; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L463:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_335;
            }
            PXLL_RETURN(0);
            goto fatbar_335_over;
            fatbar_335:
            r0 = (object *) 28162;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L464; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L464:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_336;
            }
            PXLL_RETURN(0);
            goto fatbar_336_over;
            fatbar_336:
            r0 = (object *) 29186;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L465; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L465:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3330;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_337;
            }
            PXLL_RETURN(0);
            goto fatbar_337_over;
            fatbar_337:
            r0 = (object *) 22530;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L466; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L466:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L467; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L467:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_338;
            }
            PXLL_RETURN(0);
            goto fatbar_338_over;
            fatbar_338:
            r0 = (object *) 30722;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L468; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L468:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L469; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L469:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1384_i455_i529_i0;
            } else {
              goto fatbar_339;
            }
            PXLL_RETURN(0);
            goto fatbar_339_over;
            fatbar_339:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_1032;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            fatbar_339_over: ;
            PXLL_RETURN(0);
            fatbar_338_over: ;
            PXLL_RETURN(0);
            fatbar_337_over: ;
            PXLL_RETURN(0);
            fatbar_336_over: ;
            PXLL_RETURN(0);
            fatbar_335_over: ;
            PXLL_RETURN(0);
            fatbar_334_over: ;
            PXLL_RETURN(0);
            fatbar_333_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_332;
          }
          PXLL_RETURN(0);
          goto fatbar_332_over;
          fatbar_332:
          r0 = (object *) 8706;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L470; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L470:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L471; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L471:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[54];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L472; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L472:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_340;
          }
          PXLL_RETURN(0);
          goto fatbar_340_over;
          fatbar_340:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L473; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L473:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object******) lenv) [1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L474; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L474:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object******) lenv) [1][1][1][1][1][4] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = ((object******) lenv) [1][1][1][1][1][4];
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1384_i455_i529_i0;
          fatbar_340_over: ;
          PXLL_RETURN(0);
          fatbar_332_over: ;
          PXLL_RETURN(0);
        L458:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1384_i455_i529_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object******) lenv) [1][1][1][1][1][4];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L475; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L475:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*****) lenv) [1][1][1][1][4] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r2 = (object *) constructed_1031[0];
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L476; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L476:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_331;
      }
      r1=r1;
      goto fatbar_331_over;
      fatbar_331:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L477; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L477:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1391_i489_i529_i0
        goto L478;
        FUN_loop_1391_i489_i529_i0:
          check_heap (0);
          r0 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L479; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L479:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L480; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L480:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r1;
          } else {
            r1 = (object *) 14;
          }
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L481; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L481:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = (object *) constructed_41[0];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L482; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L482:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1396_i496_i529_i0
            goto L483;
            FUN_loop_1396_i496_i529_i0:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = top[176];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L484; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L484:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
                r0=r0;
              } else {
                r0 = (object *) 11778;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
                r0=r0;
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L485; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L485:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L486; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L486:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r1 = ((object*) lenv) [2];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1396_i496_i529_i0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_41[0];
                r2[3] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L487; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                L487:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = top[54];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L488; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
                L488:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = top[79];
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
              }
              PXLL_RETURN(0);
            L483:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1396_i496_i529_i0; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_1035[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = ((object*) lenv) [2];
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            r2 = r2;
            if PXLL_IS_TRUE(r2) {
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L489; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L489:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r2;
            } else {
              r2 = (object *) 14;
            }
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L490; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L490:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r0 = (object *) constructed_71[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1391_i489_i529_i0;
            } else {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L491; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L491:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L492; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L492:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r1;
              } else {
                r1 = (object *) 14;
              }
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_1034;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L493; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L493:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L494; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L494:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1391_i489_i529_i0;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L478:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1391_i489_i529_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_1033[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L495; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L495:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_341;
      }
      r1=r1;
      goto fatbar_341_over;
      fatbar_341:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][7];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L496; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L496:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_342;
      }
      r1=r1;
      goto fatbar_342_over;
      fatbar_342:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_73;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1036;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1036;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_343;
      }
      r1=r1;
      goto fatbar_343_over;
      fatbar_343:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L497; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L497:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
                r2=r2;
              } else {
                r2 = (object *) 1;
                r2=r2;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1404_i517_i529_i0
              goto L498;
              FUN_loop_1404_i517_i529_i0:
                check_heap (0);
                r0 = ((object****) lenv) [1][1][1][4];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = ((object***) lenv) [1][1][3];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [3];
                    r1 = (object *) 1;
                    r0 = box((pxll_int)unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[166];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = top[66];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L499; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                  L499:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_1037;
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][2];
                      r0[3] = r1;
                      r1 = top[14];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = ((object****) lenv) [1][1][1][3];
                      r1 = box((pxll_int)unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][2];
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      r1 = (object *) 3;
                      r2 = ((object***) lenv) [1][1][2];
                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1404_i517_i529_i0;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L498:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1404_i517_i529_i0; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L500; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L500:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[5] = r2;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [5];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[79];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L501; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                L501:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_344;
              }
              r1=r1;
              goto fatbar_344_over;
              fatbar_344:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][5];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[79];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L502; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_425;
                L502:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1353_i528_i529_i0
                goto L503;
                FUN_loop_1353_i528_i529_i0:
                  check_heap (0);
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[79];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L504; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
                          L504:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_345;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_345_over;
                      fatbar_345:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = ((object****) lenv) [1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L505; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L505:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[79];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L506; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
                      L506:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      r1 = ((object*) lenv) [2];
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_345_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_73;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_73;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_72;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_72;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L503:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1353_i528_i529_i0; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = ((object***) lenv) [1][1][2];
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = top[49];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L507; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_364;
                L507:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_41[0];
                r2[3] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L508; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                L508:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L509; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L509:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              }
              r1=r1;
              fatbar_344_over: ;
              r1=r1;
            } break;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      fatbar_343_over: ;
      r1=r1;
      fatbar_342_over: ;
      r1=r1;
      fatbar_341_over: ;
      r1=r1;
      fatbar_331_over: ;
      r1=r1;
      fatbar_330_over: ;
      r1=r1;
      fatbar_329_over: ;
      r1=r1;
      fatbar_327_over: ;
      r1=r1;
      fatbar_307_over: ;
      r1=r1;
      fatbar_306_over: ;
      lenv = lenv[1];
      r1 = r1;
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L510; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L510:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L511; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L511:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][4];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L512; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L512:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object*****) lenv) [1][1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L513; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L513:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_303;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_303;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_303_over;
        fatbar_303:
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_54[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_642[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = ((object*) lenv) [6];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = ((object*) lenv) [7];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_304;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_304;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_304_over;
        fatbar_304:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_1016;
        r0[2] = r1;
        r1 = allocate (UOTAG(1), 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[1] = r2;
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_304_over: ;
        PXLL_RETURN(0);
        fatbar_303_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_302;
      }
      PXLL_RETURN(0);
      goto fatbar_302_over;
      fatbar_302:
      r0 = (object *) 23298;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L514; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L514:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object******) lenv) [1][1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L515; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L515:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L516; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L516:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L517; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L517:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L518; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L518:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = ((object*) lenv) [2];
          r1=r1;
        } else {
          r1 = (object*) &constructed_73;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_1017;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_1017;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
          r1=r1;
        }
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = (object *) constructed_293[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = ((object*) lenv) [8];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = ((object*) lenv) [9];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_305;
      }
      PXLL_RETURN(0);
      goto fatbar_305_over;
      fatbar_305:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
      fatbar_305_over: ;
      PXLL_RETURN(0);
      fatbar_302_over: ;
      PXLL_RETURN(0);
    L418:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1328_i0; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1330_i0
    goto L519;
    FUN_read_hex_digit_1330_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[165];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[66];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L520; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L520:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_73;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1015;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1015;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L519:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1330_i0; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1331_i0
    goto L521;
    FUN_read_hex_code_1331_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L522; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L522:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][4] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L523; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L523:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L524; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L524:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][4] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L525; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L525:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r2 = ((object*) lenv) [4];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L521:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1331_i0; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1333_i0
    goto L526;
    FUN_read_list_1333_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L527; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L527:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object***) lenv) [1][1][4] = r0;
      r0 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1387_i0
      goto L528;
      FUN_loop_1387_i0:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L529; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L529:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L530; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L530:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object*****) lenv) [1][1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][4];
          r0[2] = r1;
          r0 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L531; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L531:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object******) lenv) [1][1][1][1][1][4] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L532; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L532:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1387_i0;
        }
        PXLL_RETURN(0);
      L528:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1387_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1014[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L526:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1333_i0; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1337_i0
    goto L533;
    FUN_read_hex_int_1337_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L534; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L534:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L535; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L535:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1410_i0
      goto L536;
      FUN_loop_1410_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[165];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L537; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L537:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L538; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L538:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L539; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L539:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1410_i0;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L536:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1410_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L540; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L540:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L533:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1337_i0; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1338_i0
    goto L541;
    FUN_read_oct_int_1338_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L542; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L542:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L543; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L543:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1416_i0
      goto L544;
      FUN_loop_1416_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[167];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L545; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L545:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L546; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L546:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L547; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L547:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1416_i0;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L544:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1416_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L548; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L548:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L541:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1338_i0; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1423_i665_i0
    goto L549;
    FUN_loop_1423_i665_i0:
      check_heap (0);
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L550; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L550:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L551; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L551:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = (object *) constructed_41[0];
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L552; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L552:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_1013[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[84];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L553; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_431;
                                  L553:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L554; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L554:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L555; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L555:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  r0[3] = r1;
                                  r1 = top[21];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L556; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                                  L556:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1423_i665_i0;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_301;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_301;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_301;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_301;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_301;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_301;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_301;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_301_over;
        fatbar_301:
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1423_i665_i0;
        fatbar_301_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L549:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1423_i665_i0; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_1011[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [10];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L388:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_read_file_431; r1[2] = lenv;
  r0[84] = r1;
  // def sexp->symbol_433
  goto L557;
  FUN_sexp__3esymbol_433:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_300;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_300_over;
    fatbar_300:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1010;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_300_over: ;
    PXLL_RETURN(0);
  L557:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3esymbol_433; r1[2] = lenv;
  r0[85] = r1;
  // def sexp->int_434
  goto L558;
  FUN_sexp__3eint_434:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_299;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_299_over;
    fatbar_299:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1009;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_299_over: ;
    PXLL_RETURN(0);
  L558:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3eint_434; r1[2] = lenv;
  r0[86] = r1;
  // def field=?_435
  goto L559;
  FUN_field_3d_question_435:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][3];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][3];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[3] = r1;
      r1 = top[88];
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_436;
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L559:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_field_3d_question_435; r1[2] = lenv;
  r0[87] = r1;
  // def sexp=?_436
  goto L560;
  FUN_sexp_3d_question_436:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(6)): {
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UITAG(6)): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[50];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L561; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
            L561:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) 1;
            r1 = ((object*) lenv) [3];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(3)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[88];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[41];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_345;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[88];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[41];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_345;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[87];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[41];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_345;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[88];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L562; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_436;
            L562:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_298;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_298_over;
    fatbar_298:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_298_over: ;
    PXLL_RETURN(0);
  L560:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3d_question_436; r1[2] = lenv;
  r0[88] = r1;
  // def repr-field_438
  goto L563;
  FUN_repr_field_438:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = (object *) constructed_71[0];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object*) &constructed_1007;
      PXLL_RETURN(0);
    } else {
      goto fatbar_297;
    }
    PXLL_RETURN(0);
    goto fatbar_297_over;
    fatbar_297:
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 6);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object***) lenv) [1][1][2];
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    r2 = r2;
    r2=r2;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = top[90];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L564; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_repr_439;
    L564:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = (object*)TC_NIL;
    r1[4] = r2;
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[5] = r2;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_1008;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[6] = r2;
    r1 = ((object*) lenv) [6];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = top[47];
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    fatbar_297_over: ;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L563:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_field_438; r1[2] = lenv;
  r0[89] = r1;
  // def repr_439
  goto L565;
  FUN_repr_439:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[90];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L566; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L566:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_991;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L567; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L567:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_990;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_989;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r3 = (object*) &constructed_993;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_992;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L568; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L568:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_994;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case ((pxll_int)PXLL_TRUE): {
            r0 = (object*) &constructed_995;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_996;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[56];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
      } break;
      case (UITAG(6)): {
        r0 = (object*) &constructed_997;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[90];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L569; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L569:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1000;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L570; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L570:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_999;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_998;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[89];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L571; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L571:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1003;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L572; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L572:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_1002;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_1001;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_54[0];
        r3 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
          r2 = (object*) &constructed_1005;
          r2=r2;
        } else {
          r2 = ((object**) lenv) [1][2];
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2 = r2;
          r2=r2;
          r2=r2;
        }
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_1004;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[90];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L573; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_repr_439;
        L573:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_1006;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
    }
    PXLL_RETURN(0);
  L565:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_439; r1[2] = lenv;
  r0[90] = r1;
  // def indent_440
  goto L574;
  FUN_indent_440:
    check_heap (0);
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 262;
      PXLL_RETURN(0);
    } else {
      goto fatbar_296;
    }
    PXLL_RETURN(0);
    goto fatbar_296_over;
    fatbar_296:
    r0 = (object*) &constructed_988;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_988;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 3;
    r2 = ((object*) lenv) [2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = top[91];
    r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
    fatbar_296_over: ;
    PXLL_RETURN(0);
  L574:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_indent_440; r1[2] = lenv;
  r0[91] = r1;
  // def pp-size-field_441
  goto L575;
  FUN_pp_size_field_441:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 7);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[5] = r1;
    r1 = (object *) 3;
    r2 = ((object*) lenv) [5];
    r1 = box((pxll_int)unbox(r2)+unbox(r1));
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = top[93];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L576; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_442;
    L576:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r0 = ((object*) lenv) [7];
    r1 = ((object*) lenv) [6];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L575:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_field_441; r1[2] = lenv;
  r0[92] = r1;
  // def pp-size_442
  goto L577;
  FUN_pp_size_442:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[12];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L578; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L578:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = (object *) 3;
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[93];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L579; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L579:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[38];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_342;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 5;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(3),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = top[90];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L580; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_repr_439;
        L580:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[56];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L581; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_int__3estring_374;
        L581:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[12];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L582; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L582:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = (object *) 5;
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[93];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L583; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L583:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[38];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_342;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[12];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L584; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L584:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[92];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L585; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L585:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[38];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_342;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 8);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[5] = r1;
        r1 = ((object*) lenv) [3];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][3];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [5];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        r0[8] = r1;
        r0 = ((object*) lenv) [8];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[93];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L586; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_442;
        L586:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object*) lenv) [3];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][3];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [4];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        r0[7] = r1;
        r0 = ((object*) lenv) [7];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L577:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_442; r1[2] = lenv;
  r0[93] = r1;
  // def pp_443
  goto L587;
  FUN_pp_443:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[93];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L588; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_442;
    L588:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 161;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][3];
      r1[2] = r2;
      r2 = top[90];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L589; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_439;
      L589:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    } else {
      r0 = ((object**) lenv) [1][3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_985;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_985;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = (object*) &constructed_987;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_987;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[94];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L590; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_pp_443;
              L590:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7288
              goto L591;
              FUN_lambda_7288:
                check_heap (0);
                r0 = (object *) 2562;
                box((pxll_int)fputc (GET_CHAR(r0), stdout));
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 3;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = top[91];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L592; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
                L592:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) 3;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[94];
                r0[1] = r1[2]; lenv = r0; goto FUN_pp_443;
              L591:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7288; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = top[35];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L593; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
              L593:
              ; lenv = k[2]; k = k[1];
              r0 = (object*) &constructed_986;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_986;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_295;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_295_over;
      fatbar_295:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][3];
      r1[2] = r2;
      r2 = top[90];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L594; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_439;
      L594:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
      fatbar_295_over: ;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L587:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_443; r1[2] = lenv;
  r0[94] = r1;
  // def matches-list?_445
  goto L595;
  FUN_matches_list_question_445:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_293;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_71[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 3);
                      // def lambda_7378
                      goto L596;
                      FUN_lambda_7378:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object****) lenv) [1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[3] = r1;
                        r1 = top[96];
                        r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_447;
                      L596:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN_lambda_7378; r1[2] = lenv;
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][3];
                      r0[3] = r1;
                      r1 = top[40];
                      r0[1] = r1[2]; lenv = r0; goto FUN_every_question_344;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_294;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_294;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_294;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_294;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_294_over;
        fatbar_294:
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[96];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L597; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_447;
            L597:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_matches_list_question_445;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_293;
          }
        }
        PXLL_RETURN(0);
        fatbar_294_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_293_over;
    fatbar_293:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_293_over: ;
    PXLL_RETURN(0);
  L595:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_list_question_445; r1[2] = lenv;
  r0[95] = r1;
  // def matches-pattern?_447
  goto L598;
  FUN_matches_pattern_question_447:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object***) lenv) [1][1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[2] = r1;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = (object *) 15362;
        r1 = ((object*) lenv) [3];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object**) lenv) [1][3];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r1 = box((pxll_int)((pxll_string*)(r1))->len);
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 3;
              r2 = ((object**) lenv) [1][4];
              r1 = box((pxll_int)unbox(r2)-unbox(r1));
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][3];
              range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][3];
              r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
              r0[3] = r1;
              r0 = (object *) 15874;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 4);
                r2 = ((object**) lenv) [1][3];
                r1[2] = r2;
                r2 = (object *) 3;
                r1[3] = r2;
                r2 = (object *) 3;
                r3 = ((object**) lenv) [1][4];
                r2 = box((pxll_int)unbox(r3)-unbox(r2));
                r1[4] = r2;
                r2 = top[45];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L599; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
                L599:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object*) lenv) [3];
                r1[3] = r2;
                r2 = top[50];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L600; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
                L600:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = (object *) 1;
                r1 = ((object*) lenv) [4];
                r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 262;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_292;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_292_over;
          fatbar_292:
          r0 = (object *) 6;
          PXLL_RETURN(0);
          fatbar_292_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[95];
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_list_question_445;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_291;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_291;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_291_over;
    fatbar_291:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
    fatbar_291_over: ;
    PXLL_RETURN(0);
  L598:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_pattern_question_447; r1[2] = lenv;
  r0[96] = r1;
  // def get-ellipsis-nestings_448
  goto L601;
  FUN_get_ellipsis_nestings_448:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1536
    goto L602;
    FUN_dolist_1536:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_71[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object****) lenv) [1][1][1][2];
                        r1[2] = r2;
                        r2 = top[97];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L603; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_448;
                        L603:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = (object*)TC_NIL;
                        r0[4] = r1;
                        r0 = ((object*) lenv) [4];
                        r1 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_290;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_290;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_290;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_290;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_290_over;
          fatbar_290:
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[97];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L604; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_448;
          L604:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L605; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1536;
          L605:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L606; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L606:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          fatbar_290_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_289;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_289_over;
      fatbar_289:
      r0 = (object *) constructed_984[0];
      PXLL_RETURN(0);
      fatbar_289_over: ;
      PXLL_RETURN(0);
    L602:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1536; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1536;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_288;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_288_over;
    fatbar_288:
    r0 = (object *) constructed_983[0];
    PXLL_RETURN(0);
    fatbar_288_over: ;
    PXLL_RETURN(0);
  L601:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_ellipsis_nestings_448; r1[2] = lenv;
  r0[97] = r1;
  // def intersect?_449
  goto L607;
  FUN_intersect_question_449:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_287;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_7642
            goto L608;
            FUN_lambda_7642:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7638
              goto L609;
              FUN_lambda_7638:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[98];
                r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_449;
              L609:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7638; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[39];
              r0[1] = r1[2]; lenv = r0; goto FUN_some_question_343;
            L608:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_7642; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[39];
            r0[1] = r1[2]; lenv = r0; goto FUN_some_question_343;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_287;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_287;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_287_over;
    fatbar_287:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_287_over: ;
    PXLL_RETURN(0);
  L607:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_intersect_question_449; r1[2] = lenv;
  r0[98] = r1;
  // def ellipsis-sub-envs_450
  goto L610;
  FUN_ellipsis_sub_envs_450:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_981[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r0[3] = r1;
                        r1 = top[98];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L611; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_449;
                        L611:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        if PXLL_IS_TRUE(r0) {
                          r0 = ((object*) lenv) [2];
                          PXLL_RETURN(0);
                        } else {
                          r0 = ((object****) lenv) [1][1][1][3];
                          r1 = ((object*****) lenv) [1][1][1][1][2];
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_ellipsis_sub_envs_450;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_286;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_286;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_286;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_286;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_286_over;
    fatbar_286:
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_982;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_982;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_286_over: ;
    PXLL_RETURN(0);
  L610:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_ellipsis_sub_envs_450; r1[2] = lenv;
  r0[99] = r1;
  // def get-bindings_451
  goto L612;
  FUN_get_bindings_451:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1564
    goto L613;
    FUN_dolist_1564:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_71[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 10);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object****) lenv) [1][1][1][2];
                        r1[2] = r2;
                        r2 = top[97];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L614; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_448;
                        L614:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        // def lambda_7758
                        goto L615;
                        FUN_lambda_7758:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object******) lenv) [1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[100];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L616; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_451;
                          L616:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(0),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L615:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_7758; r2[2] = lenv;
                        r1[2] = r2;
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[3] = r2;
                        r2 = top[32];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L617; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                        L617:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r1 = ((object*) lenv) [4];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[5] = r1;
                        r1 = (object*)TC_NIL;
                        r0[6] = r1;
                        r1 = ((object*) lenv) [6];
                        r2 = ((object*) lenv) [5];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[7] = r1;
                        r1 = ((object*) lenv) [7];
                        r2 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[8] = r1;
                        r1 = ((object*) lenv) [8];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[9] = r1;
                        r1 = (object*)TC_NIL;
                        r0[10] = r1;
                        r0 = ((object*) lenv) [10];
                        r1 = ((object*) lenv) [9];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_285;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_285;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_285;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_285;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_285_over;
          fatbar_285:
          r0 = ((object**) lenv) [1][3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object*) lenv) [2];
              r1[3] = r2;
              r2 = top[100];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L618; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_451;
              L618:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = ((object*) lenv) [3];
              r1[3] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L619; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1564;
              L619:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [4];
              r1[2] = r2;
              r2 = (object *) constructed_41[0];
              r1[3] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L620; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
              L620:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object*) lenv) [5];
              r0[3] = r1;
              r1 = top[21];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_284;
            }
          }
          PXLL_RETURN(0);
          fatbar_285_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_284;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_284_over;
      fatbar_284:
      r0 = (object *) constructed_980[0];
      PXLL_RETURN(0);
      fatbar_284_over: ;
      PXLL_RETURN(0);
    L613:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1564; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = ((object***) lenv) [1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = (object*)TC_NIL;
        r0[7] = r1;
        r0 = ((object*) lenv) [7];
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1564;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_283;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_283;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_283_over;
    fatbar_283:
    r0 = (object *) constructed_979[0];
    PXLL_RETURN(0);
    fatbar_283_over: ;
    PXLL_RETURN(0);
  L612:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_bindings_451; r1[2] = lenv;
  r0[100] = r1;
  // def expand-pattern_453
  goto L621;
  FUN_expand_pattern_453:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[102];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L622; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_454;
        L622:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1580_i800
        goto L623;
        FUN_loop_1580_i800:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = ((object**) lenv) [1][2];
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                    r0 = ((object*) lenv) [2];
                                    t = alloc_no_clear (UOTAG(0),1);
                                    t[1] = r0;
                                    r0 = t;
                                    PXLL_RETURN(0);
                                  } else {
                                    r0 = ((object*****) lenv) [1][1][1][1][3];
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    lenv[2] = r0;
                                    goto FUN_loop_1580_i800;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_282;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_282;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_282;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_282;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_282;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_282_over;
              fatbar_282:
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_1580_i800;
              fatbar_282_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L623:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1580_i800; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L624; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1580_i800;
        L624:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = ((object**) lenv) [1][2];
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_281;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_281_over;
    fatbar_281:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_281_over: ;
    PXLL_RETURN(0);
  L621:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_pattern_453; r1[2] = lenv;
  r0[101] = r1;
  // def expand-list_454
  goto L625;
  FUN_expand_list_454:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sexp/append_1598
    goto L626;
    FUN_sexp_2fappend_1598:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L627; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L627:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          goto fatbar_280;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_280_over;
      fatbar_280:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_978;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_978;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_280_over: ;
      PXLL_RETURN(0);
    L626:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sexp_2fappend_1598; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_71[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 5);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = top[97];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L628; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_448;
                  L628:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [2];
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = top[99];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L629; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_ellipsis_sub_envs_450;
                  L629:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      // def lambda_8032
                      goto L630;
                      FUN_lambda_8032:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*) lenv) [2];
                        r1[2] = r2;
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[3] = r2;
                        r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L631; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_2fappend_1598;
                        L631:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = top[101];
                        r0[1] = r1[2]; lenv = r0; goto FUN_expand_pattern_453;
                      L630:
                      r2 = allocate (TC_CLOSURE, 2);
                      r2[1] = &&FUN_lambda_8032; r2[2] = lenv;
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[32];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L632; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                      L632:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_279;
                    }
                  }
                  r1=r1;
                  goto fatbar_279_over;
                  fatbar_279:
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_977;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [3];
                  r1[3] = r2;
                  r2 = top[14];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L633; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                  L633:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                  fatbar_279_over: ;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object***) lenv) [1][1][3];
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = top[102];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L634; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_454;
                  L634:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[5] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [4];
                  r1[2] = r2;
                  r2 = (object *) constructed_41[0];
                  r1[3] = r2;
                  r2 = top[21];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L635; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                  L635:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [5];
                  r0[3] = r1;
                  r1 = top[21];
                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_278;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_278;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_278;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_278_over;
        fatbar_278:
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[101];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L636; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_453;
        L636:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[102];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L637; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_454;
        L637:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_278_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_277;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_277_over;
    fatbar_277:
    r0 = ((object**) lenv) [1][2];
    PXLL_RETURN(0);
    fatbar_277_over: ;
    PXLL_RETURN(0);
  L625:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_list_454; r1[2] = lenv;
  r0[102] = r1;
  // def pred_457
  goto L638;
  FUN_pred_457:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (UOTAG(23), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][3];
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L638:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pred_457; r1[2] = lenv;
  r0[103] = r1;
  // def new-tvar_459
  goto L639;
  FUN_new_tvar_459:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[177];
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L640; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L640:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (UOTAG(23), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L639:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_tvar_459; r1[2] = lenv;
  r0[104] = r1;
  // def rlabel_464
  goto L641;
  FUN_rlabel_464:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_805[0];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = (object*)TC_NIL;
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r3 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r3 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = top[103];
    r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
  L641:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_rlabel_464; r1[2] = lenv;
  r0[105] = r1;
  // def type-repr_468
  goto L642;
  FUN_type_repr_468:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L643; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L643:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_969;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_99[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 6);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object**) lenv) [1][2];
                      r2[2] = r3;
                      r3 = top[106];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L644; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_468;
                      L644:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object***) lenv) [1][1][2];
                      r2[2] = r3;
                      r3 = top[106];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L645; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_468;
                      L645:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = ((object*) lenv) [4];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = ((object*) lenv) [5];
                      r3 = (object*) &constructed_970;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r1 = ((object*) lenv) [6];
                      r2 = ((object*) lenv) [2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      lenv = lenv[1];
                      r1 = r1;
                      r0[2] = r1;
                      r1 = top[47];
                      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_275;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_275;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_275_over;
              fatbar_275:
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 7);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = top[106];
              r3[2] = r4;
              r4 = ((object**) lenv) [1][3];
              r3[3] = r4;
              r4 = top[32];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L646; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
              L646:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = (object*) &constructed_973;
              r2[3] = r3;
              r3 = top[48];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L647; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
              L647:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = top[106];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L648; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_468;
              L648:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = (object*) &constructed_972;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = ((object*) lenv) [6];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r1 = ((object*) lenv) [7];
              r2 = (object*) &constructed_971;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = top[47];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
              fatbar_275_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_274;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_274;
        }
        PXLL_RETURN(0);
        goto fatbar_274_over;
        fatbar_274:
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_276;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_276_over;
        fatbar_276:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[106];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][3];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L649; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L649:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_976;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L650; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L650:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = (object*) &constructed_975;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = (object*) &constructed_974;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_276_over: ;
        PXLL_RETURN(0);
        fatbar_274_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L642:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_repr_468; r1[2] = lenv;
  r0[106] = r1;
  // def type->trec_470
  goto L651;
  FUN_type__3etrec_470:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L651:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type__3etrec_470; r1[2] = lenv;
  r0[107] = r1;
  // def type-find_471
  goto L652;
  FUN_type_find_471:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[107];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L653; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_470;
    L653:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = ((object**) lenv) [1][2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[108];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L654; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
        L654:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L652:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_find_471; r1[2] = lenv;
  r0[108] = r1;
  // def type-union_472
  goto L655;
  FUN_type_union_472:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[108];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L656; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
    L656:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[108];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L657; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
    L657:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = ((object**) lenv) [1][3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L655:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_union_472; r1[2] = lenv;
  r0[109] = r1;
  // def parse-type*_473
  goto L658;
  FUN_parse_type_splat_473:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    // def arrow-type?_1687
    goto L659;
    FUN_arrow_type_question_1687:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_648[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 262;
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_273;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_273;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_273_over;
          fatbar_273:
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_arrow_type_question_1687;
          fatbar_273_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L659:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_arrow_type_question_1687; r1[2] = lenv;
    r0[2] = r1;
    // def parse-list_1690
    goto L660;
    FUN_parse_list_1690:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_856[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1[2] = r2;
                            r2 = ((object**) lenv) [1][2];
                            r1[3] = r2;
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L661; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto *r2[1];
                            L661:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(0)): {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r0 = ((object*) lenv) [2];
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = top[104];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L662; t[4] = r0; k = t;
                                lenv = r1[2]; goto FUN_new_tvar_459;
                                L662:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                                r0[2] = r1;
                                r1 = ((object***) lenv) [1][1][2];
                                r0[3] = r1;
                                r1 = ((object*) lenv) [2];
                                r0[4] = r1;
                                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L663; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L663:
                                ; lenv = k[2]; k = k[1];
                                r0 = ((object*) lenv) [2];
                                PXLL_RETURN(0);
                              } break;
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_270;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_270;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_270;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_270_over;
                fatbar_270:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_965;
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                fatbar_270_over: ;
                PXLL_RETURN(0);
              } else {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_269;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_269;
            }
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_269;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_269_over;
      fatbar_269:
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L664; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_arrow_type_question_1687;
      L664:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1702_i863
        goto L665;
        FUN_loop_1702_i863:
          check_heap (0);
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_648[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object**) lenv) [1][2];
                            r1[2] = r2;
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L666; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_parse_1692;
                            L666:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*****) lenv) [1][1][1][1][2];
                            r1[2] = r2;
                            r2 = (object *) constructed_41[0];
                            r1[3] = r2;
                            r2 = top[21];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L667; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                            L667:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = (object *) constructed_99[0];
                            r0[2] = r1;
                            r1 = ((object*) lenv) [3];
                            r2 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                            r0[3] = r1;
                            r1 = top[103];
                            r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_271;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_271;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_271;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_271;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_271_over;
              fatbar_271:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L668; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_parse_1692;
              L668:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1702_i863;
              fatbar_271_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_967;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              r0[3] = r1;
              r1 = top[14];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            } break;
          }
          PXLL_RETURN(0);
        L665:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1702_i863; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_966[0];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1702_i863;
      } else {
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][5];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = top[32];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L669; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                L669:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = top[103];
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_272;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_272;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_272_over;
        fatbar_272:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_968;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_272_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_269_over: ;
      PXLL_RETURN(0);
    L660:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_list_1690; r1[2] = lenv;
    r0[3] = r1;
    // def parse-field-list_1691
    goto L670;
    FUN_parse_field_list_1691:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_71[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = top[104];
                lenv = r0[2]; goto FUN_new_tvar_459;
              } break;
              default: {
                goto fatbar_268;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_268;
          }
          PXLL_RETURN(0);
          goto fatbar_268_over;
          fatbar_268:
          r0 = allocate (TC_TUPLE, 4);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_540[0];
          r1[3] = r2;
          r2 = top[103];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L671; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
          L671:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object**) lenv) [1][3];
          r2[2] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][5];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L672; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_parse_1692;
          L672:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_537[0];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[3] = r2;
          r2 = top[103];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L673; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
          L673:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L674; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1691;
          L674:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = top[105];
          r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_464;
          fatbar_268_over: ;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_554[0];
          r1[2] = r2;
          r2 = (object *) constructed_552[0];
          r1[3] = r2;
          r2 = top[103];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L675; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
          L675:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_551[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = top[103];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
        } break;
      }
      PXLL_RETURN(0);
    L670:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_field_list_1691; r1[2] = lenv;
    r0[4] = r1;
    // def parse_1692
    goto L676;
    FUN_parse_1692:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[184];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[66];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L677; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L677:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = (object *) constructed_963[0];
              r0[3] = r1;
              r1 = top[103];
              r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
            } break;
          }
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_parse_list_1690;
        } break;
        case (UOTAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L678; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1691;
          L678:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_547[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = top[103];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
        } break;
        default: {
          goto fatbar_267;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_267_over;
      fatbar_267:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_964;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_267_over: ;
      PXLL_RETURN(0);
    L676:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_1692; r1[2] = lenv;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[1] = r1[2]; lenv = r0; goto FUN_parse_1692;
  L658:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_type_splat_473; r1[2] = lenv;
  r0[110] = r1;
  // def get-record-sig_475
  goto L679;
  FUN_get_record_sig_475:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_547[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_1738
                  goto L680;
                  FUN_loop_1738:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_551[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_265;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_265_over;
                        fatbar_265:
                        r0 = (object *) constructed_803[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = ((object****) lenv) [1][1][1][3];
                                      r1 = ((object*) lenv) [2];
                                      lenv = ((object ***)lenv)[1][1][1];
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN_loop_1738;
                                    } break;
                                    default: {
                                      lenv = ((object **)lenv)[1][1];
                                      goto fatbar_266;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_266;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_266;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_266;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_266_over;
                        fatbar_266:
                        r0 = (object *) constructed_805[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = (object *) constructed_537[0];
                                          r1 = ((object*) lenv) [2];
                                          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                            r0 = ((object**) lenv) [1][3];
                                            switch (get_case (r0)) {
                                              case (TC_PAIR): {
                                                r0 = allocate (TC_TUPLE, 3);
                                                r0[1] = lenv; lenv = r0;
                                                r1 = ((object***) lenv) [1][1][3];
                                                r1 = UOBJ_GET(r1,0);
                                                r0[2] = r1;
                                                r1 = ((object***) lenv) [1][1][3];
                                                r1 = UOBJ_GET(r1,1);
                                                r0[3] = r1;
                                                r0 = ((object*) lenv) [3];
                                                switch (get_case (r0)) {
                                                  case (TC_NIL): {
                                                    r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                    r1 = ((object****) lenv) [1][1][1][2];
                                                    t = alloc_no_clear (TC_PAIR,2);
                                                    t[1] = r1;
                                                    t[2] = r0;
                                                    r0 = t;
                                                    r1 = ((object*) lenv) [2];
                                                    lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                    lenv[2] = r1;
                                                    lenv[3] = r0;
                                                    goto FUN_loop_1738;
                                                  } break;
                                                  default: {
                                                    lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                    goto fatbar_264;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } break;
                                              default: {
                                                lenv = ((object *****)lenv)[1][1][1][1][1];
                                                goto fatbar_264;
                                              }
                                            }
                                            PXLL_RETURN(0);
                                          } else {
                                            lenv = ((object *****)lenv)[1][1][1][1][1];
                                            goto fatbar_264;
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object ****)lenv)[1][1][1][1];
                                          goto fatbar_264;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_264;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_264;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_264;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_264;
                        }
                        PXLL_RETURN(0);
                        fatbar_266_over: ;
                        PXLL_RETURN(0);
                        fatbar_265_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = ((object*) lenv) [3];
                        r1 = (object *) constructed_71[0];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                    goto fatbar_264_over;
                    fatbar_264:
                    r0 = (object *) constructed_959[0];
                    PXLL_RETURN(0);
                    fatbar_264_over: ;
                    PXLL_RETURN(0);
                  L680:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_1738; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = (object *) constructed_958[0];
                  r1[3] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L681; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_1738;
                  L681:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = top[80];
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = top[44];
                  r0[1] = r1[2]; lenv = r0; goto FUN_sort_350;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_263;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_263;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_263;
        }
        PXLL_RETURN(0);
        goto fatbar_263_over;
        fatbar_263:
        r0 = (object *) constructed_803[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = ((object*) lenv) [2];
                      lenv[2] = r0;
                      goto FUN_get_record_sig_475;
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_262;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_262;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_262;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_262;
        }
        PXLL_RETURN(0);
        fatbar_263_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_262;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_262_over;
    fatbar_262:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 5);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object***) lenv) [1][1][2];
    r3[2] = r4;
    r4 = top[106];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L682; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_468;
    L682:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_962;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_961;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L683; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L683:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_960;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_262_over: ;
    PXLL_RETURN(0);
  L679:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_record_sig_475; r1[2] = lenv;
  r0[111] = r1;
  // def make-counter_478
  goto L684;
  FUN_make_counter_478:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def inc_1768
    goto L685;
    FUN_inc_1768:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      ((object***) lenv) [1][1][2] = r0;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    L685:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_inc_1768; r1[2] = lenv;
    r0[2] = r1;
    // def get_1769
    goto L686;
    FUN_get_1769:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
    L686:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_get_1769; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (UOTAG(22), 2);
    r1 = ((object*) lenv) [3];
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L684:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_counter_478; r1[2] = lenv;
  r0[112] = r1;
  // def new-match-var_482
  goto L687;
  FUN_new_match_var_482:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = top[187];
    r4 = ((pxll_vector*)r4)->val[1];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L688; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    lenv = r4[2]; goto *r4[1];
    L688:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[2] = r4;
    r4 = top[56];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L689; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
    L689:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_957;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L690; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L690:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = top[79];
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
  L687:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_match_var_482; r1[2] = lenv;
  r0[113] = r1;
  // def notdotdotdot_483
  goto L691;
  FUN_notdotdotdot_483:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = (object *) constructed_71[0];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    } else {
      lenv = ((object *)lenv)[1];
      goto fatbar_261;
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    goto fatbar_261_over;
    fatbar_261:
    r0 = (object *) 262;
    PXLL_RETURN(0);
    fatbar_261_over: ;
    PXLL_RETURN(0);
  L691:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_notdotdotdot_483; r1[2] = lenv;
  r0[114] = r1;
  // def compile-pattern_484
  goto L692;
  FUN_compile_pattern_484:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 20);
    r0[1] = lenv; lenv = r0;
    // def remove-first-pat_1796
    goto L693;
    FUN_remove_first_pat_1796:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_260;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_260_over;
      fatbar_260:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_956;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_956;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_260_over: ;
      PXLL_RETURN(0);
    L693:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_remove_first_pat_1796; r1[2] = lenv;
    r0[2] = r1;
    // def first-pattern-kind_1797
    goto L694;
    FUN_first_pattern_kind_1797:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) constructed_854[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(1)): {
              r0 = (object *) constructed_950[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(2)): {
              r0 = (object *) constructed_471[0];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = (object *) constructed_944[0];
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_259;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_259_over;
      fatbar_259:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_955;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_955;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_259_over: ;
      PXLL_RETURN(0);
    L694:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_pattern_kind_1797; r1[2] = lenv;
    r0[3] = r1;
    // def compare-first-patterns_1798
    goto L695;
    FUN_compare_first_patterns_1798:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L696; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1797;
      L696:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L697; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1797;
      L697:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      PXLL_RETURN(0);
    L695:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compare_first_patterns_1798; r1[2] = lenv;
    r0[4] = r1;
    // def compile-match_1799
    goto L698;
    FUN_compile_match_1799:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object*) lenv) [4];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_258;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_258_over;
      fatbar_258:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][4];
      r1[3] = r2;
      r2 = top[42];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L699; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pack_347;
      L699:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[22];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L700; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
      L700:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L701; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L701:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][6];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1800;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10072
        goto L702;
        FUN_lambda_10072:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L703; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1800;
          L703:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object***) lenv) [1][1][4] = r0;
          PXLL_RETURN(0);
        L702:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10072; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) constructed_41[0];
        r1[3] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L704; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
        L704:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[35];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L705; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L705:
        ; lenv = k[2]; k = k[1];
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_258_over: ;
      PXLL_RETURN(0);
    L698:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_match_1799; r1[2] = lenv;
    r0[5] = r1;
    // def compile-group_1800
    goto L706;
    FUN_compile_group_1800:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[19];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L707; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
      L707:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L708; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1797;
      L708:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) constructed_944[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object****) lenv) [1][1][1][3];
        r3[2] = r4;
        r4 = top[19];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L709; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_319;
        L709:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object**) lenv) [1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L710; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L710:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][9];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object*) lenv) [2];
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L711; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1806;
        L711:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L712; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L712:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10346_i925
        goto L713;
        FUN_lambda_10346_i925:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2 = r2;
          r2=r2;
          r1[2] = r2;
          r2 = top[19];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L714; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
          L714:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][9];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][11];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L715; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1806;
          L715:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L716; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L716:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = top[13];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][3];
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = top[41];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L717; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_every2_question_345;
          L717:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [4];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_942;
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L713:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10346_i925; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = top[20];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L718; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
        L718:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[35];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L719; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L719:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 13);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = top[27];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L720; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
        L720:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10376_i925
        goto L721;
        FUN_lambda_10376_i925:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object****) lenv) [1][1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_941;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L722; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L722:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[79];
          r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
        L721:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10376_i925; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L723; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L723:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10405_i925
        goto L724;
        FUN_lambda_10405_i925:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][10];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object*) lenv) [2];
          r3[2] = r4;
          r4 = top[19];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L725; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_car_319;
          L725:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = ((object*******) lenv) [1][1][1][1][1][1][11];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L726; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1806;
          L726:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L727; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L727:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L728; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
          L728:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [3];
          r2[2] = r3;
          r3 = (object *) constructed_41[0];
          r2[3] = r3;
          r3 = top[21];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L729; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
          L729:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L730; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L730:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = UOBJ_GET(r2,1);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
          r0[6] = r1;
          r0 = ((object*) lenv) [6];
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        L724:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10405_i925; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L731; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L731:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L732; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L732:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_1927_i925
        goto L733;
        FUN__24loop_1927_i925:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][5];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [3];
            r0[2] = r1;
            r1 = (object *) constructed_41[0];
            r0[3] = r1;
            r1 = top[21];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          } else {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L734; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L734:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L735; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L735:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (UOTAG(10),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = (object*)TC_NIL;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [6];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = ((object*) lenv) [9];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [10];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_1927_i925;
          }
          PXLL_RETURN(0);
        L733:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_1927_i925; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L736; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1927_i925;
        L736:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[6] = r1;
        r1 = (object *) constructed_610[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object*****) lenv) [1][1][1][1][2];
        r3[2] = r4;
        r4 = top[20];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L737; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_320;
        L737:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][3];
        r3[2] = r4;
        r4 = (object *) constructed_41[0];
        r3[3] = r4;
        r4 = top[21];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L738; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
        L738:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object*) lenv) [2];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L739; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L739:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = ((object*) lenv) [4];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        r1[4] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][5];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L740; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1799;
        L740:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[9] = r1;
        r1 = (object*)TC_NIL;
        r0[10] = r1;
        r1 = ((object*) lenv) [10];
        r2 = ((object*) lenv) [9];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[11] = r1;
        r1 = ((object*) lenv) [11];
        r2 = ((object*) lenv) [8];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[12] = r1;
        r1 = ((object*) lenv) [12];
        r2 = ((object*) lenv) [7];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[13] = r1;
        r0 = ((object*) lenv) [13];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_252;
      }
      PXLL_RETURN(0);
      goto fatbar_252_over;
      fatbar_252:
      r0 = (object *) constructed_471[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object***) lenv) [1][1][3];
        r2[2] = r3;
        r3 = top[19];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L741; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
        L741:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][18];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L742; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_rule__3econstructor_dt_1817;
        L742:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][18];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][14];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L743; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_collect_1813;
        L743:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[69];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L744; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_410;
        L744:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L745; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L745:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object *) 3;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(unbox(r3)==unbox(r2));
        r1[3] = r2;
        r1 = (object *) 6;
        r2 = ((object*) lenv) [3];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_948;
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L746; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L746:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        } else {
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object****) lenv) [1][1][1][19];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L747; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_collect_1813;
          L747:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        }
        r0[5] = r1;
        r1 = (object *) 1;
        r0[6] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][3];
        r3[2] = r4;
        r4 = top[19];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L748; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_319;
        L748:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][18];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L749; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_rule__3econstructor_dt_1817;
        L749:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L750; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L750:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][4];
        r1[2] = r2;
        r2 = top[185];
        r1[3] = r2;
        r2 = top[88];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L751; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_3d_question_436;
        L751:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object***) lenv) [1][1][4];
          r1=r1;
        } else {
          r1 = top[186];
          r1=r1;
        }
        r0[8] = r1;
        r1 = (object *) constructed_947[0];
        r0[9] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_11067_i963
        goto L752;
        FUN_lambda_11067_i963:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][7];
          switch (get_case (r1)) {
            case (UITAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object***) lenv) [1][1][3];
              r5 = ((pxll_vector*)r5)->val[4];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L753; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              lenv = r5[2]; goto *r5[1];
              L753:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object**) lenv) [1][2];
              r5 = UOBJ_GET(r5,0);
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              lenv = lenv[1];
              r4 = r4;
              r4=r4;
              lenv = lenv[1];
              r4 = r4;
              r3[2] = r4;
              r4 = top[19];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L754; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_car_319;
              L754:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = ((object******) lenv) [1][1][1][1][1][17];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L755; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3esubs_1816;
              L755:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L756; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L756:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } break;
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object****) lenv) [1][1][1][7];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object***) lenv) [1][1][2];
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r3 = ((pxll_vector*)r3)->val[1];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L757; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L757:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = ((object*) lenv) [3];
              r1 = ((pxll_vector*)r1)->val[0];
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[113];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L758; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1822;
          L758:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          ensure_heap (1, unbox(r1));
          r1 = (object *) 262;
          r2 = ((object*) lenv) [2];
          if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
            t = alloc_no_clear (TC_VECTOR, unbox(r2));
            for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
            r1 = t;
          }
          r0[4] = r1;
          r1 = (object *) constructed_946[0];
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def frob-rule_1988_i963
          goto L759;
          FUN_frob_rule_1988_i963:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[19];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L760; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
            L760:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][17];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L761; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1816;
            L761:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L762; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L762:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            r0[3] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [3];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_945;
              r0[2] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
              r0[3] = r1;
              r1 = top[14];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L763; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              L763:
              ; lenv = k[2]; k = k[1];
              r0 = result;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[19];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L764; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
            L764:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][17];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L765; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1816;
            L765:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[20];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L766; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
            L766:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L767; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L767:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L768; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L768:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][5];
            r1 = ((object*) lenv) [5];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object****) lenv) [1][1][1][5] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_1994_i963
            goto L769;
            FUN__24loop_1994_i963:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L770; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L770:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_627[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                      r0=r0;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_254;
                    }
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } break;
                  default: {
                    goto fatbar_254;
                  }
                }
                r0=r0;
                goto fatbar_254_over;
                fatbar_254:
                r0 = ((object**) lenv) [1][2];
                r1 = (object *) 6;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                r0=r0;
                fatbar_254_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_1994_i963;
              }
              PXLL_RETURN(0);
            L769:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_1994_i963; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_1994_i963;
            PXLL_RETURN(0);
          L759:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_frob_rule_1988_i963; r1[2] = lenv;
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object****) lenv) [1][1][1][6];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          ((object****) lenv) [1][1][1][6] = r0;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L771; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L771:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L772; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L772:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_1999_i963
          goto L773;
          FUN__24loop_1999_i963:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = (object *) constructed_41[0];
              r0[3] = r1;
              r1 = top[21];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r2 = ((object******) lenv) [1][1][1][1][1][4];
              range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
              r1 = ((pxll_vector*)r2)->val[unbox(r1)];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) constructed_627[0];
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L774; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L774:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              }
              r0[2] = r1;
              r0 = ((object**) lenv) [1][3];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN__24loop_1999_i963;
            }
            PXLL_RETURN(0);
          L773:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_1999_i963; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object*)TC_NIL;
          r1[3] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L775; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1999_i963;
          L775:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          r2 = (object *) constructed_54[0];
          t = alloc_no_clear (UOTAG(9),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L776; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L776:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
          r3[2] = r4;
          r4 = top[20];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L777; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_cdr_320;
          L777:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = allocate (TC_TUPLE, 3);
          r4 = ((object*****) lenv) [1][1][1][1][3];
          r3[2] = r4;
          r4 = (object *) constructed_41[0];
          r3[3] = r4;
          r4 = top[21];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L778; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
          L778:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r2[3] = r3;
          r3 = top[21];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L779; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
          L779:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][5];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          r1[4] = r2;
          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L780; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1799;
          L780:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = (object*)TC_NIL;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object*) lenv) [6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r1 = ((object*) lenv) [8];
          r2 = ((object*) lenv) [5];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[9] = r1;
          r1 = ((object*) lenv) [9];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[10] = r1;
          r0 = ((object******) lenv) [1][1][1][1][1][9];
          r1 = ((object*) lenv) [10];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object*****) lenv) [1][1][1][1][9] = r0;
          PXLL_RETURN(0);
        L752:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_11067_i963; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = top[68];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L781; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
        L781:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][7];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][7];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = ((pxll_vector*)r2)->val[3];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L782; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L782:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r2 = ((object****) lenv) [1][1][1][6];
            r1 = PXLL_TEST(unbox(r2)<unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 6);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_623[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = (object*)TC_NIL;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              r3 = ((object****) lenv) [1][1][1][8];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[6] = r2;
              r1 = ((object****) lenv) [1][1][1][9];
              r2 = ((object*) lenv) [6];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              ((object***) lenv) [1][1][9] = r1;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 12);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_594[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r2 = ((pxll_vector*)r2)->val[7];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object******) lenv) [1][1][1][1][1][2];
            r2[2] = r3;
            r3 = top[19];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L783; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
            L783:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = (object*)TC_NIL;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [6];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r2 = ((object*) lenv) [8];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[9] = r2;
            r2 = ((object*) lenv) [9];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[10] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object****) lenv) [1][1][1][9];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L784; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L784:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[11] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = ((object*) lenv) [10];
            r3[2] = r4;
            r4 = (object *) constructed_41[0];
            r3[3] = r4;
            r4 = top[21];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L785; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
            L785:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = ((object*) lenv) [11];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L786; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L786:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[12] = r2;
            r1 = ((object*) lenv) [12];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 9);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_594[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*****) lenv) [1][1][1][1][2];
            r2[2] = r3;
            r3 = top[19];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L787; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
            L787:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = (object*)TC_NIL;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object***) lenv) [1][1][9];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L788; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L788:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[8] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = ((object*) lenv) [7];
            r3[2] = r4;
            r4 = (object *) constructed_41[0];
            r3[3] = r4;
            r4 = top[21];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L789; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
            L789:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = ((object*) lenv) [8];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L790; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L790:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[9] = r2;
            r1 = ((object*) lenv) [9];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = top[185];
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][7];
          r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1801;
        } else {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } else {
        goto fatbar_253;
      }
      PXLL_RETURN(0);
      goto fatbar_253_over;
      fatbar_253:
      r0 = (object *) constructed_950[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L791; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L791:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10251_i1020
        goto L792;
        FUN_lambda_10251_i1020:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L793; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
          L793:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[19];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L794; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
          L794:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L795; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_subst_1802;
          L795:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        L792:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10251_i1020; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L796; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L796:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[20];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L797; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
        L797:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[4] = r1;
        r1 = ((object****) lenv) [1][1][1][5];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_match_1799;
      } else {
        goto fatbar_255;
      }
      PXLL_RETURN(0);
      goto fatbar_255_over;
      fatbar_255:
      r0 = (object *) constructed_854[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1940_i1023
        goto L798;
        FUN_loop_1940_i1023:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object*) lenv) [3];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[19];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L799; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_car_319;
              L799:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object**) lenv) [1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[19];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L800; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
              L800:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][12];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L801; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1810;
              L801:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              switch (get_case (r1)) {
                case (UOTAG(2)): {
                  r1 = (object *) constructed_952[0];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_257;
                }
              }
              r1=r1;
              goto fatbar_257_over;
              fatbar_257:
              r1 = (object *) constructed_954[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r1=r1;
              fatbar_257_over: ;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 20);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_586[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object******) lenv) [1][1][1][1][1][2];
              r2[2] = r3;
              r3 = top[19];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L802; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
              L802:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = (object*)TC_NIL;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = ((object**) lenv) [1][4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = (object *) constructed_856[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = ((object*) lenv) [6];
              r3 = ((object*) lenv) [7];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r2 = ((object*) lenv) [8];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[9] = r2;
              r2 = (object*)TC_NIL;
              r1[10] = r2;
              r2 = ((object*) lenv) [10];
              r3 = ((object*) lenv) [9];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[11] = r2;
              r2 = ((object*) lenv) [11];
              r3 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[12] = r2;
              r2 = ((object*) lenv) [12];
              r3 = ((object**) lenv) [1][5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[13] = r2;
              r2 = ((object*) lenv) [13];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[14] = r2;
              r2 = allocate (TC_TUPLE, 4);
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object******) lenv) [1][1][1][1][1][2];
              r3[2] = r4;
              r4 = top[20];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L803; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_cdr_320;
              L803:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r3[2] = r4;
              r4 = ((object**) lenv) [1][2];
              r3[3] = r4;
              r4 = top[32];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L804; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
              L804:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = top[186];
              r2[4] = r3;
              r3 = ((object*******) lenv) [1][1][1][1][1][1][5];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L805; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_match_1799;
              L805:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[15] = r2;
              r2 = (object*)TC_NIL;
              r1[16] = r2;
              r2 = ((object*) lenv) [16];
              r3 = top[186];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[17] = r2;
              r2 = ((object*) lenv) [17];
              r3 = ((object*) lenv) [15];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[18] = r2;
              r2 = ((object*) lenv) [18];
              r3 = ((object*) lenv) [14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[19] = r2;
              r2 = ((object*) lenv) [19];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[20] = r2;
              r1 = ((object*) lenv) [20];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r0[3] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][7];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L806; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1801;
              L806:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1940_i1023;
            } break;
          }
          PXLL_RETURN(0);
        L798:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1940_i1023; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][13];
        r1[3] = r2;
        r2 = top[42];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L807; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pack_347;
        L807:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1940_i1023;
      } else {
        goto fatbar_256;
      }
      PXLL_RETURN(0);
      goto fatbar_256_over;
      fatbar_256:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_72;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_72;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_256_over: ;
      PXLL_RETURN(0);
      fatbar_255_over: ;
      PXLL_RETURN(0);
      fatbar_253_over: ;
      PXLL_RETURN(0);
      fatbar_252_over: ;
      PXLL_RETURN(0);
    L706:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_group_1800; r1[2] = lenv;
    r0[6] = r1;
    // def fatbar_1801
    goto L808;
    FUN_fatbar_1801:
      check_heap (0);
      r0 = top[186];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = top[186];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[6] = r1;
          r1 = (object *) constructed_495[0];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [7];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = ((object*) lenv) [8];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L808:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fatbar_1801; r1[2] = lenv;
    r0[7] = r1;
    // def subst_1802
    goto L809;
    FUN_subst_1802:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_627[0];
          r2 = ((object**) lenv) [1][2];
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_850[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object*)TC_NIL;
            r0[9] = r1;
            r1 = ((object*) lenv) [9];
            r2 = ((object***) lenv) [1][1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r1 = ((object*) lenv) [10];
            r2 = ((object*) lenv) [8];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = ((object*) lenv) [11];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[12] = r1;
            r0 = ((object*) lenv) [12];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = ((object**) lenv) [1][4];
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_251;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_251_over;
      fatbar_251:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_72;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_72;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_251_over: ;
      PXLL_RETURN(0);
    L809:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_subst_1802; r1[2] = lenv;
    r0[8] = r1;
    // def fieldpair->label_1804
    goto L810;
    FUN_fieldpair__3elabel_1804:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L810:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3elabel_1804; r1[2] = lenv;
    r0[9] = r1;
    // def fieldpair->pattern_1805
    goto L811;
    FUN_fieldpair__3epattern_1805:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,1);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L811:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3epattern_1805; r1[2] = lenv;
    r0[10] = r1;
    // def pattern->fieldpairs_1806
    goto L812;
    FUN_pattern__3efieldpairs_1806:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_250;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_250_over;
      fatbar_250:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_940;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_940;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_250_over: ;
      PXLL_RETURN(0);
    L812:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3efieldpairs_1806; r1[2] = lenv;
    r0[11] = r1;
    // def pattern->literal_1810
    goto L813;
    FUN_pattern__3eliteral_1810:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_249;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_249_over;
      fatbar_249:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_939;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_939;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_249_over: ;
      PXLL_RETURN(0);
    L813:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3eliteral_1810; r1[2] = lenv;
    r0[12] = r1;
    // def first-literal=?_1811
    goto L814;
    FUN_first_literal_3d_question_1811:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object**) lenv) [1][3];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][3];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][2];
      r2[2] = r3;
      r3 = top[19];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L815; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
      L815:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object****) lenv) [1][1][1][12];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L816; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1810;
      L816:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = top[19];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L817; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
      L817:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object****) lenv) [1][1][1][12];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L818; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1810;
      L818:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[88];
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_436;
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L814:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_literal_3d_question_1811; r1[2] = lenv;
    r0[13] = r1;
    // def collect_1813
    goto L819;
    FUN_collect_1813:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1949
      goto L820;
      FUN_loop_1949:
        check_heap (0);
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L821; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L821:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [4];
            r1[3] = r2;
            r2 = top[66];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L822; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L822:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = ((object*) lenv) [5];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_938[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 6);
                r1[1] = lenv; lenv = r1;
                // def push_1772_i1125
                goto L823;
                FUN_push_1772_i1125:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object***) lenv) [1][1][2] = r0;
                  PXLL_RETURN(0);
                L823:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_push_1772_i1125; r2[2] = lenv;
                r1[2] = r2;
                // def pop_1773_i1125
                goto L824;
                FUN_pop_1773_i1125:
                  check_heap (0);
                  r0 = ((object**) lenv) [1][2];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_73;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_73;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_937;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_937;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = ((object*) lenv) [2];
                      r0[4] = r1;
                      r0 = ((object*) lenv) [3];
                      ((object***) lenv) [1][1][2] = r0;
                      r0 = ((object*) lenv) [4];
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L824:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_pop_1773_i1125; r2[2] = lenv;
                r1[3] = r2;
                // def get_1774_i1125
                goto L825;
                FUN_get_1774_i1125:
                  r0 = ((object**) lenv) [1][2];
                  PXLL_RETURN(0);
                L825:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_get_1774_i1125; r2[2] = lenv;
                r1[4] = r2;
                // def top_1775_i1125
                goto L826;
                FUN_top_1775_i1125:
                  check_heap (0);
                  r0 = ((object**) lenv) [1][2];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_73;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_73;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_936;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_936;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L826:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_top_1775_i1125; r2[2] = lenv;
                r1[5] = r2;
                // def stack-length_1776_i1125
                goto L827;
                FUN_stack_length_1776_i1125:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = ((object**) lenv) [1][2];
                  r0[2] = r1;
                  r1 = top[22];
                  r0[1] = r1[2]; lenv = r0; goto FUN_length_324;
                L827:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_stack_length_1776_i1125; r2[2] = lenv;
                r1[6] = r2;
                r1 = allocate (UOTAG(21), 5);
                r2 = ((object*) lenv) [4];
                r1[1] = r2;
                r2 = ((object*) lenv) [6];
                r1[2] = r2;
                r2 = ((object*) lenv) [3];
                r1[3] = r2;
                r2 = ((object*) lenv) [2];
                r1[4] = r2;
                r2 = ((object*) lenv) [5];
                r1[5] = r2;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [3];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L828; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L828:
                ; lenv = k[2]; k = k[1];
                r0 = ((object*) lenv) [3];
                r1 = ((object***) lenv) [1][1][2];
                r2 = ((object**) lenv) [1][4];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                r1 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_1949;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][5];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L829; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L829:
                ; lenv = k[2]; k = k[1];
                r0 = ((object**) lenv) [1][3];
                r1 = ((object***) lenv) [1][1][2];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_1949;
              } break;
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L820:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1949; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*)UITAG(0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][3];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1949;
    L819:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_collect_1813; r1[2] = lenv;
    r0[14] = r1;
    // def pattern->dt_1814
    goto L830;
    FUN_pattern__3edt_1814:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_248;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_248_over;
      fatbar_248:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_935;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_935;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_248_over: ;
      PXLL_RETURN(0);
    L830:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3edt_1814; r1[2] = lenv;
    r0[15] = r1;
    // def pattern->alt_1815
    goto L831;
    FUN_pattern__3ealt_1815:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_247;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_247_over;
      fatbar_247:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_934;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_934;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_247_over: ;
      PXLL_RETURN(0);
    L831:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3ealt_1815; r1[2] = lenv;
    r0[16] = r1;
    // def pattern->subs_1816
    goto L832;
    FUN_pattern__3esubs_1816:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_246;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_246_over;
      fatbar_246:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_933;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_933;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_246_over: ;
      PXLL_RETURN(0);
    L832:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3esubs_1816; r1[2] = lenv;
    r0[17] = r1;
    // def rule->constructor-dt_1817
    goto L833;
    FUN_rule__3econstructor_dt_1817:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[19];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L834; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
      L834:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][15];
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3edt_1814;
      PXLL_RETURN(0);
    L833:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_dt_1817; r1[2] = lenv;
    r0[18] = r1;
    // def rule->constructor-alt_1818
    goto L835;
    FUN_rule__3econstructor_alt_1818:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[19];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L836; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
      L836:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][16];
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3ealt_1815;
      PXLL_RETURN(0);
    L835:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_alt_1818; r1[2] = lenv;
    r0[19] = r1;
    // def nthunk_1822
    goto L837;
    FUN_nthunk_1822:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) constructed_932[0];
        PXLL_RETURN(0);
      } else {
        goto fatbar_245;
      }
      PXLL_RETURN(0);
      goto fatbar_245_over;
      fatbar_245:
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L838; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L838:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = (object *) 3;
      r3 = ((object**) lenv) [1][2];
      r2 = box((pxll_int)unbox(r3)-unbox(r2));
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = ((object***) lenv) [1][1][20];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L839; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1822;
      L839:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
      fatbar_245_over: ;
      PXLL_RETURN(0);
    L837:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_nthunk_1822; r1[2] = lenv;
    r0[20] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_1846_i1189
    goto L840;
    FUN_loop_1846_i1189:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_648[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    r1[2] = r2;
                    r2 = (object *) constructed_41[0];
                    r1[3] = r2;
                    r2 = top[21];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L841; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                    L841:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L842; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L842:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[4] = r1;
                    r0 = ((object*****) lenv) [1][1][1][1][3];
                    r1 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = ((object*) lenv) [3];
                    r2 = (object *) constructed_926[0];
                    lenv = ((object ***)lenv)[1][1][1];
                    lenv[2] = r2;
                    lenv[3] = r0;
                    lenv[4] = r1;
                    goto FUN_loop_1846_i1189;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_240;
                  }
                }
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_240;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_240;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_240_over;
          fatbar_240:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          // def parse-fieldpair_1824_i915_i1189
          goto L843;
          FUN_parse_fieldpair_1824_i915_i1189:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L844; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_kind_1825_i915_i1189;
            L844:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          L843:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_parse_fieldpair_1824_i915_i1189; r2[2] = lenv;
          r1[2] = r2;
          // def kind_1825_i915_i1189
          goto L845;
          FUN_kind_1825_i915_i1189:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(8)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object***) lenv) [1][1][2];
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = top[114];
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[34];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L846; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_filter_338;
                L846:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = top[32];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L847; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                L847:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(4)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(r1) {
                  r1 = (object *) constructed_49[0];
                  r1=r1;
                } else {
                  r1 = (object *) constructed_46[0];
                  r1=r1;
                }
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = (object *) constructed_927[0];
                r2 = (object *) constructed_51[0];
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = (object *) constructed_54[0];
                    r1 = (object *) constructed_928[0];
                    r2 = (object *) constructed_56[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = (object *) constructed_930[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = ((object*) lenv) [2];
                                  r0[2] = r1;
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_kind_1825_i915_i1189;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_244;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_244;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_244;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_244_over;
                        fatbar_244:
                        r0 = (object *) constructed_856[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r0 = ((object*) lenv) [2];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_243;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_243;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_243;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_243;
                        }
                        PXLL_RETURN(0);
                        fatbar_244_over: ;
                        PXLL_RETURN(0);
                      } break;
                      case (UOTAG(9)): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object**) lenv) [1][3];
                        r1[3] = r2;
                        r2 = top[32];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L848; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                        L848:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object*) lenv) [4];
                        r2 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(2),3);
                        t[1] = r2;
                        t[2] = r0;
                        t[3] = r1;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        goto fatbar_243;
                      }
                    }
                    PXLL_RETURN(0);
                    goto fatbar_243_over;
                    fatbar_243:
                    r0 = allocate (TC_TUPLE, 6);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L849; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1825_i915_i1189;
                    L849:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L850; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1825_i915_i1189;
                    L850:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = ((object*) lenv) [4];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r0 = (object *) constructed_66[0];
                    r1 = ((object*) lenv) [6];
                    r2 = (object *) constructed_56[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                    fatbar_243_over: ;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
                goto fatbar_242_over;
                fatbar_242:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_931;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                fatbar_242_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_241;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_241_over;
            fatbar_241:
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_241_over: ;
            PXLL_RETURN(0);
          L845:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_kind_1825_i915_i1189; r2[2] = lenv;
          r1[3] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L851; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_kind_1825_i915_i1189;
          L851:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object**) lenv) [1][3];
          r2 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_1846_i1189;
          fatbar_240_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L840:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_1846_i1189; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 4);
    r2 = (object *) constructed_925[0];
    r1[2] = r2;
    r2 = (object *) constructed_924[0];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][5];
    r1[4] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L852; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_1846_i1189;
    L852:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][2];
    r3[2] = r4;
    r4 = top[19];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L853; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_car_319;
    L853:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    r2 = r2;
    r2=r2;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L854; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L854:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][4];
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
        r1=r1;
      } break;
      default: {
        goto fatbar_239;
      }
    }
    r1=r1;
    goto fatbar_239_over;
    fatbar_239:
    r1 = (object *) 6;
    r1=r1;
    fatbar_239_over: ;
    if PXLL_IS_TRUE(r1) {
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = top[113];
      r1[3] = r2;
      r2 = ((object**) lenv) [1][20];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L855; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1822;
      L855:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r1=r1;
    } else {
      r1 = ((object***) lenv) [1][1][4];
      r1=r1;
    }
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[185];
    r1[4] = r2;
    r2 = ((object**) lenv) [1][5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L856; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1799;
    L856:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r0 = allocate (UOTAG(1), 2);
    r1 = ((object*) lenv) [4];
    r0[1] = r1;
    r1 = ((object*) lenv) [5];
    r0[2] = r1;
    PXLL_RETURN(0);
  L692:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_compile_pattern_484; r1[2] = lenv;
  r0[115] = r1;
  // def print-datatype_487
  goto L857;
  FUN_print_datatype_487:
    check_heap (0);
    r0 = (object*) &constructed_923;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_923;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[7];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_13742
    goto L858;
    FUN_lambda_13742:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r3 = r3;
      r3=r3;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = top[106];
      r4[2] = r5;
      r5 = ((object***) lenv) [1][1][3];
      r5 = ((pxll_vector*)r5)->val[3];
      r4[3] = r5;
      r5 = top[32];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L859; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
      L859:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_922;
      r3[3] = r4;
      r4 = top[48];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L860; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
      L860:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_921;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_920;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_919;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L861; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L861:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L858:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_13742; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L862; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L862:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_918;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_918;
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    PXLL_RETURN(0);
  L857:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_print_datatype_487; r1[2] = lenv;
  r0[116] = r1;
  // def make-node_492
  goto L863;
  FUN_make_node_492:
    check_heap (0);
    r0 = allocate (UOTAG(20), 6);
    r1 = (object *) 1;
    r0[1] = r1;
    r1 = top[188];
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L864; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L864:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_13760_i1550
    goto L865;
    FUN_lambda_13760_i1550:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][3];
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      PXLL_RETURN(0);
    L865:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13760_i1550; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object *) 3;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r1[4] = r2;
    r2 = top[37];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L866; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_341;
    L866:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[189];
    r0[6] = r1;
    PXLL_RETURN(0);
  L863:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_node_492; r1[2] = lenv;
  r0[117] = r1;
  // def varref->name_495
  goto L867;
  FUN_varref__3ename_495:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_238;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_238_over;
    fatbar_238:
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_917;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_917;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_238_over: ;
    PXLL_RETURN(0);
  L867:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_varref__3ename_495; r1[2] = lenv;
  r0[118] = r1;
  // def node/if_499
  goto L868;
  FUN_node_2fif_499:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)UITAG(6);
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[3] = r1;
    r1 = top[117];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
  L868:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fif_499; r1[2] = lenv;
  r0[119] = r1;
  // def node/fix_504
  goto L869;
  FUN_node_2ffix_504:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L870; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L870:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L871; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L871:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(10),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    r0[3] = r1;
    r1 = top[117];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
  L869:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2ffix_504; r1[2] = lenv;
  r0[120] = r1;
  // def node/let_505
  goto L872;
  FUN_node_2flet_505:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L873; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L873:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L874; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L874:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    r0[3] = r1;
    r1 = top[117];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
  L872:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2flet_505; r1[2] = lenv;
  r0[121] = r1;
  // def node/nvcase_506
  goto L875;
  FUN_node_2fnvcase_506:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][6];
    r2 = ((object**) lenv) [1][7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r3 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(4),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[117];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
  L875:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fnvcase_506; r1[2] = lenv;
  r0[122] = r1;
  // def unpack-fix_510
  goto L876;
  FUN_unpack_fix_510:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) constructed_41[0];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L877; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L877:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (UOTAG(4), 2);
        r1 = ((object*) lenv) [2];
        r0[1] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = (object *) constructed_41[0];
        r1[3] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L878; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
        L878:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_237;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_237_over;
    fatbar_237:
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_916;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_916;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_237_over: ;
    PXLL_RETURN(0);
  L876:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_fix_510; r1[2] = lenv;
  r0[123] = r1;
  // def literal->string_511
  goto L879;
  FUN_literal__3estring_511:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L880; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L880:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L881; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L881:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[56];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8962;
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L882; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L882:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 23554;
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L883; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L883:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[46];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L884; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L884:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UITAG(3)): {
        r0 = (object*) &constructed_904;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][3];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_907;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = (object*) &constructed_906;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = ((object*) lenv) [8];
            r2 = (object*) &constructed_905;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = top[47];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          default: {
            goto fatbar_236;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_236_over;
        fatbar_236:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 11);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[124];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][4];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L885; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L885:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_912;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L886; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L886:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_911;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = ((object*) lenv) [7];
        r3 = (object*) &constructed_910;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r2 = ((object*) lenv) [8];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[9] = r2;
        r2 = ((object*) lenv) [9];
        r3 = (object*) &constructed_909;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[10] = r2;
        r2 = ((object*) lenv) [10];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[11] = r2;
        r1 = ((object*) lenv) [11];
        r2 = (object*) &constructed_908;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_236_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[124];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[32];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L887; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
        L887:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_915;
        r2[3] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L888; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L888:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_914;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_913;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
    }
    PXLL_RETURN(0);
  L879:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_literal__3estring_511; r1[2] = lenv;
  r0[124] = r1;
  // def flags-repr_512
  goto L889;
  FUN_flags_repr_512:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2410
    goto L890;
    FUN_loop_2410:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[54];
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)&unbox(r1));
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)>>unbox(r0));
          r1 = ((object*) lenv) [2];
          r2 = (object *) 12546;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2410;
        } else {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)>>unbox(r0));
          r1 = ((object*) lenv) [2];
          r2 = (object *) 12290;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2410;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L890:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2410; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_903[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2410;
  L889:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_flags_repr_512; r1[2] = lenv;
  r0[125] = r1;
  // def pp-node_514
  goto L891;
  FUN_pp_node_514:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def PP_2416
    goto L892;
    FUN__50_50_2416:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][2];
      r3 = ((pxll_vector*)r3)->val[5];
      r2[2] = r3;
      r3 = top[139];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L893; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_apply_subst_537;
      L893:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = top[106];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L894; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
      L894:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 11);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r4 = ((pxll_vector*)r4)->val[1];
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L895; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L895:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 13;
      r3[2] = r4;
      r4 = ((object*) lenv) [2];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L896; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L896:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r4 = ((pxll_vector*)r4)->val[2];
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L897; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L897:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[4] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 11;
      r3[2] = r4;
      r4 = ((object*) lenv) [4];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L898; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L898:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[5] = r3;
      r3 = top[192];
      r4 = (object *) 5;
      r3 = box((pxll_int)unbox(r4)+unbox(r3));
      r2[6] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r4 = ((pxll_vector*)r4)->val[0];
      r3[2] = r4;
      r4 = top[125];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L899; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_flags_repr_512;
      L899:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[7] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = ((object*) lenv) [6];
      r3[2] = r4;
      r4 = ((object*) lenv) [7];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L900; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L900:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[8] = r3;
      r3 = (object*)TC_NIL;
      r2[9] = r3;
      r3 = ((object*) lenv) [9];
      r4 = ((object*) lenv) [8];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[10] = r3;
      r3 = ((object*) lenv) [10];
      r4 = ((object*) lenv) [5];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[11] = r3;
      r2 = ((object*) lenv) [11];
      r3 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L901; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L901:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = (object *) 2562;
      box((pxll_int)fputc (GET_CHAR(r0), stdout));
      r0 = ((object*) lenv) [3];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [3];
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object *) 1;
      r1 = ((object**) lenv) [1][3];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
        r0=r0;
      } else {
        goto fatbar_235;
      }
      goto fatbar_235_over;
      fatbar_235:
      r0 = (object*) &constructed_902;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_902;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 3;
      r2 = ((object**) lenv) [1][3];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r1 = top[91];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L902; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
      L902:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      fatbar_235_over: ;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_870;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_869;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L903; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L903:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_872;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_871;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L904; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L904:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r3[2] = r4;
          r4 = top[124];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L905; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_literal__3estring_511;
          L905:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_874;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_873;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L906; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L906:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L907; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_468;
          L907:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_877;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object**) lenv) [1][4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_876;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = ((object*) lenv) [8];
          r3 = (object*) &constructed_875;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L908; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L908:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [5];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_878;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L909; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L909:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_879;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L910; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L910:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_880;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L911; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L911:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[77];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][3];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L912; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L912:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_884;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L913; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L913:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_883;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = (object*) &constructed_882;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = ((object*) lenv) [9];
          r3 = (object*) &constructed_881;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L914; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L914:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[77];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][2];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L915; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L915:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_887;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L916; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L916:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_886;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_885;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L917; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L917:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(4)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 12);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[77];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][3];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L918; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L918:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_893;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L919; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L919:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[56];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][4];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L920; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L920:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_892;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L921; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L921:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r3 = (object*)TC_NIL;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_891;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = (object*) &constructed_890;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r3 = ((object*) lenv) [9];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[10] = r3;
          r3 = ((object*) lenv) [10];
          r4 = (object*) &constructed_889;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[11] = r3;
          r3 = ((object*) lenv) [11];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[12] = r3;
          r2 = ((object*) lenv) [12];
          r3 = (object*) &constructed_888;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L922; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L922:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [5];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 7);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = ((object**) lenv) [1][3];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][3];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_895;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r2 = ((object*) lenv) [7];
          r3 = (object*) &constructed_894;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L923; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L923:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(12)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[90];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L924; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_repr_439;
          L924:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_898;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = (object*) &constructed_897;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = ((object*) lenv) [9];
          r3 = (object*) &constructed_896;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L925; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L925:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[77];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][2];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L926; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L926:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_901;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L927; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L927:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_900;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_899;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L928; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L928:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
      }
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][3];
      r2 = (object *) 3;
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_14342_i1728
      goto L929;
      FUN_lambda_14342_i1728:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2416;
      L929:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_14342_i1728; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L892:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__50_50_2416; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L930; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2416;
    L930:
    ; lenv = k[2]; k = k[1];
    r0 = (object *) 2562;
    r0 = box((pxll_int)fputc (GET_CHAR(r0), stdout));
    PXLL_RETURN(0);
  L891:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_node_514; r1[2] = lenv;
  r0[126] = r1;
  // def get-formals_515
  goto L931;
  FUN_get_formals_515:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_2444
    goto L932;
    FUN_p_2444:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_234;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_234_over;
      fatbar_234:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_868;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_234_over: ;
      PXLL_RETURN(0);
    L932:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_2444; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) constructed_867[0];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][2];
    r1[4] = r2;
    r2 = top[37];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L933; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_341;
    L933:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = (object *) constructed_41[0];
    r0[3] = r1;
    r1 = top[21];
    r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
  L931:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_formals_515; r1[2] = lenv;
  r0[127] = r1;
  // def unpack-bindings_516
  goto L934;
  FUN_unpack_bindings_516:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2449
    goto L935;
    FUN_loop_2449:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(1), 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L936; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L936:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[1] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [4];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L937; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L937:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                              r1 = ((object**) lenv) [1][2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              r1 = ((object******) lenv) [1][1][1][1][1][4];
                              r2 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = ((object*****) lenv) [1][1][1][1][3];
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r0;
                              lenv[4] = r1;
                              goto FUN_loop_2449;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_233;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_233;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_233;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_233;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_233;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_233_over;
      fatbar_233:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_866;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_233_over: ;
      PXLL_RETURN(0);
    L935:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2449; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_865[0];
    r0[3] = r1;
    r1 = (object *) constructed_864[0];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2449;
  L934:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_bindings_516; r1[2] = lenv;
  r0[128] = r1;
  // def parse-cexp-sig_517
  goto L938;
  FUN_parse_cexp_sig_517:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[194];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L939; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L939:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[110];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L940; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_parse_type_splat_473;
    L940:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[7];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L941; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L941:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = ((object*) lenv) [3];
    r0[2] = r1;
    PXLL_RETURN(0);
  L938:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_cexp_sig_517; r1[2] = lenv;
  r0[129] = r1;
  // def sort-fix-inits_518
  goto L942;
  FUN_sort_fix_inits_518:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_863[0];
    r0[2] = r1;
    r1 = (object *) constructed_862[0];
    r0[3] = r1;
    r1 = (object *) constructed_861[0];
    r0[4] = r1;
    r1 = (object *) constructed_860[0];
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L943; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L943:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][6];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def $loop_2472
    goto L944;
    FUN__24loop_2472:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[27];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L945; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
        L945:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][3];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[27];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L946; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
        L946:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object*****) lenv) [1][1][1][1][2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object******) lenv) [1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object*****) lenv) [1][1][1][1][4] = r0;
            r0=r0;
          } break;
          default: {
            goto fatbar_232;
          }
        }
        r0=r0;
        goto fatbar_232_over;
        fatbar_232:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][3];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object*****) lenv) [1][1][1][1][3] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][5];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object*****) lenv) [1][1][1][1][5] = r0;
        r0=r0;
        fatbar_232_over: ;
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN__24loop_2472;
      }
      PXLL_RETURN(0);
    L944:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__24loop_2472; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L947; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2472;
    L947:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = r0;
    lenv = lenv[1];
    r0 = allocate (UOTAG(3), 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L948; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L948:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [4];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L949; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L949:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [3];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L950; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L950:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [5];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L951; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L951:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[1] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][4];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L952; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L952:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][5];
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [4];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L953; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L953:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [3];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L954; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L954:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [5];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L955; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L955:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    PXLL_RETURN(0);
  L942:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_fix_inits_518; r1[2] = lenv;
  r0[130] = r1;
  // def walk_519
  goto L956;
  FUN_walk_519:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_778[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(r1) {
          r1 = (object *) constructed_49[0];
          r1=r1;
        } else {
          r1 = (object *) constructed_46[0];
          r1=r1;
        }
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_846[0];
        r3 = (object *) constructed_51[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object*)UITAG(3);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        // def lambda_15107
        goto L957;
        FUN_lambda_15107:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[131];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L958; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
          L958:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = (object*)TC_NIL;
          r0[6] = r1;
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [5];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r2 = (object *) constructed_488[0];
          t = alloc_no_clear (UOTAG(12),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = ((object*) lenv) [8];
          r0[3] = r1;
          r1 = top[117];
          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
          PXLL_RETURN(0);
        L957:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_15107; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r3 = (object *) constructed_485[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = (object *) constructed_847[0];
        r1[3] = r2;
        r2 = top[117];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L959; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
        L959:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[4] = r1;
        r1 = top[38];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_342;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[131];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L960; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
        L960:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = (object*)TC_NIL;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [5];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r2 = (object *) constructed_482[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = top[133];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L961; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_521;
        L961:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_795[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 6);
        r3[1] = lenv; lenv = r3;
        r4 = ((object**) lenv) [1][2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object***) lenv) [1][1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[2] = r4;
        r4 = ((object**) lenv) [1][3];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object***) lenv) [1][1][3];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[3] = r4;
        r4 = (object*)TC_NIL;
        r3[4] = r4;
        r4 = ((object*) lenv) [4];
        r5 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[5] = r4;
        r4 = ((object*) lenv) [5];
        r5 = (object*) &constructed_848;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = top[47];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L962; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L962:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[79];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L963; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
        L963:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_778[0];
        r0[3] = r1;
        r1 = top[117];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_850[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = ((object**) lenv) [1][3];
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = ((object*) lenv) [3];
                                                  switch (get_case (r0)) {
                                                    case (TC_NIL): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = ((object**) lenv) [1][2];
                                                      r1[2] = r2;
                                                      r2 = top[131];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L964; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                                      L964:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      r0[2] = r1;
                                                      r0 = allocate (TC_TUPLE, 3);
                                                      r1 = ((object***) lenv) [1][1][2];
                                                      r2 = ((object*****) lenv) [1][1][1][1][2];
                                                      t = alloc_no_clear (UOTAG(11),2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      r0[2] = r1;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = (object*)TC_NIL;
                                                      r1[2] = r2;
                                                      r1 = ((object*) lenv) [2];
                                                      r2 = ((object**) lenv) [1][2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      lenv = lenv[1];
                                                      r1 = r1;
                                                      r0[3] = r1;
                                                      r1 = top[117];
                                                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                                                    } break;
                                                    default: {
                                                      lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                      goto fatbar_219;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                  goto fatbar_219;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_219;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_219;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_219;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_219;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_219;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_219;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_219;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_219;
                }
                PXLL_RETURN(0);
                goto fatbar_219_over;
                fatbar_219:
                r0 = (object *) constructed_852[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = top[128];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L965; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_516;
                          L965:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = ((object*) lenv) [2];
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = top[131];
                              r1[2] = r2;
                              r2 = ((object*) lenv) [3];
                              r1[3] = r2;
                              r2 = top[32];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L966; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                              L966:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = top[131];
                              r2[2] = r3;
                              r3 = ((object****) lenv) [1][1][1][3];
                              r2[3] = r3;
                              r3 = top[32];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L967; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
                              L967:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = ((object*) lenv) [2];
                              r1[3] = r2;
                              r2 = top[117];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L968; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
                              L968:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r1 = r1;
                              r0[4] = r1;
                              r1 = top[120];
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_504;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_220;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_220;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_220;
                }
                PXLL_RETURN(0);
                goto fatbar_220_over;
                fatbar_220:
                r0 = (object *) constructed_596[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = top[128];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L969; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_516;
                          L969:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = ((object*) lenv) [2];
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = top[131];
                              r1[2] = r2;
                              r2 = ((object*) lenv) [3];
                              r1[3] = r2;
                              r2 = top[32];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L970; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                              L970:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = top[131];
                              r2[2] = r3;
                              r3 = ((object****) lenv) [1][1][1][3];
                              r2[3] = r3;
                              r3 = top[32];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L971; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
                              L971:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = ((object*) lenv) [2];
                              r1[3] = r2;
                              r2 = top[117];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L972; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
                              L972:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r1 = r1;
                              r0[4] = r1;
                              r1 = top[121];
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_505;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_221;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_221;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_221;
                }
                PXLL_RETURN(0);
                goto fatbar_221_over;
                fatbar_221:
                r0 = (object *) constructed_673[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][2];
                                  r2[2] = r3;
                                  r3 = top[127];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L973; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_get_formals_515;
                                  L973:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = top[131];
                                  r2[2] = r3;
                                  r3 = ((object*) lenv) [2];
                                  r2[3] = r3;
                                  r3 = top[32];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L974; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
                                  L974:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r2 = top[130];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L975; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_fix_inits_518;
                                  L975:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case_noint (r0)) {
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = allocate (TC_TUPLE, 4);
                                      r1 = ((object*) lenv) [2];
                                      r0[2] = r1;
                                      r1 = ((object*) lenv) [3];
                                      r0[3] = r1;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = top[131];
                                      r2[2] = r3;
                                      r3 = ((object****) lenv) [1][1][1][3];
                                      r2[3] = r3;
                                      r3 = top[32];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L976; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
                                      L976:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = (object*)UITAG(5);
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[117];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L977; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
                                      L977:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r0[4] = r1;
                                      r1 = top[120];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_504;
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_222;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_222;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_222;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_222;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_222;
                }
                PXLL_RETURN(0);
                goto fatbar_222_over;
                fatbar_222:
                r0 = (object *) constructed_592[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 5);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = top[127];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L978; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_get_formals_515;
                                  L978:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = top[131];
                                  r1[2] = r2;
                                  r2 = ((object**) lenv) [1][3];
                                  r1[3] = r2;
                                  r2 = top[32];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L979; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                  L979:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object*)UITAG(5);
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [4];
                                  r1[3] = r2;
                                  r2 = top[117];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L980; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
                                  L980:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[5] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object*) lenv) [3];
                                  r2 = ((object***) lenv) [1][1][2];
                                  t = alloc_no_clear (UOTAG(7),2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = (object*)TC_NIL;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  r2 = ((object**) lenv) [1][5];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[3] = r1;
                                  r1 = top[117];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_223;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_223;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_223;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_223;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_223;
                }
                PXLL_RETURN(0);
                goto fatbar_223_over;
                fatbar_223:
                r0 = (object *) constructed_602[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object***) lenv) [1][1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object***) lenv) [1][1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(0)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = ((object**) lenv) [1][3];
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = ((object***) lenv) [1][1][3];
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = ((object***) lenv) [1][1][3];
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = ((object*) lenv) [2];
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(0)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = ((object**) lenv) [1][2];
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = ((object**) lenv) [1][3];
                                                      switch (get_case (r0)) {
                                                        case (TC_PAIR): {
                                                          r0 = allocate (TC_TUPLE, 3);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = ((object***) lenv) [1][1][3];
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r1 = ((object***) lenv) [1][1][3];
                                                          r1 = UOBJ_GET(r1,1);
                                                          r0[3] = r1;
                                                          r0 = ((object*) lenv) [3];
                                                          switch (get_case (r0)) {
                                                            case (TC_NIL): {
                                                              r0 = allocate (TC_TUPLE, 7);
                                                              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                                              r0[2] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[85];
                                                              r1[2] = r2;
                                                              r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                              r1[3] = r2;
                                                              r2 = top[32];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L981; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                                              L981:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[3] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[86];
                                                              r1[2] = r2;
                                                              r2 = ((object****) lenv) [1][1][1][2];
                                                              r1[3] = r2;
                                                              r2 = top[32];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L982; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                                              L982:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[4] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                              r1[2] = r2;
                                                              r2 = top[131];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L983; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                                              L983:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[5] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[131];
                                                              r1[2] = r2;
                                                              r2 = ((object**) lenv) [1][2];
                                                              r1[3] = r2;
                                                              r2 = top[32];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L984; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                                              L984:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[6] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = ((object*) lenv) [2];
                                                              r1[2] = r2;
                                                              r2 = top[131];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L985; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                                              L985:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[7] = r1;
                                                              r1 = top[122];
                                                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2fnvcase_506;
                                                            } break;
                                                            default: {
                                                              lenv = ((object **********)lenv)[1][1][1][1][1][1][1][1][1][1];
                                                              goto fatbar_224;
                                                            }
                                                          }
                                                          PXLL_RETURN(0);
                                                        } break;
                                                        default: {
                                                          lenv = ((object *********)lenv)[1][1][1][1][1][1][1][1][1];
                                                          goto fatbar_224;
                                                        }
                                                      }
                                                      PXLL_RETURN(0);
                                                    } break;
                                                    default: {
                                                      lenv = ((object ********)lenv)[1][1][1][1][1][1][1][1];
                                                      goto fatbar_224;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_224;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_224;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_224;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_224;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_224;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_224;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_224;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_224;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_224;
                }
                PXLL_RETURN(0);
                goto fatbar_224_over;
                fatbar_224:
                r0 = (object *) constructed_604[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object***) lenv) [1][1][2];
                              r1[2] = r2;
                              r2 = top[129];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L986; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_parse_cexp_sig_517;
                              L986:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case_noint (r0)) {
                                default: {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = top[131];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[3] = r2;
                                  r2 = top[32];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L987; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                  L987:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object*) lenv) [3];
                                  r2 = ((object**) lenv) [1][2];
                                  r3 = ((object*) lenv) [2];
                                  t = alloc_no_clear (UOTAG(3),3);
                                  t[1] = r3;
                                  t[2] = r1;
                                  t[3] = r2;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [4];
                                  r0[3] = r1;
                                  r1 = top[117];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                                } break;
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_225;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_225;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_225;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_225;
                }
                PXLL_RETURN(0);
                goto fatbar_225_over;
                fatbar_225:
                r0 = (object *) constructed_586[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][2];
                                  r1[2] = r2;
                                  r2 = top[131];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L988; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                  L988:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[131];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L989; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                  L989:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = top[131];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L990; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                  L990:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = top[119];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_node_2fif_499;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_226;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_226;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_226;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_226;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_226;
                }
                PXLL_RETURN(0);
                goto fatbar_226_over;
                fatbar_226:
                r0 = (object *) constructed_854[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[133];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L991; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_521;
                          L991:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_795[0];
                          r0[3] = r1;
                          r1 = top[117];
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_227;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_227;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_227;
                }
                PXLL_RETURN(0);
                goto fatbar_227_over;
                fatbar_227:
                r0 = (object *) constructed_856[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[133];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L992; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_521;
                          L992:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_795[0];
                          r0[3] = r1;
                          r1 = top[117];
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_228;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_228;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_228;
                }
                PXLL_RETURN(0);
                goto fatbar_228_over;
                fatbar_228:
                r0 = (object *) constructed_588[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[131];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L993; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                                  L993:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][2];
                                  t = alloc_no_clear (UOTAG(1),1);
                                  t[1] = r1;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = (object*)TC_NIL;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  r2 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[3] = r1;
                                  r1 = top[117];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_229;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_229;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_229;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_229;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_229;
                }
                PXLL_RETURN(0);
                goto fatbar_229_over;
                fatbar_229:
                r0 = (object *) constructed_590[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[131];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L994; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L994:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(5);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = top[117];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_218;
                }
                PXLL_RETURN(0);
                fatbar_229_over: ;
                PXLL_RETURN(0);
                fatbar_228_over: ;
                PXLL_RETURN(0);
                fatbar_227_over: ;
                PXLL_RETURN(0);
                fatbar_226_over: ;
                PXLL_RETURN(0);
                fatbar_225_over: ;
                PXLL_RETURN(0);
                fatbar_224_over: ;
                PXLL_RETURN(0);
                fatbar_223_over: ;
                PXLL_RETURN(0);
                fatbar_222_over: ;
                PXLL_RETURN(0);
                fatbar_221_over: ;
                PXLL_RETURN(0);
                fatbar_220_over: ;
                PXLL_RETURN(0);
                fatbar_219_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_218;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_218_over;
            fatbar_218:
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                r0[2] = r1;
                r1 = (object *) 1;
                r2 = ((object*) lenv) [2];
                range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                r1 = (object *) 1;
                r2 = ((object*) lenv) [2];
                r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                r0[3] = r1;
                r0 = (object *) 9474;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = top[131];
                      r1[2] = r2;
                      r2 = ((object*) lenv) [3];
                      r1[3] = r2;
                      r2 = top[32];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L995; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                      L995:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = ((object*) lenv) [2];
                      r2 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (UOTAG(12),2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [4];
                      r0[3] = r1;
                      r1 = top[117];
                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                    } break;
                    default: {
                      goto fatbar_231;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_231_over;
                  fatbar_231:
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*) &constructed_857;
                  r0[2] = r1;
                  r1 = ((object***) lenv) [1][1][2];
                  r0[3] = r1;
                  r1 = top[14];
                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                  fatbar_231_over: ;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = top[131];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L996; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                  L996:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[131];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L997; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L997:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [4];
                  r0[3] = r1;
                  r1 = top[117];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                }
                PXLL_RETURN(0);
              } break;
              case (UOTAG(9)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_54[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][3];
                  r1[2] = r2;
                  r2 = top[22];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L998; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                  L998:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  t = alloc_no_clear (UOTAG(5),1);
                  t[1] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r1 = (object*)TC_NIL;
                  r0[5] = r1;
                  r1 = ((object*) lenv) [5];
                  r2 = ((object*) lenv) [4];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [6];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = ((object*) lenv) [7];
                  t = alloc_no_clear (UOTAG(0),1);
                  t[1] = r1;
                  r1 = t;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[131];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L999; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L999:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [8];
                  r2 = (object *) constructed_493[0];
                  t = alloc_no_clear (UOTAG(12),2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [9];
                  r0[3] = r1;
                  r1 = top[117];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = top[131];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1000; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
                  L1000:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[131];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1001; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L1001:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [4];
                  r0[3] = r1;
                  r1 = top[117];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_230;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_230_over;
            fatbar_230:
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[131];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1002; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
            L1002:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = top[131];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1003; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L1003:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*)UITAG(8);
            r0[2] = r1;
            r1 = ((object*) lenv) [4];
            r0[3] = r1;
            r1 = top[117];
            r0[1] = r1[2]; lenv = r0; goto FUN_make_node_492;
            fatbar_230_over: ;
            PXLL_RETURN(0);
            fatbar_218_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_217;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_217_over;
        fatbar_217:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_858;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_217_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_216_over;
    fatbar_216:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_859;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_216_over: ;
    PXLL_RETURN(0);
  L956:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_walk_519; r1[2] = lenv;
  r0[131] = r1;
  // def build-list-literal_520
  goto L1004;
  FUN_build_list_literal_520:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = top[133];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1005; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L1005:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(5),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_215;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_215_over;
        fatbar_215:
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = top[133];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1006; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_521;
        L1006:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = top[132];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1007; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_list_literal_520;
        L1007:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object*)TC_NIL;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r0 = (object *) constructed_66[0];
        r1 = ((object*) lenv) [6];
        r2 = (object *) constructed_56[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_215_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) constructed_54[0];
        r1 = (object *) constructed_845[0];
        r2 = (object *) constructed_56[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1004:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_list_literal_520; r1[2] = lenv;
  r0[132] = r1;
  // def build-literal_521
  goto L1008;
  FUN_build_literal_521:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object*)UITAG(3);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[132];
        r0[1] = r1[2]; lenv = r0; goto FUN_build_list_literal_520;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[133];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1009; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1009:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(6),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_214;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_214_over;
    fatbar_214:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_844;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_214_over: ;
    PXLL_RETURN(0);
  L1008:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_literal_521; r1[2] = lenv;
  r0[133] = r1;
  // def make-vardef_523
  goto L1010;
  FUN_make_vardef_523:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][2];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = ((object***) lenv) [1][1][3];
    r4[2] = r5;
    r5 = top[56];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L1011; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
    L1011:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = ((object*) lenv) [4];
    r5 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = ((object*) lenv) [5];
    r5 = (object*) &constructed_843;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = top[47];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1012; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
    L1012:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = top[79];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1013; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
    L1013:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (UOTAG(19), 5);
    r1 = (object *) constructed_842[0];
    r0[1] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = (object *) constructed_841[0];
    r0[4] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[5] = r1;
    PXLL_RETURN(0);
  L1010:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_vardef_523; r1[2] = lenv;
  r0[134] = r1;
  // def k/free_528
  goto L1014;
  FUN_k_2ffree_528:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_840;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_840;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1014:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ffree_528; r1[2] = lenv;
  r0[135] = r1;
  // def k/target_529
  goto L1015;
  FUN_k_2ftarget_529:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_839;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_839;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1015:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ftarget_529; r1[2] = lenv;
  r0[136] = r1;
  // def print-insn_532
  goto L1016;
  FUN_print_insn_532:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def mprint-insn_3142
    goto L1017;
    FUN_mprint_insn_3142:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[137];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1017:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_mprint_insn_3142; r1[2] = lenv;
    r0[2] = r1;
    // def print-line_3143
    goto L1018;
    FUN_print_line_3143:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = (object *) 2562;
          box((pxll_int)fputc (GET_CHAR(r0), stdout));
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = top[91];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1019; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
          L1019:
          ; lenv = k[2]; k = k[1];
          r0 = (object *) -1;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object*) &constructed_837;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_837;
            r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          } else {
            r0 = ((object*) lenv) [2];
            r0 = dump_object (r0, 0);
          }
          r0 = (object*) &constructed_836;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_836;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object**) lenv) [1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1020; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L1020:
          ; lenv = k[2]; k = k[1];
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [4];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_print_insn_532;
        } break;
        default: {
          r0 = (object *) 2562;
          box((pxll_int)fputc (GET_CHAR(r0), stdout));
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = top[91];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1021; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
          L1021:
          ; lenv = k[2]; k = k[1];
          r0 = (object*) &constructed_838;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_838;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          lenv = r0[2]; goto *r0[1];
        } break;
      }
      PXLL_RETURN(0);
    L1018:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_print_line_3143; r1[2] = lenv;
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = (object *) 2562;
        box((pxll_int)fputc (GET_CHAR(r0), stdout));
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object***) lenv) [1][1][3];
        r0[2] = r1;
        r1 = top[91];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1022; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_indent_440;
        L1022:
        ; lenv = k[2]; k = k[1];
        r0 = (object*) &constructed_811;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_811;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_810;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_810;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = ((object*) lenv) [2];
        r0 = dump_object (r0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(14)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19591
        goto L1023;
        FUN_lambda_19591:
          r0 = (object*) &constructed_813;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_813;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1023:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19591; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(15)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19621
        goto L1024;
        FUN_lambda_19621:
          r0 = (object*) &constructed_814;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_814;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1024:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19621; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19645
        goto L1025;
        FUN_lambda_19645:
          check_heap (0);
          r0 = (object*) &constructed_815;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_815;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[124];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1026; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_literal__3estring_511;
          L1026:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1025:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19645; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19670
        goto L1027;
        FUN_lambda_19670:
          r0 = (object*) &constructed_816;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_816;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1027:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19670; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19710
        goto L1028;
        FUN_lambda_19710:
          check_heap (0);
          r0 = (object*) &constructed_817;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_817;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1029; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
          L1029:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1030; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
          L1030:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1028:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19710; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19751
        goto L1031;
        FUN_lambda_19751:
          check_heap (0);
          r0 = (object*) &constructed_818;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_818;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1032; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
          L1032:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
        L1031:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19751; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(6)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19773
        goto L1033;
        FUN_lambda_19773:
          r0 = (object*) &constructed_819;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_819;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          r0 = dump_object (r0, 0);
          PXLL_RETURN(0);
        L1033:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19773; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19803
        goto L1034;
        FUN_lambda_19803:
          check_heap (0);
          r0 = (object*) &constructed_820;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_820;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
        L1034:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19803; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19829
        goto L1035;
        FUN_lambda_19829:
          r0 = (object*) &constructed_821;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_821;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1035:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19829; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19860
        goto L1036;
        FUN_lambda_19860:
          r0 = (object*) &constructed_822;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_822;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1036:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19860; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19897
        goto L1037;
        FUN_lambda_19897:
          r0 = (object*) &constructed_823;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_823;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1037:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19897; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(13)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19930
        goto L1038;
        FUN_lambda_19930:
          r0 = (object*) &constructed_824;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_824;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1038:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19930; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19952
        goto L1039;
        FUN_lambda_19952:
          r0 = (object*) &constructed_825;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_825;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1039:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19952; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(11)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19977
        goto L1040;
        FUN_lambda_19977:
          r0 = (object*) &constructed_826;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_826;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1040:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19977; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(16)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19998
        goto L1041;
        FUN_lambda_19998:
          r0 = (object*) &constructed_827;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_827;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1041:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19998; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(17)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20018
        goto L1042;
        FUN_lambda_20018:
          r0 = (object*) &constructed_828;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_828;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1042:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20018; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(18)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20057
        goto L1043;
        FUN_lambda_20057:
          check_heap (0);
          r0 = (object*) &constructed_829;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_829;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[90];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1044; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_repr_439;
          L1044:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1045; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
          L1045:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1043:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20057; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(19)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20085
        goto L1046;
        FUN_lambda_20085:
          r0 = (object*) &constructed_830;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_830;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1046:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20085; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(20)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20124
        goto L1047;
        FUN_lambda_20124:
          check_heap (0);
          r0 = (object*) &constructed_831;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_831;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1048; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
          L1048:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
        L1047:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20124; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(21)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20149
        goto L1049;
        FUN_lambda_20149:
          r0 = (object*) &constructed_832;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_832;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1049:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20149; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20200
        goto L1050;
        FUN_lambda_20200:
          check_heap (0);
          r0 = (object*) &constructed_833;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_833;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1051; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
          L1051:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1052; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
          L1052:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[137];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
        L1050:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20200; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      case (UOTAG(22)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20257
        goto L1053;
        FUN_lambda_20257:
          check_heap (0);
          r0 = (object*) &constructed_834;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_834;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_20245
          goto L1054;
          FUN_lambda_20245:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = (object *) 3;
            r2 = ((object****) lenv) [1][1][1][3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[3] = r1;
            r1 = top[137];
            r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
          L1054:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_20245; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [5];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1055; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L1055:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_mprint_insn_3142;
        L1053:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20257; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20314
        goto L1056;
        FUN_lambda_20314:
          check_heap (0);
          r0 = (object*) &constructed_835;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_835;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_810;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_810;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_812;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_812;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_20302
          goto L1057;
          FUN_lambda_20302:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = (object *) 3;
            r2 = ((object****) lenv) [1][1][1][3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[3] = r1;
            r1 = top[137];
            r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
          L1057:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_20302; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [5];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1058; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L1058:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_mprint_insn_3142;
        L1056:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20314; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3143;
      } break;
    }
    PXLL_RETURN(0);
  L1016:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_print_insn_532; r1[2] = lenv;
  r0[137] = r1;
  // def unify_536
  goto L1059;
  FUN_unify_536:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def type-error_3303
    goto L1060;
    FUN_type_error_3303:
      check_heap (0);
      r0 = (object *) 2562;
      box((pxll_int)fputc (GET_CHAR(r0), stdout));
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = top[126];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1061; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_514;
      L1061:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[139];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1062; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_537;
      L1062:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = top[139];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1063; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_537;
      L1063:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r3[2] = r4;
      r4 = top[106];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1064; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_468;
      L1064:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[106];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1065; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_468;
      L1065:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_809;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_808;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_807;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1066; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L1066:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_806;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_806;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
    L1060:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_type_error_3303; r1[2] = lenv;
    r0[2] = r1;
    // def U_3304
    goto L1067;
    FUN__55_3304:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_20956
      goto L1068;
      FUN_lambda_20956:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[108];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1069; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
        L1069:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = top[108];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1070; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
        L1070:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r2 = ((object**) lenv) [1][2];
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) 14;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object**) lenv) [1][3];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = (object *) 14;
                  r0=r0;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object***) lenv) [1][1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = (object *) constructed_803[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) constructed_803[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                      r0=r0;
                    } else {
                      goto fatbar_208;
                    }
                    r0=r0;
                    goto fatbar_208_over;
                    fatbar_208:
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object**) lenv) [1][3];
                    r2[2] = r3;
                    r3 = top[19];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1071; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                    L1071:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1072; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3304;
                    L1072:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1073; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1073:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                    fatbar_208_over: ;
                    r0=r0;
                  } else {
                    goto fatbar_207;
                  }
                  r0=r0;
                  goto fatbar_207_over;
                  fatbar_207:
                  r0 = (object *) constructed_803[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object*) lenv) [3];
                    r2[2] = r3;
                    r3 = top[19];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1074; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                    L1074:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][2];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1075; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3304;
                    L1075:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1076; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1076:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_209;
                  }
                  r0=r0;
                  goto fatbar_209_over;
                  fatbar_209:
                  r0 = (object *) constructed_805[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][2];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1077; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3306;
                    L1077:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1078; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1078:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_210;
                  }
                  r0=r0;
                  goto fatbar_210_over;
                  fatbar_210:
                  r0 = (object *) constructed_805[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][2];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1079; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3306;
                    L1079:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1080; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1080:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_211;
                  }
                  r0=r0;
                  goto fatbar_211_over;
                  fatbar_211:
                  r0 = (object *) constructed_551[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][2];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1081; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3306;
                    L1081:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1082; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1082:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_212;
                  }
                  r0=r0;
                  goto fatbar_212_over;
                  fatbar_212:
                  r0 = (object *) constructed_551[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][2];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1083; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3306;
                    L1083:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1084; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1084:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_213;
                  }
                  r0=r0;
                  goto fatbar_213_over;
                  fatbar_213:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r2 = ((object***) lenv) [1][1][2];
                  r1 = PXLL_TEST(r2==r1);
                  r0[2] = r1;
                  r0 = (object *) 6;
                  r1 = ((object*) lenv) [2];
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = (object *) 262;
                    r0=r0;
                  } else {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = top[22];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1085; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                    L1085:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][3];
                    r1[2] = r2;
                    r2 = top[22];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1086; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                    L1086:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r2 = ((object*) lenv) [2];
                    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                    r0[4] = r1;
                    r0 = (object *) 6;
                    r1 = ((object*) lenv) [4];
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object*****) lenv) [1][1][1][1][2];
                    r0[2] = r1;
                    r1 = ((object*****) lenv) [1][1][1][1][3];
                    r0[3] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1087; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3303;
                    L1087:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  r0=r0;
                  fatbar_213_over: ;
                  r0=r0;
                  fatbar_212_over: ;
                  r0=r0;
                  fatbar_211_over: ;
                  r0=r0;
                  fatbar_210_over: ;
                  r0=r0;
                  fatbar_209_over: ;
                  r0=r0;
                  fatbar_207_over: ;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
              }
              lenv = lenv[1];
              r0 = r0;
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[109];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1088; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_type_union_472;
          L1088:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = ((object**) lenv) [1][3];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[3] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[4] = r1;
                  r1 = top[36];
                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_340;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_206;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_206;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_206_over;
          fatbar_206:
          r0 = (object *) 14;
          PXLL_RETURN(0);
          fatbar_206_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L1068:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_20956; r1[2] = lenv;
      r0[2] = r1;
      r1 = top[16];
      r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
    L1067:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_3304; r1[2] = lenv;
    r0[3] = r1;
    // def U-row_3306
    goto L1089;
    FUN__55_row_3306:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_551[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = ((object***) lenv) [1][1][3];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_551[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_203;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_203;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_203;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_203_over;
                        fatbar_203:
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object**) lenv) [1][3];
                        r1[2] = r2;
                        r2 = top[22];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1090; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                        L1090:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_3338
                        goto L1091;
                        FUN__24loop_3338:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][3];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = ((object*) lenv) [3];
                            r0[2] = r1;
                            r1 = (object *) constructed_41[0];
                            r0[3] = r1;
                            r1 = top[21];
                            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = top[104];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1092; t[4] = r0; k = t;
                            lenv = r1[2]; goto FUN_new_tvar_459;
                            L1092:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = ((object**) lenv) [1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            lenv = lenv[1];
                            r0 = r0;
                            r1 = (object *) 3;
                            r2 = ((object*) lenv) [2];
                            r1 = box((pxll_int)unbox(r2)+unbox(r1));
                            lenv[2] = r1;
                            lenv[3] = r0;
                            goto FUN__24loop_3338;
                          }
                          PXLL_RETURN(0);
                        L1091:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_3338; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1093; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3338;
                        L1093:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[4] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object***) lenv) [1][1][2];
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object**) lenv) [1][2];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [4];
                        r1[3] = r2;
                        r2 = top[103];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1094; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                        L1094:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = ((object******) lenv) [1][1][1][1][1][3];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1095; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                        L1095:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        // def $loop_3343
                        goto L1096;
                        FUN__24loop_3343:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][2];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*****) lenv) [1][1][1][1][3];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [2];
                            r1[3] = r2;
                            r2 = top[27];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1097; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                            L1097:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 3);
                            r3 = ((object*****) lenv) [1][1][1][1][4];
                            r2[2] = r3;
                            r3 = ((object**) lenv) [1][2];
                            r2[3] = r3;
                            r3 = top[27];
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1098; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                            L1098:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = (object *) constructed_551[0];
                            r1[2] = r2;
                            r2 = allocate (TC_TUPLE, 2);
                            r2[1] = lenv; lenv = r2;
                            r3 = (object*)TC_NIL;
                            r2[2] = r3;
                            r2 = ((object*) lenv) [2];
                            r3 = ((object**) lenv) [1][2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r2 = r2;
                            r1[3] = r2;
                            r2 = top[103];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1099; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                            L1099:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            lenv = lenv[1];
                            r1 = r1;
                            r0[3] = r1;
                            r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L1100; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                            L1100:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = ((object*) lenv) [2];
                            r0 = box((pxll_int)unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_3343;
                          }
                          PXLL_RETURN(0);
                        L1096:
                        r1 = allocate (TC_CLOSURE, 2);
                        r1[1] = &&FUN__24loop_3343; r1[2] = lenv;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object *) 1;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3343;
                        fatbar_203_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_202;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_202;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_202;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_202;
          }
          PXLL_RETURN(0);
          goto fatbar_202_over;
          fatbar_202:
          r0 = (object *) constructed_805[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = ((object*****) lenv) [1][1][1][1][3];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object******) lenv) [1][1][1][1][1][3];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = ((object******) lenv) [1][1][1][1][1][3];
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = (object *) constructed_805[0];
                                r1 = ((object*) lenv) [2];
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [3];
                                          switch (get_case (r0)) {
                                            case (TC_PAIR): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][3];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = ((object**) lenv) [1][3];
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = ((object*) lenv) [3];
                                              switch (get_case (r0)) {
                                                case (TC_NIL): {
                                                  r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(1)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = ((object****) lenv) [1][1][1][2];
                                                      switch (get_case (r0)) {
                                                        case (UOTAG(1)): {
                                                          r0 = allocate (TC_TUPLE, 2);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = ((object*****) lenv) [1][1][1][1][2];
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r0 = ((object*) lenv) [2];
                                                          r1 = ((object**) lenv) [1][2];
                                                          r0 = PXLL_TEST(r1==r0);
                                                          lenv = lenv[1];
                                                          r0 = r0;
                                                          r0=r0;
                                                        } break;
                                                        default: {
                                                          lenv = ((object *)lenv)[1];
                                                          goto fatbar_205;
                                                        }
                                                      }
                                                      lenv = lenv[1];
                                                      r0 = r0;
                                                      r0=r0;
                                                    } break;
                                                    default: {
                                                      goto fatbar_205;
                                                    }
                                                  }
                                                  r0=r0;
                                                  goto fatbar_205_over;
                                                  fatbar_205:
                                                  r0 = (object *) 6;
                                                  r0=r0;
                                                  fatbar_205_over: ;
                                                  if PXLL_IS_TRUE(r0) {
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = ((object**) lenv) [1][2];
                                                    r0[3] = r1;
                                                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1101; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                                    L1101:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object*****) lenv) [1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = ((object*) lenv) [2];
                                                    r0[3] = r1;
                                                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                                  } else {
                                                    r0 = allocate (TC_TUPLE, 2);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = top[104];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1102; t[4] = r0; k = t;
                                                    lenv = r1[2]; goto FUN_new_tvar_459;
                                                    L1102:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[2] = r1;
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = ((object****) lenv) [1][1][1][2];
                                                    r1[2] = r2;
                                                    r2 = ((object***) lenv) [1][1][2];
                                                    r1[3] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[4] = r2;
                                                    r2 = top[105];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1103; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_464;
                                                    L1103:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1104; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                                    L1104:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object**) lenv) [1][2];
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                    r1[2] = r2;
                                                    r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                    r1[3] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[4] = r2;
                                                    r2 = top[105];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1105; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_464;
                                                    L1105:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ***)lenv)[1][1][1];
                                                  goto fatbar_204;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_204;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_204;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_204;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } else {
                                  goto fatbar_204;
                                }
                                PXLL_RETURN(0);
                                goto fatbar_204_over;
                                fatbar_204:
                                r0 = (object *) constructed_551[0];
                                r1 = ((object*) lenv) [2];
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = top[19];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1106; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
                                  L1106:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1107; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                  L1107:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][2];
                                  r0[3] = r1;
                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                } else {
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][3];
                                  r1[2] = r2;
                                  r2 = top[22];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1108; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                                  L1108:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3362
                                  goto L1109;
                                  FUN__24loop_3362:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][3];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = ((object*) lenv) [3];
                                      r0[2] = r1;
                                      r1 = (object *) constructed_41[0];
                                      r0[3] = r1;
                                      r1 = top[21];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = top[104];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1110; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_459;
                                      L1110:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      r1 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r1 = (object *) 3;
                                      r2 = ((object*) lenv) [2];
                                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3362;
                                    }
                                    PXLL_RETURN(0);
                                  L1109:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3362; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = ((object*) lenv) [2];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1111; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3362;
                                  L1111:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[4] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[5] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3367
                                  goto L1112;
                                  FUN__24loop_3367:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][5];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = ((object*) lenv) [3];
                                      r0[2] = r1;
                                      r1 = (object *) constructed_41[0];
                                      r0[3] = r1;
                                      r1 = top[21];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = top[104];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1113; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_459;
                                      L1113:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      r1 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r1 = (object *) 3;
                                      r2 = ((object*) lenv) [2];
                                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3367;
                                    }
                                    PXLL_RETURN(0);
                                  L1112:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3367; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = ((object*) lenv) [2];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1114; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3367;
                                  L1114:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[6] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [4];
                                  r1[3] = r2;
                                  r2 = top[103];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1115; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                                  L1115:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object****) lenv) [1][1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1116; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                  L1116:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [6];
                                  r1[3] = r2;
                                  r2 = top[103];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1117; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                                  L1117:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1118; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                  L1118:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def $loop_3372
                                  goto L1119;
                                  FUN__24loop_3372:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][2];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = (object *) 14;
                                      PXLL_RETURN(0);
                                    } else {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object*****) lenv) [1][1][1][1][3];
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[27];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1120; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                                      L1120:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 4);
                                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      r1[2] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object****) lenv) [1][1][1][4];
                                      r2[2] = r3;
                                      r3 = ((object*) lenv) [2];
                                      r2[3] = r3;
                                      r3 = top[27];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1121; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                                      L1121:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[3] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object****) lenv) [1][1][1][6];
                                      r2[2] = r3;
                                      r3 = ((object*) lenv) [2];
                                      r2[3] = r3;
                                      r3 = top[27];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1122; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                                      L1122:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[4] = r2;
                                      r2 = top[105];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1123; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_464;
                                      L1123:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1124; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
                                      L1124:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = (object *) 3;
                                      r1 = ((object*) lenv) [2];
                                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                                      lenv[2] = r0;
                                      goto FUN__24loop_3372;
                                    }
                                    PXLL_RETURN(0);
                                  L1119:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN__24loop_3372; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3372;
                                }
                                PXLL_RETURN(0);
                                fatbar_204_over: ;
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_201;
                              }
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_201;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_201;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_201;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_201;
              }
            }
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_201;
          }
          PXLL_RETURN(0);
          fatbar_202_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_201;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_201_over;
      fatbar_201:
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3303;
      fatbar_201_over: ;
      PXLL_RETURN(0);
    L1089:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_row_3306; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][4];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN__55_3304;
  L1059:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unify_536; r1[2] = lenv;
  r0[138] = r1;
  // def apply-subst_537
  goto L1125;
  FUN_apply_subst_537:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_3375
    goto L1126;
    FUN_p_3375:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[108];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1127; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_find_471;
      L1127:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[107];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1128; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_470;
      L1128:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r0 = ((pxll_vector*)r0)->val[2];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = top[104];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1129; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_459;
        L1129:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = ((object**) lenv) [1][3];
        ((pxll_vector*)r1)->val[0] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_803[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } else {
              goto fatbar_200;
            }
            PXLL_RETURN(0);
            goto fatbar_200_over;
            fatbar_200:
            r0 = (object *) 262;
            r1 = ((object**) lenv) [1][3];
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*****) lenv) [1][1][1][1][2];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][3];
            r2[3] = r3;
            r3 = top[32];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1130; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
            L1130:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[103];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1131; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
            L1131:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object***) lenv) [1][1][3];
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = ((pxll_vector*)r1)->val[0];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) constructed_803[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = (object*)TC_NIL;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r3 = ((object****) lenv) [1][1][1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[3] = r2;
                r1 = ((object*) lenv) [3];
                r2 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r1 = top[103];
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
              } break;
              default: {
                r0 = ((object**) lenv) [1][2];
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
            fatbar_200_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1126:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_3375; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_p_3375;
  L1125:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_apply_subst_537; r1[2] = lenv;
  r0[139] = r1;
  // def symbol-set-maker_544
  goto L1132;
  FUN_symbol_set_maker_544:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = top[196];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1133; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L1133:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_24582
    goto L1134;
    FUN_lambda_24582:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1134:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_24582; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[35];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1135; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1135:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1132:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_set_maker_544; r1[2] = lenv;
  r0[140] = r1;
  // def build-dependency-graph_545
  goto L1136;
  FUN_build_dependency_graph_545:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = top[81];
    r1[2] = r2;
    r2 = top[195];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1137; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1137:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def search_3840
    goto L1138;
    FUN_search_3840:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1139; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1139:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[19];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1140; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
          L1140:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3840;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1141; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L1141:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_3848
          goto L1142;
          FUN__24loop_3848:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[27];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1143; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
              L1143:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[27];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1144; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
              L1144:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object *) constructed_801[0];
              r1[2] = r2;
              r2 = top[140];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1145; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_544;
              L1145:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r1 = ((pxll_vector*)r1)->val[1];
              r1 = ((pxll_vector*)r1)->val[0];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1146; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1146:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = ((object*) lenv) [4];
              r0[3] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1147; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_search_3840;
              L1147:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_3848;
            }
            PXLL_RETURN(0);
          L1142:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_3848; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1148; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3848;
          L1148:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[22];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1149; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
          L1149:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1150; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L1150:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3840;
        } break;
        default: {
          goto fatbar_199;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_199_over;
      fatbar_199:
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_24702
      goto L1151;
      FUN_lambda_24702:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_search_3840;
      L1151:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_24702; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      fatbar_199_over: ;
      PXLL_RETURN(0);
    L1138:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_3840; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_800[0];
    r1[2] = r2;
    r2 = top[140];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1152; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_544;
    L1152:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) constructed_506[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1153; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1153:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object****) lenv) [1][1][1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1154; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_search_3840;
    L1154:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = ((object**) lenv) [1][2];
    r1 = ((object***) lenv) [1][1][3];
    ((pxll_vector*)r1)->val[2] = r0;
    PXLL_RETURN(0);
  L1136:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_dependency_graph_545; r1[2] = lenv;
  r0[141] = r1;
  // def symbol-add-suffix_554
  goto L1155;
  FUN_symbol_add_suffix_554:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = allocate (TC_TUPLE, 2);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = UOBJ_GET(r4,0);
    r3[2] = r4;
    r3 = ((object*) lenv) [2];
    lenv = lenv[1];
    r3 = r3;
    r3=r3;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1156; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L1156:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = top[79];
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
  L1155:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_add_suffix_554; r1[2] = lenv;
  r0[142] = r1;
  // def do-simple-optimizations_557
  goto L1157;
  FUN_do_simple_optimizations_557:
    check_heap (0);
    r0 = (object *) 1;
    top[198] = r0;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4111
    goto L1158;
    FUN_loop_4111:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 5);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = top[198];
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1159; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L1159:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = (object*)TC_NIL;
      r2[3] = r3;
      r3 = ((object*) lenv) [3];
      r4 = (object*) &constructed_799;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r2 = ((object*) lenv) [5];
      r3 = (object*) &constructed_798;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1160; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L1160:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[198];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 1;
        top[198] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[144];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1161; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_simpleopt_558;
        L1161:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv[2] = r0;
        goto FUN_loop_4111;
      } else {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1158:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4111; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[144];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1162; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
    L1162:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4111;
  L1157:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_simple_optimizations_557; r1[2] = lenv;
  r0[143] = r1;
  // def simpleopt_558
  goto L1163;
  FUN_simpleopt_558:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_27263
    goto L1164;
    FUN_lambda_27263:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[198];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      top[198] = r0;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = ((object*****) lenv) [1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = top[19];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1165; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
              L1165:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[144];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1166; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
              L1166:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1167; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1167:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r0=r0;
            } break;
            default: {
              goto fatbar_192;
            }
          }
          r0=r0;
          goto fatbar_192_over;
          fatbar_192:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[123];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1168; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
          L1168:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][5];
                  r1[2] = r2;
                  r2 = top[123];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1169; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
                  L1169:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object*****) lenv) [1][1][1][1][2];
                      r4[2] = r5;
                      r5 = (object *) constructed_41[0];
                      r4[3] = r5;
                      r5 = top[21];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1170; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                      L1170:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object**) lenv) [1][2];
                      r3[3] = r4;
                      r4 = top[21];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1171; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                      L1171:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object***) lenv) [1][1][3];
                      r4[2] = r5;
                      r5 = (object *) constructed_41[0];
                      r4[3] = r5;
                      r5 = top[21];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1172; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                      L1172:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = top[21];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1173; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                      L1173:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      r2[4] = r3;
                      r3 = top[120];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1174; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2ffix_504;
                      L1174:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = top[144];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1175; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                      L1175:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1176; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1176:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_193;
                }
              }
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
          }
          r0=r0;
          goto fatbar_193_over;
          fatbar_193:
          r0 = (object *) 14;
          r0=r0;
          fatbar_193_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_192_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = ((object*****) lenv) [1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = top[19];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1177; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
              L1177:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[144];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1178; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
              L1178:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1179; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1179:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r0=r0;
            } break;
            default: {
              goto fatbar_194;
            }
          }
          r0=r0;
          goto fatbar_194_over;
          fatbar_194:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[123];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1180; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
          L1180:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][5];
                  r1[2] = r2;
                  r2 = top[123];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1181; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
                  L1181:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object*****) lenv) [1][1][1][1][2];
                      r4[2] = r5;
                      r5 = (object *) constructed_41[0];
                      r4[3] = r5;
                      r5 = top[21];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1182; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                      L1182:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object**) lenv) [1][2];
                      r3[3] = r4;
                      r4 = top[21];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1183; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                      L1183:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object***) lenv) [1][1][3];
                      r4[2] = r5;
                      r5 = (object *) constructed_41[0];
                      r4[3] = r5;
                      r5 = top[21];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1184; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                      L1184:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = top[21];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1185; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                      L1185:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      r2[4] = r3;
                      r3 = top[121];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1186; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_505;
                      L1186:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = top[144];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1187; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                      L1187:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1188; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1188:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_195;
                }
              }
              r0=r0;
              goto fatbar_195_over;
              fatbar_195:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1189; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L1189:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def $loop_4138
              goto L1190;
              FUN__24loop_4138:
                check_heap (0);
                r0 = ((object***) lenv) [1][1][2];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[27];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1191; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                  L1191:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[3] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[4] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (UOTAG(9)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][4];
                      r1[2] = r2;
                      r2 = top[123];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1192; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
                      L1192:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case_noint (r0)) {
                        default: {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 4);
                          r3 = allocate (TC_TUPLE, 4);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[29];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1193; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_333;
                          L1193:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = ((object*) lenv) [2];
                          r5[2] = r6;
                          r6 = (object *) constructed_41[0];
                          r5[3] = r6;
                          r6 = top[21];
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1194; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_321;
                          L1194:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = ((object***) lenv) [1][1][2];
                          r4[3] = r5;
                          r5 = top[21];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1195; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                          L1195:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                          r4[2] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[3] = r5;
                          r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[29];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1196; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_333;
                          L1196:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*) lenv) [3];
                          r4[2] = r5;
                          r5 = (object *) constructed_41[0];
                          r4[3] = r5;
                          r5 = top[21];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1197; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                          L1197:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = ((object*) lenv) [4];
                          r3[3] = r4;
                          r4 = top[21];
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1198; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                          L1198:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[29];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1199; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_333;
                          L1199:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = ((object*) lenv) [2];
                          r5[2] = r6;
                          r6 = (object *) constructed_41[0];
                          r5[3] = r6;
                          r6 = top[21];
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1200; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_321;
                          L1200:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = ((object**) lenv) [1][3];
                          r4[3] = r5;
                          r5 = top[21];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1201; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                          L1201:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r4[2] = r5;
                          r5 = (object *) 3;
                          r6 = ((object*****) lenv) [1][1][1][1][2];
                          r5 = box((pxll_int)unbox(r6)+unbox(r5));
                          r4[3] = r5;
                          r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[29];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1202; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_333;
                          L1202:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object**) lenv) [1][2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*) lenv) [3];
                          r4[2] = r5;
                          r5 = (object *) constructed_41[0];
                          r4[3] = r5;
                          r5 = top[21];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1203; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                          L1203:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = ((object*) lenv) [5];
                          r3[3] = r4;
                          r4 = top[21];
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1204; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                          L1204:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[3] = r3;
                          r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r2[4] = r3;
                          r3 = top[121];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1205; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_505;
                          L1205:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = top[144];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1206; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                          L1206:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1207; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          L1207:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = r0;
                          r0=r0;
                        } break;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      goto fatbar_196;
                    }
                  }
                  r0=r0;
                  goto fatbar_196_over;
                  fatbar_196:
                  r0 = (object *) 14;
                  r0=r0;
                  fatbar_196_over: ;
                  lenv = lenv[1];
                  r0 = (object *) 3;
                  r1 = ((object*) lenv) [2];
                  r0 = box((pxll_int)unbox(r1)+unbox(r0));
                  lenv[2] = r0;
                  goto FUN__24loop_4138;
                }
                PXLL_RETURN(0);
              L1190:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN__24loop_4138; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = (object *) 1;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1208; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4138;
              L1208:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = r0;
              lenv = lenv[1];
              r0 = (object *) 14;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
              fatbar_195_over: ;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
          }
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_194_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(5)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = (object *) constructed_51[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object***) lenv) [1][1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object****) lenv) [1][1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object****) lenv) [1][1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            switch (get_case (r0)) {
                              case (TC_PAIR): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = ((object*) lenv) [3];
                                switch (get_case (r0)) {
                                  case (TC_NIL): {
                                    r0 = (object *) constructed_49[0];
                                    r1 = ((object***) lenv) [1][1][3];
                                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = ((object**) lenv) [1][2];
                                      r1[2] = r2;
                                      r2 = top[144];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1209; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                                      L1209:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1210; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1210:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                      r0=r0;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = ((object*) lenv) [2];
                                      r1[2] = r2;
                                      r2 = top[144];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1211; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                                      L1211:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1212; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1212:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                      r0=r0;
                                    }
                                    r0=r0;
                                  } break;
                                  default: {
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    goto fatbar_197;
                                  }
                                }
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_197;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            lenv = ((object ***)lenv)[1][1][1];
                            goto fatbar_197;
                          }
                        }
                        r0=r0;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_197;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_197;
                    }
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_197;
                }
              }
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_197;
            }
          }
          r0=r0;
          goto fatbar_197_over;
          fatbar_197:
          r0 = (object *) 14;
          r0=r0;
          fatbar_197_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object****) lenv) [1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1213; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L1213:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object***) lenv) [1][1][2];
            r3 = ((pxll_vector*)r3)->val[3];
            r2[2] = r3;
            r3 = (object *) 1;
            r2[3] = r3;
            r3 = top[27];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1214; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
            L1214:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[144];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1215; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
            L1215:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1216; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1216:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1217; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L1217:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4161
            goto L1218;
            FUN__24loop_4161:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1219; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1219:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[3];
                r0[4] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (UITAG(5)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = allocate (TC_TUPLE, 5);
                    r2[1] = lenv; lenv = r2;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = ((object******) lenv) [1][1][1][1][1][2];
                    r3[2] = r4;
                    r4 = (object *) 1;
                    r3[3] = r4;
                    r4 = ((object***) lenv) [1][1][2];
                    r3[4] = r4;
                    r4 = top[29];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1220; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_333;
                    L1220:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[2] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = ((object*) lenv) [2];
                    r4[2] = r5;
                    r5 = (object *) constructed_41[0];
                    r4[3] = r5;
                    r5 = top[21];
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1221; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                    L1221:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = ((object**) lenv) [1][4];
                    r3[3] = r4;
                    r4 = top[21];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1222; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                    L1222:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[3] = r3;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = ((object******) lenv) [1][1][1][1][1][2];
                    r3[2] = r4;
                    r4 = ((object***) lenv) [1][1][2];
                    r5 = (object *) 3;
                    r4 = box((pxll_int)unbox(r5)+unbox(r4));
                    r3[3] = r4;
                    r4 = ((object******) lenv) [1][1][1][1][1][3];
                    r3[4] = r4;
                    r4 = top[29];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1223; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_333;
                    L1223:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[4] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = ((object*) lenv) [3];
                    r4[2] = r5;
                    r5 = (object *) constructed_41[0];
                    r4[3] = r5;
                    r5 = top[21];
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1224; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
                    L1224:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = ((object*) lenv) [4];
                    r3[3] = r4;
                    r4 = top[21];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1225; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                    L1225:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[5] = r3;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object*)UITAG(5);
                    r2[2] = r3;
                    r3 = ((object*) lenv) [5];
                    r2[3] = r3;
                    r3 = top[117];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1226; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_make_node_492;
                    L1226:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    lenv = lenv[1];
                    r2 = r2;
                    r1[2] = r2;
                    r2 = top[144];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1227; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_558;
                    L1227:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1228; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1228:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } break;
                  default: {
                    goto fatbar_198;
                  }
                }
                r0=r0;
                goto fatbar_198_over;
                fatbar_198:
                r0 = (object *) 14;
                r0=r0;
                fatbar_198_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4161;
              }
              PXLL_RETURN(0);
            L1218:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4161; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1229; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4161;
            L1229:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = (object *) 14;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          }
          r0=r0;
        } break;
        default: {
          goto fatbar_191;
        }
      }
      r0=r0;
      goto fatbar_191_over;
      fatbar_191:
      r0 = (object *) 14;
      r0=r0;
      fatbar_191_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[198];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)-unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      top[198] = r0;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[144];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][2];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[3] = r2;
      r2 = top[32];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1230; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
      L1230:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object***) lenv) [1][1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object***) lenv) [1][1][2];
      PXLL_RETURN(0);
    L1164:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_27263; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[16];
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
  L1163:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_simpleopt_558; r1[2] = lenv;
  r0[144] = r1;
  // def do-one-round_561
  goto L1231;
  FUN_do_one_round_561:
    check_heap (0);
    r0 = (object*)UITAG(2);
    r1 = ((object*) lenv) [3];
    ((pxll_vector*)r1)->val[15] = r0;
    r0 = (object*)UITAG(2);
    r1 = ((object*) lenv) [3];
    ((pxll_vector*)r1)->val[3] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[8];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1232; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_262;
    L1232:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_506[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[7];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1233; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_var_261;
    L1233:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3918_i3118_i3121
    goto L1234;
    FUN_walk_3918_i3118_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1235; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L1235:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object******) lenv) [1][1][1][1][1][3];
              r1[2] = r2;
              r2 = ((object*) lenv) [2];
              r1[3] = r2;
              r2 = top[5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1236; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
              L1236:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object****) lenv) [1][1][1][3];
              r0[3] = r1;
              r1 = top[25];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1237; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
              L1237:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = ((pxll_vector*)r1)->val[1];
                r0[2] = r1;
                r0 = top[152];
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r0 = r0;
                r1 = ((object*) lenv) [3];
                ((pxll_vector*)r1)->val[1] = r0;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = top[190];
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r0 = r0;
                r1 = ((object****) lenv) [1][1][1][2];
                ((pxll_vector*)r1)->val[0] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = ((pxll_vector*)r1)->val[0];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = (object *) 3;
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv = lenv[1];
              r0 = r0;
              r1 = ((object*) lenv) [3];
              ((pxll_vector*)r1)->val[0] = r0;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_190;
            }
          }
          r0=r0;
          goto fatbar_190_over;
          fatbar_190:
          r0 = (object *) 14;
          r0=r0;
          fatbar_190_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = top[80];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[5] = r1;
          r1 = top[71];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1238; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
          L1238:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          ((pxll_vector*)r1)->val[3] = r0;
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[154];
          r0[4] = r1;
          r1 = top[6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1239; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
          L1239:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_189;
        }
      }
      r0=r0;
      goto fatbar_189_over;
      fatbar_189:
      r0 = (object *) 14;
      r0=r0;
      fatbar_189_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_25379_i3118_i3121
      goto L1240;
      FUN_lambda_25379_i3118_i3121:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_3918_i3118_i3121;
      L1240:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_25379_i3118_i3121; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1234:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3918_i3118_i3121; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_797[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1241; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3918_i3118_i3121;
    L1241:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def add-ref_3935_i3119_i3121
    goto L1242;
    FUN_add_ref_3935_i3119_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][3];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1243; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
      L1243:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[3] = r0;
      PXLL_RETURN(0);
    L1242:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_ref_3935_i3119_i3121; r1[2] = lenv;
    r0[2] = r1;
    // def add-set_3936_i3119_i3121
    goto L1244;
    FUN_add_set_3936_i3119_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][3];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1245; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
      L1245:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[4] = r0;
      PXLL_RETURN(0);
    L1244:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_set_3936_i3119_i3121; r1[2] = lenv;
    r0[3] = r1;
    // def walk_3937_i3119_i3121
    goto L1246;
    FUN_walk_3937_i3119_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1247; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
          L1247:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [3];
          ((pxll_vector*)r1)->val[3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1248; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
          L1248:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [3];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_188;
        }
      }
      r0=r0;
      goto fatbar_188_over;
      fatbar_188:
      r0 = (object *) 14;
      r0=r0;
      fatbar_188_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1246:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3937_i3119_i3121; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1249; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3937_i3119_i3121;
    L1249:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_796[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def find-escaping-functions_4083_i3120_i3121
    goto L1250;
    FUN_find_escaping_functions_4083_i3120_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(10)): {
              r0 = (object *) 14;
              r0=r0;
            } break;
            default: {
              goto fatbar_186;
            }
          }
          r0=r0;
          goto fatbar_186_over;
          fatbar_186:
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[153];
          r0[4] = r1;
          r1 = top[6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1251; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
          L1251:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object*****) lenv) [1][1][1][1][2] = r0;
          r0=r0;
          fatbar_186_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1252; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
          L1252:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[1];
          r0[3] = r1;
          r0 = top[154];
          r1 = ((object*) lenv) [3];
          r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(8)): {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][3];
                r1 = ((pxll_vector*)r1)->val[3];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = top[19];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1253; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
                L1253:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r2 = ((object*) lenv) [3];
                r1 = PXLL_TEST(r2==r1);
                r0[4] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [4];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[3] = r1;
                  r1 = top[153];
                  r0[4] = r1;
                  r1 = top[6];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1254; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
                  L1254:
                  ; lenv = k[2]; k = k[1];
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object***) lenv) [1][1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object******) lenv) [1][1][1][1][1][2] = r0;
                  r0=r0;
                } else {
                  r0 = (object *) 14;
                  r0=r0;
                }
                r0=r0;
              } break;
              default: {
                goto fatbar_187;
              }
            }
            r0=r0;
            goto fatbar_187_over;
            fatbar_187:
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[153];
            r0[4] = r1;
            r1 = top[6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1255; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
            L1255:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object******) lenv) [1][1][1][1][1][2] = r0;
            r0=r0;
            fatbar_187_over: ;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } else {
            r0 = (object *) 14;
            r0=r0;
          }
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_185;
        }
      }
      r0=r0;
      goto fatbar_185_over;
      fatbar_185:
      r0 = (object *) 14;
      r0=r0;
      fatbar_185_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_26597_i3120_i3121
      goto L1256;
      FUN_lambda_26597_i3120_i3121:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_4083_i3120_i3121;
      L1256:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_26597_i3120_i3121; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1250:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_functions_4083_i3120_i3121; r1[2] = lenv;
    r0[2] = r1;
    // def maybe-var-escapes_4084_i3120_i3121
    goto L1257;
    FUN_maybe_var_escapes_4084_i3120_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = top[25];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1258; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_329;
      L1258:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object****) lenv) [1][1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[153];
        r0[4] = r1;
        r1 = top[6];
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1257:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_maybe_var_escapes_4084_i3120_i3121; r1[2] = lenv;
    r0[3] = r1;
    // def find-escaping-variables_4085_i3120_i3121
    goto L1259;
    FUN_find_escaping_variables_4085_i3120_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1260; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1260:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[21];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1261; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          L1261:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1262; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1262:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[21];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1263; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          L1263:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1264; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1264:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[21];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1265; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          L1265:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1266; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_4084_i3120_i3121;
          L1266:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1267; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_4084_i3120_i3121;
          L1267:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_184;
        }
      }
      r0=r0;
      goto fatbar_184_over;
      fatbar_184:
      r0 = (object *) 14;
      r0=r0;
      fatbar_184_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_26682_i3120_i3121
      goto L1268;
      FUN_lambda_26682_i3120_i3121:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_4085_i3120_i3121;
      L1268:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_26682_i3120_i3121; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[35];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1259:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_variables_4085_i3120_i3121; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = (object *) 1;
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(2),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r2 = (object *) constructed_795[0];
    r1[3] = r2;
    r2 = top[117];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1269; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
    L1269:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1270; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_4083_i3120_i3121;
    L1270:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_26726_i3120_i3121
    goto L1271;
    FUN_lambda_26726_i3120_i3121:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 4);
      r2 = ((object*****) lenv) [1][1][1][1][3];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[2] = r2;
      r2 = top[80];
      r1[3] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[4] = r2;
      r2 = top[72];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1272; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
      L1272:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UOTAG(0)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_794;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1273; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1273:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        } break;
      }
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = (object *) constructed_793[0];
      r0[3] = r1;
      r1 = ((object***) lenv) [1][1][4];
      r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_4085_i3120_i3121;
    L1271:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_26726_i3120_i3121; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[35];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1274; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1274:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = r0;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[141];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1275; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_build_dependency_graph_545;
    L1275:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][3];
    r4 = ((pxll_vector*)r4)->val[2];
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = (object *) constructed_792[0];
    r4[2] = r5;
    r5 = top[140];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L1276; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_symbol_set_maker_544;
    L1276:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    // def walk_4171_i3123
    goto L1277;
    FUN_walk_4171_i3123:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1278; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1278:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1279; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1279:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_27304_i3123
          goto L1280;
          FUN_lambda_27304_i3123:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
            r2 = ((pxll_vector*)r2)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1281; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1281:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[1] = r1[2]; lenv = r0; goto FUN_walk_4171_i3123;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1280:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_27304_i3123; r1[2] = lenv;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1282; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1282:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[35];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        } break;
      }
      PXLL_RETURN(0);
    L1277:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_walk_4171_i3123; r4[2] = lenv;
    r3[2] = r4;
    // def trim_4172_i3123
    goto L1283;
    FUN_trim_4172_i3123:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UOTAG(10)): {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[22];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1284; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
          L1284:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[4] = r2;
          r2 = (object *) constructed_791[0];
          r1[5] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_4184_i3123
          goto L1285;
          FUN__24loop_4184_i3123:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*****) lenv) [1][1][1][1][2];
              r2[2] = r3;
              r3 = ((object**) lenv) [1][2];
              r2[3] = r3;
              r3 = top[27];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1286; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
              L1286:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
              r2 = ((pxll_vector*)r2)->val[2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1287; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L1287:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][5];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object****) lenv) [1][1][1][5] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4184_i3123;
            }
            PXLL_RETURN(0);
          L1285:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_4184_i3123; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1288; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4184_i3123;
          L1288:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
              r1=r1;
            } break;
            default: {
              goto fatbar_183;
            }
          }
          r1=r1;
          goto fatbar_183_over;
          fatbar_183:
          r1 = (object *) 6;
          r1=r1;
          fatbar_183_over: ;
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = ((object***) lenv) [1][1][2];
            r1=r1;
          } else {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_790[0];
            r1[2] = r2;
            r2 = (object *) constructed_789[0];
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 3);
            // def lambda_27385_i3123
            goto L1289;
            FUN_lambda_27385_i3123:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[27];
              r0[1] = r1[2]; lenv = r0; goto FUN_nth_331;
            L1289:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN_lambda_27385_i3123; r3[2] = lenv;
            r2[2] = r3;
            r3 = ((object**) lenv) [1][5];
            r2[3] = r3;
            r3 = top[32];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1290; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
            L1290:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][3];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4191_i3123
            goto L1291;
            FUN__24loop_4191_i3123:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object******) lenv) [1][1][1][1][1][5];
                r1[3] = r2;
                r2 = top[25];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1292; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_329;
                L1292:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[27];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1293; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                  L1293:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][2];
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object****) lenv) [1][1][1][2] = r0;
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][4];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[27];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1294; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                  L1294:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][3];
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object****) lenv) [1][1][1][3] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4191_i3123;
              }
              PXLL_RETURN(0);
            L1291:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4191_i3123; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1295; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4191_i3123;
            L1295:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 4);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1296; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L1296:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1297; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L1297:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1298; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_last_327;
            L1298:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = top[120];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1299; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_node_2ffix_504;
            L1299:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          goto fatbar_182;
        }
      }
      r1=r1;
      goto fatbar_182_over;
      fatbar_182:
      r1 = ((object**) lenv) [1][2];
      r1=r1;
      fatbar_182_over: ;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object***) lenv) [1][1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[32];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1300; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_336;
      L1300:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object*) lenv) [3];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    L1283:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_trim_4172_i3123; r4[2] = lenv;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 2);
    r4 = (object *) constructed_506[0];
    r3[2] = r4;
    r4 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1301; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_walk_4171_i3123;
    L1301:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object****) lenv) [1][1][1][2];
    r3[2] = r4;
    r4 = ((object*) lenv) [3];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1302; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_trim_4172_i3123;
    L1302:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    lenv = lenv[1];
    r3 = r3;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = top[143];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1303; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_do_simple_optimizations_557;
    L1303:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = top[112];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1304; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_478;
    L1304:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = top[112];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1305; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_478;
    L1305:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[4] = r2;
    r2 = (object*)UITAG(0);
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 7);
    r1[1] = lenv; lenv = r1;
    // def set-multiplier_3953_i3122
    goto L1306;
    FUN_set_multiplier_3953_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object*) lenv) [2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1307; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1307:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          // def lambda_25561_i3122
          goto L1308;
          FUN_lambda_25561_i3122:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][5];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[66];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1309; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L1309:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                r0[2] = r1;
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                r1 = ((object*) lenv) [2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object*******) lenv) [1][1][1][1][1][1][5] = r0;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1308:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_25561_i3122; r1[2] = lenv;
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,30)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1306:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_set_multiplier_3953_i3122; r2[2] = lenv;
    r1[2] = r2;
    // def follow-aliases_3954_i3122
    goto L1310;
    FUN_follow_aliases_3954_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = top[66];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1311; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L1311:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_follow_aliases_3954_i3122;
            } break;
            default: {
              goto fatbar_181;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_181_over;
          fatbar_181:
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
          fatbar_181_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1310:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_follow_aliases_3954_i3122; r2[2] = lenv;
    r1[3] = r2;
    // def get-fun-calls_3955_i3122
    goto L1312;
    FUN_get_fun_calls_3955_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][5];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[66];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1313; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L1313:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)*unbox(r0));
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1312:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_get_fun_calls_3955_i3122; r2[2] = lenv;
    r1[4] = r2;
    // def inline_3956_i3122
    goto L1314;
    FUN_inline_3956_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_25872_i3122
      goto L1315;
      FUN_lambda_25872_i3122:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1316; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L1316:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_3984_i3122
            goto L1317;
            FUN__24loop_3984_i3122:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][3];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1318; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1318:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1319; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1319:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r0[4] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [4];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object******) lenv) [1][1][1][1][1][3] = r0;
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_3984_i3122;
              }
              PXLL_RETURN(0);
            L1317:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_3984_i3122; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1320; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3984_i3122;
            L1320:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UITAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = (object*) &constructed_73;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_73;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_72;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_72;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
                r0=r0;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[4] = r1;
                r0 = ((object*) lenv) [4];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1321; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_follow_aliases_3954_i3122;
                    L1321:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (UITAG(1)): {
                        r0 = (object *) 14;
                        r0=r0;
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 8);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object**) lenv) [1][2];
                        r1[3] = r2;
                        r2 = top[5];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1322; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
                        L1322:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = ((object*) lenv) [3];
                        r1 = ((pxll_vector*)r1)->val[1];
                        r0[4] = r1;
                        r1 = top[153];
                        r2 = ((object*) lenv) [4];
                        r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                        r0[5] = r1;
                        r1 = ((object*) lenv) [3];
                        r1 = ((pxll_vector*)r1)->val[1];
                        r0[6] = r1;
                        r1 = top[152];
                        r2 = ((object*) lenv) [6];
                        r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                        r0[7] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object**) lenv) [1][2];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [3];
                        r2 = ((pxll_vector*)r2)->val[0];
                        r1[3] = r2;
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1323; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_fun_calls_3955_i3122;
                        L1323:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[8] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case (r0)) {
                          case (UOTAG(7)): {
                            r0 = (object *) 262;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_180;
                          }
                        }
                        r0=r0;
                        goto fatbar_180_over;
                        fatbar_180:
                        r0 = (object *) 6;
                        r0=r0;
                        fatbar_180_over: ;
                        lenv = lenv[1];
                        r0 = r0;
                        if PXLL_IS_TRUE(r0) {
                          r0 = allocate (TC_TUPLE, 4);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][2];
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object****) lenv) [1][1][1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = ((object*) lenv) [2];
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                          r0[2] = r1;
                          r1 = (object *) 1;
                          r2 = ((object*) lenv) [2];
                          range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                          r1 = (object *) 1;
                          r2 = ((object*) lenv) [2];
                          r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                          r0[3] = r1;
                          r1 = (object *) 24066;
                          r2 = ((object*) lenv) [3];
                          r1 = PXLL_TEST(r2==r1);
                          r0[4] = r1;
                          r0 = (object *) 6;
                          r1 = ((object*) lenv) [4];
                          r0 = PXLL_TEST(r1==r0);
                          lenv = lenv[1];
                          r0 = r0;
                          if PXLL_IS_TRUE(r0) {
                            r0 = (object *) 1;
                            r1 = ((object*) lenv) [8];
                            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,72)];
                              r0[2] = r1;
                              r0 = top[197];
                              r1 = ((object*) lenv) [2];
                              r0 = PXLL_TEST(unbox(r1)<=unbox(r0));
                              lenv = lenv[1];
                              r0 = r0;
                              if PXLL_IS_TRUE(r0) {
                                r0 = (object *) 262;
                                r0=r0;
                              } else {
                                r0 = (object *) 3;
                                r1 = ((object*) lenv) [8];
                                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                  r0 = (object *) 6;
                                  r1 = ((object*) lenv) [5];
                                  r0 = PXLL_TEST(r1==r0);
                                  r0=r0;
                                } else {
                                  r0 = (object *) 6;
                                  r0=r0;
                                }
                                r0=r0;
                              }
                              if PXLL_IS_TRUE(r0) {
                                r0 = (object *) 6;
                                r1 = ((object*) lenv) [7];
                                r0 = PXLL_TEST(r1==r0);
                                r0=r0;
                              } else {
                                r0 = (object *) 6;
                                r0=r0;
                              }
                              r0=r0;
                            } else {
                              r0 = (object *) 6;
                              r0=r0;
                            }
                            r0=r0;
                          } else {
                            r0 = (object *) 6;
                            r0=r0;
                          }
                          r0=r0;
                        } else {
                          r0 = (object *) 6;
                          r0=r0;
                        }
                        if PXLL_IS_TRUE(r0) {
                          r0 = (object *) 3;
                          r1 = ((object*) lenv) [8];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = ((object**) lenv) [1][2];
                            r0[2] = r1;
                            r1 = ((object*) lenv) [8];
                            r0[3] = r1;
                            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L1324; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto FUN_set_multiplier_3953_i3122;
                            L1324:
                            ; lenv = k[2]; k = k[1];
                            r0 = result;
                          } else {
                            r0 = (object *) 14;
                          }
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = ((object****) lenv) [1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][6];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1325; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_inline_application_3959_i3122;
                          L1325:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = ((object*) lenv) [2];
                          r0[2] = r1;
                          r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                          r0[3] = r1;
                          r1 = top[8];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1326; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_262;
                          L1326:
                          ; lenv = k[2]; k = k[1];
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1327; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_inline_3956_i3122;
                          L1327:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1328; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          L1328:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = r0;
                          r0=r0;
                        } else {
                          r0 = (object *) 14;
                          r0=r0;
                        }
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } break;
                    }
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } break;
                  case (UOTAG(7)): {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object******) lenv) [1][1][1][1][1][2];
                    r3 = ((pxll_vector*)r3)->val[lookup_field((GET_TYPECODE(*r3)-TC_USEROBJ)>>2,73)];
                    r2[2] = r3;
                    r3 = top[19];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1329; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                    L1329:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object**) lenv) [1][3];
                    r1[3] = r2;
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][6];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1330; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_inline_application_3959_i3122;
                    L1330:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object*) lenv) [4];
                    r0[2] = r1;
                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                    r0[3] = r1;
                    r1 = top[8];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1331; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_262;
                    L1331:
                    ; lenv = k[2]; k = k[1];
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*) lenv) [4];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    r1[3] = r2;
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][5];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1332; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_inline_3956_i3122;
                    L1332:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*****) lenv) [1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1333; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1333:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_179;
                  }
                }
                lenv = lenv[1];
                r0 = r0;
                r0=r0;
              } break;
            }
            r0=r0;
            goto fatbar_179_over;
            fatbar_179:
            r0 = (object *) 14;
            r0=r0;
            fatbar_179_over: ;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          default: {
            goto fatbar_178;
          }
        }
        r0=r0;
        goto fatbar_178_over;
        fatbar_178:
        r0 = (object *) 14;
        r0=r0;
        fatbar_178_over: ;
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_25864_i3122
        goto L1334;
        FUN_lambda_25864_i3122:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][5];
          r0[1] = r1[2]; lenv = r0; goto FUN_inline_3956_i3122;
        L1334:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_25864_i3122; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,73)];
        r0[3] = r1;
        r1 = top[32];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1335; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_336;
        L1335:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,73)] = r0;
        r0 = ((object**) lenv) [1][2];
        PXLL_RETURN(0);
      L1315:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_25872_i3122; r1[2] = lenv;
      r0[2] = r1;
      r1 = top[16];
      r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
    L1314:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_3956_i3122; r2[2] = lenv;
    r1[5] = r2;
    // def inline-application_3959_i3122
    goto L1336;
    FUN_inline_application_3959_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_788[0];
      r0[2] = r1;
      r1 = (object *) constructed_787[0];
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = top[22];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1337; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
      L1337:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1338; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L1338:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r2 = ((object***) lenv) [1][1][4];
          r1 = PXLL_TEST(unbox(r2)==unbox(r1));
          r0[3] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [3];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_777;
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4042_i3122
            goto L1339;
            FUN__24loop_4042_i3122:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1340; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1340:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[5];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1341; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
                L1341:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1342; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1342:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[2] = r1;
                r0 = (object *) 1;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object***) lenv) [1][1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object******) lenv) [1][1][1][1][1][3] = r0;
                  r0=r0;
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(2)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object****) lenv) [1][1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      lenv = lenv[1];
                      r0 = r0;
                      ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
                      r0=r0;
                    } break;
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[5];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1343; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
                      L1343:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = ((pxll_vector*)r1)->val[4];
                      r0[2] = r1;
                      r0 = (object *) 1;
                      r1 = ((object*) lenv) [2];
                      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        ((object********) lenv) [1][1][1][1][1][1][1][3] = r0;
                        r0=r0;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
                        r0=r0;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      goto fatbar_176;
                    }
                  }
                  r0=r0;
                  goto fatbar_176_over;
                  fatbar_176:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][3];
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = (object *) 3;
                  r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[3] = r1;
                        r1 = ((object*) lenv) [2];
                        r1 = ((pxll_vector*)r1)->val[3];
                        r0[4] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (UOTAG(12)): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r0 = (object *) constructed_312[0];
                            r1 = ((object*) lenv) [2];
                            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                              r0 = ((object**) lenv) [1][4];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 4);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object***************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][3];
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[5];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1344; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
                                      L1344:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = ((object*) lenv) [3];
                                      r1 = ((pxll_vector*)r1)->val[4];
                                      r0[4] = r1;
                                      r0 = ((object*) lenv) [4];
                                      r1 = (object *) 1;
                                      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r0=r0;
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_177;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r0 = r0;
                                  r0=r0;
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_177;
                                }
                              }
                              r0=r0;
                            } else {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_177;
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            lenv = ((object *)lenv)[1];
                            goto fatbar_177;
                          }
                        }
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } break;
                      default: {
                        goto fatbar_177;
                      }
                    }
                    r0=r0;
                    goto fatbar_177_over;
                    fatbar_177:
                    r0 = (object *) 6;
                    r0=r0;
                    fatbar_177_over: ;
                    r0=r0;
                  } else {
                    r0 = (object *) 6;
                    r0=r0;
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
                    r0=r0;
                  } else {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    ((object*******) lenv) [1][1][1][1][1][1][3] = r0;
                    r0=r0;
                  }
                  r0=r0;
                  fatbar_176_over: ;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                }
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4042_i3122;
              }
              PXLL_RETURN(0);
            L1339:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4042_i3122; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1345; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4042_i3122;
            L1345:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_785[0];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r4 = ((pxll_vector*)r4)->val[1];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L1346; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            lenv = r4[2]; goto *r4[1];
            L1346:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = top[56];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L1347; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
            L1347:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [3];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_784;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = top[47];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1348; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
            L1348:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[3];
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1349; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1349:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            // def append-suffix_4006_i3037_i3122
            goto L1350;
            FUN_append_suffix_4006_i3037_i3122:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = ((object**) lenv) [1][2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object***) lenv) [1][1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object****) lenv) [1][1][1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1351; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L1351:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = top[79];
              r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_425;
            L1350:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_append_suffix_4006_i3037_i3122; r2[2] = lenv;
            r1[2] = r2;
            // def rename_4007_i3037_i3122
            goto L1352;
            FUN_rename_4007_i3037_i3122:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def get-new-name_4011_i3037_i3122
              goto L1353;
              FUN_get_new_name_4011_i3037_i3122:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1354; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4006_i3037_i3122;
                L1354:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][3];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object****) lenv) [1][1][1][3] = r0;
                r0 = ((object*) lenv) [2];
                PXLL_RETURN(0);
              L1353:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_get_new_name_4011_i3037_i3122; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = ((object*) lenv) [2];
                  r0=r0;
                } break;
                default: {
                  goto fatbar_175;
                }
              }
              r0=r0;
              goto fatbar_175_over;
              fatbar_175:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[3] = r2;
              r2 = top[117];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1355; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
              L1355:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object**) lenv) [1][2];
              r0 = ((pxll_vector*)r0)->val[0];
              r1 = ((object*) lenv) [2];
              ((pxll_vector*)r1)->val[0] = r0;
              r0 = ((object**) lenv) [1][2];
              r0 = ((pxll_vector*)r0)->val[5];
              r1 = ((object*) lenv) [2];
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
              fatbar_175_over: ;
              lenv = lenv[1];
              r0 = r0;
              ((object**) lenv) [1][2] = r0;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1356; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L1356:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(9),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1357; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L1357:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(10),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(7)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][2];
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1358; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_new_name_4011_i3037_i3122;
                  L1358:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][3];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1359; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L1359:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(7),2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r0[2] = r1;
                  r1 = ((object****) lenv) [1][1][1][3];
                  r0[3] = r1;
                  r1 = top[25];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1360; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
                  L1360:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1361; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4006_i3037_i3122;
                    L1361:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = ((object****) lenv) [1][1][1][2];
                    ((pxll_vector*)r1)->val[4] = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r0[2] = r1;
                  r1 = ((object****) lenv) [1][1][1][3];
                  r0[3] = r1;
                  r1 = top[25];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1362; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
                  L1362:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1363; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4006_i3037_i3122;
                    L1363:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = ((object****) lenv) [1][1][1][2];
                    ((pxll_vector*)r1)->val[4] = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_174;
                }
              }
              r0=r0;
              goto fatbar_174_over;
              fatbar_174:
              r0 = (object *) 14;
              r0=r0;
              fatbar_174_over: ;
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_26035_i3037_i3122
              goto L1364;
              FUN_lambda_26035_i3037_i3122:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r0[3] = r1;
                r1 = ((object****) lenv) [1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_4007_i3037_i3122;
              L1364:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_26035_i3037_i3122; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[3] = r1;
              r1 = top[32];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1365; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_map_336;
              L1365:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = ((object**) lenv) [1][2];
              ((pxll_vector*)r1)->val[3] = r0;
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            L1352:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_rename_4007_i3037_i3122; r2[2] = lenv;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = (object *) constructed_783[0];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1366; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_rename_4007_i3037_i3122;
            L1366:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            switch (get_case (r2)) {
              case (TC_NIL): {
                r2 = (object *) 262;
                r2=r2;
              } break;
              default: {
                goto fatbar_173;
              }
            }
            r2=r2;
            goto fatbar_173_over;
            fatbar_173:
            r2 = (object *) 6;
            r2=r2;
            fatbar_173_over: ;
            r1[3] = r2;
            r1 = (object *) 6;
            r2 = ((object*) lenv) [3];
            r1 = PXLL_TEST(r2==r1);
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_26268_i3122
              goto L1367;
              FUN_lambda_26268_i3122:
                check_heap (0);
                r0 = allocate (UOTAG(1), 2);
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object***) lenv) [1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1368; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1368:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[1] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1369; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1369:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                PXLL_RETURN(0);
              L1367:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_26268_i3122; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[32];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1370; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
              L1370:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) constructed_782[0];
              r1=r1;
            }
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r0[2] = r1;
            r1 = (object*)TC_NIL;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [5];
              r0[2] = r1;
              r1 = ((object*) lenv) [6];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][7];
              r0[1] = r1[2]; lenv = r0; goto FUN_substitute_3960_i3122;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_781[0];
              r0[2] = r1;
              r1 = (object *) constructed_780[0];
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object****) lenv) [1][1][1][3];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1371; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L1371:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_26337_i3122
              goto L1372;
              FUN_lambda_26337_i3122:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*****) lenv) [1][1][1][1][3];
                r2[2] = r3;
                r3 = ((object**) lenv) [1][2];
                r2[3] = r3;
                r3 = top[27];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1373; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                L1373:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 4);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r5 = ((pxll_vector*)r5)->val[1];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L1374; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                lenv = r5[2]; goto *r5[1];
                L1374:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L1375; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L1375:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_779;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1376; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L1376:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = top[142];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1377; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_symbol_add_suffix_554;
                L1377:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object***) lenv) [1][1][2] = r0;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object***) lenv) [1][1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1378; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1378:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][3];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object***) lenv) [1][1][3] = r0;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (UOTAG(1), 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object******) lenv) [1][1][1][1][1][3];
                r2[2] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r2[3] = r3;
                r3 = top[27];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1379; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                L1379:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[1] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r3;
                r3 = t;
                r2[2] = r3;
                r3 = (object *) constructed_778[0];
                r2[3] = r3;
                r3 = top[117];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1380; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_make_node_492;
                L1380:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][6];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object****) lenv) [1][1][1][6] = r0;
                PXLL_RETURN(0);
              L1372:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_26337_i3122; r1[2] = lenv;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object*****) lenv) [1][1][1][1][3];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_41[0];
              r1[3] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1381; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
              L1381:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[3] = r1;
              r1 = top[35];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1382; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
              L1382:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object***) lenv) [1][1][5];
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][6];
              r1[3] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][7];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1383; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substitute_3960_i3122;
              L1383:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_41[0];
              r1[3] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1384; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
              L1384:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_41[0];
              r1[3] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1385; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
              L1385:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r0[4] = r1;
              r1 = top[121];
              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_505;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_172;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_172_over;
      fatbar_172:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_786;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_172_over: ;
      PXLL_RETURN(0);
    L1336:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_application_3959_i3122; r2[2] = lenv;
    r1[6] = r2;
    // def substitute_3960_i3122
    goto L1386;
    FUN_substitute_3960_i3122:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      // def lookup_4061_i3122
      goto L1387;
      FUN_lookup_4061_i3122:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_4064_i3122
        goto L1388;
        FUN_loop_4064_i3122:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case_noint (r0)) {
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object*****) lenv) [1][1][1][1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object**) lenv) [1][3];
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    goto FUN_loop_4064_i3122;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1388:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_4064_i3122; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object****) lenv) [1][1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_4064_i3122;
      L1387:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lookup_4061_i3122; r1[2] = lenv;
      r0[2] = r1;
      // def walk_4062_i3122
      goto L1389;
      FUN_walk_4062_i3122:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1390; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_4061_i3122;
            L1390:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                r1 = ((object***) lenv) [1][1][2];
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1391; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_4061_i3122;
            L1391:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 4);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*) lenv) [2];
                r3 = ((pxll_vector*)r3)->val[lookup_field((GET_TYPECODE(*r3)-TC_USEROBJ)>>2,54)];
                r2[2] = r3;
                r3 = top[118];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1392; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_varref__3ename_495;
                L1392:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object****) lenv) [1][1][1][2];
                r3 = ((pxll_vector*)r3)->val[3];
                r2[2] = r3;
                r3 = top[19];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1393; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                L1393:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r2;
                r2 = t;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r2 = ((object*) lenv) [2];
                r3 = ((object**) lenv) [1][4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[3] = r2;
                r2 = top[117];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1394; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_make_node_492;
                L1394:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                r1 = ((object***) lenv) [1][1][2];
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            goto fatbar_171;
          }
        }
        r1=r1;
        goto fatbar_171_over;
        fatbar_171:
        r1 = ((object**) lenv) [1][2];
        r1=r1;
        fatbar_171_over: ;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = top[32];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1395; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_336;
        L1395:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*) lenv) [3];
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      L1389:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_4062_i3122; r1[2] = lenv;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[1] = r1[2]; lenv = r0; goto FUN_walk_4062_i3122;
    L1386:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_substitute_3960_i3122; r2[2] = lenv;
    r1[7] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = ((object*) lenv) [5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1396; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_inline_3956_i3122;
    L1396:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = top[143];
    r0[1] = r1[2]; lenv = r0; goto FUN_do_simple_optimizations_557;
  L1231:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_one_round_561; r1[2] = lenv;
  r0[145] = r1;
  // def encode-immediate_564
  goto L1397;
  FUN_encode_immediate_564:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)<<unbox(r1));
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = box((pxll_int)GET_CHAR(r1));
        r0[3] = r1;
        r1 = (object *) 17;
        r2 = ((object*) lenv) [3];
        r1 = box((pxll_int)unbox(r2)<<unbox(r1));
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        r1 = (object *) 5;
        r0 = box((pxll_int)unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = (object *) 29;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_46[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 13;
            PXLL_RETURN(0);
          } else {
            goto fatbar_170;
          }
          PXLL_RETURN(0);
          goto fatbar_170_over;
          fatbar_170:
          r0 = (object *) constructed_49[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 525;
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_169;
          }
          PXLL_RETURN(0);
          fatbar_170_over: ;
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_169;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_169;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_169_over;
    fatbar_169:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_776;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_169_over: ;
    PXLL_RETURN(0);
  L1397:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_encode_immediate_564; r1[2] = lenv;
  r0[146] = r1;
  // def wrap-in_565
  goto L1398;
  FUN_wrap_in_565:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_512[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_88[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = (object*)TC_NIL;
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r3 = (object*) &constructed_761;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*****) lenv) [1][1][1][1][3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_760;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[2] = r1;
                        r1 = top[47];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_158;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_158;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_158;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_158;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_158_over;
          fatbar_158:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_762;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[14];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          fatbar_158_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_157;
        }
        PXLL_RETURN(0);
        goto fatbar_157_over;
        fatbar_157:
        r0 = (object *) constructed_764[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_159;
        }
        PXLL_RETURN(0);
        goto fatbar_159_over;
        fatbar_159:
        r0 = (object *) constructed_718[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_160;
        }
        PXLL_RETURN(0);
        goto fatbar_160_over;
        fatbar_160:
        r0 = (object *) constructed_63[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_161;
        }
        PXLL_RETURN(0);
        goto fatbar_161_over;
        fatbar_161:
        r0 = (object *) constructed_469[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_162;
        }
        PXLL_RETURN(0);
        goto fatbar_162_over;
        fatbar_162:
        r0 = (object *) constructed_99[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_163;
        }
        PXLL_RETURN(0);
        goto fatbar_163_over;
        fatbar_163:
        r0 = (object *) constructed_744[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_164;
        }
        PXLL_RETURN(0);
        goto fatbar_164_over;
        fatbar_164:
        r0 = (object *) constructed_478[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 7);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object***) lenv) [1][1][2];
          r2[2] = r3;
          r3 = top[148];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1399; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_566;
          L1399:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = (object*)TC_NIL;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_767;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r2 = ((object*) lenv) [4];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[5] = r2;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_766;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[6] = r2;
          r2 = ((object*) lenv) [6];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[7] = r2;
          r1 = ((object*) lenv) [7];
          r2 = (object*) &constructed_765;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_165;
        }
        PXLL_RETURN(0);
        goto fatbar_165_over;
        fatbar_165:
        r0 = (object *) constructed_747[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_768;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_166;
        }
        PXLL_RETURN(0);
        goto fatbar_166_over;
        fatbar_166:
        r0 = (object *) constructed_88[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_770;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_769;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_167;
        }
        PXLL_RETURN(0);
        goto fatbar_167_over;
        fatbar_167:
        r0 = (object *) constructed_223[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_772;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_771;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_168;
        }
        PXLL_RETURN(0);
        goto fatbar_168_over;
        fatbar_168:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[200];
        r0[3] = r1;
        r1 = top[25];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1400; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
        L1400:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_774;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_773;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_775;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[14];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        }
        PXLL_RETURN(0);
        fatbar_168_over: ;
        PXLL_RETURN(0);
        fatbar_167_over: ;
        PXLL_RETURN(0);
        fatbar_166_over: ;
        PXLL_RETURN(0);
        fatbar_165_over: ;
        PXLL_RETURN(0);
        fatbar_164_over: ;
        PXLL_RETURN(0);
        fatbar_163_over: ;
        PXLL_RETURN(0);
        fatbar_162_over: ;
        PXLL_RETURN(0);
        fatbar_161_over: ;
        PXLL_RETURN(0);
        fatbar_160_over: ;
        PXLL_RETURN(0);
        fatbar_159_over: ;
        PXLL_RETURN(0);
        fatbar_157_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1398:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_in_565; r1[2] = lenv;
  r0[147] = r1;
  // def irken-type->c-type_566
  goto L1401;
  FUN_irken_type__3ec_type_566:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_756[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = allocate (TC_TUPLE, 4);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object**) lenv) [1][2];
                  r2[2] = r3;
                  r3 = top[148];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L1402; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_566;
                  L1402:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = (object*)TC_NIL;
                  r1[3] = r2;
                  r2 = ((object*) lenv) [3];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[4] = r2;
                  r1 = ((object*) lenv) [4];
                  r2 = (object*) &constructed_754;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[2] = r1;
                  r1 = top[47];
                  r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_155;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_155;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_155;
        }
        PXLL_RETURN(0);
        goto fatbar_155_over;
        fatbar_155:
        r0 = (object *) constructed_478[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = allocate (TC_TUPLE, 5);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object**) lenv) [1][2];
                  r2[2] = r3;
                  r3 = top[148];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L1403; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_566;
                  L1403:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = (object*)TC_NIL;
                  r1[3] = r2;
                  r2 = ((object*) lenv) [3];
                  r3 = (object*) &constructed_758;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[4] = r2;
                  r2 = ((object*) lenv) [4];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[5] = r2;
                  r1 = ((object*) lenv) [5];
                  r2 = (object*) &constructed_757;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[2] = r1;
                  r1 = top[47];
                  r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_156;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_156;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_156;
        }
        PXLL_RETURN(0);
        goto fatbar_156_over;
        fatbar_156:
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_154;
          }
        }
        PXLL_RETURN(0);
        fatbar_156_over: ;
        PXLL_RETURN(0);
        fatbar_155_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_154;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_154_over;
    fatbar_154:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_759;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[106];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1404; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_468;
    L1404:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_154_over: ;
    PXLL_RETURN(0);
  L1401:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_irken_type__3ec_type_566; r1[2] = lenv;
  r0[148] = r1;
  // def wrap-out_567
  goto L1405;
  FUN_wrap_out_567:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = (object *) constructed_744[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_742;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_150;
        }
        PXLL_RETURN(0);
        goto fatbar_150_over;
        fatbar_150:
        r0 = (object *) constructed_747[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_745;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_151;
        }
        PXLL_RETURN(0);
        goto fatbar_151_over;
        fatbar_151:
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_749;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_748;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_152;
        }
        PXLL_RETURN(0);
        goto fatbar_152_over;
        fatbar_152:
        r0 = (object *) constructed_223[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_751;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_750;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_153;
        }
        PXLL_RETURN(0);
        goto fatbar_153_over;
        fatbar_153:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[200];
        r0[3] = r1;
        r1 = top[25];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1406; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
        L1406:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_753;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_752;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
        fatbar_153_over: ;
        PXLL_RETURN(0);
        fatbar_152_over: ;
        PXLL_RETURN(0);
        fatbar_151_over: ;
        PXLL_RETURN(0);
        fatbar_150_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_149;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_149_over;
    fatbar_149:
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
    fatbar_149_over: ;
    PXLL_RETURN(0);
  L1405:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_out_567; r1[2] = lenv;
  r0[149] = r1;
  // def cexp-subst_568
  goto L1407;
  FUN_cexp_subst_568:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) 9474;
    r1[3] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1408; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_split_364;
    L1408:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4248
    goto L1409;
    FUN_loop_4248:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1410; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1410:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[47];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object*) &constructed_740;
          r1[3] = r2;
          r2 = top[50];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1411; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
          L1411:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_738;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][2];
                r2 = (object*) &constructed_739;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = ((object*) lenv) [3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_4248;
              } break;
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_148;
          }
          PXLL_RETURN(0);
          goto fatbar_148_over;
          fatbar_148:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[166];
          r1[2] = r2;
          r2 = (object *) 1;
          r3 = ((object**) lenv) [1][2];
          range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
          r2 = (object *) 1;
          r3 = ((object**) lenv) [1][2];
          r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
          r1[3] = r2;
          r2 = top[66];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1412; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L1412:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UITAG(1)): {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_741;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[3] = r1;
              r1 = top[14];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              r2 = ((object****) lenv) [1][1][1][2];
              r1[2] = r2;
              r2 = (object *) 3;
              r1[3] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[4] = r2;
              r2 = top[45];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1413; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
              L1413:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[27];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1414; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
              L1414:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = ((object***) lenv) [1][1][3];
              lenv = ((object ***)lenv)[1][1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_4248;
            } break;
          }
          PXLL_RETURN(0);
          fatbar_148_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1409:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4248; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = allocate (TC_TUPLE, 3);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object***) lenv) [1][1][2];
    r2[2] = r3;
    r3 = top[19];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1415; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
    L1415:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[20];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1416; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
    L1416:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4248;
  L1407:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cexp_subst_568; r1[2] = lenv;
  r0[150] = r1;
  // def getenv-or_578
  goto L1417;
  FUN_getenv_or_578:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[53];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1418; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
    L1418:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1 = (object*)getenv (((pxll_string*)(r1))->data);
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST((char*)r1==NULL)) {
      r1 = (object*) &constructed_737;
      r1=r1;
    } else {
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[60];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1419; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_copy_cstring_382;
      L1419:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r1=r1;
    }
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = (object *) 1;
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = ((object**) lenv) [1][3];
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1417:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_getenv_or_578; r1[2] = lenv;
  r0[151] = r1;
  r1 = (object *) 1;
  r0[152] = r1;
  r1 = (object *) 3;
  r0[153] = r1;
  r1 = (object *) 5;
  r0[154] = r1;
  r1 = (object *) 7;
  r0[155] = r1;
  r1 = (object *) 11;
  r0[156] = r1;
  r1 = (object *) constructed_736[0];
  r0[157] = r1;
  r1 = box((pxll_int)O_RDONLY);
  r0[158] = r1;
  r1 = box((pxll_int)O_WRONLY);
  r0[159] = r1;
  r1 = box((pxll_int)O_CREAT);
  r0[160] = r1;
  r1 = box((pxll_int)O_TRUNC);
  r0[161] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = box((pxll_int)argc);
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  ensure_heap (2, unbox(r2));
  r2 = (object*) &constructed_735;
  r3 = ((object*) lenv) [2];
  if (unbox(r3) == 0) { r2 = (object *) TC_EMPTY_VECTOR; } else {
    t = alloc_no_clear (TC_VECTOR, unbox(r3));
    for (i=0; i<unbox(r3); i++) { t[i+1] = r2; }
    r2 = t;
  }
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  // def loop_4782
  goto L1420;
  FUN_loop_4782:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r0)==0)) {
      r0 = ((object***) lenv) [1][1][3];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 3;
      r2 = ((object**) lenv) [1][2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r1 = (object*)argv[unbox(r1)];
      r0[2] = r1;
      r1 = top[60];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1421; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_copy_cstring_382;
      L1421:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      r1 = (object *) 3;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r2 = ((object***) lenv) [1][1][3];
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      ((pxll_vector*)r2)->val[unbox(r1)] = r0;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)-unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_4782;
    }
    PXLL_RETURN(0);
  L1420:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_loop_4782; r3[2] = lenv;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][2];
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1422; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_loop_4782;
  L1422:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  lenv = lenv[1];
  r2 = r2;
  r1[4] = r2;
  r1 = allocate (UOTAG(18), 2);
  r2 = ((object*) lenv) [2];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[162] = r1;
  r1 = (object *) 1;
  r0[163] = r1;
  r1 = (object*)UITAG(2);
  r0[164] = r1;
  r1 = (object *) constructed_734[0];
  r0[165] = r1;
  r1 = (object *) constructed_733[0];
  r0[166] = r1;
  r1 = (object *) constructed_732[0];
  r0[167] = r1;
  r1 = (object *) constructed_731[0];
  r0[168] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_730;
  r1[2] = r2;
  r2 = top[55];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1423; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1423:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[169] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_729;
  r1[2] = r2;
  r2 = top[55];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1424; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1424:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[170] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 3);
  r3 = top[168];
  r2[2] = r3;
  r3 = (object *) constructed_41[0];
  r2[3] = r3;
  r3 = top[21];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1425; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
  L1425:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = top[169];
  r1[3] = r2;
  r2 = top[21];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1426; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
  L1426:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[171] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_728;
  r1[2] = r2;
  r2 = top[55];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1427; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1427:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[172] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_727[0];
  r1[2] = r2;
  r2 = top[82];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1428; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_429;
  L1428:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[173] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = top[171];
  r1[2] = r2;
  r2 = top[82];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1429; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_429;
  L1429:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[174] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = top[172];
  r1[2] = r2;
  r2 = top[82];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1430; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_429;
  L1430:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[175] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = allocate (TC_TUPLE, 3);
  r4 = allocate (TC_TUPLE, 3);
  r5 = top[170];
  r4[2] = r5;
  r5 = (object *) constructed_41[0];
  r4[3] = r5;
  r5 = top[21];
  t = allocate (TC_SAVE, 7);
  t[1] = k; t[2] = lenv; t[3] = &&L1431; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
  r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_321;
  L1431:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
  r4 = result;
  r3[2] = r4;
  r4 = top[172];
  r3[3] = r4;
  r4 = top[21];
  t = allocate (TC_SAVE, 6);
  t[1] = k; t[2] = lenv; t[3] = &&L1432; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
  L1432:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
  r3 = result;
  r2[2] = r3;
  r2 = ((object*) lenv) [2];
  r3 = (object *) 11522;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = top[82];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1433; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_429;
  L1433:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[176] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[112];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1434; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_478;
  L1434:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[177] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_223[0];
  r1[2] = r2;
  r2 = (object *) constructed_726[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1435; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1435:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[178] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_718[0];
  r1[2] = r2;
  r2 = (object *) constructed_725[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1436; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1436:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[179] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_88[0];
  r1[2] = r2;
  r2 = (object *) constructed_724[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1437; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1437:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[180] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_720[0];
  r1[2] = r2;
  r2 = (object *) constructed_723[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1438; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1438:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[181] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_51[0];
  r1[2] = r2;
  r2 = (object *) constructed_722[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1439; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1439:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[182] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_63[0];
  r1[2] = r2;
  r2 = (object *) constructed_721[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1440; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1440:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[183] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = top[183];
  r3 = ((object*) lenv) [2];
  r4 = (object *) constructed_63[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[3] = r2;
  r2 = top[181];
  r3 = ((object*) lenv) [3];
  r4 = (object *) constructed_720[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[4] = r2;
  r2 = top[180];
  r3 = ((object*) lenv) [4];
  r4 = (object *) constructed_88[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[5] = r2;
  r2 = top[179];
  r3 = ((object*) lenv) [5];
  r4 = (object *) constructed_718[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[6] = r2;
  r1 = top[178];
  r2 = ((object*) lenv) [6];
  r3 = (object *) constructed_223[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r3;
  t[2] = r1;
  t[3] = r2;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[184] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_500[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = ((object*) lenv) [4];
  r3 = ((object*) lenv) [3];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = ((object*) lenv) [5];
  r3 = ((object*) lenv) [2];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = ((object*) lenv) [6];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[185] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_498[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = ((object*) lenv) [4];
  r3 = ((object*) lenv) [3];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = ((object*) lenv) [5];
  r3 = ((object*) lenv) [2];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = ((object*) lenv) [6];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[186] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[112];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1441; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_478;
  L1441:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[187] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[112];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1442; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_478;
  L1442:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[188] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_716[0];
  r1[2] = r2;
  r2 = (object *) constructed_714[0];
  r1[3] = r2;
  r2 = top[103];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1443; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
  L1443:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[189] = r1;
  r1 = (object *) 1;
  r0[190] = r1;
  r1 = (object *) 5;
  r0[191] = r1;
  r1 = (object *) 7;
  r0[192] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  // def in_3705_i4758
  goto L1444;
  FUN_in_3705_i4758:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3711_i4758
    goto L1445;
    FUN_loop_3711_i4758:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } else {
            r0 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3711_i4758;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1445:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3711_i4758; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3711_i4758;
  L1444:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_in_3705_i4758; r2[2] = lenv;
  r1[2] = r2;
  // def add_3706_i4758
  goto L1446;
  FUN_add_3706_i4758:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1447; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1447:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r0 = r0;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[0] = r0;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1446:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3706_i4758; r2[2] = lenv;
  r1[3] = r2;
  // def get_3707_i4758
  goto L1448;
  FUN_get_3707_i4758:
    r0 = ((object*) lenv) [2];
    r0 = ((pxll_vector*)r0)->val[0];
    PXLL_RETURN(0);
  L1448:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_3707_i4758; r2[2] = lenv;
  r1[4] = r2;
  // def iterate_3708_i4758
  goto L1449;
  FUN_iterate_3708_i4758:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3720_i4758
    goto L1450;
    FUN_loop_3720_i4758:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1451; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1451:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3720_i4758;
        } break;
      }
      PXLL_RETURN(0);
    L1450:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3720_i4758; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3720_i4758;
  L1449:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3708_i4758; r2[2] = lenv;
  r1[5] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(13), 4);
  r3 = ((object**) lenv) [1][3];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def new_3725_i4758
  goto L1452;
  FUN_new_3725_i4758:
    r0 = allocate (UOTAG(17), 2);
    r1 = ((object*) lenv) [2];
    r0[1] = r1;
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1452:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_new_3725_i4758; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[193] = r1;
  r1 = allocate (TC_TUPLE, 9);
  r1[1] = lenv; lenv = r1;
  // def add_3727_i4759
  goto L1453;
  FUN_add_3727_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][4];
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[0] = r0;
    PXLL_RETURN(0);
  L1453:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3727_i4759; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_3728_i4759
  goto L1454;
  FUN_lookup_3728_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3740_i4759
    goto L1455;
    FUN_loop_3740_i4759:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object****) lenv) [1][1][1][3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = ((object*) lenv) [4];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3740_i4759;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1455:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3740_i4759; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3740_i4759;
  L1454:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_3728_i4759; r2[2] = lenv;
  r1[3] = r2;
  // def lookup*_3729_i4759
  goto L1456;
  FUN_lookup_splat_3729_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1457; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3728_i4759;
    L1457:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1456:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_splat_3729_i4759; r2[2] = lenv;
  r1[4] = r2;
  // def get-error_3730_i4759
  goto L1458;
  FUN_get_error_3730_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1459; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3728_i4759;
    L1459:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1458:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_error_3730_i4759; r2[2] = lenv;
  r1[5] = r2;
  // def iterate_3731_i4759
  goto L1460;
  FUN_iterate_3731_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3757_i4759
    goto L1461;
    FUN_loop_3757_i4759:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1462; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1462:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [4];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3757_i4759;
        } break;
      }
      PXLL_RETURN(0);
    L1461:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3757_i4759; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3757_i4759;
  L1460:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3731_i4759; r2[2] = lenv;
  r1[6] = r2;
  // def map_3732_i4759
  goto L1463;
  FUN_map_3732_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3764_i4759
    goto L1464;
    FUN_loop_3764_i4759:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1465; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1465:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object*) lenv) [4];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3764_i4759;
        } break;
      }
      PXLL_RETURN(0);
    L1464:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3764_i4759; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_713[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3764_i4759;
  L1463:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_map_3732_i4759; r2[2] = lenv;
  r1[7] = r2;
  // def keys_3733_i4759
  goto L1466;
  FUN_keys_3733_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3771_i4759
    goto L1467;
    FUN_loop_3771_i4759:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3771_i4759;
        } break;
      }
      PXLL_RETURN(0);
    L1467:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3771_i4759; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_712[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3771_i4759;
  L1466:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_keys_3733_i4759; r2[2] = lenv;
  r1[8] = r2;
  // def values_3734_i4759
  goto L1468;
  FUN_values_3734_i4759:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3777_i4759
    goto L1469;
    FUN_loop_3777_i4759:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3777_i4759;
        } break;
      }
      PXLL_RETURN(0);
    L1469:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3777_i4759; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_711[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3777_i4759;
  L1468:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_values_3734_i4759; r2[2] = lenv;
  r1[9] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(15), 8);
  r3 = ((object**) lenv) [1][2];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][3];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r3 = ((object**) lenv) [1][6];
  r2[5] = r3;
  r3 = ((object**) lenv) [1][8];
  r2[6] = r3;
  r3 = ((object**) lenv) [1][7];
  r2[7] = r3;
  r3 = ((object**) lenv) [1][9];
  r2[8] = r3;
  r1[2] = r2;
  // def lambda_24325_i4759
  goto L1470;
  FUN_lambda_24325_i4759:
    r0 = allocate (UOTAG(16), 2);
    r1 = (object*)UITAG(0);
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1470:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_24325_i4759; r1[2] = lenv;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[194] = r1;
  r1 = allocate (TC_TUPLE, 9);
  r1[1] = lenv; lenv = r1;
  // def add_3783_i4760
  goto L1471;
  FUN_add_3783_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1472; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L1472:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_710;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[5] = r1;
        r1 = top[71];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1473; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L1473:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[2] = r0;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1471:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3783_i4760; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_3784_i4760
  goto L1474;
  FUN_lookup_3784_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[4] = r1;
    r1 = top[72];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fmember_415;
  L1474:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_3784_i4760; r2[2] = lenv;
  r1[3] = r2;
  // def lookup*_3785_i4760
  goto L1475;
  FUN_lookup_splat_3785_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1476; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L1476:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1475:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_splat_3785_i4760; r2[2] = lenv;
  r1[4] = r2;
  // def get-error_3786_i4760
  goto L1477;
  FUN_get_error_3786_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1478; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L1478:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
    }
    PXLL_RETURN(0);
  L1477:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_error_3786_i4760; r2[2] = lenv;
  r1[5] = r2;
  // def iterate_3787_i4760
  goto L1479;
  FUN_iterate_3787_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[3] = r1;
    r1 = top[73];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
  L1479:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3787_i4760; r2[2] = lenv;
  r1[6] = r2;
  // def map_3788_i4760
  goto L1480;
  FUN_map_3788_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_709[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_24434_i4760
    goto L1481;
    FUN_lambda_24434_i4760:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1482; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1482:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r0 = r0;
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L1481:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_24434_i4760; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[3] = r1;
    r1 = top[74];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1483; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_417;
    L1483:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1480:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_map_3788_i4760; r2[2] = lenv;
  r1[7] = r2;
  // def keys_3789_i4760
  goto L1484;
  FUN_keys_3789_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[2] = r1;
    r1 = top[75];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fkeys_419;
  L1484:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_keys_3789_i4760; r2[2] = lenv;
  r1[8] = r2;
  // def values_3790_i4760
  goto L1485;
  FUN_values_3790_i4760:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[2] = r1;
    r1 = top[76];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fvalues_420;
  L1485:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_values_3790_i4760; r2[2] = lenv;
  r1[9] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(15), 8);
  r3 = ((object**) lenv) [1][2];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][3];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r3 = ((object**) lenv) [1][6];
  r2[5] = r3;
  r3 = ((object**) lenv) [1][8];
  r2[6] = r3;
  r3 = ((object**) lenv) [1][7];
  r2[7] = r3;
  r3 = ((object**) lenv) [1][9];
  r2[8] = r3;
  r1[2] = r2;
  // def lambda_24482_i4760
  goto L1486;
  FUN_lambda_24482_i4760:
    r0 = allocate (UOTAG(14), 3);
    r1 = ((object*) lenv) [2];
    r0[1] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object*)UITAG(2);
    r0[3] = r1;
    PXLL_RETURN(0);
  L1486:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_24482_i4760; r1[2] = lenv;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[195] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  // def in_3818_i4761
  goto L1487;
  FUN_in_3818_i4761:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,54)];
    r1[2] = r2;
    r2 = top[11];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object***) lenv) [1][1][3];
    r3 = UOBJ_GET(r3,1);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    r2 = r2;
    r2=r2;
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1488; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L1488:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1487:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_in_3818_i4761; r2[2] = lenv;
  r1[2] = r2;
  // def add_3819_i4761
  goto L1489;
  FUN_add_3819_i4761:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1490; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_in_3818_i4761;
    L1490:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 5);
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
      r0[2] = r1;
      r1 = top[11];
      r0[3] = r1;
      r1 = ((object*) lenv) [3];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][3];
      r2 = UOBJ_GET(r2,1);
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r0[5] = r1;
      r1 = top[71];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1491; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
      L1491:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)] = r0;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1489:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3819_i4761; r2[2] = lenv;
  r1[3] = r2;
  // def get_3820_i4761
  goto L1492;
  FUN_get_3820_i4761:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[2] = r1;
    r1 = top[76];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fvalues_420;
  L1492:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_3820_i4761; r2[2] = lenv;
  r1[4] = r2;
  // def iterate_3821_i4761
  goto L1493;
  FUN_iterate_3821_i4761:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_24538_i4761
    goto L1494;
    FUN_lambda_24538_i4761:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][3];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1494:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_24538_i4761; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,54)];
    r0[3] = r1;
    r1 = top[73];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
  L1493:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3821_i4761; r2[2] = lenv;
  r1[5] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(13), 4);
  r3 = ((object**) lenv) [1][3];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def new_3833_i4761
  goto L1495;
  FUN_new_3833_i4761:
    r0 = allocate (UOTAG(12), 2);
    r1 = ((object**) lenv) [1][2];
    r0[1] = r1;
    r1 = (object*)UITAG(2);
    r0[2] = r1;
    PXLL_RETURN(0);
  L1495:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_new_3833_i4761; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[196] = r1;
  r1 = (object *) 27;
  r0[197] = r1;
  r1 = (object *) 1;
  r0[198] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = top[112];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1496; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_478;
  L1496:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  // def lambda_27743
  goto L1497;
  FUN_lambda_27743:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[1];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1498; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    lenv = r3[2]; goto *r3[1];
    L1498:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = top[56];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1499; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
    L1499:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = ((object*) lenv) [4];
    r2 = (object*) &constructed_708;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = top[47];
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
  L1497:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_27743; r1[2] = lenv;
  lenv = lenv[1];
  r1 = r1;
  r0[199] = r1;
  r1 = (object *) constructed_707[0];
  r0[200] = r1;
  r1 = (object *) 262;
  r0[201] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object*) &constructed_690;
  r2[2] = r3;
  r3 = top[55];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1500; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string__3elist_372;
  L1500:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = top[82];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1501; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_429;
  L1501:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[202] = r1;
  r1 = (object*) &constructed_689;
  r0[203] = r1;
  r1 = (object*) &constructed_688;
  r0[204] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = (object *) pxll_internal_symbols;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  // def loop_1307_i4765
  goto L1502;
  FUN_loop_1307_i4765:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = box((pxll_int)(r1 == (object*) TC_EMPTY_VECTOR) ? 0 : GET_TUPLE_LENGTH(*r1));
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r2 = ((object***) lenv) [1][1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      r1 = ((pxll_vector*)r2)->val[unbox(r1)];
      r0[2] = r1;
      r1 = top[78];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1503; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_intern_symbol_424;
      L1503:
      ; lenv = k[2]; k = k[1];
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_1307_i4765;
    }
    PXLL_RETURN(0);
  L1502:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_loop_1307_i4765; r1[2] = lenv;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r1 = (object *) 1;
  r0[2] = r1;
  r1 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L1504; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1307_i4765;
  L1504:
  ; lenv = k[2]; k = k[1];
  r0 = result;
  lenv = lenv[1];
  r0 = r0;
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = top[162];
  r1 = ((pxll_vector*)r1)->val[0];
  r0[2] = r1;
  r0 = (object *) 5;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(unbox(r1)<unbox(r0));
  lenv = lenv[1];
  r0 = r0;
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_73;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_73;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_687;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_687;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
  } else {
    r0 = (object *) 14;
  }
  r0 = allocate (TC_TUPLE, 42);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (UOTAG(9), 16);
  r2 = (object *) constructed_686[0];
  r1[1] = r2;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = top[81];
  r2[2] = r3;
  r3 = top[195];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1505; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1505:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = (object*)UITAG(2);
  r1[4] = r2;
  r2 = (object *) constructed_685[0];
  r1[5] = r2;
  r2 = (object*)UITAG(2);
  r1[6] = r2;
  r2 = (object *) constructed_684[0];
  r1[7] = r2;
  r2 = (object*)UITAG(0);
  r1[8] = r2;
  r2 = allocate (UOTAG(11), 4);
  r3 = (object*) &constructed_683;
  r2[1] = r3;
  r3 = (object *) 6;
  r2[2] = r3;
  r3 = (object *) 6;
  r2[3] = r3;
  r3 = (object *) 6;
  r2[4] = r3;
  r1[9] = r2;
  r2 = (object *) constructed_682[0];
  r1[10] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = (object *) -1;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  // def allocate_2675_i4_i4665_i4766
  goto L1506;
  FUN_allocate_2675_i4_i4665_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2678_i4_i4665_i4766
    goto L1507;
    FUN_loop_2678_i4_i4665_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[10];
      r0[4] = r1;
      r1 = top[24];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1508; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_member_question_328;
      L1508:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_2678_i4_i4665_i4766;
      } else {
        r0 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
          r0 = ((object*) lenv) [2];
          r0=r0;
        } else {
          r0 = ((object*****) lenv) [1][1][1][1][2];
          r0=r0;
        }
        ((object*****) lenv) [1][1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1507:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2678_i4_i4665_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2678_i4_i4665_i4766;
  L1506:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_allocate_2675_i4_i4665_i4766; r3[2] = lenv;
  r2[2] = r3;
  // def get-max_2676_i4_i4665_i4766
  goto L1509;
  FUN_get_max_2676_i4_i4665_i4766:
    r0 = ((object**) lenv) [1][2];
    PXLL_RETURN(0);
  L1509:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_get_max_2676_i4_i4665_i4766; r3[2] = lenv;
  r2[3] = r3;
  r2 = allocate (UOTAG(10), 2);
  r3 = ((object*) lenv) [2];
  r2[1] = r3;
  r3 = ((object*) lenv) [3];
  r2[2] = r3;
  lenv = lenv[1];
  r2 = r2;
  lenv = lenv[1];
  r2 = r2;
  r1[11] = r2;
  r2 = (object *) constructed_681[0];
  r1[12] = r2;
  r2 = (object*) &constructed_680;
  r1[13] = r2;
  r2 = (object*)UITAG(0);
  r1[14] = r2;
  r2 = (object*)UITAG(0);
  r1[15] = r2;
  r2 = (object*)UITAG(2);
  r1[16] = r2;
  r0[2] = r1;
  r1 = top[162];
  r1 = ((pxll_vector*)r1)->val[1];
  r0[3] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[8];
  r0[4] = r1;
  r1 = ((object*) lenv) [3];
  r1 = box((pxll_int)(r1 == (object*) TC_EMPTY_VECTOR) ? 0 : GET_TUPLE_LENGTH(*r1));
  r0[5] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def $loop_4736_i4666_i4766
  goto L1510;
  FUN__24loop_4736_i4666_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r0 = ((object****) lenv) [1][1][1][5];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[162];
      r1 = ((pxll_vector*)r1)->val[1];
      r2 = ((object**) lenv) [1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r2));
      r1 = ((pxll_vector*)r1)->val[unbox(r2)];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_676;
      r1[3] = r2;
      r2 = top[50];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1511; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
      L1511:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[2] = r0;
        r0=r0;
      } else {
        goto fatbar_144;
      }
      r0=r0;
      goto fatbar_144_over;
      fatbar_144:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_677;
      r1[3] = r2;
      r2 = top[50];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1512; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
      L1512:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        ((object**) lenv) [1][2] = r0;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object****) lenv) [1][1][1][3];
        range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r0));
        r0 = ((pxll_vector*)r1)->val[unbox(r0)];
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[0] = r0;
        r0=r0;
      } else {
        goto fatbar_145;
      }
      r0=r0;
      goto fatbar_145_over;
      fatbar_145:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_678;
      r1[3] = r2;
      r2 = top[50];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1513; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
      L1513:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[3] = r0;
        r0=r0;
      } else {
        goto fatbar_146;
      }
      r0=r0;
      goto fatbar_146_over;
      fatbar_146:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_679;
      r1[3] = r2;
      r2 = top[50];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1514; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
      L1514:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[1] = r0;
        r0=r0;
      } else {
        goto fatbar_147;
      }
      r0=r0;
      goto fatbar_147_over;
      fatbar_147:
      r0 = (object *) 14;
      r0=r0;
      fatbar_147_over: ;
      r0=r0;
      fatbar_146_over: ;
      r0=r0;
      fatbar_145_over: ;
      r0=r0;
      fatbar_144_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      lenv[2] = r0;
      goto FUN__24loop_4736_i4666_i4766;
    }
    PXLL_RETURN(0);
  L1510:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN__24loop_4736_i4666_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1515; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4736_i4666_i4766;
  L1515:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[6] = r1;
  r1 = allocate (TC_TUPLE, 27);
  r1[1] = lenv; lenv = r1;
  // def go_2016_i4667_i4766
  goto L1516;
  FUN_go_2016_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    switch (get_case (r1)) {
      case (UOTAG(0)): {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object***) lenv) [1][1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        switch (get_case (r1)) {
          case (TC_NIL): {
            r1 = (object *) constructed_674[0];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (TC_NIL): {
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1517; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                L1517:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_143;
              }
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r1=r1;
        goto fatbar_143_over;
        fatbar_143:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][5];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1518; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_find_declarations_2021_i4667_i4766;
        L1518:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[3] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1519; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2022_i4667_i4766;
        L1519:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        fatbar_143_over: ;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } break;
      default: {
        goto fatbar_142;
      }
    }
    r1=r1;
    goto fatbar_142_over;
    fatbar_142:
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_675;
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[14];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1520; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
    L1520:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
    fatbar_142_over: ;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object***) lenv) [1][1][20];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_with_constructors_2039_i4667_i4766;
  L1516:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_go_2016_i4667_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def wrap-fix_2017_i4667_i4766
  goto L1521;
  FUN_wrap_fix_2017_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1522; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L1522:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)>unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 9);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_673[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = (object*)TC_NIL;
      r0[5] = r1;
      r1 = ((object*) lenv) [5];
      r2 = ((object**) lenv) [1][4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = ((object*) lenv) [6];
      r2 = ((object*) lenv) [4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[7] = r1;
      r1 = ((object*) lenv) [7];
      r2 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = ((object*) lenv) [8];
      r2 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[9] = r1;
      r0 = ((object*) lenv) [9];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1521:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_fix_2017_i4667_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def wrap-definitions_2019_i4667_i4766
  goto L1523;
  FUN_wrap_definitions_2019_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_671[0];
    r0[2] = r1;
    r1 = (object *) constructed_670[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_11383_i4667_i4766
    goto L1524;
    FUN_lambda_11383_i4667_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][2] = r0;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1525; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
          L1525:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][3] = r0;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1524:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_11383_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[35];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1526; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L1526:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = (object *) constructed_41[0];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1527; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L1527:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = (object *) constructed_41[0];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1528; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L1528:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 3);
    r2[1] = lenv; lenv = r2;
    r3 = (object *) constructed_590[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r3;
    r3 = t;
    r2[2] = r3;
    r3 = ((object***) lenv) [1][1][3];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][8];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1529; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
    L1529:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_2017_i4667_i4766;
  L1523:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_definitions_2019_i4667_i4766; r2[2] = lenv;
  r1[4] = r2;
  // def find-declarations_2021_i4667_i4766
  goto L1530;
  FUN_find_declarations_2021_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2071_i4667_i4766
    goto L1531;
    FUN_recur_2071_i4667_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) constructed_41[0];
          r0[3] = r1;
          r1 = top[21];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_663[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 4);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                // def loop_2227_i1215_i4667_i4766
                                goto L1532;
                                FUN_loop_2227_i1215_i4667_i4766:
                                  check_heap (0);
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = (object *) constructed_659[0];
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(1)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = (object *) constructed_648[0];
                                              r1 = ((object*) lenv) [2];
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = ((object**) lenv) [1][3];
                                                switch (get_case (r0)) {
                                                  case (TC_PAIR): {
                                                    r0 = allocate (TC_TUPLE, 5);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = ((object***) lenv) [1][1][3];
                                                    r1 = UOBJ_GET(r1,0);
                                                    r0[2] = r1;
                                                    r1 = ((object***) lenv) [1][1][3];
                                                    r1 = UOBJ_GET(r1,1);
                                                    r0[3] = r1;
                                                    r1 = allocate (UOTAG(1), 2);
                                                    r2 = ((object****) lenv) [1][1][1][2];
                                                    r1[1] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[2] = r2;
                                                    r0[4] = r1;
                                                    r1 = allocate (TC_TUPLE, 2);
                                                    r2 = ((object*) lenv) [3];
                                                    r1[2] = r2;
                                                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1533; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_loop_2227_i1215_i4667_i4766;
                                                    L1533:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[5] = r1;
                                                    r0 = ((object*) lenv) [5];
                                                    r1 = ((object*) lenv) [4];
                                                    t = alloc_no_clear (TC_PAIR,2);
                                                    t[1] = r1;
                                                    t[2] = r0;
                                                    r0 = t;
                                                    PXLL_RETURN(0);
                                                  } break;
                                                  default: {
                                                    lenv = ((object ***)lenv)[1][1][1];
                                                    goto fatbar_139;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_139;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_139;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_139;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_139_over;
                                  fatbar_139:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_660;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = top[14];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                                  fatbar_139_over: ;
                                  PXLL_RETURN(0);
                                L1532:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_loop_2227_i1215_i4667_i4766; r2[2] = lenv;
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = ((object***) lenv) [1][1][3];
                                r1[2] = r2;
                                r2 = ((object*) lenv) [2];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1534; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_loop_2227_i1215_i4667_i4766;
                                L1534:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[3] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r1[1] = lenv; lenv = r1;
                                // def apply_1614_i1216_i4667_i4766
                                goto L1535;
                                FUN_apply_1614_i1216_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def loop_1617_i1216_i4667_i4766
                                  goto L1536;
                                  FUN_loop_1617_i1216_i4667_i4766:
                                    check_heap (0);
                                    r0 = ((object*) lenv) [2];
                                    switch (get_case (r0)) {
                                      case (TC_PAIR): {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = ((object*) lenv) [2];
                                        switch (get_case_noint (r0)) {
                                          default: {
                                            r0 = allocate (TC_TUPLE, 3);
                                            r0[1] = lenv; lenv = r0;
                                            r1 = ((object**) lenv) [1][2];
                                            r1 = UOBJ_GET(r1,0);
                                            r0[2] = r1;
                                            r1 = ((object**) lenv) [1][2];
                                            r1 = UOBJ_GET(r1,1);
                                            r0[3] = r1;
                                            r0 = allocate (TC_TUPLE, 3);
                                            r1 = ((object*) lenv) [2];
                                            r0[2] = r1;
                                            r1 = ((object*****) lenv) [1][1][1][1][2];
                                            r0[3] = r1;
                                            r1 = top[96];
                                            t = allocate (TC_SAVE, 3);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1537; ; k = t;
                                            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_447;
                                            L1537:
                                            ; lenv = k[2]; k = k[1];
                                            r0 = result;
                                            if PXLL_IS_TRUE(r0) {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = allocate (TC_TUPLE, 3);
                                              r2 = ((object**) lenv) [1][3];
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = ((object**) lenv) [1][2];
                                              r2[2] = r3;
                                              r3 = ((object******) lenv) [1][1][1][1][1][2];
                                              r2[3] = r3;
                                              r3 = top[100];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1538; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_get_bindings_451;
                                              L1538:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r2 = top[101];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1539; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_453;
                                              L1539:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[2] = r1;
                                              r0 = ((object*) lenv) [2];
                                              PXLL_RETURN(0);
                                            } else {
                                              r0 = ((object**) lenv) [1][3];
                                              lenv = ((object **)lenv)[1][1];
                                              lenv[2] = r0;
                                              goto FUN_loop_1617_i1216_i4667_i4766;
                                            }
                                            PXLL_RETURN(0);
                                          } break;
                                        }
                                        PXLL_RETURN(0);
                                      } break;
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object*) &constructed_658;
                                        r0[2] = r1;
                                        r1 = allocate (TC_TUPLE, 2);
                                        r2 = ((object***) lenv) [1][1][2];
                                        r1[2] = r2;
                                        r2 = top[90];
                                        t = allocate (TC_SAVE, 4);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1540; t[4] = r0; k = t;
                                        r1[1] = r2[2]; lenv = r1; goto FUN_repr_439;
                                        L1540:
                                        r0 = k[4]; lenv = k[2]; k = k[1];
                                        r1 = result;
                                        r0[3] = r1;
                                        r1 = top[14];
                                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1536:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_loop_1617_i1216_i4667_i4766; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = ((object****) lenv) [1][1][1][3];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1617_i1216_i4667_i4766;
                                L1535:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_apply_1614_i1216_i4667_i4766; r2[2] = lenv;
                                r1[2] = r2;
                                // def unread-macro_1615_i1216_i4667_i4766
                                goto L1541;
                                FUN_unread_macro_1615_i1216_i4667_i4766:
                                  check_heap (0);
                                  r0 = (object*) &constructed_657;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_657;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = ((object**) lenv) [1][2];
                                  dump_object (r0, 0);
                                  r0 = (object*) &constructed_656;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_656;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = allocate (TC_TUPLE, 3);
                                  // def lambda_8182_i1216_i4667_i4766
                                  goto L1542;
                                  FUN_lambda_8182_i1216_i4667_i4766:
                                    check_heap (0);
                                    r0 = ((object*) lenv) [2];
                                    switch (get_case_noint (r0)) {
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = ((object*) lenv) [2];
                                        r0[3] = r1;
                                        r1 = top[94];
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1543; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_443;
                                        L1543:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_655;
                                        r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_655;
                                        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = ((object*) lenv) [3];
                                        r0[3] = r1;
                                        r1 = top[94];
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1544; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_443;
                                        L1544:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_654;
                                        r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_654;
                                        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        PXLL_RETURN(0);
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1542:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_lambda_8182_i1216_i4667_i4766; r1[2] = lenv;
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r0[3] = r1;
                                  r1 = top[35];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1545; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
                                  L1545:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = (object*) &constructed_653;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_653;
                                  r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  PXLL_RETURN(0);
                                L1541:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_unread_macro_1615_i1216_i4667_i4766; r2[2] = lenv;
                                r1[3] = r2;
                                r1 = allocate (UOTAG(7), 4);
                                r2 = ((object*) lenv) [2];
                                r1[1] = r2;
                                r2 = ((object**) lenv) [1][2];
                                r1[2] = r2;
                                r2 = ((object**) lenv) [1][3];
                                r1[3] = r2;
                                r2 = ((object*) lenv) [3];
                                r1[4] = r2;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[4] = r1;
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                r1 = ((pxll_vector*)r1)->val[7];
                                r0[2] = r1;
                                r0 = ((object**) lenv) [1][4];
                                r1 = ((object*) lenv) [2];
                                r2 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r0 = r0;
                                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                                ((pxll_vector*)r1)->val[7] = r0;
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_138;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_138;
                          }
                        }
                        goto fatbar_138_over;
                        fatbar_138:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_661;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r0[3] = r1;
                        r1 = top[14];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1546; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                        L1546:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_138_over: ;
                        r0 = ((object*****) lenv) [1][1][1][1][3];
                        r1 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2071_i4667_i4766;
                      } else {
                        goto fatbar_137;
                      }
                      PXLL_RETURN(0);
                      goto fatbar_137_over;
                      fatbar_137:
                      r0 = (object *) constructed_669[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 6);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = top[194];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1547; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1547:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = top[194];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1548; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1548:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[4] = r1;
                                r1 = (object *) 1;
                                r0[5] = r1;
                                r1 = allocate (TC_TUPLE, 8);
                                r1[1] = lenv; lenv = r1;
                                // def get_2241_i1222_i4667_i4766
                                goto L1549;
                                FUN_get_2241_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = (object*) &constructed_666;
                                  r0[4] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[3];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1549:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_2241_i1222_i4667_i4766; r2[2] = lenv;
                                r1[2] = r2;
                                // def add_2242_i1222_i4667_i4766
                                goto L1550;
                                FUN_add_2242_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r1 = ((pxll_vector*)r1)->val[2];
                                  r0[3] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[4] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[0];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1551; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                  L1551:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = ((object***) lenv) [1][1][5];
                                  r1 = ((object*) lenv) [2];
                                  ((pxll_vector*)r1)->val[1] = r0;
                                  r0 = ((object***) lenv) [1][1][5];
                                  r1 = (object *) 3;
                                  r0 = box((pxll_int)unbox(r1)+unbox(r0));
                                  ((object***) lenv) [1][1][5] = r0;
                                  PXLL_RETURN(0);
                                L1550:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_add_2242_i1222_i4667_i4766; r2[2] = lenv;
                                r1[3] = r2;
                                // def iterate_2243_i1222_i4667_i4766
                                goto L1552;
                                FUN_iterate_2243_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1552:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_iterate_2243_i1222_i4667_i4766; r2[2] = lenv;
                                r1[4] = r2;
                                // def get-nalts_2244_i1222_i4667_i4766
                                goto L1553;
                                FUN_get_nalts_2244_i1222_i4667_i4766:
                                  r0 = ((object**) lenv) [1][5];
                                  PXLL_RETURN(0);
                                L1553:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_nalts_2244_i1222_i4667_i4766; r2[2] = lenv;
                                r1[5] = r2;
                                // def get-scheme_2245_i1222_i4667_i4766
                                goto L1554;
                                FUN_get_scheme_2245_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1555; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1555:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1556; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L1556:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (UOTAG(2), 2);
                                  r1 = ((object*) lenv) [3];
                                  r0[1] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object***) lenv) [1][1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [3];
                                  r1[3] = r2;
                                  r2 = top[103];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1557; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                                  L1557:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  PXLL_RETURN(0);
                                L1554:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_scheme_2245_i1222_i4667_i4766; r2[2] = lenv;
                                r1[6] = r2;
                                // def get-tvars_2246_i1222_i4667_i4766
                                goto L1558;
                                FUN_get_tvars_2246_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1559; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1559:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object*) lenv) [2];
                                  r0[2] = r1;
                                  r1 = (object *) constructed_41[0];
                                  r0[3] = r1;
                                  r1 = top[21];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
                                L1558:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_tvars_2246_i1222_i4667_i4766; r2[2] = lenv;
                                r1[7] = r2;
                                // def get-alt-scheme_2247_i1222_i4667_i4766
                                goto L1560;
                                FUN_get_alt_scheme_2247_i1222_i4667_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 4);
                                  r2 = ((object****) lenv) [1][1][1][4];
                                  r1[2] = r2;
                                  r2 = ((object**) lenv) [1][2];
                                  r1[3] = r2;
                                  r2 = (object*) &constructed_665;
                                  r1[4] = r2;
                                  r2 = ((object****) lenv) [1][1][1][4];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[3];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1561; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1561:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object****) lenv) [1][1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object****) lenv) [1][1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1562; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1562:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_41[0];
                                  r1[3] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1563; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                  L1563:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object****) lenv) [1][1][1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [4];
                                  r1[3] = r2;
                                  r2 = top[103];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1564; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                                  L1564:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[5] = r1;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = ((object*) lenv) [4];
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = ((object**) lenv) [1][2];
                                  r3 = ((pxll_vector*)r3)->val[3];
                                  r2[2] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_99[0];
                                  r2[2] = r3;
                                  r3 = ((object*) lenv) [2];
                                  r4 = ((object**) lenv) [1][5];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = top[103];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1565; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                  L1565:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r2 = r2;
                                  r1[2] = r2;
                                  r0[6] = r1;
                                  r0 = ((object*) lenv) [6];
                                  PXLL_RETURN(0);
                                L1560:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_alt_scheme_2247_i1222_i4667_i4766; r2[2] = lenv;
                                r1[8] = r2;
                                r1 = allocate (UOTAG(8), 8);
                                r2 = ((object*) lenv) [3];
                                r1[1] = r2;
                                r2 = ((object*) lenv) [2];
                                r1[2] = r2;
                                r2 = ((object*) lenv) [8];
                                r1[3] = r2;
                                r2 = ((object*) lenv) [5];
                                r1[4] = r2;
                                r2 = ((object*) lenv) [6];
                                r1[5] = r2;
                                r2 = ((object*) lenv) [7];
                                r1[6] = r2;
                                r2 = ((object*) lenv) [4];
                                r1[7] = r2;
                                r2 = ((object**) lenv) [1][2];
                                r1[8] = r2;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[6] = r1;
                                r0 = allocate (TC_TUPLE, 3);
                                // def lambda_13215_i1221_i4667_i4766
                                goto L1566;
                                FUN_lambda_13215_i1221_i4667_i4766:
                                  check_heap (0);
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(9)): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = (object *) constructed_54[0];
                                              r1 = ((object*) lenv) [2];
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = allocate (TC_TUPLE, 2);
                                                r1 = allocate (TC_TUPLE, 4);
                                                r2 = ((object*****) lenv) [1][1][1][1][3];
                                                r1[2] = r2;
                                                r2 = ((object*) lenv) [3];
                                                r1[3] = r2;
                                                r2 = ((object**) lenv) [1][3];
                                                r1[4] = r2;
                                                r2 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][22];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1567; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_make_alt_2041_i4667_i4766;
                                                L1567:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r0[2] = r1;
                                                r1 = ((object*****) lenv) [1][1][1][1][6];
                                                r1 = ((pxll_vector*)r1)->val[0];
                                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_141;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_141;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_141;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_141;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_141_over;
                                  fatbar_141:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_664;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = top[14];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                                  fatbar_141_over: ;
                                  PXLL_RETURN(0);
                                L1566:
                                r1 = allocate (TC_CLOSURE, 2);
                                r1[1] = &&FUN_lambda_13215_i1221_i4667_i4766; r1[2] = lenv;
                                r0[2] = r1;
                                r1 = ((object**) lenv) [1][3];
                                r0[3] = r1;
                                r1 = top[35];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L1568; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
                                L1568:
                                ; lenv = k[2]; k = k[1];
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                r1 = ((pxll_vector*)r1)->val[1];
                                r0[2] = r1;
                                r0 = ((object**) lenv) [1][6];
                                r1 = ((object*) lenv) [2];
                                r2 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r0 = r0;
                                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                                ((pxll_vector*)r1)->val[1] = r0;
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_140;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_140;
                          }
                        }
                        goto fatbar_140_over;
                        fatbar_140:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_667;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r0[3] = r1;
                        r1 = top[14];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1569; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                        L1569:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_140_over: ;
                        r0 = ((object*****) lenv) [1][1][1][1][3];
                        r1 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2071_i4667_i4766;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_136;
                      }
                      PXLL_RETURN(0);
                      fatbar_137_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_136;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_136;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_136;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_136_over;
          fatbar_136:
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_recur_2071_i4667_i4766;
          fatbar_136_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1531:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2071_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_652[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2071_i4667_i4766;
  L1530:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_declarations_2021_i4667_i4766; r2[2] = lenv;
  r1[5] = r2;
  // def find-definitions_2022_i4667_i4766
  goto L1570;
  FUN_find_definitions_2022_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2082_i4667_i4766
    goto L1571;
    FUN_recur_2082_i4667_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1572; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1572:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1573; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1573:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_651[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object***) lenv) [1][1][3];
                        switch (get_case (r1)) {
                          case (TC_PAIR): {
                            r1 = allocate (TC_TUPLE, 3);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object****) lenv) [1][1][1][3];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r2 = ((object****) lenv) [1][1][1][3];
                            r2 = UOBJ_GET(r2,1);
                            r1[3] = r2;
                            r1 = ((object*) lenv) [2];
                            switch (get_case (r1)) {
                              case (UOTAG(1)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = ((object**) lenv) [1][2];
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 4);
                                r2 = (object *) constructed_648[0];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r2;
                                r2 = t;
                                r1[2] = r2;
                                r2 = ((object**) lenv) [1][3];
                                r1[3] = r2;
                                r2 = top[88];
                                r1[4] = r2;
                                r2 = top[24];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1574; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_member_question_328;
                                L1574:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                if PXLL_IS_TRUE(r1) {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 5);
                                  r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                  r2[2] = r3;
                                  r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][8];
                                  r2[3] = r3;
                                  r3 = (object *) constructed_645[0];
                                  r2[4] = r3;
                                  r3 = ((object***) lenv) [1][1][3];
                                  r2[5] = r3;
                                  r3 = top[115];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1575; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_compile_pattern_484;
                                  L1575:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case_noint (r1)) {
                                    default: {
                                      r1 = allocate (TC_TUPLE, 3);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,1);
                                      r1[3] = r2;
                                      r1 = allocate (UOTAG(1), 2);
                                      r2 = ((object***) lenv) [1][1][2];
                                      r1[1] = r2;
                                      r2 = allocate (TC_TUPLE, 11);
                                      r2[1] = lenv; lenv = r2;
                                      r3 = (object *) constructed_592[0];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[2] = r3;
                                      r3 = ((object****) lenv) [1][1][1][2];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[3] = r3;
                                      r3 = allocate (TC_TUPLE, 3);
                                      r4 = top[3];
                                      r3[2] = r4;
                                      r4 = ((object**) lenv) [1][2];
                                      r3[3] = r4;
                                      r4 = top[32];
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1576; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
                                      L1576:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[4] = r3;
                                      r3 = ((object*) lenv) [4];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[5] = r3;
                                      r3 = allocate (TC_TUPLE, 2);
                                      r4 = ((object**) lenv) [1][3];
                                      r3[2] = r4;
                                      r4 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][8];
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1577; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_expand_2024_i4667_i4766;
                                      L1577:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[6] = r3;
                                      r3 = (object*)TC_NIL;
                                      r2[7] = r3;
                                      r3 = ((object*) lenv) [7];
                                      r4 = ((object*) lenv) [6];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[8] = r3;
                                      r3 = ((object*) lenv) [8];
                                      r4 = ((object*) lenv) [5];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[9] = r3;
                                      r3 = ((object*) lenv) [9];
                                      r4 = ((object*) lenv) [3];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[10] = r3;
                                      r3 = ((object*) lenv) [10];
                                      r4 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[11] = r3;
                                      r2 = ((object*) lenv) [11];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r2;
                                      r2 = t;
                                      lenv = lenv[1];
                                      r2 = r2;
                                      r1[2] = r2;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } else {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][3];
                                  r2[2] = r3;
                                  r3 = top[22];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1578; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
                                  L1578:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [2];
                                  r3 = (object *) 3;
                                  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
                                  r1[3] = r2;
                                  r1 = (object *) 6;
                                  r2 = ((object*) lenv) [3];
                                  r1 = PXLL_TEST(r2==r1);
                                  lenv = lenv[1];
                                  r1 = r1;
                                  if PXLL_IS_TRUE(r1) {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r2 = (object*) &constructed_646;
                                    r1[2] = r2;
                                    r2 = ((object*) lenv) [2];
                                    r1[3] = r2;
                                    r2 = top[14];
                                    t = allocate (TC_SAVE, 4);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1579; t[4] = r0; k = t;
                                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                                    L1579:
                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                    r1 = result;
                                    r1=r1;
                                  } else {
                                    r1 = allocate (UOTAG(1), 2);
                                    r2 = ((object*) lenv) [2];
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 2);
                                    r3 = ((object**) lenv) [1][3];
                                    r2[2] = r3;
                                    r3 = top[19];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1580; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                                    L1580:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    r1[2] = r2;
                                    r1=r1;
                                  }
                                  r1=r1;
                                }
                                lenv = lenv[1];
                                r1 = r1;
                                r1=r1;
                              } break;
                              case (UOTAG(0)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = ((object**) lenv) [1][2];
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = ((object*) lenv) [2];
                                switch (get_case (r1)) {
                                  case (TC_PAIR): {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = ((object**) lenv) [1][2];
                                    r2 = UOBJ_GET(r2,0);
                                    r1[2] = r2;
                                    r2 = ((object**) lenv) [1][2];
                                    r2 = UOBJ_GET(r2,1);
                                    r1[3] = r2;
                                    r1 = ((object*) lenv) [2];
                                    switch (get_case (r1)) {
                                      case (UOTAG(1)): {
                                        r1 = allocate (TC_TUPLE, 2);
                                        r1[1] = lenv; lenv = r1;
                                        r2 = ((object**) lenv) [1][2];
                                        r2 = UOBJ_GET(r2,0);
                                        r1[2] = r2;
                                        r1 = allocate (UOTAG(1), 2);
                                        r2 = ((object*) lenv) [2];
                                        r1[1] = r2;
                                        r2 = allocate (TC_TUPLE, 10);
                                        r2[1] = lenv; lenv = r2;
                                        r3 = (object *) constructed_592[0];
                                        t = alloc_no_clear (UOTAG(1),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[2] = r3;
                                        r3 = ((object**) lenv) [1][2];
                                        t = alloc_no_clear (UOTAG(1),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[3] = r3;
                                        r3 = ((object***) lenv) [1][1][3];
                                        t = alloc_no_clear (UOTAG(0),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[4] = r3;
                                        r3 = allocate (TC_TUPLE, 3);
                                        r4 = ((object*****) lenv) [1][1][1][1][3];
                                        r3[2] = r4;
                                        r4 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][4];
                                        r3[3] = r4;
                                        r4 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][6];
                                        t = allocate (TC_SAVE, 6);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1581; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                        r3[1] = r4[2]; lenv = r3; goto FUN_find_definitions_2022_i4667_i4766;
                                        L1581:
                                        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                        r3 = result;
                                        r2[5] = r3;
                                        r3 = (object*)TC_NIL;
                                        r2[6] = r3;
                                        r3 = ((object*) lenv) [6];
                                        r4 = ((object*) lenv) [5];
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[7] = r3;
                                        r3 = ((object*) lenv) [7];
                                        r4 = ((object*) lenv) [4];
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[8] = r3;
                                        r3 = ((object*) lenv) [8];
                                        r4 = ((object*) lenv) [3];
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[9] = r3;
                                        r3 = ((object*) lenv) [9];
                                        r4 = ((object*) lenv) [2];
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[10] = r3;
                                        r2 = ((object*) lenv) [10];
                                        t = alloc_no_clear (UOTAG(0),1);
                                        t[1] = r2;
                                        r2 = t;
                                        lenv = lenv[1];
                                        r2 = r2;
                                        r1[2] = r2;
                                        lenv = lenv[1];
                                        r1 = r1;
                                        r1=r1;
                                      } break;
                                      default: {
                                        lenv = ((object ***)lenv)[1][1][1];
                                        goto fatbar_135;
                                      }
                                    }
                                    lenv = lenv[1];
                                    r1 = r1;
                                    r1=r1;
                                  } break;
                                  default: {
                                    lenv = ((object **)lenv)[1][1];
                                    goto fatbar_135;
                                  }
                                }
                                lenv = lenv[1];
                                r1 = r1;
                                r1=r1;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_135;
                              }
                            }
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                          } break;
                          default: {
                            goto fatbar_135;
                          }
                        }
                        r1=r1;
                        goto fatbar_135_over;
                        fatbar_135:
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object*) &constructed_649;
                        r1[2] = r2;
                        r2 = ((object***) lenv) [1][1][3];
                        r1[3] = r2;
                        r2 = top[14];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1582; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                        L1582:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                        fatbar_135_over: ;
                        r0[2] = r1;
                        r0 = ((object******) lenv) [1][1][1][1][1][2];
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        r1 = ((object*****) lenv) [1][1][1][1][3];
                        r2 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r0;
                        lenv[3] = r1;
                        lenv[4] = r2;
                        goto FUN_recur_2082_i4667_i4766;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_134;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_134;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_134;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_134;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_134_over;
          fatbar_134:
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_2082_i4667_i4766;
          fatbar_134_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1571:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2082_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_644[0];
    r0[2] = r1;
    r1 = (object *) constructed_643[0];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2082_i4667_i4766;
  L1570:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_definitions_2022_i4667_i4766; r2[2] = lenv;
  r1[6] = r2;
  // def expand-field_2023_i4667_i4766
  goto L1583;
  FUN_expand_field_2023_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][8];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1584; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
    L1584:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = ((object*) lenv) [4];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L1583:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_field_2023_i4667_i4766; r2[2] = lenv;
  r1[7] = r2;
  // def expand_2024_i4667_i4766
  goto L1585;
  FUN_expand_2024_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][9];
        r0[1] = r1[2]; lenv = r0; goto FUN_maybe_expand_2025_i4667_i4766;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][8];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1586; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1586:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][7];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1587; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1587:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(8),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][8];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1588; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
        L1588:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(10),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1585:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_2024_i4667_i4766; r2[2] = lenv;
  r1[8] = r2;
  // def maybe-expand_2025_i4667_i4766
  goto L1589;
  FUN_maybe_expand_2025_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_638[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][27];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[66];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1590; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L1590:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][3];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[7];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[66];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1591; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                L1591:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r2 = ((pxll_vector*)r2)->val[0];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1592; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L1592:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][8];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_2024_i4667_i4766;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    r1[2] = r2;
                    r2 = ((object****) lenv) [1][1][1][3];
                    r1[3] = r2;
                    r2 = top[32];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1593; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                    L1593:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r2 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_642[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(1)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 8);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = (object *) constructed_640[0];
                                      r2 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][2];
                                      r2 = ((object*) lenv) [2];
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[3] = r1;
                                      r1 = (object*)TC_NIL;
                                      r0[4] = r1;
                                      r1 = ((object*) lenv) [4];
                                      r2 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[5] = r1;
                                      r1 = ((object*) lenv) [5];
                                      r2 = ((object*) lenv) [3];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[6] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][8];
                                      r1[2] = r2;
                                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                      r1[3] = r2;
                                      r2 = top[32];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1594; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                                      L1594:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[7] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object*) lenv) [6];
                                      r2[2] = r3;
                                      r3 = (object *) constructed_41[0];
                                      r2[3] = r3;
                                      r3 = top[21];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1595; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                                      L1595:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [7];
                                      r1[3] = r2;
                                      r2 = top[21];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1596; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                                      L1596:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[8] = r1;
                                      r0 = ((object*) lenv) [8];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_133;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_133;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_133;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_133;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_133;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_133;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_133;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_133;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_133_over;
        fatbar_133:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][8];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1597; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1597:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_133_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1589:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_maybe_expand_2025_i4667_i4766; r2[2] = lenv;
  r1[9] = r2;
  // def expand-if_2026_i4667_i4766
  goto L1598;
  FUN_expand_if_2026_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 10);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object***) lenv) [1][1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1599; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                L1599:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1600; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                L1600:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = (object*)UITAG(6);
                r0[4] = r1;
                r1 = (object*)TC_NIL;
                r0[5] = r1;
                r1 = ((object*) lenv) [5];
                r2 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[6] = r1;
                r1 = ((object*) lenv) [6];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[7] = r1;
                r1 = ((object*) lenv) [7];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[8] = r1;
                r1 = (object *) constructed_586[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[9] = r1;
                r1 = ((object*) lenv) [8];
                r2 = ((object*) lenv) [9];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[10] = r1;
                r0 = ((object*) lenv) [10];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object****) lenv) [1][1][1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1601; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1601:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object***) lenv) [1][1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1602; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1602:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1603; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1603:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [7];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_586[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = ((object*) lenv) [8];
                    r2 = ((object*) lenv) [9];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = ((object*) lenv) [10];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_132;
                  }
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_132;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_132;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_132_over;
    fatbar_132:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_637;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_132_over: ;
    PXLL_RETURN(0);
  L1598:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_if_2026_i4667_i4766; r2[2] = lenv;
  r1[10] = r2;
  // def expand-set!_2027_i4667_i4766
  goto L1604;
  FUN_expand_set_bang_2027_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object***) lenv) [1][1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1605; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1605:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1606; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1606:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [7];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_480[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = ((object*) lenv) [8];
                    r2 = ((object*) lenv) [9];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = ((object*) lenv) [10];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_131;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_131;
              }
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_293[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [3];
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = allocate (TC_TUPLE, 11);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = ((object****) lenv) [1][1][1][2];
                                              r1[2] = r2;
                                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][8];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1607; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                                              L1607:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[2] = r1;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = ((object***) lenv) [1][1][2];
                                              r1[2] = r2;
                                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][8];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1608; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                                              L1608:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[3] = r1;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = ((object**) lenv) [1][2];
                                              r1[2] = r2;
                                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][8];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1609; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                                              L1609:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[4] = r1;
                                              r1 = (object*)TC_NIL;
                                              r0[5] = r1;
                                              r1 = ((object*) lenv) [5];
                                              r2 = ((object*) lenv) [4];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[6] = r1;
                                              r1 = ((object*) lenv) [6];
                                              r2 = ((object*) lenv) [3];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[7] = r1;
                                              r1 = ((object*) lenv) [7];
                                              r2 = ((object*) lenv) [2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[8] = r1;
                                              r1 = ((object*) lenv) [8];
                                              r2 = ((object*****) lenv) [1][1][1][1][2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[9] = r1;
                                              r1 = (object *) constructed_284[0];
                                              t = alloc_no_clear (UOTAG(1),1);
                                              t[1] = r1;
                                              r1 = t;
                                              r0[10] = r1;
                                              r1 = ((object*) lenv) [9];
                                              r2 = ((object*) lenv) [10];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[11] = r1;
                                              r0 = ((object*) lenv) [11];
                                              t = alloc_no_clear (UOTAG(0),1);
                                              t[1] = r0;
                                              r0 = t;
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ********)lenv)[1][1][1][1][1][1][1][1];
                                              goto fatbar_131;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                          goto fatbar_131;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                      goto fatbar_131;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  goto fatbar_131;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_131;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_131;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ****)lenv)[1][1][1][1];
                      goto fatbar_131;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_131;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_131;
              }
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 8);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][2];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1610; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                    L1610:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = ((object*) lenv) [4];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = (object *) constructed_588[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [7];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r0 = ((object*) lenv) [8];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_131;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_131;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_131;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_131;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_131_over;
    fatbar_131:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_636;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_131_over: ;
    PXLL_RETURN(0);
  L1604:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_set_bang_2027_i4667_i4766; r2[2] = lenv;
  r1[11] = r2;
  // def expand-begin_2028_i4667_i4766
  goto L1611;
  FUN_expand_begin_2028_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_635;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_635;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][8];
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_2024_i4667_i4766;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_130;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_130_over;
    fatbar_130:
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object***) lenv) [1][1][8];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[32];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1612; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
    L1612:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = (object *) constructed_590[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r0 = ((object*) lenv) [4];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_130_over: ;
    PXLL_RETURN(0);
  L1611:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_begin_2028_i4667_i4766; r2[2] = lenv;
  r1[12] = r2;
  // def expand-let-splat_2029_i4667_i4766
  goto L1613;
  FUN_expand_let_splat_2029_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_12173_i4667_i4766
            goto L1614;
            FUN_lambda_12173_i4667_i4766:
              check_heap (0);
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 5);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object**) lenv) [1][2];
                              r1[2] = r2;
                              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][8];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1615; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                              L1615:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = (object*)TC_NIL;
                              r0[3] = r1;
                              r1 = ((object*) lenv) [3];
                              r2 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[4] = r1;
                              r1 = ((object*) lenv) [4];
                              r2 = ((object***) lenv) [1][1][2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[5] = r1;
                              r0 = ((object*) lenv) [5];
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r0;
                              r0 = t;
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_129;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_129;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_129;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_129;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_129_over;
              fatbar_129:
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_633;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[14];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              fatbar_129_over: ;
              PXLL_RETURN(0);
            L1614:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_12173_i4667_i4766; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1616; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L1616:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][4];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1617; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2022_i4667_i4766;
            L1617:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = (object*)TC_NIL;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object*) lenv) [5];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object *) constructed_596[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [9];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_128;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_128;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_128_over;
    fatbar_128:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_634;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_128_over: ;
    PXLL_RETURN(0);
  L1613:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_let_splat_2029_i4667_i4766; r2[2] = lenv;
  r1[13] = r2;
  // def expand-lambda_2030_i4667_i4766
  goto L1618;
  FUN_expand_lambda_2030_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = (object *) constructed_578[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1619; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2022_i4667_i4766;
        L1619:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][16];
        r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_2032_i4667_i4766;
      } break;
      default: {
        goto fatbar_127;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_127_over;
    fatbar_127:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_632;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_127_over: ;
    PXLL_RETURN(0);
  L1618:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_lambda_2030_i4667_i4766; r2[2] = lenv;
  r1[14] = r2;
  // def expand-function_2031_i4667_i4766
  goto L1620;
  FUN_expand_function_2031_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][4];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1621; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2022_i4667_i4766;
            L1621:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = ((object****) lenv) [1][1][1][16];
            r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_2032_i4667_i4766;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_126;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_126;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_126_over;
    fatbar_126:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_631;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_126_over: ;
    PXLL_RETURN(0);
  L1620:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_function_2031_i4667_i4766; r2[2] = lenv;
  r1[15] = r2;
  // def exp-function_2032_i4667_i4766
  goto L1622;
  FUN_exp_function_2032_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 7);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = (object *) constructed_592[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = ((object*) lenv) [5];
    r2 = ((object*) lenv) [6];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[7] = r1;
    r0 = ((object*) lenv) [7];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1622:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_exp_function_2032_i4667_i4766; r2[2] = lenv;
  r1[16] = r2;
  // def make-nvget_2034_i4667_i4766
  goto L1623;
  FUN_make_nvget_2034_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 15);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_312[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object**) lenv) [1][4];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object**) lenv) [1][5];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = (object*)TC_NIL;
    r0[6] = r1;
    r1 = ((object*) lenv) [6];
    r2 = ((object*) lenv) [5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = ((object*) lenv) [7];
    r2 = ((object*) lenv) [4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = ((object*) lenv) [8];
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = ((object*) lenv) [9];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[10] = r1;
    r1 = ((object**) lenv) [1][6];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[11] = r1;
    r1 = (object*)TC_NIL;
    r0[12] = r1;
    r1 = ((object*) lenv) [12];
    r2 = ((object*) lenv) [11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[13] = r1;
    r1 = ((object*) lenv) [13];
    r2 = ((object*) lenv) [10];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[14] = r1;
    r1 = ((object*) lenv) [14];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[15] = r1;
    r0 = ((object*) lenv) [15];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1623:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_nvget_2034_i4667_i4766; r2[2] = lenv;
  r1[17] = r2;
  // def expand-vcase_2035_i4667_i4766
  goto L1624;
  FUN_expand_vcase_2035_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = ((object***) lenv) [1][1][2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r0[4] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][19];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_2036_i4667_i4766;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_125;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_125;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_125_over;
            fatbar_125:
            r0 = allocate (TC_TUPLE, 4);
            r1 = (object *) constructed_54[0];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[4] = r1;
            r1 = ((object****) lenv) [1][1][1][19];
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_2036_i4667_i4766;
            fatbar_125_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_124;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_124;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_124_over;
    fatbar_124:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_630;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_124_over: ;
    PXLL_RETURN(0);
  L1624:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_2035_i4667_i4766; r2[2] = lenv;
  r1[18] = r2;
  // def expand-vcase*_2036_i4667_i4766
  goto L1625;
  FUN_expand_vcase_splat_2036_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lambda_12739_i4667_i4766
    goto L1626;
    FUN_lambda_12739_i4667_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_629[0];
      r0[2] = r1;
      r1 = (object *) constructed_628[0];
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][4];
      r1[2] = r2;
      r2 = top[22];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1627; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
      L1627:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_2211_i4667_i4766
      goto L1628;
      FUN__24loop_2211_i4667_i4766:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1629; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L1629:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1630; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L1630:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1631; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L1631:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def loop_2216_i4667_i4766
          goto L1632;
          FUN_loop_2216_i4667_i4766:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][3];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = (object *) constructed_41[0];
              r0[3] = r1;
              r1 = top[21];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object****) lenv) [1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[27];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1633; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
              L1633:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_627[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) 3;
                    r1 = ((object***) lenv) [1][1][2];
                    r0 = box((pxll_int)unbox(r1)+unbox(r0));
                    r1 = ((object***) lenv) [1][1][3];
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_2216_i4667_i4766;
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_123;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_123;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_123_over;
              fatbar_123:
              r0 = allocate (TC_TUPLE, 6);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 6);
              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[3] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[4] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][3];
              r1[5] = r2;
              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
              r1[6] = r2;
              r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][17];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1634; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_nvget_2034_i4667_i4766;
              L1634:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object*)TC_NIL;
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              r0[6] = r1;
              r0 = ((object***) lenv) [1][1][3];
              r1 = ((object*) lenv) [6];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = (object *) 3;
              r2 = ((object**) lenv) [1][2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_2216_i4667_i4766;
              fatbar_123_over: ;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1632:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_loop_2216_i4667_i4766; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object *) constructed_625[0];
          r1[3] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1635; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_loop_2216_i4667_i4766;
          L1635:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object*****) lenv) [1][1][1][1][2] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
              r1=r1;
            } break;
            default: {
              goto fatbar_122;
            }
          }
          r1=r1;
          goto fatbar_122_over;
          fatbar_122:
          r1 = (object *) 6;
          r1=r1;
          fatbar_122_over: ;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_610[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][5];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = (object*)TC_NIL;
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1636; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1636:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = (object*)TC_NIL;
            r0[8] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [7];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [6];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1637; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L1637:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [9];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1638; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L1638:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r1 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r0[12] = r1;
            r0 = ((object*) lenv) [12];
            r1 = ((object*) lenv) [11];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object*****) lenv) [1][1][1][1][3] = r0;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1639; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1639:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object*****) lenv) [1][1][1][1][3] = r0;
            r0=r0;
          }
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_2211_i4667_i4766;
        }
        PXLL_RETURN(0);
      L1628:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_2211_i4667_i4766; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1640; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2211_i4667_i4766;
      L1640:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 19);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_602[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][2];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][2];
      r1[3] = r2;
      r2 = top[32];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1641; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
      L1641:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[5] = r1;
      r1 = ((object*) lenv) [5];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[4];
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][2];
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = (object *) constructed_41[0];
      r2[3] = r3;
      r3 = top[21];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1642; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
      L1642:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r2 = r2;
      r1[3] = r2;
      r2 = top[32];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1643; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
      L1643:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[7] = r1;
      r1 = ((object*) lenv) [7];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object******) lenv) [1][1][1][1][1][8];
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][3];
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = (object *) constructed_41[0];
      r2[3] = r3;
      r3 = top[21];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1644; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
      L1644:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r2 = r2;
      r1[3] = r2;
      r2 = top[32];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1645; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
      L1645:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[9] = r1;
      r1 = ((object*) lenv) [9];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[10] = r1;
      r1 = ((object***) lenv) [1][1][5];
      switch (get_case (r1)) {
        case (UITAG(1)): {
          r1 = top[185];
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][5];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1646; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
          L1646:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      r0[11] = r1;
      r1 = (object*)TC_NIL;
      r0[12] = r1;
      r1 = ((object*) lenv) [12];
      r2 = ((object*) lenv) [11];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[13] = r1;
      r1 = ((object*) lenv) [13];
      r2 = ((object*) lenv) [10];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[14] = r1;
      r1 = ((object*) lenv) [14];
      r2 = ((object*) lenv) [8];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[15] = r1;
      r1 = ((object*) lenv) [15];
      r2 = ((object*) lenv) [6];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[16] = r1;
      r1 = ((object*) lenv) [16];
      r2 = ((object*) lenv) [4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[17] = r1;
      r1 = ((object*) lenv) [17];
      r2 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[18] = r1;
      r1 = ((object*) lenv) [18];
      r2 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[19] = r1;
      r0 = ((object*) lenv) [19];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L1626:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_12739_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2174_i1349_i4667_i4766
    goto L1647;
    FUN_loop_2174_i1349_i4667_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [5];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object*) lenv) [4];
          r0[4] = r1;
          r1 = (object*)UITAG(1);
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(9)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,1);
                              r0[2] = r1;
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 3);
                              r2[1] = lenv; lenv = r2;
                              r3 = (object *) constructed_590[0];
                              t = alloc_no_clear (UOTAG(1),1);
                              t[1] = r3;
                              r3 = t;
                              r2[2] = r3;
                              r3 = ((object******) lenv) [1][1][1][1][1][3];
                              r4 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              r2[3] = r3;
                              r2 = ((object*) lenv) [3];
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r2;
                              r2 = t;
                              lenv = lenv[1];
                              r2 = r2;
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][8];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1648; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2024_i4667_i4766;
                              L1648:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r0 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                              r1 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              lenv = lenv[1];
                              r0 = r0;
                              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                              r2 = ((object**) lenv) [1][3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                              r3 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r3;
                              t[2] = r2;
                              r2 = t;
                              r3 = ((object******) lenv) [1][1][1][1][1][3];
                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r1;
                              lenv[4] = r0;
                              lenv[5] = r3;
                              goto FUN_loop_2174_i1349_i4667_i4766;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_121;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_121;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_623[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object****) lenv) [1][1][1][3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = ((object*****) lenv) [1][1][1][1][2];
                            r0[2] = r1;
                            r1 = ((object*****) lenv) [1][1][1][1][3];
                            r0[3] = r1;
                            r1 = ((object*****) lenv) [1][1][1][1][4];
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 2);
                            r3 = allocate (TC_TUPLE, 3);
                            r3[1] = lenv; lenv = r3;
                            r4 = (object *) constructed_590[0];
                            t = alloc_no_clear (UOTAG(1),1);
                            t[1] = r4;
                            r4 = t;
                            r3[2] = r4;
                            r4 = ((object****) lenv) [1][1][1][3];
                            r5 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r5;
                            t[2] = r4;
                            r4 = t;
                            r3[3] = r4;
                            r3 = ((object*) lenv) [3];
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r3;
                            r3 = t;
                            lenv = lenv[1];
                            r3 = r3;
                            r2[2] = r3;
                            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][8];
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1649; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_expand_2024_i4667_i4766;
                            L1649:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r1;
                            r1 = t;
                            lenv = lenv[1];
                            r1 = r1;
                            r0[5] = r1;
                            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_121;
                          }
                        }
                        PXLL_RETURN(0);
                      } else {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_121;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_121;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_121;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_121;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_121_over;
      fatbar_121:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [5];
      r1[2] = r2;
      r2 = top[19];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1650; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
      L1650:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[94];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1651; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_443;
      L1651:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_624;
      r0[2] = r1;
      r1 = ((object*) lenv) [5];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_121_over: ;
      PXLL_RETURN(0);
    L1647:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2174_i1349_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) constructed_621[0];
    r0[2] = r1;
    r1 = (object *) constructed_620[0];
    r0[3] = r1;
    r1 = (object *) constructed_619[0];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][4];
    r0[5] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2174_i1349_i4667_i4766;
  L1625:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_splat_2036_i4667_i4766; r2[2] = lenv;
  r1[19] = r2;
  // def wrap-with-constructors_2039_i4667_i4766
  goto L1652;
  FUN_wrap_with_constructors_2039_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_618[0];
    r0[2] = r1;
    r1 = (object *) constructed_617[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_13004_i4667_i4766
    goto L1653;
    FUN_lambda_13004_i4667_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_13001_i4667_i4766
      goto L1654;
      FUN_lambda_13001_i4667_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 7);
        r3[1] = lenv; lenv = r3;
        r4 = ((object****) lenv) [1][1][1][3];
        r4 = ((pxll_vector*)r4)->val[7];
        r3[2] = r4;
        r4 = ((object*) lenv) [2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object**) lenv) [1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[3] = r4;
        r4 = ((object***) lenv) [1][1][2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object****) lenv) [1][1][1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[4] = r4;
        r4 = (object*)TC_NIL;
        r3[5] = r4;
        r4 = ((object*) lenv) [5];
        r5 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r4 = ((object*) lenv) [6];
        r5 = (object*) &constructed_616;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[7] = r4;
        r3 = ((object*) lenv) [7];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = top[47];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1655; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L1655:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[79];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1656; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
        L1656:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[7];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[4] = r2;
        r2 = ((object******) lenv) [1][1][1][1][1][21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1657; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_constructor_2040_i4667_i4766;
        L1657:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][3];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object***) lenv) [1][1][3] = r0;
        PXLL_RETURN(0);
      L1654:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_13001_i4667_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r1 = ((pxll_vector*)r1)->val[6];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1653:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_13004_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r1 = top[68];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1658; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
    L1658:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[3];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[32];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1659; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
    L1659:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_2017_i4667_i4766;
  L1652:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_with_constructors_2039_i4667_i4766; r2[2] = lenv;
  r1[20] = r2;
  // def make-constructor_2040_i4667_i4766
  goto L1660;
  FUN_make_constructor_2040_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 19);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][4];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2268_i4667_i4766
    goto L1661;
    FUN__24loop_2268_i4667_i4766:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_41[0];
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 4);
        r3[1] = lenv; lenv = r3;
        r4 = allocate (TC_TUPLE, 2);
        r5 = ((object***) lenv) [1][1][2];
        r4[2] = r5;
        r5 = top[56];
        t = allocate (TC_SAVE, 7);
        t[1] = k; t[2] = lenv; t[3] = &&L1662; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
        L1662:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
        r4 = result;
        r3[2] = r4;
        r4 = (object*)TC_NIL;
        r3[3] = r4;
        r4 = ((object*) lenv) [3];
        r5 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[4] = r4;
        r3 = ((object*) lenv) [4];
        r4 = (object*) &constructed_615;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = top[47];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1663; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L1663:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[79];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1664; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
        L1664:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2268_i4667_i4766;
      }
      PXLL_RETURN(0);
    L1661:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2268_i4667_i4766; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1665; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2268_i4667_i4766;
    L1665:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = (object *) constructed_592[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][2];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[2] = r4;
    r4 = ((object***) lenv) [1][1][3];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][3];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = ((object*) lenv) [4];
    r5 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = ((object*) lenv) [5];
    r5 = (object*) &constructed_614;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = top[47];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1666; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
    L1666:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = top[79];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1667; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
    L1667:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = ((object*) lenv) [5];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = (object *) constructed_326[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = (object*)TC_NIL;
    r0[10] = r1;
    r1 = ((object*) lenv) [10];
    r2 = ((object*) lenv) [9];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[11] = r1;
    r1 = ((object*) lenv) [11];
    r2 = ((object*) lenv) [8];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[12] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [12];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1668; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L1668:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1669; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L1669:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[13] = r1;
    r1 = ((object*) lenv) [13];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[14] = r1;
    r1 = (object*)TC_NIL;
    r0[15] = r1;
    r1 = ((object*) lenv) [15];
    r2 = ((object*) lenv) [14];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[16] = r1;
    r1 = ((object*) lenv) [16];
    r2 = ((object*) lenv) [7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[17] = r1;
    r1 = ((object*) lenv) [17];
    r2 = ((object*) lenv) [6];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[18] = r1;
    r1 = ((object*) lenv) [18];
    r2 = ((object*) lenv) [4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[19] = r1;
    r0 = ((object*) lenv) [19];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1660:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_constructor_2040_i4667_i4766; r2[2] = lenv;
  r1[21] = r2;
  // def make-alt_2041_i4667_i4766
  goto L1670;
  FUN_make_alt_2041_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_13133_i4667_i4766
    goto L1671;
    FUN_lambda_13133_i4667_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[110];
      r0[1] = r1[2]; lenv = r0; goto FUN_parse_type_splat_473;
    L1671:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13133_i4667_i4766; r2[2] = lenv;
    r1[2] = r2;
    r2 = ((object**) lenv) [1][4];
    r1[3] = r2;
    r2 = top[32];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1672; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
    L1672:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1673; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L1673:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(6), 4);
    r1 = ((object*) lenv) [3];
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    PXLL_RETURN(0);
  L1670:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_alt_2041_i4667_i4766; r2[2] = lenv;
  r1[22] = r2;
  // def expand-match_2047_i4667_i4766
  goto L1674;
  FUN_expand_match_2047_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2309_i4667_i4766
    goto L1675;
    FUN_loop_2309_i4667_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_612[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 5);
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                r1[2] = r2;
                r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object****) lenv) [1][1][1][2];
                r2[2] = r3;
                r3 = (object *) constructed_41[0];
                r2[3] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1676; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                L1676:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r2 = ((object***) lenv) [1][1][3];
                r1[5] = r2;
                r2 = top[115];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1677; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_compile_pattern_484;
                L1677:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case_noint (r0)) {
                  default: {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = ((object*****) lenv) [1][1][1][1][3];
                    switch (get_case (r1)) {
                      case (TC_NIL): {
                        r1 = (object *) 262;
                        r1=r1;
                      } break;
                      default: {
                        goto fatbar_120;
                      }
                    }
                    r1=r1;
                    goto fatbar_120_over;
                    fatbar_120:
                    r1 = (object *) 6;
                    r1=r1;
                    fatbar_120_over: ;
                    if PXLL_IS_TRUE(r1) {
                      r1 = ((object*) lenv) [2];
                      r1=r1;
                    } else {
                      r1 = allocate (TC_TUPLE, 7);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) constructed_610[0];
                      t = alloc_no_clear (UOTAG(1),1);
                      t[1] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][3];
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = ((object*) lenv) [4];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = ((object*) lenv) [5];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r2 = ((object*) lenv) [6];
                      r3 = ((object*) lenv) [2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[7] = r2;
                      r1 = ((object*) lenv) [7];
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r1;
                      r1 = t;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    }
                    r0[2] = r1;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][8];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_2024_i4667_i4766;
                  } break;
                }
                PXLL_RETURN(0);
              } else {
                goto fatbar_119;
              }
              PXLL_RETURN(0);
              goto fatbar_119_over;
              fatbar_119:
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              r1 = ((object***) lenv) [1][1][3];
              r2 = ((object**) lenv) [1][3];
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              lenv[4] = r2;
              goto FUN_loop_2309_i4667_i4766;
              fatbar_119_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_118;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_118_over;
          fatbar_118:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = top[113];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1678; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_match_var_482;
          L1678:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object***) lenv) [1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object***) lenv) [1][1][2];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r2 = ((object**) lenv) [1][3];
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_2309_i4667_i4766;
          fatbar_118_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_117;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_117_over;
      fatbar_117:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_613;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[14];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      fatbar_117_over: ;
      PXLL_RETURN(0);
    L1675:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2309_i4667_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_608[0];
    r0[2] = r1;
    r1 = (object *) constructed_607[0];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2309_i4667_i4766;
  L1674:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_match_2047_i4667_i4766; r2[2] = lenv;
  r1[23] = r2;
  // def expand-cinclude_2048_i4667_i4766
  goto L1679;
  FUN_expand_cinclude_2048_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object******) lenv) [1][1][1][1][1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                ((pxll_vector*)r1)->val[0] = r0;
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_590[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[2] = r1;
                r1 = (object*)TC_NIL;
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[4] = r1;
                r0 = ((object*) lenv) [4];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_116;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_116;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_116;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_116_over;
    fatbar_116:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_606;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_116_over: ;
    PXLL_RETURN(0);
  L1679:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_cinclude_2048_i4667_i4766; r2[2] = lenv;
  r1[24] = r2;
  // def expand-%nvcase_2049_i4667_i4766
  goto L1680;
  FUN_expand__percentnvcase_2049_i4667_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_602[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1680:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percentnvcase_2049_i4667_i4766; r2[2] = lenv;
  r1[25] = r2;
  // def expand-%%cexp_2050_i4667_i4766
  goto L1681;
  FUN_expand__percent_percentcexp_2050_i4667_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_604[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object**) lenv) [1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][8];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1682; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L1682:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [8];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1683; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L1683:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [9];
            r1[3] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1684; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
            L1684:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r0 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_115;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_115;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_115_over;
    fatbar_115:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_605;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_115_over: ;
    PXLL_RETURN(0);
  L1681:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percent_percentcexp_2050_i4667_i4766; r2[2] = lenv;
  r1[26] = r2;
  r2 = allocate (TC_TUPLE, 12);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)UITAG(0);
  r2[2] = r3;
  r3 = ((object**) lenv) [1][26];
  r4 = ((object*) lenv) [2];
  r5 = (object *) constructed_604[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[3] = r3;
  r3 = ((object**) lenv) [1][25];
  r4 = ((object*) lenv) [3];
  r5 = (object *) constructed_602[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[4] = r3;
  r3 = ((object**) lenv) [1][24];
  r4 = ((object*) lenv) [4];
  r5 = (object *) constructed_600[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[5] = r3;
  r3 = ((object**) lenv) [1][23];
  r4 = ((object*) lenv) [5];
  r5 = (object *) constructed_598[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[6] = r3;
  r3 = ((object**) lenv) [1][13];
  r4 = ((object*) lenv) [6];
  r5 = (object *) constructed_596[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[7] = r3;
  r3 = ((object**) lenv) [1][18];
  r4 = ((object*) lenv) [7];
  r5 = (object *) constructed_594[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[8] = r3;
  r3 = ((object**) lenv) [1][15];
  r4 = ((object*) lenv) [8];
  r5 = (object *) constructed_592[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[9] = r3;
  r3 = ((object**) lenv) [1][14];
  r4 = ((object*) lenv) [9];
  r5 = (object *) constructed_578[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[10] = r3;
  r3 = ((object**) lenv) [1][12];
  r4 = ((object*) lenv) [10];
  r5 = (object *) constructed_590[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[11] = r3;
  r3 = ((object**) lenv) [1][11];
  r4 = ((object*) lenv) [11];
  r5 = (object *) constructed_588[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[12] = r3;
  r2 = ((object**) lenv) [1][10];
  r3 = ((object*) lenv) [12];
  r4 = (object *) constructed_586[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[27] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  r1 = r1;
  r0[7] = r1;
  r1 = top[162];
  r1 = ((pxll_vector*)r1)->val[1];
  r2 = (object *) 3;
  range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r2));
  r1 = ((pxll_vector*)r1)->val[unbox(r2)];
  r0[8] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [8];
  r1[2] = r2;
  r2 = (object *) 11778;
  r1[3] = r2;
  r2 = top[49];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1685; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_split_364;
  L1685:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[9] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [9];
  r1[2] = r2;
  r2 = (object *) constructed_41[0];
  r1[3] = r2;
  r2 = top[21];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1686; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
  L1686:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[10] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][10];
  r2[2] = r3;
  r3 = top[19];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1687; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
  L1687:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object*) lenv) [2];
  r2[2] = r3;
  r3 = (object*) &constructed_584;
  r2[3] = r3;
  r3 = top[50];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1688; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
  L1688:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = (object *) 1;
  r3 = ((object*) lenv) [3];
  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
  r1[4] = r2;
  r1 = (object *) 6;
  r2 = ((object*) lenv) [4];
  r1 = PXLL_TEST(r2==r1);
  lenv = lenv[1];
  r1 = r1;
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_582;
    r1[2] = r2;
    r2 = ((object*) lenv) [8];
    r1[3] = r2;
    r2 = top[14];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1689; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
    L1689:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  } else {
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][10];
    r3[2] = r4;
    r4 = top[20];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1690; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_cdr_320;
    L1690:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_41[0];
    r2[3] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1691; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
    L1691:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = (object*) &constructed_583;
    r1[3] = r2;
    r2 = top[48];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1692; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_join_363;
    L1692:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  }
  r0[11] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)TC_NIL;
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  r4 = (object*) &constructed_581;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[3] = r3;
  r2 = ((object*) lenv) [3];
  r3 = ((object**) lenv) [1][11];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = top[47];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1693; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
  L1693:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[12] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [8];
  r1[2] = r2;
  r2 = top[84];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1694; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_431;
  L1694:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[13] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r2 = top[2];
  r1[2] = r2;
  r2 = ((object*) lenv) [13];
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object*) lenv) [2];
  r3 = ((pxll_vector*)r3)->val[12];
  r2[2] = r3;
  r3 = top[84];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1695; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_read_file_431;
  L1695:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = top[38];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1696; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_foldr_342;
  L1696:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[14] = r1;
  r1 = ((object*) lenv) [14];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  r0[15] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [15];
  r1[2] = r2;
  r2 = ((object*) lenv) [7];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1697; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1697:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[16] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [16];
  r1[2] = r2;
  r2 = top[131];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1698; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_519;
  L1698:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[17] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def shadow_2651_i4674_i4766
  goto L1699;
  FUN_shadow_2651_i4674_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r1[3] = r2;
        r2 = top[25];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1700; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_329;
        L1700:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1701; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_shadow_2651_i4674_i4766;
          L1701:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2651_i4674_i4766;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1699:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_shadow_2651_i4674_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2652_i4674_i4766
  goto L1702;
  FUN_lookup_2652_i4674_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object***) lenv) [1][1][2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[1];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_lookup_2652_i4674_i4766;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1702:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2652_i4674_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def walk_2653_i4674_i4766
  goto L1703;
  FUN_walk_2653_i4674_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_16707_i4674_i4766
    goto L1704;
    FUN_lambda_16707_i4674_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1705; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2651_i4674_i4766;
          L1705:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object****) lenv) [1][1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1706; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2651_i4674_i4766;
          L1706:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object****) lenv) [1][1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1707; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2651_i4674_i4766;
          L1707:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object****) lenv) [1][1][1][3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(5), 2);
          r2 = ((object**) lenv) [1][2];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][3];
          r2[2] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][3];
          r2[3] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1708; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_lookup_2652_i4674_i4766;
          L1708:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object****) lenv) [1][1][1][3] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object****) lenv) [1][1][1][2];
          r3 = ((pxll_vector*)r3)->val[3];
          r2[2] = r3;
          r3 = top[19];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1709; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
          L1709:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          r1[3] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1710; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_2653_i4674_i4766;
          L1710:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1711; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1711:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1712; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2652_i4674_i4766;
          L1712:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1713; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2652_i4674_i4766;
          L1713:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_114;
        }
      }
      r0=r0;
      goto fatbar_114_over;
      fatbar_114:
      r0 = (object *) 14;
      r0=r0;
      fatbar_114_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_16699_i4674_i4766
      goto L1714;
      FUN_lambda_16699_i4674_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_2653_i4674_i4766;
      L1714:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_16699_i4674_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[32];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1715; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_336;
      L1715:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object**) lenv) [1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
    L1704:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16707_i4674_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[16];
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
  L1703:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_walk_2653_i4674_i4766; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][17];
  r1[2] = r2;
  r2 = (object *) constructed_580[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [4];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1716; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_2653_i4674_i4766;
  L1716:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[18] = r1;
  r1 = (object*)UITAG(2);
  r0[19] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[112];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1717; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_478;
  L1717:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[20] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def add_2598_i1837_i4675_i4766
  goto L1718;
  FUN_add_2598_i1837_i4675_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object****) lenv) [1][1][1][20];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1719; t[4] = r0; t[5] = r1; k = t;
    lenv = r2[2]; goto *r2[1];
    L1719:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = top[134];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1720; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_vardef_523;
    L1720:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object****) lenv) [1][1][1][19];
    r0[2] = r1;
    r1 = top[80];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[71];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1721; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
    L1721:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    ((object****) lenv) [1][1][1][19] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1718:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_2598_i1837_i4675_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2599_i1837_i4675_i4766
  goto L1722;
  FUN_lookup_2599_i1837_i4675_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][19];
    r0[2] = r1;
    r1 = top[80];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    r1 = top[72];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fmember_415;
  L1722:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2599_i1837_i4675_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def get_2600_i1837_i4675_i4766
  goto L1723;
  FUN_get_2600_i1837_i4675_i4766:
    r0 = ((object**) lenv) [1][19];
    PXLL_RETURN(0);
  L1723:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_2600_i1837_i4675_i4766; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (UOTAG(4), 3);
  r2 = ((object*) lenv) [2];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[21] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def rename_2607_i4675_i4766
  goto L1724;
  FUN_rename_2607_i4675_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lookup_2613_i4675_i4766
    goto L1725;
    FUN_lookup_2613_i4675_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop0_2615_i4675_i4766
      goto L1726;
      FUN_loop0_2615_i4675_i4766:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*)UITAG(1);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop1_2619_i4675_i4766
            goto L1727;
            FUN_loop1_2619_i4675_i4766:
              check_heap (0);
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = ((object***) lenv) [1][1][3];
                  lenv = ((object ***)lenv)[1][1][1];
                  lenv[2] = r0;
                  goto FUN_loop0_2615_i4675_i4766;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,21)];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    goto FUN_loop1_2619_i4675_i4766;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            L1727:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop1_2619_i4675_i4766; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[1] = r1[2]; lenv = r0; goto FUN_loop1_2619_i4675_i4766;
          } break;
        }
        PXLL_RETURN(0);
      L1726:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop0_2615_i4675_i4766; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object****) lenv) [1][1][1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop0_2615_i4675_i4766;
    L1725:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lookup_2613_i4675_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][21];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1728; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1728:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1729; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2613_i4675_i4766;
        L1729:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        switch (get_case (r1)) {
          case (UITAG(1)): {
            r1 = (object *) constructed_578[0];
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object*****) lenv) [1][1][1][1][2];
              r5 = ((pxll_vector*)r5)->val[1];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1730; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L1730:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_576;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1731; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L1731:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = top[79];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1732; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_425;
              L1732:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = ((object*) lenv) [2];
              r1=r1;
            }
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r1 = ((pxll_vector*)r1)->val[2];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16307_i4675_i4766
        goto L1733;
        FUN_lambda_16307_i4675_i4766:
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1733:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16307_i4675_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][4];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1734; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1734:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][6];
        t = alloc_no_clear (UOTAG(7),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        r2 = ((object**) lenv) [1][4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16192_i1846_i4675_i4766
        goto L1735;
        FUN_lambda_16192_i1846_i4675_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
        L1735:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16192_i1846_i4675_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[35];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][21];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1736; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1736:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16340_i4675_i4766
        goto L1737;
        FUN_lambda_16340_i4675_i4766:
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1737:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16340_i4675_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1738; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1738:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(10),1);
        t[1] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        r2 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16192_i1849_i4675_i4766
        goto L1739;
        FUN_lambda_16192_i1849_i4675_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
        L1739:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16192_i1849_i4675_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[35];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object****) lenv) [1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[123];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1740; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_510;
        L1740:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_579[0];
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1741; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L1741:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_2641_i4675_i4766
            goto L1742;
            FUN__24loop_2641_i4675_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 3);
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1743; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L1743:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r1[2] = r2;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L1744; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
                L1744:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object******) lenv) [1][1][1][1][1][2];
                r2[2] = r3;
                r3 = ((object**) lenv) [1][2];
                r2[3] = r3;
                r3 = top[27];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1745; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                L1745:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][21];
                r2 = ((pxll_vector*)r2)->val[0];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1746; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L1746:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][4];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object****) lenv) [1][1][1][4] = r0;
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_2641_i4675_i4766;
              }
              PXLL_RETURN(0);
            L1742:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_2641_i4675_i4766; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1747; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2641_i4675_i4766;
            L1747:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_16424_i4675_i4766
            goto L1748;
            FUN_lambda_16424_i4675_i4766:
              r0 = ((object*) lenv) [2];
              r0 = ((pxll_vector*)r0)->val[2];
              PXLL_RETURN(0);
            L1748:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_16424_i4675_i4766; r2[2] = lenv;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][4];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_41[0];
            r2[3] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1749; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
            L1749:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1750; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L1750:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(9),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[3] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1751; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2613_i4675_i4766;
        L1751:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1752; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2613_i4675_i4766;
        L1752:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
            r0=r0;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
        }
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16192_i1860_i4675_i4766
        goto L1753;
        FUN_lambda_16192_i1860_i4675_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
        L1753:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16192_i1860_i4675_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[35];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      } break;
      default: {
        goto fatbar_113;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_113_over;
    fatbar_113:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_16192_i1861_i4675_i4766
    goto L1754;
    FUN_lambda_16192_i1861_i4675_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      r0[3] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_rename_2607_i4675_i4766;
    L1754:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16192_i1861_i4675_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[35];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    fatbar_113_over: ;
    PXLL_RETURN(0);
  L1724:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_rename_2607_i4675_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][18];
  r1[2] = r2;
  r2 = (object *) constructed_575[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1755; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_rename_2607_i4675_i4766;
  L1755:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[22] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [18];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[145];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1756; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_561;
  L1756:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[23] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [23];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[145];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1757; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_561;
  L1757:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[24] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def search_3929_i4676_i4766
  goto L1758;
  FUN_search_3929_i4676_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = top[40];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1759; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_every_question_344;
    L1759:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UITAG(8)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[0];
          r1[2] = r2;
          r1 = top[190];
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          goto fatbar_112;
        }
      }
      r1=r1;
      goto fatbar_112_over;
      fatbar_112:
      r1 = (object *) 262;
      r1=r1;
      fatbar_112_over: ;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = top[191];
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
        lenv = lenv[1];
        r0 = r0;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[0] = r0;
      } else {
        r0 = (object *) 14;
      }
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1758:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_3929_i4676_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object**) lenv) [1][24];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1760; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_search_3929_i4676_i4766;
  L1760:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[25] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[8];
  r1 = ((pxll_vector*)r1)->val[3];
  if PXLL_IS_TRUE(r1) {
    r1 = (object*) &constructed_574;
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r2 = (object*) &constructed_574;
    (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [24];
    r1[2] = r2;
    r2 = top[126];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1761; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_node_514;
    L1761:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 14;
    r1=r1;
  } else {
    r1 = (object *) 14;
    r1=r1;
  }
  r0[26] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [24];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[141];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1762; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_build_dependency_graph_545;
  L1762:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[27] = r1;
  r1 = (object*) &constructed_573;
  r1 = box((pxll_int)((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_573;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[28] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[2];
  r0[29] = r1;
  r1 = (object *) constructed_572[0];
  r0[30] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_571[0];
  r1[2] = r2;
  r2 = top[140];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1763; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_544;
  L1763:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[31] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit0_3870_i4679_i4766
  goto L1764;
  FUN_visit0_3870_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][31];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][31];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1765; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1765:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][29];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][29];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1766; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1766:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
        r0=r0;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        // def lambda_24885_i4679_i4766
        goto L1767;
        FUN_lambda_24885_i4679_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][31];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][31];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1768; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1768:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3870_i4679_i4766;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1767:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_24885_i4679_i4766; r1[2] = lenv;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,30)];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1769; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1769:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        r0=r0;
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][30];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    ((object***) lenv) [1][1][30] = r0;
    PXLL_RETURN(0);
  L1764:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit0_3870_i4679_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][29];
  r1[2] = r2;
  // def lambda_24920_i4679_i4766
  goto L1770;
  FUN_lambda_24920_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][31];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][31];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
    r2 = ((pxll_vector*)r2)->val[2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1771; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1771:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 6;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3870_i4679_i4766;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1770:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lambda_24920_i4679_i4766; r2[2] = lenv;
  r1[3] = r2;
  r2 = ((object**) lenv) [1][29];
  r2 = ((pxll_vector*)r2)->val[1];
  r2 = ((pxll_vector*)r2)->val[4];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1772; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1772:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = top[81];
  r2[2] = r3;
  r3 = top[195];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1773; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1773:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][29];
  r2[2] = r3;
  // def lambda_24755_i2941_i4679_i4766
  goto L1774;
  FUN_lambda_24755_i2941_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_570[0];
    r1[2] = r2;
    r2 = top[140];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1775; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_544;
    L1775:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1774:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_24755_i2941_i4679_i4766; r3[2] = lenv;
  r2[3] = r3;
  r3 = ((object***) lenv) [1][1][29];
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1776; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1776:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][29];
  r2[2] = r3;
  // def lambda_24806_i2941_i4679_i4766
  goto L1777;
  FUN_lambda_24806_i2941_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_24798_i2941_i4679_i4766
    goto L1778;
    FUN_lambda_24798_i2941_i4679_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1779; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1779:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[140];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1780; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_544;
          L1780:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L1778:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_24798_i2941_i4679_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1781; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1781:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[35];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
  L1777:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_24806_i2941_i4679_i4766; r3[2] = lenv;
  r2[3] = r3;
  r3 = ((object***) lenv) [1][1][29];
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1782; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1782:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_569[0];
  r2[2] = r3;
  r3 = top[140];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1783; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_symbol_set_maker_544;
  L1783:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = (object *) constructed_568[0];
  r1[5] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_567[0];
  r2[2] = r3;
  r3 = top[140];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1784; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_symbol_set_maker_544;
  L1784:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[6] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit1_3881_i4679_i4766
  goto L1785;
  FUN_visit1_3881_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][4];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][4];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1786; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1786:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][3];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][3];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1787; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1787:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
        r0=r0;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        // def lambda_24966_i4679_i4766
        goto L1788;
        FUN_lambda_24966_i4679_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1789; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1789:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3881_i4679_i4766;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1788:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_24966_i4679_i4766; r1[2] = lenv;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,30)];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1790; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1790:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        r0=r0;
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][6];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][6];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1785:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit1_3881_i4679_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def $loop_3886_i4679_i4766
  goto L1791;
  FUN__24loop_3886_i4679_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object******) lenv) [1][1][1][1][1][30];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
        r1=r1;
      } break;
      default: {
        goto fatbar_111;
      }
    }
    r1=r1;
    goto fatbar_111_over;
    fatbar_111:
    r1 = (object *) 6;
    r1=r1;
    fatbar_111_over: ;
    r0[3] = r1;
    r0 = (object *) 6;
    r1 = ((object*) lenv) [3];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object******) lenv) [1][1][1][1][1][30];
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object*) &constructed_73;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_566;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_566;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][30];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][30];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          ((object*******) lenv) [1][1][1][1][1][1][30] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
      r2 = ((pxll_vector*)r2)->val[2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1792; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1792:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) constructed_565[0];
        r0[2] = r1;
        r1 = top[140];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1793; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_symbol_set_maker_544;
        L1793:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][6] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1794; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3881_i4679_i4766;
        L1794:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*****) lenv) [1][1][1][1][6];
        r1[2] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
        r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1795; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1795:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][5];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object****) lenv) [1][1][1][5] = r0;
        r0=r0;
      } else {
        r0 = (object *) 14;
        r0=r0;
      }
      lenv = lenv[1];
      goto FUN__24loop_3886_i4679_i4766;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1791:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN__24loop_3886_i4679_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1796; t[4] = r0; k = t;
  lenv = r1[2]; goto FUN__24loop_3886_i4679_i4766;
  L1796:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = ((object**) lenv) [1][5];
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[32] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[8];
  r1 = ((pxll_vector*)r1)->val[3];
  if PXLL_IS_TRUE(r1) {
    r1 = ((object*) lenv) [32];
    dump_object (r1, 0); fprintf (stdout, "\n");
    r1 = (object *) 14;
    r1=r1;
  } else {
    r1 = (object *) 14;
    r1=r1;
  }
  r0[33] = r1;
  r1 = ((object*) lenv) [32];
  r2 = ((object*) lenv) [2];
  ((pxll_vector*)r2)->val[11] = r1;
  r0[34] = r1;
  r1 = (object*) &constructed_564;
  r1 = box((pxll_int)((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_564;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[35] = r1;
  r1 = allocate (TC_TUPLE, 14);
  r1[1] = lenv; lenv = r1;
  // def instantiate-type-scheme_3390_i4682_i4766
  goto L1797;
  FUN_instantiate_type_scheme_3390_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_21558_i4682_i4766
    goto L1798;
    FUN_lambda_21558_i4682_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = top[104];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1799; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_459;
          L1799:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object**) lenv) [1][3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),3);
          t[1] = r2;
          t[2] = r0;
          t[3] = r1;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_110;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_110_over;
      fatbar_110:
      r0 = (object*) &constructed_73;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_73;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_563;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_563;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_110_over: ;
      PXLL_RETURN(0);
    L1798:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_21558_i4682_i4766; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[38];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1800; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_foldr_342;
    L1800:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3427_i4682_i4766
    goto L1801;
    FUN_walk_3427_i4682_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [3];
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1802; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L1802:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[103];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[66];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1803; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L1803:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1801:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3427_i4682_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3427_i4682_i4766;
  L1797:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_instantiate_type_scheme_3390_i4682_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def occurs-in-type_3391_i4682_i4766
  goto L1804;
  FUN_occurs_in_type_3391_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21646_i4682_i4766
    goto L1805;
    FUN_lambda_21646_i4682_i4766:
      check_heap (0);
      r0 = ((object**) lenv) [1][3];
      r1 = ((object**) lenv) [1][2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } else {
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_21634_i4682_i4766
            goto L1806;
            FUN_lambda_21634_i4682_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1807; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3391_i4682_i4766;
              L1807:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            L1806:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_21634_i4682_i4766; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[35];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1808; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
            L1808:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1805:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21646_i4682_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[16];
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
  L1804:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_in_type_3391_i4682_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def occurs-free-in-tenv_3392_i4682_i4766
  goto L1809;
  FUN_occurs_free_in_tenv_3392_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21687_i4682_i4766
    goto L1810;
    FUN_lambda_21687_i4682_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_21681_i4682_i4766
      goto L1811;
      FUN_lambda_21681_i4682_i4766:
        check_heap (0);
        r0 = ((object*) lenv) [3];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[25];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1812; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_329;
            L1812:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1813; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3391_i4682_i4766;
              L1813:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L1811:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21681_i4682_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][3];
      r0[3] = r1;
      r1 = top[68];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1814; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      L1814:
      ; lenv = k[2]; k = k[1];
      r0 = (object *) 6;
      PXLL_RETURN(0);
    L1810:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21687_i4682_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[16];
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_308;
  L1809:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_free_in_tenv_3392_i4682_i4766; r2[2] = lenv;
  r1[4] = r2;
  // def build-type-scheme_3393_i4682_i4766
  goto L1815;
  FUN_build_type_scheme_3393_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_562[0];
    r1[2] = r2;
    r2 = top[193];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1816; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1816:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def find-generic-tvars_3449_i4682_i4766
    goto L1817;
    FUN_find_generic_tvars_3449_i4682_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1818; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_occurs_free_in_tenv_3392_i4682_i4766;
          L1818:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object***) lenv) [1][1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[35];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        } break;
      }
      PXLL_RETURN(0);
    L1817:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_generic_tvars_3449_i4682_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][2];
    r1[2] = r2;
    r2 = top[139];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1819; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_537;
    L1819:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1820; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_generic_tvars_3449_i4682_i4766;
    L1820:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object***) lenv) [1][1][2];
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][2];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1821; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1821:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1815:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_build_type_scheme_3393_i4682_i4766; r2[2] = lenv;
  r1[5] = r2;
  // def type-of*_3394_i4682_i4766
  goto L1822;
  FUN_type_of_splat_3394_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[4] = r1;
        r1 = ((object****) lenv) [1][1][1][7];
        r0[1] = r1[2]; lenv = r0; goto FUN_type_of_literal_3396_i4682_i4766;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1823; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3390_i4682_i4766;
        L1823:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_99[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1824; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L1824:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)-unbox(r1));
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1825; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L1825:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*) lenv) [3];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              r0[5] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [5];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_515;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[3] = r1;
                r1 = top[14];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
              } else {
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = (object*) &constructed_516;
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r0[3] = r1;
                    r1 = top[14];
                    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    // def lambda_22141_i2386_i4682_i4766
                    goto L1826;
                    FUN_lambda_22141_i2386_i4682_i4766:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                      r1[3] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1827; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
                      L1827:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object**) lenv) [1][2];
                      ((pxll_vector*)r1)->val[5] = r0;
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    L1826:
                    r2 = allocate (TC_CLOSURE, 2);
                    r2[1] = &&FUN_lambda_22141_i2386_i4682_i4766; r2[2] = lenv;
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    r2 = ((pxll_vector*)r2)->val[3];
                    r1[3] = r2;
                    r2 = top[32];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1828; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                    L1828:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    // def lambda_22154_i2386_i4682_i4766
                    goto L1829;
                    FUN_lambda_22154_i2386_i4682_i4766:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = ((object******) lenv) [1][1][1][1][1][2];
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1830; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unraw_3397_i4682_i4766;
                      L1830:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = ((object*) lenv) [3];
                      r0[4] = r1;
                      r1 = top[138];
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                    L1829:
                    r1 = allocate (TC_CLOSURE, 2);
                    r1[1] = &&FUN_lambda_22154_i2386_i4682_i4766; r1[2] = lenv;
                    r0[2] = r1;
                    r1 = ((object*) lenv) [3];
                    r0[3] = r1;
                    r1 = ((object*) lenv) [4];
                    r0[4] = r1;
                    r1 = top[36];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1831; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_340;
                    L1831:
                    ; lenv = k[2]; k = k[1];
                    r0 = ((object*) lenv) [2];
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_77;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_77;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_77_over;
        fatbar_77:
        r0 = ((object*) lenv) [4];
        PXLL_RETURN(0);
        fatbar_77_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_22188_i2392_i4682_i4766
        goto L1832;
        FUN_lambda_22188_i2392_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1833; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
          L1833:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        L1832:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_22188_i2392_i4682_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1834; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1834:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object***) lenv) [1][1][2];
                        r0[3] = r1;
                        r1 = top[182];
                        r0[4] = r1;
                        r1 = top[138];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1835; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                        L1835:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r0[3] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[4] = r1;
                        r1 = top[138];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1836; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                        L1836:
                        ; lenv = k[2]; k = k[1];
                        r0 = ((object*) lenv) [2];
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_78;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_78;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_78;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_78;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_78_over;
        fatbar_78:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_517;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_78_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_3525_i2394_i4682_i4766
        goto L1837;
        FUN_loop_3525_i2394_i4682_i4766:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_73;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_73;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = (object*) &constructed_518;
              dump_object (r0, 0); fprintf (stdout, "\n");
              r0 = (object*) &constructed_518;
              PXLL_UNDEFINED; result=r0; goto Lreturn;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object**) lenv) [1][2];
                  r1[2] = r2;
                  r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1838; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
                  L1838:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object**) lenv) [1][2];
                  ((pxll_vector*)r1)->val[5] = r0;
                  r0 = ((object*) lenv) [2];
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_79;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_79_over;
              fatbar_79:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r1[3] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1839; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
              L1839:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_3525_i2394_i4682_i4766;
              fatbar_79_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1837:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_3525_i2394_i4682_i4766; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_3525_i2394_i4682_i4766;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1840; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L1840:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[4] = r1;
        r1 = (object *) constructed_520[0];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_22313_i2398_i4682_i4766
        goto L1841;
        FUN_lambda_22313_i2398_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = top[104];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1842; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_459;
          L1842:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][5];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          ((object***) lenv) [1][1][5] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_519[0];
          r1[1] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object****) lenv) [1][1][1][4];
          r2 = ((object***) lenv) [1][1][2];
          t = alloc_no_clear (UOTAG(1),3);
          t[1] = r2;
          t[2] = r0;
          t[3] = r1;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][4] = r0;
          PXLL_RETURN(0);
        L1841:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_22313_i2398_i4682_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[35];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1843; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L1843:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][4];
        r1[3] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1844; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
        L1844:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][3];
        ((pxll_vector*)r2)->val[5] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][5];
        r1[2] = r2;
        r2 = (object *) constructed_41[0];
        r1[3] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1845; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
        L1845:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_99[0];
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = top[103];
        r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][9];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1846; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3403_i4682_i4766;
        L1846:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1847; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L1847:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][9];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1848; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3403_i4682_i4766;
        L1848:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1849; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
        L1849:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [3];
        ((pxll_vector*)r2)->val[5] = r1;
        r1 = ((object*) lenv) [5];
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object*) lenv) [6];
        r0[4] = r1;
        r1 = top[138];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1850; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
        L1850:
        ; lenv = k[2]; k = k[1];
        r0 = top[181];
        PXLL_RETURN(0);
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_22402_i2408_i4682_i4766
        goto L1851;
        FUN_lambda_22402_i2408_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1852; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
          L1852:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        L1851:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_22402_i2408_i4682_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1853; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L1853:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = top[104];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1854; t[4] = r0; k = t;
            lenv = r1[2]; goto FUN_new_tvar_459;
            L1854:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object *) constructed_99[0];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = top[103];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1855; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
            L1855:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = top[138];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1856; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
            L1856:
            ; lenv = k[2]; k = k[1];
            r0 = ((object*) lenv) [4];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_521;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_521;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 17);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[11];
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1857; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L1857:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = top[81];
        r1[2] = r2;
        r2 = top[195];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1858; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1858:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [6];
        r1[2] = r2;
        r2 = top[30];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1859; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_range_334;
        L1859:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[8] = r1;
        r1 = (object *) constructed_529[0];
        r0[9] = r1;
        r1 = (object *) constructed_528[0];
        r0[10] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][6];
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_3898_i2414_i4682_i4766
        goto L1860;
        FUN__24loop_3898_i2414_i4682_i4766:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object****) lenv) [1][1][1][7];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1861; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1861:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (UOTAG(3), 2);
            r2 = (object *) 6;
            r1[1] = r2;
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r0[4] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1862; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1862:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 3;
            r1 = ((object*) lenv) [2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3898_i2414_i4682_i4766;
          }
          PXLL_RETURN(0);
        L1860:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_3898_i2414_i4682_i4766; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1863; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3898_i2414_i4682_i4766;
        L1863:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_25171_i2414_i4682_i4766
        goto L1864;
        FUN_lambda_25171_i2414_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][10];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1865; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L1865:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object**) lenv) [1][9];
            r1 = ((object**) lenv) [1][10];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            ((object**) lenv) [1][9] = r0;
            r0 = (object *) constructed_527[0];
            ((object**) lenv) [1][10] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_25166_i2414_i4682_i4766
          goto L1866;
          FUN_lambda_25166_i2414_i4682_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][7];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][7];
            r2 = ((pxll_vector*)r2)->val[1];
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1867; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1867:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r0 = ((object******) lenv) [1][1][1][1][1][10];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  ((object*****) lenv) [1][1][1][1][10] = r0;
                  r0 = (object *) 262;
                  r1 = ((object*) lenv) [2];
                  ((pxll_vector*)r1)->val[0] = r0;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][8];
                  r0[3] = r1;
                  r1 = top[26];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1868; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_remove_eq_330;
                  L1868:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object*****) lenv) [1][1][1][1][8] = r0;
                  PXLL_RETURN(0);
                } else {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1866:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_25166_i2414_i4682_i4766; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[35];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L1864:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_25171_i2414_i4682_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [5];
        r1[3] = r2;
        r2 = top[35];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1869; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_339;
        L1869:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][10];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1870; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L1870:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*) lenv) [9];
          r2 = ((object*) lenv) [10];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          ((object*) lenv) [9] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][8];
        r2[2] = r3;
        r3 = top[22];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1871; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
        L1871:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*) lenv) [9];
          r2 = ((object*) lenv) [8];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          ((object*) lenv) [9] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [9];
        r1[2] = r2;
        r2 = (object *) constructed_41[0];
        r1[3] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1872; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
        L1872:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[11] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1873; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L1873:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[12] = r1;
        r1 = (object *) constructed_526[0];
        r0[13] = r1;
        r1 = (object *) constructed_525[0];
        r0[14] = r1;
        r1 = (object *) constructed_524[0];
        r0[15] = r1;
        r1 = (object *) 1;
        r0[16] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_25264_i2413_i4682_i4766
        goto L1874;
        FUN_lambda_25264_i2413_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_523[0];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_25250_i2413_i4682_i4766
          goto L1875;
          FUN_lambda_25250_i2413_i4682_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1876; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1876:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][13];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object****) lenv) [1][1][1][13] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1877; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1877:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][14];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object****) lenv) [1][1][1][14] = r0;
            r0 = ((object**) lenv) [1][2];
            r1 = ((object****) lenv) [1][1][1][16];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            ((object**) lenv) [1][2] = r0;
            r0 = (object *) 3;
            r1 = ((object****) lenv) [1][1][1][16];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            ((object****) lenv) [1][1][1][16] = r0;
            PXLL_RETURN(0);
          L1875:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_25250_i2413_i4682_i4766; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1878; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L1878:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1879; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L1879:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object****) lenv) [1][1][1][15];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          ((object***) lenv) [1][1][15] = r0;
          PXLL_RETURN(0);
        L1874:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_25264_i2413_i4682_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [11];
        r1[3] = r2;
        r2 = top[35];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1880; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_339;
        L1880:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (UOTAG(5), 4);
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [13];
        r2[2] = r3;
        r3 = (object *) constructed_41[0];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1881; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L1881:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [14];
        r2[2] = r3;
        r3 = (object *) constructed_41[0];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1882; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L1882:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [4];
        r2[2] = r3;
        r3 = ((object*) lenv) [12];
        r2[3] = r3;
        r3 = top[27];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1883; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
        L1883:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [15];
        r2[2] = r3;
        r3 = (object *) constructed_41[0];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1884; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L1884:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r0[17] = r1;
        r0 = ((object*) lenv) [17];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,3);
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1885; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L1885:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[43];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1886; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_349;
            L1886:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = top[43];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1887; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_349;
            L1887:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_3571_i2412_i4682_i4766
            goto L1888;
            FUN__24loop_3571_i2412_i4682_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_41[0];
                r0[3] = r1;
                r1 = top[21];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = top[104];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1889; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_new_tvar_459;
                L1889:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_3571_i2412_i4682_i4766;
              }
              PXLL_RETURN(0);
            L1888:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_3571_i2412_i4682_i4766; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1890; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_3571_i2412_i4682_i4766;
            L1890:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = top[43];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1891; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_349;
            L1891:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = ((object*) lenv) [6];
            ensure_heap (1, unbox(r1));
            r1 = top[189];
            r2 = ((object*) lenv) [6];
            if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
              t = alloc_no_clear (TC_VECTOR, unbox(r2));
              for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
              r1 = t;
            }
            r0[10] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_22574_i2412_i4682_i4766
            goto L1892;
            FUN_lambda_22574_i2412_i4682_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              // def lambda_22514_i2412_i4682_i4766
              goto L1893;
              FUN_lambda_22514_i2412_i4682_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object*****) lenv) [1][1][1][1][7];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (UOTAG(2), 2);
                r2 = (object *) constructed_522[0];
                r1[1] = r2;
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][9];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object**) lenv) [1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              L1893:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_22514_i2412_i4682_i4766; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][3];
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object *) constructed_41[0];
              r2[3] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1894; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
              L1894:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r2 = top[38];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1895; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_foldr_342;
              L1895:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22546_i2412_i4682_i4766
              goto L1896;
              FUN_lambda_22546_i2412_i4682_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 6);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object*****) lenv) [1][1][1][1][8];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object***) lenv) [1][1][2];
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][6];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1897; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
                L1897:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r2 = ((object*) lenv) [2];
                ((pxll_vector*)r2)->val[5] = r1;
                r1 = ((object*) lenv) [3];
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 4);
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][8];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = ((object*) lenv) [4];
                r1[3] = r2;
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][9];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[4] = r2;
                r2 = top[138];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1898; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_unify_536;
                L1898:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [4];
                r1[2] = r2;
                r2 = top[139];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1899; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_537;
                L1899:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[6] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*) lenv) [6];
                r2 = ((object*****) lenv) [1][1][1][1][10];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                PXLL_RETURN(0);
              L1896:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22546_i2412_i4682_i4766; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[35];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1900; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
              L1900:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22567_i2412_i4682_i4766
              goto L1901;
              FUN_lambda_22567_i2412_i4682_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][10];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1902; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_build_type_scheme_3393_i4682_i4766;
                L1902:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r2 = ((object******) lenv) [1][1][1][1][1][7];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object******) lenv) [1][1][1][1][1][3] = r0;
                PXLL_RETURN(0);
              L1901:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22567_i2412_i4682_i4766; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[35];
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
            L1892:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_22574_i2412_i4682_i4766; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [5];
            r0[3] = r1;
            r1 = top[35];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1903; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
            L1903:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1904; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
            L1904:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][4];
            ((pxll_vector*)r1)->val[5] = r0;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1905; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L1905:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def $loop_3592_i2446_i4682_i4766
        goto L1906;
        FUN__24loop_3592_i2446_i4682_i4766:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][5];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1907; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1907:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1908; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L1908:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1[3] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1909; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
            L1909:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [2];
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = ((object*) lenv) [4];
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (UOTAG(2), 2);
            r2 = (object *) constructed_530[0];
            r1[1] = r2;
            r2 = ((object**) lenv) [1][5];
            r1[2] = r2;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r2 = ((object**) lenv) [1][3];
            t = alloc_no_clear (UOTAG(1),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object*****) lenv) [1][1][1][1][3] = r0;
            lenv = lenv[1];
            r0 = (object *) 3;
            r1 = ((object*) lenv) [2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3592_i2446_i4682_i4766;
          }
          PXLL_RETURN(0);
        L1906:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN__24loop_3592_i2446_i4682_i4766; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1910; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3592_i2446_i4682_i4766;
        L1910:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][5];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][4];
        r1[3] = r2;
        r2 = top[27];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1911; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
        L1911:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1912; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
        L1912:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        ((pxll_vector*)r1)->val[5] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = (object *) constructed_228[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_478[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object******) lenv) [1][1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1913; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1913:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [6];
          r4 = top[181];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1914; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1914:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_81;
        }
        r1=r1;
        goto fatbar_81_over;
        fatbar_81:
        r1 = (object *) constructed_237[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_478[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object******) lenv) [1][1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1915; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1915:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1916; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1916:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_82;
        }
        r1=r1;
        goto fatbar_82_over;
        fatbar_82:
        r1 = (object *) constructed_241[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1917; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1917:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_83;
        }
        r1=r1;
        goto fatbar_83_over;
        fatbar_83:
        r1 = (object *) constructed_248[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][3];
          r2[2] = r3;
          r3 = top[194];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1918; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          lenv = r3[2]; goto *r3[1];
          L1918:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = top[110];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1919; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_parse_type_splat_473;
          L1919:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_533[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_478[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object***) lenv) [1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1920; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1920:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1921; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1921:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_84;
        }
        r1=r1;
        goto fatbar_84_over;
        fatbar_84:
        r1 = (object *) constructed_312[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (UOTAG(9)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object**) lenv) [1][3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[3] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (UOTAG(5)): {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r1 = ((object**) lenv) [1][3];
                                      switch (get_case (r1)) {
                                        case (TC_NIL): {
                                          r1 = (object *) constructed_54[0];
                                          r2 = ((object*****) lenv) [1][1][1][1][2];
                                          if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                            r1 = allocate (TC_TUPLE, 6);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 2);
                                            r3 = ((object**) lenv) [1][2];
                                            r2[2] = r3;
                                            r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][10];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1922; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3413_i4682_i4766;
                                            L1922:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r2 = top[104];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1923; t[4] = r0; t[5] = r1; k = t;
                                            lenv = r2[2]; goto FUN_new_tvar_459;
                                            L1923:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[3] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = ((object******) lenv) [1][1][1][1][1][3];
                                            r2[2] = r3;
                                            r3 = (object *) constructed_540[0];
                                            r2[3] = r3;
                                            r3 = top[103];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1924; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                            L1924:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[4] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r3 = ((object*) lenv) [4];
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object *) 3;
                                            r5 = ((object***) lenv) [1][1][2];
                                            if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)>unbox(r4))) {
                                              r4 = allocate (TC_TUPLE, 3);
                                              r5 = (object *) constructed_539[0];
                                              r4[2] = r5;
                                              r5 = ((object**) lenv) [1][2];
                                              r4[3] = r5;
                                              r5 = top[103];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1925; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
                                              L1925:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r4=r4;
                                            } else {
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object**) lenv) [1][2];
                                              r4[2] = r5;
                                              r5 = top[19];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1926; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_car_319;
                                              L1926:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r4=r4;
                                            }
                                            r3[2] = r4;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = (object *) constructed_537[0];
                                            r3[2] = r4;
                                            r4 = allocate (TC_TUPLE, 2);
                                            r4[1] = lenv; lenv = r4;
                                            r5 = (object*)TC_NIL;
                                            r4[2] = r5;
                                            r4 = ((object*) lenv) [2];
                                            r5 = ((object**) lenv) [1][2];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r5;
                                            t[2] = r4;
                                            r4 = t;
                                            lenv = lenv[1];
                                            r4 = r4;
                                            r3[3] = r4;
                                            r4 = top[103];
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1927; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
                                            L1927:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            lenv = lenv[1];
                                            r3 = r3;
                                            r2[3] = r3;
                                            r3 = ((object*) lenv) [3];
                                            r2[4] = r3;
                                            r3 = top[105];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1928; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_rlabel_464;
                                            L1928:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[5] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_535[0];
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object*)TC_NIL;
                                            r3[2] = r4;
                                            r3 = ((object*) lenv) [2];
                                            r4 = ((object**) lenv) [1][5];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            lenv = lenv[1];
                                            r3 = r3;
                                            r2[3] = r3;
                                            r3 = top[103];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1929; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                            L1929:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[6] = r2;
                                            r1 = allocate (UOTAG(2), 2);
                                            r2 = ((object*) lenv) [2];
                                            r3 = ((object*) lenv) [3];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r3;
                                            t[2] = r2;
                                            r2 = t;
                                            r1[1] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r2[1] = lenv; lenv = r2;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = ((object**) lenv) [1][2];
                                            r3[2] = r4;
                                            r4 = ((object*****) lenv) [1][1][1][1][2];
                                            r3[3] = r4;
                                            r4 = top[27];
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1930; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_nth_331;
                                            L1930:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            r2[2] = r3;
                                            r3 = (object*)TC_NIL;
                                            r2[3] = r3;
                                            r3 = ((object*) lenv) [3];
                                            r4 = ((object**) lenv) [1][6];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[4] = r3;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_99[0];
                                            r2[2] = r3;
                                            r3 = ((object*) lenv) [4];
                                            r4 = ((object*) lenv) [2];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[3] = r3;
                                            r3 = top[103];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1931; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                            L1931:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            lenv = lenv[1];
                                            r2 = r2;
                                            r1[2] = r2;
                                            lenv = lenv[1];
                                            r1 = r1;
                                            r1=r1;
                                          } else {
                                            r1 = allocate (TC_TUPLE, 2);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                            r3 = ((pxll_vector*)r3)->val[1];
                                            r2[2] = r3;
                                            r3 = ((object******) lenv) [1][1][1][1][1][2];
                                            r2[3] = r3;
                                            r3 = top[66];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1932; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                                            L1932:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r1 = ((object*) lenv) [2];
                                            switch (get_case (r1)) {
                                              case (UITAG(1)): {
                                                r1 = allocate (TC_TUPLE, 3);
                                                r2 = (object*) &constructed_541;
                                                r1[2] = r2;
                                                r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                r1[3] = r2;
                                                r2 = top[14];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1933; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                                                L1933:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r1=r1;
                                              } break;
                                              default: {
                                                r1 = allocate (TC_TUPLE, 5);
                                                r1[1] = lenv; lenv = r1;
                                                r2 = ((object**) lenv) [1][2];
                                                r2 = UOBJ_GET(r2,0);
                                                r1[2] = r2;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [2];
                                                r3 = ((pxll_vector*)r3)->val[1];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1934; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto *r3[1];
                                                L1934:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[3] = r2;
                                                r2 = ((object*) lenv) [2];
                                                r2 = ((pxll_vector*)r2)->val[5];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1935; t[4] = r0; t[5] = r1; k = t;
                                                lenv = r2[2]; goto *r2[1];
                                                L1935:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[4] = r2;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r2[3] = r3;
                                                r3 = top[103];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1936; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                                L1936:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[5] = r2;
                                                r1 = allocate (UOTAG(2), 2);
                                                r2 = ((object*) lenv) [4];
                                                r1[1] = r2;
                                                r2 = allocate (TC_TUPLE, 4);
                                                r2[1] = lenv; lenv = r2;
                                                r3 = allocate (TC_TUPLE, 3);
                                                r4 = ((object**) lenv) [1][3];
                                                r4 = ((pxll_vector*)r4)->val[3];
                                                r3[2] = r4;
                                                r4 = ((object******) lenv) [1][1][1][1][1][2];
                                                r3[3] = r4;
                                                r4 = top[27];
                                                t = allocate (TC_SAVE, 6);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1937; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                                r3[1] = r4[2]; lenv = r3; goto FUN_nth_331;
                                                L1937:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                                r3 = result;
                                                r2[2] = r3;
                                                r3 = (object*)TC_NIL;
                                                r2[3] = r3;
                                                r3 = ((object*) lenv) [3];
                                                r4 = ((object**) lenv) [1][5];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[4] = r3;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = (object *) constructed_99[0];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r4 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[3] = r3;
                                                r3 = top[103];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1938; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                                L1938:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                lenv = lenv[1];
                                                r2 = r2;
                                                r1[2] = r2;
                                                lenv = lenv[1];
                                                r1 = r1;
                                                r1=r1;
                                              } break;
                                            }
                                            lenv = lenv[1];
                                            r1 = r1;
                                            r1=r1;
                                          }
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                          goto fatbar_86;
                                        }
                                      }
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_86;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_86;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_86;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_86;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_86;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_86;
                }
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_86;
            }
          }
          r1=r1;
          goto fatbar_86_over;
          fatbar_86:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1939; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1939:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_86_over: ;
          r1=r1;
        } else {
          goto fatbar_85;
        }
        r1=r1;
        goto fatbar_85_over;
        fatbar_85:
        r1 = (object *) constructed_493[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (UOTAG(1)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = ((object**) lenv) [1][3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_NIL): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = ((object****) lenv) [1][1][1][2];
                                  r2[2] = r3;
                                  r3 = (object *) constructed_540[0];
                                  r2[3] = r3;
                                  r3 = top[103];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1940; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                  L1940:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                  r3 = ((pxll_vector*)r3)->val[14];
                                  r2[2] = r3;
                                  r3 = ((object*****) lenv) [1][1][1][1][2];
                                  r2[3] = r3;
                                  r3 = top[66];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1941; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                                  L1941:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (UOTAG(0)): {
                                      r1 = (object *) 14;
                                      r1=r1;
                                    } break;
                                    default: {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 2);
                                      r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      r3 = ((pxll_vector*)r3)->val[14];
                                      r2[2] = r3;
                                      r3 = top[70];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1942; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flength_412;
                                      L1942:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      r2 = ((pxll_vector*)r2)->val[14];
                                      r1[2] = r2;
                                      r1 = ((object**) lenv) [1][2];
                                      r2 = ((object*) lenv) [2];
                                      r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                      t = alloc_no_clear (UOTAG(1),3);
                                      t[1] = r3;
                                      t[2] = r1;
                                      t[3] = r2;
                                      r1 = t;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      ((pxll_vector*)r2)->val[14] = r1;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                  }
                                  lenv = lenv[1];
                                  r1 = (object *) 3;
                                  r2 = ((object**) lenv) [1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r3 = ((object*) lenv) [2];
                                    r4 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][13];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r2 = ((object*) lenv) [3];
                                    r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][12];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 5);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = ((object**) lenv) [1][2];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_537[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = ((object*) lenv) [2];
                                    r6 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][12];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r5 = r5;
                                    r4[3] = r5;
                                    r5 = top[103];
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1943; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
                                    L1943:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    r3[3] = r4;
                                    r4 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][13];
                                    r3[4] = r4;
                                    r4 = top[105];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1944; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
                                    L1944:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_535[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = ((object*) lenv) [2];
                                    r5 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = top[103];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1945; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
                                    L1945:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r3 = (object*)TC_NIL;
                                    r2[4] = r3;
                                    r3 = ((object*) lenv) [4];
                                    r4 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][12];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[5] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_99[0];
                                    r2[2] = r3;
                                    r3 = ((object*) lenv) [5];
                                    r4 = ((object*) lenv) [3];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = top[103];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1946; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                    L1946:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[2] = r2;
                                    r1=r1;
                                  } else {
                                    goto fatbar_89;
                                  }
                                  r1=r1;
                                  goto fatbar_89_over;
                                  fatbar_89:
                                  r1 = (object *) 1;
                                  r2 = ((object**) lenv) [1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 2);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r2 = ((object*) lenv) [2];
                                    r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][12];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = ((object**) lenv) [1][2];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = allocate (TC_TUPLE, 3);
                                    r6 = (object *) constructed_539[0];
                                    r5[2] = r6;
                                    r6 = (object *) constructed_544[0];
                                    r5[3] = r6;
                                    r6 = top[103];
                                    t = allocate (TC_SAVE, 8);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1947; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                    r5[1] = r6[2]; lenv = r5; goto FUN_pred_457;
                                    L1947:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                    r5 = result;
                                    r4[2] = r5;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_537[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = ((object*) lenv) [2];
                                    r6 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r5 = r5;
                                    r4[3] = r5;
                                    r5 = top[103];
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1948; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
                                    L1948:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][12];
                                    r3[4] = r4;
                                    r4 = top[105];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1949; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
                                    L1949:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_535[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = ((object*) lenv) [2];
                                    r5 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = top[103];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1950; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
                                    L1950:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_99[0];
                                    r2[2] = r3;
                                    r3 = (object *) constructed_543[0];
                                    r4 = ((object*) lenv) [3];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = top[103];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1951; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                    L1951:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[2] = r2;
                                    r1=r1;
                                  } else {
                                    goto fatbar_90;
                                  }
                                  r1=r1;
                                  goto fatbar_90_over;
                                  fatbar_90:
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = top[104];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1952; t[4] = r0; t[5] = r1; k = t;
                                  lenv = r2[2]; goto FUN_new_tvar_459;
                                  L1952:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][2];
                                  r2[2] = r3;
                                  r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][10];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1953; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3413_i4682_i4766;
                                  L1953:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = ((object*) lenv) [3];
                                  r3 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r3;
                                  t[2] = r2;
                                  r2 = t;
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = allocate (TC_TUPLE, 4);
                                  r4 = ((object***) lenv) [1][1][2];
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = allocate (TC_TUPLE, 3);
                                  r6 = (object *) constructed_539[0];
                                  r5[2] = r6;
                                  r6 = ((object***) lenv) [1][1][3];
                                  r5[3] = r6;
                                  r6 = top[103];
                                  t = allocate (TC_SAVE, 8);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1954; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                  r5[1] = r6[2]; lenv = r5; goto FUN_pred_457;
                                  L1954:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                  r5 = result;
                                  r4[2] = r5;
                                  r4 = allocate (TC_TUPLE, 3);
                                  r5 = (object *) constructed_537[0];
                                  r4[2] = r5;
                                  r5 = allocate (TC_TUPLE, 2);
                                  r5[1] = lenv; lenv = r5;
                                  r6 = (object*)TC_NIL;
                                  r5[2] = r6;
                                  r5 = ((object*) lenv) [2];
                                  r6 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r6;
                                  t[2] = r5;
                                  r5 = t;
                                  lenv = lenv[1];
                                  r5 = r5;
                                  r4[3] = r5;
                                  r5 = top[103];
                                  t = allocate (TC_SAVE, 7);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1955; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                  r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
                                  L1955:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                  r4 = result;
                                  lenv = lenv[1];
                                  r4 = r4;
                                  r3[3] = r4;
                                  r4 = ((object**) lenv) [1][2];
                                  r3[4] = r4;
                                  r4 = top[105];
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1956; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
                                  L1956:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[2] = r3;
                                  r3 = allocate (TC_TUPLE, 3);
                                  r4 = (object *) constructed_535[0];
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = (object*)TC_NIL;
                                  r4[2] = r5;
                                  r4 = ((object*) lenv) [2];
                                  r5 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r5;
                                  t[2] = r4;
                                  r4 = t;
                                  lenv = lenv[1];
                                  r4 = r4;
                                  r3[3] = r4;
                                  r4 = top[103];
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1957; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
                                  L1957:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[3] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_99[0];
                                  r2[2] = r3;
                                  r3 = ((object**) lenv) [1][3];
                                  r4 = ((object*) lenv) [3];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = top[103];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1958; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                                  L1958:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r2 = r2;
                                  r1[2] = r2;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                  fatbar_90_over: ;
                                  r1=r1;
                                  fatbar_89_over: ;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_88;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_88;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_88;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_88;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_88;
                }
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_88;
            }
          }
          r1=r1;
          goto fatbar_88_over;
          fatbar_88:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1959; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1959:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_88_over: ;
          r1=r1;
        } else {
          goto fatbar_87;
        }
        r1=r1;
        goto fatbar_87_over;
        fatbar_87:
        r1 = (object *) constructed_326[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(9)): {
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,1);
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object******) lenv) [1][1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[1];
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r2[3] = r3;
              r3 = top[66];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1960; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
              L1960:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r1 = ((object*) lenv) [4];
              switch (get_case (r1)) {
                case (UITAG(1)): {
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_545;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[14];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1961; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                  L1961:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][4];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][3];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r2 = ((pxll_vector*)r2)->val[2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1962; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L1962:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_92;
            }
          }
          r1=r1;
          goto fatbar_92_over;
          fatbar_92:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1963; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1963:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_92_over: ;
          r1=r1;
        } else {
          goto fatbar_91;
        }
        r1=r1;
        goto fatbar_91_over;
        fatbar_91:
        r1 = (object *) constructed_480[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = ((object*) lenv) [3];
              r3 = ((object******) lenv) [1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 6);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = (object *) constructed_540[0];
              r4[3] = r5;
              r5 = top[103];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1964; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
              L1964:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_537[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object*******) lenv) [1][1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = top[103];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1965; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
              L1965:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              r3[4] = r4;
              r4 = top[105];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1966; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
              L1966:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_547[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = top[103];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1967; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
              L1967:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = ((object******) lenv) [1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_99[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [6];
              r4 = top[181];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[103];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1968; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
              L1968:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_94;
            }
          }
          r1=r1;
          goto fatbar_94_over;
          fatbar_94:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1969; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1969:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_94_over: ;
          r1=r1;
        } else {
          goto fatbar_93;
        }
        r1=r1;
        goto fatbar_93_over;
        fatbar_93:
        r1 = (object *) constructed_482[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = ((object*) lenv) [3];
              r3 = ((object******) lenv) [1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 5);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = (object *) constructed_540[0];
              r4[3] = r5;
              r5 = top[103];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1970; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
              L1970:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_537[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object*******) lenv) [1][1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = top[103];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1971; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
              L1971:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              r3[4] = r4;
              r4 = top[105];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1972; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
              L1972:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_547[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = top[103];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1973; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
              L1973:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_99[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object******) lenv) [1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[103];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1974; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
              L1974:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_96;
            }
          }
          r1=r1;
          goto fatbar_96_over;
          fatbar_96:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1975; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1975:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_96_over: ;
          r1=r1;
        } else {
          goto fatbar_95;
        }
        r1=r1;
        goto fatbar_95_over;
        fatbar_95:
        r1 = (object *) constructed_488[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = (object *) constructed_540[0];
              r2[3] = r3;
              r3 = top[103];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1976; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
              L1976:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object******) lenv) [1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = ((object******) lenv) [1][1][1][1][1][12];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_537[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object*******) lenv) [1][1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = top[103];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1977; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_457;
              L1977:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              r3[4] = r4;
              r4 = top[105];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1978; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
              L1978:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_547[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = top[103];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1979; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
              L1979:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 4);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = ((object******) lenv) [1][1][1][1][1][12];
              r3[3] = r4;
              r4 = ((object******) lenv) [1][1][1][1][1][13];
              r3[4] = r4;
              r4 = top[105];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1980; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_464;
              L1980:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_547[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = top[103];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1981; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
              L1981:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = ((object******) lenv) [1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_99[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [8];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[103];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1982; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
              L1982:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_98;
            }
          }
          r1=r1;
          goto fatbar_98_over;
          fatbar_98:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_542;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1983; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
          L1983:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_98_over: ;
          r1=r1;
        } else {
          goto fatbar_97;
        }
        r1=r1;
        goto fatbar_97_over;
        fatbar_97:
        r1 = (object *) constructed_253[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_548[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[181];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1984; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1984:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_99;
        }
        r1=r1;
        goto fatbar_99_over;
        fatbar_99:
        r1 = (object *) constructed_485[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_555[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_554[0];
          r3[2] = r4;
          r4 = (object *) constructed_552[0];
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1985; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1985:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_551[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1986; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1986:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_547[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1987; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1987:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = (object *) constructed_549[0];
          r4 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1988; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1988:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_100;
        }
        r1=r1;
        goto fatbar_100_over;
        fatbar_100:
        r1 = (object *) constructed_284[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_469[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object******) lenv) [1][1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1989; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1989:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [6];
          r4 = top[181];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1990; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1990:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_101;
        }
        r1=r1;
        goto fatbar_101_over;
        fatbar_101:
        r1 = (object *) constructed_293[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_469[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object******) lenv) [1][1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1991; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1991:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1992; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1992:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_102;
        }
        r1=r1;
        goto fatbar_102_over;
        fatbar_102:
        r1 = (object *) constructed_306[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_469[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object******) lenv) [1][1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = top[103];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1993; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_457;
          L1993:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[178];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1994; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1994:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_103;
        }
        r1=r1;
        goto fatbar_103_over;
        fatbar_103:
        r1 = (object *) constructed_500[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = (object *) constructed_556[0];
          r4 = ((object****) lenv) [1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1995; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1995:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_104;
        }
        r1=r1;
        goto fatbar_104_over;
        fatbar_104:
        r1 = (object *) constructed_498[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = (object *) constructed_557[0];
          r4 = ((object****) lenv) [1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1996; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1996:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_105;
        }
        r1=r1;
        goto fatbar_105_over;
        fatbar_105:
        r1 = (object *) constructed_495[0];
        r2 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_99[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*****) lenv) [1][1][1][1][12];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[103];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1997; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
          L1997:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_106;
        }
        r1=r1;
        goto fatbar_106_over;
        fatbar_106:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_558;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[14];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1998; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
        L1998:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_106_over: ;
        r1=r1;
        fatbar_105_over: ;
        r1=r1;
        fatbar_104_over: ;
        r1=r1;
        fatbar_103_over: ;
        r1=r1;
        fatbar_102_over: ;
        r1=r1;
        fatbar_101_over: ;
        r1=r1;
        fatbar_100_over: ;
        r1=r1;
        fatbar_99_over: ;
        r1=r1;
        fatbar_97_over: ;
        r1=r1;
        fatbar_95_over: ;
        r1=r1;
        fatbar_93_over: ;
        r1=r1;
        fatbar_91_over: ;
        r1=r1;
        fatbar_87_over: ;
        r1=r1;
        fatbar_85_over: ;
        r1=r1;
        fatbar_84_over: ;
        r1=r1;
        fatbar_83_over: ;
        r1=r1;
        fatbar_82_over: ;
        r1=r1;
        fatbar_81_over: ;
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1999; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3390_i4682_i4766;
            L1999:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_99[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[22];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2000; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                      L2000:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*****) lenv) [1][1][1][1][4];
                      r1[2] = r2;
                      r2 = top[22];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2001; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                      L2001:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = ((object*) lenv) [3];
                      r2 = ((object*) lenv) [2];
                      r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                      r0[4] = r1;
                      r0 = (object *) 6;
                      r1 = ((object*) lenv) [4];
                      r0 = PXLL_TEST(r1==r0);
                      lenv = lenv[1];
                      r0 = r0;
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_531;
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][4];
                        r0[3] = r1;
                        r1 = top[14];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2002; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                        L2002:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = (object *) 14;
                      }
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[22];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2003; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                      L2003:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3698_i2452_i4682_i4766
                      goto L2004;
                      FUN__24loop_3698_i2452_i4682_i4766:
                        check_heap (0);
                        r0 = ((object***) lenv) [1][1][2];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 5);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[27];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2005; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                          L2005:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][6];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2006; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
                          L2006:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r1 = ((object*) lenv) [3];
                          r2 = ((object*) lenv) [2];
                          ((pxll_vector*)r2)->val[5] = r1;
                          r1 = ((object*) lenv) [3];
                          r0[4] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*****) lenv) [1][1][1][1][3];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[27];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2007; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                          L2007:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[5] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = ((object*) lenv) [2];
                          r0[2] = r1;
                          r1 = ((object*) lenv) [4];
                          r0[3] = r1;
                          r1 = ((object*) lenv) [5];
                          r0[4] = r1;
                          r1 = top[138];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L2008; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                          L2008:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = ((object*) lenv) [2];
                          r0 = box((pxll_int)unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3698_i2452_i4682_i4766;
                        }
                        PXLL_RETURN(0);
                      L2004:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3698_i2452_i4682_i4766; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2009; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3698_i2452_i4682_i4766;
                      L2009:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      lenv = lenv[1];
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_80;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_80;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_80;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_80_over;
            fatbar_80:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_532;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            fatbar_80_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_54[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 7);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r1 = top[104];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2010; t[4] = r0; k = t;
                  lenv = r1[2]; goto FUN_new_tvar_459;
                  L2010:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[5] = r1;
                  r1 = ((object*) lenv) [5];
                  switch (get_case (r1)) {
                    case (UOTAG(12)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][5];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = (object *) constructed_500[0];
                      r2 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                        r1 = (object *) 6;
                        r1=r1;
                      } else {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_108;
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_108;
                    }
                  }
                  r1=r1;
                  goto fatbar_108_over;
                  fatbar_108:
                  r1 = (object *) 262;
                  r1=r1;
                  fatbar_108_over: ;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [6];
                  if PXLL_IS_TRUE(r1) {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object *) constructed_554[0];
                    r2[2] = r3;
                    r3 = (object *) constructed_552[0];
                    r2[3] = r3;
                    r3 = top[103];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L2011; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                    L2011:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object *) constructed_551[0];
                    r1[2] = r2;
                    r2 = allocate (TC_TUPLE, 2);
                    r2[1] = lenv; lenv = r2;
                    r3 = (object*)TC_NIL;
                    r2[2] = r3;
                    r2 = ((object*) lenv) [2];
                    r3 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r3;
                    t[2] = r2;
                    r2 = t;
                    lenv = lenv[1];
                    r2 = r2;
                    r1[3] = r2;
                    r2 = top[103];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2012; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                    L2012:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } else {
                    r1 = top[104];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2013; t[4] = r0; k = t;
                    lenv = r1[2]; goto FUN_new_tvar_459;
                    L2013:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r1=r1;
                  }
                  r0[7] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object*****) lenv) [1][1][1][1][3];
                  r1[2] = r2;
                  r2 = top[22];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2014; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                  L2014:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  // def $loop_3633_i2625_i4682_i4766
                  goto L2015;
                  FUN__24loop_3633_i2625_i4682_i4766:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 5);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object*****) lenv) [1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[27];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2016; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                      L2016:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[27];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2017; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                      L2017:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[27];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2018; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                      L2018:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [4];
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][10];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2019; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3413_i4682_i4766;
                      L2019:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[5] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object*) lenv) [3];
                      r1[2] = r2;
                      r2 = (object *) constructed_540[0];
                      r1[3] = r2;
                      r2 = top[103];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2020; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                      L2020:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) 3;
                      r3 = ((object**) lenv) [1][4];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][5];
                        r2[2] = r3;
                        r3 = top[19];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2021; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                        L2021:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r2=r2;
                      } else {
                        r2 = allocate (TC_TUPLE, 3);
                        r3 = (object *) constructed_539[0];
                        r2[2] = r3;
                        r3 = ((object**) lenv) [1][5];
                        r2[3] = r3;
                        r3 = top[103];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2022; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_pred_457;
                        L2022:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r2=r2;
                      }
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object *) constructed_537[0];
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      r3 = (object*)TC_NIL;
                      r2[2] = r3;
                      r2 = ((object*) lenv) [2];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[3] = r2;
                      r2 = top[103];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2023; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                      L2023:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r0[3] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][7];
                      r0[4] = r1;
                      r1 = top[105];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2024; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_464;
                      L2024:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      ((object*****) lenv) [1][1][1][1][7] = r0;
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = ((object*) lenv) [2];
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][4];
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object**) lenv) [1][2];
                      r2[2] = r3;
                      r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                      r2[3] = r3;
                      r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2025; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
                      L2025:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r1 = ((object*) lenv) [2];
                      r2 = ((object**) lenv) [1][2];
                      ((pxll_vector*)r2)->val[5] = r1;
                      r1 = ((object*) lenv) [2];
                      lenv = lenv[1];
                      r1 = r1;
                      r0[4] = r1;
                      r1 = top[138];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2026; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                      L2026:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_3633_i2625_i4682_i4766;
                    }
                    PXLL_RETURN(0);
                  L2015:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN__24loop_3633_i2625_i4682_i4766; r1[2] = lenv;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L2027; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3633_i2625_i4682_i4766;
                  L2027:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  lenv = lenv[1];
                  r0 = r0;
                  lenv = lenv[1];
                  r0 = ((object*) lenv) [6];
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = ((object*) lenv) [2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [4];
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = ((object**) lenv) [1][2];
                    r2[2] = r3;
                    r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                    r2[3] = r3;
                    r3 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L2028; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
                    L2028:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = ((object*) lenv) [2];
                    r2 = ((object**) lenv) [1][2];
                    ((pxll_vector*)r2)->val[5] = r1;
                    r1 = ((object*) lenv) [2];
                    lenv = lenv[1];
                    r1 = r1;
                    r0[4] = r1;
                    r1 = top[138];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L2029; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                    L2029:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    r0 = (object *) 14;
                  }
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object**) lenv) [1][2];
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object *) constructed_535[0];
                  r1[2] = r2;
                  r2 = allocate (TC_TUPLE, 2);
                  r2[1] = lenv; lenv = r2;
                  r3 = (object*)TC_NIL;
                  r2[2] = r3;
                  r2 = ((object*) lenv) [2];
                  r3 = ((object**) lenv) [1][7];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r2 = r2;
                  r1[3] = r2;
                  r2 = top[103];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2030; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                  L2030:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object***) lenv) [1][1][2];
                  r2[2] = r3;
                  r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r2[3] = r3;
                  r3 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2031; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
                  L2031:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  r2 = ((object***) lenv) [1][1][2];
                  ((pxll_vector*)r2)->val[5] = r1;
                  r1 = ((object*) lenv) [2];
                  lenv = lenv[1];
                  r1 = r1;
                  r0[4] = r1;
                  r1 = top[138];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L2032; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                  L2032:
                  ; lenv = k[2]; k = k[1];
                  r0 = ((object*) lenv) [4];
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_107;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_107;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_107_over;
          fatbar_107:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_559;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r1 = top[14];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          fatbar_107_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[1];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = (object*) &constructed_560;
          r1[4] = r2;
          r2 = top[67];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2033; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
          L2033:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2034; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2034:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2035; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2035:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [3];
          r2[2] = r3;
          r3 = top[20];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2036; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_320;
          L2036:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = top[20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2037; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
          L2037:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [4];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          r1[3] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2038; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3394_i4682_i4766;
          L2038:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object*) lenv) [4];
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = ((object*) lenv) [7];
          r0[8] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2039; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L2039:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[9] = r1;
          r1 = top[104];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2040; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_459;
          L2040:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[10] = r1;
          r0 = ((object*) lenv) [9];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][9];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][9];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = (object *) 262;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_109;
                }
              }
              r0=r0;
              goto fatbar_109_over;
              fatbar_109:
              r0 = (object *) 6;
              r0=r0;
              fatbar_109_over: ;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object**) lenv) [1][8];
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r0[4] = r1;
                r1 = top[138];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2041; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                L2041:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2042; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3390_i4682_i4766;
                L2042:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object******) lenv) [1][1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][8];
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r0[4] = r1;
                r1 = top[138];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2043; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                L2043:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
                r0 = r0;
                r0=r0;
              }
              lenv = lenv[1];
              r0 = r0;
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_22748_i2638_i4682_i4766
          goto L2044;
          FUN_lambda_22748_i2638_i4682_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][10];
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object******) lenv) [1][1][1][1][1][3];
            r2[3] = r3;
            r3 = ((object*******) lenv) [1][1][1][1][1][1][6];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2045; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
            L2045:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r2 = ((object**) lenv) [1][2];
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r1 = r1;
            r0[4] = r1;
            r1 = top[138];
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
          L2044:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_22748_i2638_i4682_i4766; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [6];
          r0[3] = r1;
          r1 = top[35];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2046; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
          L2046:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = ((object*) lenv) [10];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][3];
          r2[3] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2047; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
          L2047:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][5];
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = top[138];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2048; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
          L2048:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [10];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_76;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_76_over;
    fatbar_76:
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = top[126];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2049; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_514;
    L2049:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_561;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[14];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
    fatbar_76_over: ;
    PXLL_RETURN(0);
  L1822:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_splat_3394_i4682_i4766; r2[2] = lenv;
  r1[6] = r2;
  // def type-of-literal_3396_i4682_i4766
  goto L2050;
  FUN_type_of_literal_3396_i4682_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = top[180];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = top[178];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = top[179];
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = top[181];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = top[183];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object****) lenv) [1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = (object*) &constructed_514;
        r1[4] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2051; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
        L2051:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object*) lenv) [5];
        r2 = ((pxll_vector*)r2)->val[2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2052; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L2052:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r0 = ((object*) lenv) [6];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][6];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][6];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2053; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3390_i4682_i4766;
            L2053:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_99[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[22];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2054; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                      L2054:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3488_i4682_i4766
                      goto L2055;
                      FUN__24loop_3488_i4682_i4766:
                        check_heap (0);
                        r0 = ((object***) lenv) [1][1][2];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 4);
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                          r2[2] = r3;
                          r3 = ((object**) lenv) [1][2];
                          r2[3] = r3;
                          r3 = top[27];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2056; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                          L2056:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][7];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2057; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3396_i4682_i4766;
                          L2057:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r0[2] = r1;
                          r1 = ((object*) lenv) [2];
                          r0[3] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*****) lenv) [1][1][1][1][3];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[27];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2058; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                          L2058:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[4] = r1;
                          r1 = top[138];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L2059; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
                          L2059:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = ((object*) lenv) [2];
                          r0 = box((pxll_int)unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3488_i4682_i4766;
                        }
                        PXLL_RETURN(0);
                      L2055:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3488_i4682_i4766; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2060; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3488_i4682_i4766;
                      L2060:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      lenv = lenv[1];
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_75;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_75;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_75;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_75_over;
            fatbar_75:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_513;
            r0[2] = r1;
            r1 = ((object*) lenv) [4];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            fatbar_75_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = top[104];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2061; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_459;
        L2061:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_22040_i4682_i4766
        goto L2062;
        FUN_lambda_22040_i4682_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          r1[4] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][7];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2063; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3396_i4682_i4766;
          L2063:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[4] = r1;
          r1 = top[138];
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_536;
        L2062:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_22040_i4682_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[35];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2064; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L2064:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_469[0];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = top[103];
        r0[1] = r1[2]; lenv = r0; goto FUN_pred_457;
      } break;
    }
    PXLL_RETURN(0);
  L2050:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_literal_3396_i4682_i4766; r2[2] = lenv;
  r1[7] = r2;
  // def unraw_3397_i4682_i4766
  goto L2065;
  FUN_unraw_3397_i4682_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_512[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = ((object*) lenv) [2];
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_74;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_74;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_74;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_74;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_74_over;
    fatbar_74:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_74_over: ;
    PXLL_RETURN(0);
  L2065:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_unraw_3397_i4682_i4766; r2[2] = lenv;
  r1[8] = r2;
  // def apply-tenv_3403_i4682_i4766
  goto L2066;
  FUN_apply_tenv_3403_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[66];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2067; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L2067:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_510;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_instantiate_type_scheme_3390_i4682_i4766;
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2066:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_tenv_3403_i4682_i4766; r2[2] = lenv;
  r1[9] = r2;
  // def n-tvars_3413_i4682_i4766
  goto L2068;
  FUN_n_tvars_3413_i4682_i4766:
    check_heap (0);
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) constructed_509[0];
      PXLL_RETURN(0);
    } else {
      goto fatbar_73;
    }
    PXLL_RETURN(0);
    goto fatbar_73_over;
    fatbar_73:
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[104];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2069; t[4] = r0; k = t;
    lenv = r1[2]; goto FUN_new_tvar_459;
    L2069:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) 3;
    r3 = ((object**) lenv) [1][2];
    r2 = box((pxll_int)unbox(r3)-unbox(r2));
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][10];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2070; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3413_i4682_i4766;
    L2070:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_73_over: ;
    PXLL_RETURN(0);
  L2068:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_n_tvars_3413_i4682_i4766; r2[2] = lenv;
  r1[10] = r2;
  // def apply-subst-to-program_3417_i4682_i4766
  goto L2071;
  FUN_apply_subst_to_program_3417_i4682_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[5];
    r0[2] = r1;
    r1 = top[139];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2072; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_apply_subst_537;
    L2072:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[5] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][11];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = top[35];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
  L2071:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_subst_to_program_3417_i4682_i4766; r2[2] = lenv;
  r1[11] = r2;
  r2 = top[104];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2073; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_459;
  L2073:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[12] = r2;
  r2 = top[104];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2074; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_459;
  L2074:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[13] = r2;
  r2 = top[104];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2075; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_459;
  L2075:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[14] = r2;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][24];
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][6];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2076; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3394_i4682_i4766;
  L2076:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = ((object*) lenv) [3];
  r3 = ((object***) lenv) [1][1][24];
  ((pxll_vector*)r3)->val[5] = r2;
  r2 = ((object*) lenv) [3];
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object***) lenv) [1][1][24];
  r2 = ((pxll_vector*)r2)->val[5];
  r1[2] = r2;
  r2 = top[139];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2077; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_537;
  L2077:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r2 = ((object***) lenv) [1][1][24];
  ((pxll_vector*)r2)->val[5] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][11];
  r1[2] = r2;
  r2 = ((object***) lenv) [1][1][24];
  r2 = ((pxll_vector*)r2)->val[3];
  r1[3] = r2;
  r2 = top[35];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2078; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_for_each_339;
  L2078:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = ((object*) lenv) [4];
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[36] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[8];
  r1 = ((pxll_vector*)r1)->val[3];
  if PXLL_IS_TRUE(r1) {
    r1 = (object*) &constructed_508;
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r2 = (object*) &constructed_508;
    (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [24];
    r1[2] = r2;
    r2 = top[126];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2079; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_node_514;
    L2079:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 2562;
    box((pxll_int)fputc (GET_CHAR(r1), stdout));
    r1 = (object *) 14;
    r1=r1;
  } else {
    r1 = (object *) 14;
    r1=r1;
  }
  r0[37] = r1;
  r1 = (object *) constructed_507[0];
  r0[38] = r1;
  r1 = allocate (TC_TUPLE, 22);
  r1[1] = lenv; lenv = r1;
  // def cont_2693_i4685_i4766
  goto L2080;
  FUN_cont_2693_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[10];
    r2 = ((pxll_vector*)r2)->val[0];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2081; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L2081:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2082; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L2082:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2080:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_cont_2693_i4685_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def compile_2695_i4685_i4766
  goto L2083;
  FUN_compile_2695_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [5];
      r1[2] = r2;
      r2 = top[135];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2084; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
      L2084:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][19];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2085; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_cont_2693_i4685_i4766;
      L2085:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object*) lenv) [5] = r0;
    } else {
      r0 = (object *) 14;
    }
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[1];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2086; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_symbol_index_2698_i4685_i4766;
            L2086:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_63[0];
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2087; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2697_i4685_i4766;
            L2087:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_88[0];
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2088; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2699_i4685_i4766;
            L2088:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2089; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2697_i4685_i4766;
            L2089:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_469[0];
            r1 = ((object***) lenv) [1][1][4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r0 = (object *) constructed_51[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object**) lenv) [1][4];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(1),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              goto fatbar_50;
            }
            PXLL_RETURN(0);
            goto fatbar_50_over;
            fatbar_50:
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2090; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2699_i4685_i4766;
            L2090:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2091; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2697_i4685_i4766;
            L2091:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_471[0];
            r1 = ((object***) lenv) [1][1][4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_50_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_49;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_49_over;
        fatbar_49:
        r0 = ((object*) lenv) [4];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_49_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][5];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][8];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_sequence_2701_i4685_i4766;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][5];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[136];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2092; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_529;
        L2092:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[135];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2093; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
        L2093:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object****) lenv) [1][1][1][2];
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case (r0)) {
                          case (UOTAG(3)): {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,1);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,2);
                            r0[3] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][2];
                            r1[2] = r2;
                            r2 = top[135];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2094; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
                            L2094:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][2];
                            r1[2] = r2;
                            r2 = top[136];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2095; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_529;
                            L2095:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            // def finish_2826_i1887_i4685_i4766
                            goto L2096;
                            FUN_finish_2826_i1887_i4685_i4766:
                              check_heap (0);
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                              r1[2] = r2;
                              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = ((object****) lenv) [1][1][1][4];
                              r2[2] = r3;
                              // def lambda_17477_i1887_i4685_i4766
                              goto L2097;
                              FUN_lambda_17477_i1887_i4685_i4766:
                                check_heap (0);
                                r0 = ((object*****) lenv) [1][1][1][1][5];
                                r1 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L2097:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17477_i1887_i4685_i4766; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2098; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
                              L2098:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2099; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
                              L2099:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                              r1[2] = r2;
                              r2 = ((object******) lenv) [1][1][1][1][1][2];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = ((object****) lenv) [1][1][1][4];
                              r2[2] = r3;
                              // def lambda_17491_i1887_i4685_i4766
                              goto L2100;
                              FUN_lambda_17491_i1887_i4685_i4766:
                                check_heap (0);
                                r0 = ((object*****) lenv) [1][1][1][1][5];
                                r1 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L2100:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17491_i1887_i4685_i4766; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2101; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
                              L2101:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2102; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
                              L2102:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                              r2 = ((object****) lenv) [1][1][1][2];
                              r3 = ((object****) lenv) [1][1][1][3];
                              r4 = ((object*) lenv) [3];
                              r5 = ((object**) lenv) [1][2];
                              t = alloc_no_clear (UOTAG(5),6);
                              t[1] = r5;
                              t[2] = r2;
                              t[3] = r3;
                              t[4] = r0;
                              t[5] = r4;
                              t[6] = r1;
                              r0 = t;
                              PXLL_RETURN(0);
                            L2096:
                            r1 = allocate (TC_CLOSURE, 2);
                            r1[1] = &&FUN_finish_2826_i1887_i4685_i4766; r1[2] = lenv;
                            r0[2] = r1;
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = ((object******) lenv) [1][1][1][1][1][2];
                            r1 = ((pxll_vector*)r1)->val[3];
                            r0[2] = r1;
                            r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                            r0[3] = r1;
                            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                            r0[4] = r1;
                            r1 = ((object*) lenv) [2];
                            r0[5] = r1;
                            r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][12];
                            r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
                          } break;
                          default: {
                            goto fatbar_52;
                          }
                        }
                        PXLL_RETURN(0);
                        goto fatbar_52_over;
                        fatbar_52:
                        r0 = allocate (TC_TUPLE, 5);
                        r1 = (object *) 6;
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][2];
                        r0[3] = r1;
                        r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                        r0[4] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*****) lenv) [1][1][1][1][4];
                        r1[2] = r2;
                        // def lambda_17422_i1886_i4685_i4766
                        goto L2103;
                        FUN_lambda_17422_i1886_i4685_i4766:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object*****) lenv) [1][1][1][1][2];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r2[2] = r3;
                          // def lambda_17402_i1886_i4685_i4766
                          goto L2104;
                          FUN_lambda_17402_i1886_i4685_i4766:
                            check_heap (0);
                            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L2104:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17402_i1886_i4685_i4766; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2105; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
                          L2105:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2106; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
                          L2106:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object****) lenv) [1][1][1][2];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r2[2] = r3;
                          // def lambda_17416_i1886_i4685_i4766
                          goto L2107;
                          FUN_lambda_17416_i1886_i4685_i4766:
                            check_heap (0);
                            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L2107:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17416_i1886_i4685_i4766; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2108; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
                          L2108:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2109; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
                          L2109:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                          r1 = ((object*) lenv) [2];
                          r2 = ((object*) lenv) [3];
                          r3 = ((object**) lenv) [1][2];
                          t = alloc_no_clear (UOTAG(4),4);
                          t[1] = r3;
                          t[2] = r1;
                          t[3] = r2;
                          t[4] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L2103:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_17422_i1886_i4685_i4766; r2[2] = lenv;
                        r1[3] = r2;
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2110; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                        L2110:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[5] = r1;
                        r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
                        fatbar_52_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_51;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_51;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_51;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_51;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_51_over;
        fatbar_51:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_472;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
        fatbar_51_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[1];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2111; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L2111:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*****) lenv) [1][1][1][1][38];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2112; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L2112:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[155];
        r0[4] = r1;
        r1 = top[6];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2113; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
        L2113:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][38];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object*****) lenv) [1][1][1][1][38] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 5);
        r2 = (object *) 262;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][5];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][3];
        switch (get_case (r2)) {
          case (TC_NIL): {
            r2 = ((object****) lenv) [1][1][1][4];
            r2=r2;
          } break;
          default: {
            goto fatbar_53;
          }
        }
        r2=r2;
        goto fatbar_53_over;
        fatbar_53:
        r2 = ((object****) lenv) [1][1][1][4];
        r3 = ((object**) lenv) [1][3];
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r2=r2;
        fatbar_53_over: ;
        r1[4] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = (object *) constructed_474[0];
        r2[2] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][19];
        r2[3] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2114; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
        L2114:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[5] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2115; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
        L2115:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][6];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (UOTAG(7),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[3] = r1;
        r0 = ((object******) lenv) [1][1][1][1][1][38];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_473;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_473;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][38];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][38];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            ((object*******) lenv) [1][1][1][1][1][1][38] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = r0;
          } break;
        }
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[4] = r2;
        r2 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2116; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2707_i4685_i4766;
        L2116:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case_noint (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = (object *) -1;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(19),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][3];
            r2 = (object *) -1;
            t = alloc_no_clear (UOTAG(8),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[19];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2117; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
        L2117:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[4] = r2;
        r2 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2118; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2707_i4685_i4766;
        L2118:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        switch (get_case_noint (r1)) {
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            // def lambda_17761_i1903_i4685_i4766
            goto L2119;
            FUN_lambda_17761_i1903_i4685_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][4];
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(9),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2119:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17761_i1903_i4685_i4766; r1[2] = lenv;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(6)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            // def lambda_17775_i1903_i4685_i4766
            goto L2120;
            FUN_lambda_17775_i1903_i4685_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][4];
              r1 = ((object**) lenv) [1][2];
              r2 = ((object*) lenv) [2];
              r3 = (object *) -1;
              t = alloc_no_clear (UOTAG(9),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2120:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17775_i1903_i4685_i4766; r1[2] = lenv;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            // def lambda_17787_i1903_i4685_i4766
            goto L2121;
            FUN_lambda_17787_i1903_i4685_i4766:
              check_heap (0);
              r0 = ((object**) lenv) [1][2];
              r1 = ((object***) lenv) [1][1][4];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (UOTAG(19),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2121:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17787_i1903_i4685_i4766; r1[2] = lenv;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object*) lenv) [4];
        r2[2] = r3;
        r3 = top[135];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2122; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_528;
        L2122:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [6];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2123; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
        L2123:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object****) lenv) [1][1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[3] = r1;
        r1 = ((object*) lenv) [5];
        r0[4] = r1;
        // def lambda_18059_i1907_i4685_i4766
        goto L2124;
        FUN_lambda_18059_i1907_i4685_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[2] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          r2 = ((object***) lenv) [1][1][4];
          r3 = ((object***) lenv) [1][1][5];
          r4 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (UOTAG(3),5);
          t[1] = r4;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          t[5] = r3;
          r0 = t;
          PXLL_RETURN(0);
        L2124:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_18059_i1907_i4685_i4766; r1[2] = lenv;
        r0[5] = r1;
        r1 = ((object****) lenv) [1][1][1][12];
        r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][5];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object****) lenv) [1][1][1][2];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r1 = ((pxll_vector*)r1)->val[0];
                  r0[2] = r1;
                  r0 = top[190];
                  r1 = ((object*) lenv) [2];
                  r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 5);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][38];
                    r1[2] = r2;
                    r2 = top[19];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2125; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
                    L2125:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = top[5];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2126; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
                    L2126:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r1 = ((pxll_vector*)r1)->val[1];
                    r0[4] = r1;
                    r1 = top[153];
                    r2 = ((object*) lenv) [4];
                    r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                    r0[5] = r1;
                    r0 = (object *) 6;
                    r1 = ((object*) lenv) [5];
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 6;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_56;
                }
              }
              r0=r0;
              goto fatbar_56_over;
              fatbar_56:
              r0 = (object *) 6;
              r0=r0;
              fatbar_56_over: ;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } else {
              r0 = (object *) 6;
              r0=r0;
            }
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = top[118];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2127; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_varref__3ename_495;
              L2127:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) 1;
              r1[3] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[4] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][11];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2128; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2707_i4685_i4766;
              L2128:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case_noint (r0)) {
                case (UOTAG(7)): {
                  r0 = (object*) &constructed_73;
                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                  r1 = (object*) &constructed_73;
                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                  r0 = (object*) &constructed_475;
                  dump_object (r0, 0); fprintf (stdout, "\n");
                  r0 = (object*) &constructed_475;
                  PXLL_UNDEFINED; result=r0; goto Lreturn;
                  PXLL_RETURN(0);
                } break;
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object***) lenv) [1][1][3];
                  r0[2] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][4];
                  r0[3] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[4] = r1;
                  // def lambda_18313_i4685_i4766_i7
                  goto L2129;
                  FUN_lambda_18313_i4685_i4766_i7:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    r2 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (UOTAG(15),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  L2129:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN_lambda_18313_i4685_i4766_i7; r1[2] = lenv;
                  r0[5] = r1;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][12];
                  r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object***) lenv) [1][1][3];
                  r0[2] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][4];
                  r0[3] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[4] = r1;
                  // def lambda_18313_i4685_i4766_i8
                  goto L2130;
                  FUN_lambda_18313_i4685_i4766_i8:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    r2 = (object *) -1;
                    t = alloc_no_clear (UOTAG(15),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  L2130:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN_lambda_18313_i4685_i4766_i8; r1[2] = lenv;
                  r0[5] = r1;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][12];
                  r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
                } break;
              }
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              if PXLL_IS_TRUE(r1) {
                r1 = ((object******) lenv) [1][1][1][1][1][21];
                r1=r1;
              } else {
                r1 = ((object******) lenv) [1][1][1][1][1][20];
                r1=r1;
              }
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                  r2[2] = r3;
                  r3 = ((object**) lenv) [1][2];
                  r2[3] = r3;
                  r3 = top[5];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2131; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_257;
                  L2131:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r2 = ((pxll_vector*)r2)->val[1];
                  r1[3] = r2;
                  r1 = top[154];
                  r2 = ((object*) lenv) [3];
                  r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                  lenv = lenv[1];
                  r1 = r1;
                  if PXLL_IS_TRUE(r1) {
                    r1 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r1;
                    r1 = t;
                    r1=r1;
                  } else {
                    r1 = (object*)UITAG(1);
                    r1=r1;
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_55;
                }
              }
              r1=r1;
              goto fatbar_55_over;
              fatbar_55:
              r1 = (object*)UITAG(1);
              r1=r1;
              fatbar_55_over: ;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def make-call_2971_i1909_i4685_i4766
              goto L2132;
              FUN_make_call_2971_i1909_i4685_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = (object *) 6;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[3] = r1;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object******) lenv) [1][1][1][1][1][2];
                r3[2] = r4;
                r4 = top[135];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2133; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_528;
                L2133:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = ((object*) lenv) [2];
                r3 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                // def lambda_18426_i1909_i4685_i4766
                goto L2134;
                FUN_lambda_18426_i1909_i4685_i4766:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object****) lenv) [1][1][1][4];
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[4] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][2];
                  r0[5] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2134:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18426_i1909_i4685_i4766; r2[2] = lenv;
                r1[3] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2135; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                L2135:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
              L2132:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_make_call_2971_i1909_i4685_i4766; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object****) lenv) [1][1][1][3];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2136; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L2136:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 1;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*****) lenv) [1][1][1][1][2];
                r2[2] = r3;
                r3 = top[135];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2137; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_528;
                L2137:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2138; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                L2138:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][38];
                r1[2] = r2;
                r2 = top[19];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2139; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
                L2139:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = top[155];
                r0[4] = r1;
                r1 = top[6];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2140; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
                L2140:
                ; lenv = k[2]; k = k[1];
                r0 = ((object****) lenv) [1][1][1][3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = ((object*) lenv) [2];
                    r1 = (object *) 1;
                    t = alloc_no_clear (UOTAG(10),2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_54;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_54_over;
                fatbar_54:
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = top[22];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2141; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                L2141:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[135];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2142; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_528;
                L2142:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                // def lambda_18503_i1921_i4685_i4766
                goto L2143;
                FUN_lambda_18503_i1921_i4685_i4766:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 8);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = (object *) 3;
                  r0[3] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                  r0[4] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object****) lenv) [1][1][1][2];
                  r2[2] = r3;
                  r3 = top[135];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2144; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_528;
                  L2144:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  r2 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[6] = r1;
                  r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                  r0[7] = r1;
                  r1 = ((object***) lenv) [1][1][2];
                  r0[8] = r1;
                  r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][16];
                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2720_i4685_i4766;
                L2143:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18503_i1921_i4685_i4766; r2[2] = lenv;
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2145; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                L2145:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(10),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
                fatbar_54_over: ;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) -1;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[1] = r1[2]; lenv = r0; goto FUN_make_call_2971_i1909_i4685_i4766;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_476;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_476;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = (object *) constructed_228[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 5;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2146; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2146:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2147; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2147:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][5];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][5];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = (object *) constructed_478[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = (object*)TC_NIL;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r2 = ((object****) lenv) [1][1][1][3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object *) constructed_99[0];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object**) lenv) [1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[3] = r2;
                        r2 = top[103];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2148; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_pred_457;
                        L2148:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r0 = allocate (TC_TUPLE, 7);
                        r1 = ((object*****) lenv) [1][1][1][1][5];
                        r0[2] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        r0[3] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][3];
                        r0[4] = r1;
                        r1 = ((object*) lenv) [4];
                        r0[5] = r1;
                        r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                        r0[6] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][4];
                        r0[7] = r1;
                        r1 = ((object********) lenv) [1][1][1][1][1][1][1][14];
                        r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2714_i4685_i4766;
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_58;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_58;
                  }
                }
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_58;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_58;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_58_over;
          fatbar_58:
          r0 = (object*) &constructed_73;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_72;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_72;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
          fatbar_58_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_57;
        }
        PXLL_RETURN(0);
        goto fatbar_57_over;
        fatbar_57:
        r0 = (object *) constructed_480[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2149; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2149:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[111];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2150; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_475;
          L2150:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2151; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L2151:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][5];
          r0[2] = r1;
          r1 = (object *) constructed_264[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[6] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[7] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2714_i4685_i4766;
        } else {
          goto fatbar_59;
        }
        PXLL_RETURN(0);
        goto fatbar_59_over;
        fatbar_59:
        r0 = (object *) constructed_482[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2152; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2152:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[111];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2153; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_475;
          L2153:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[32];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2154; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
          L2154:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][5];
          r0[2] = r1;
          r1 = (object *) constructed_275[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[6] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[7] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2714_i4685_i4766;
        } else {
          goto fatbar_60;
        }
        PXLL_RETURN(0);
        goto fatbar_60_over;
        fatbar_60:
        r0 = (object *) constructed_488[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3087_i1947_i4685_i4766
          goto L2155;
          FUN_loop_3087_i1947_i4685_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(12)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_485[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  // def lambda_19163_i1947_i4685_i4766
                  goto L2156;
                  FUN_lambda_19163_i1947_i4685_i4766:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case_noint (r0)) {
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object***) lenv) [1][1][2];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                            r0[3] = r1;
                            r1 = ((object*) lenv) [2];
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object**) lenv) [1][2];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*) lenv) [3];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [4];
                            r1[3] = r2;
                            r2 = top[50];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2157; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
                            L2157:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = (object *) 1;
                            r1 = ((object*) lenv) [5];
                            r0 = PXLL_TEST(unbox(r1)<unbox(r0));
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2156:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_19163_i1947_i4685_i4766; r2[2] = lenv;
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r1[3] = r2;
                  r2 = top[44];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2158; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_350;
                  L2158:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[17];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2159; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L2159:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[18];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[32];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2160; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
                  L2160:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_3124_i1950_i4685_i4766
                  goto L2161;
                  FUN_loop_3124_i1950_i4685_i4766:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object**) lenv) [1][2];
                            r1[2] = r2;
                            r2 = top[22];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2162; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                            L2162:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][3];
                            r1[2] = r2;
                            r2 = top[22];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2163; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                            L2163:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            r1 = ((object*) lenv) [2];
                            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                            lenv = lenv[1];
                            r0 = r0;
                            if PXLL_IS_TRUE(r0) {
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = top[13];
                              r0[2] = r1;
                              r1 = ((object*) lenv) [2];
                              r0[3] = r1;
                              r1 = ((object*****) lenv) [1][1][1][1][3];
                              r0[4] = r1;
                              r1 = top[41];
                              t = allocate (TC_SAVE, 3);
                              t[1] = k; t[2] = lenv; t[3] = &&L2164; ; k = t;
                              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_345;
                              L2164:
                              ; lenv = k[2]; k = k[1];
                              r0 = result;
                              r0=r0;
                            } else {
                              r0 = (object *) 6;
                              r0=r0;
                            }
                            if PXLL_IS_TRUE(r0) {
                              r0 = ((object*) lenv) [3];
                              PXLL_RETURN(0);
                            } else {
                              r0 = ((object**) lenv) [1][3];
                              lenv = ((object **)lenv)[1][1];
                              lenv[2] = r0;
                              goto FUN_loop_3124_i1950_i4685_i4766;
                            }
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                        r2 = ((pxll_vector*)r2)->val[9];
                        r1[2] = r2;
                        r2 = top[22];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2165; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                        L2165:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][18];
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r0[3] = r1;
                        r1 = top[35];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2166; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
                        L2166:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (UOTAG(1), 2);
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[1] = r2;
                        r2 = ((object**) lenv) [1][2];
                        r1[2] = r2;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                        r1 = ((pxll_vector*)r1)->val[9];
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        r1 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                        ((pxll_vector*)r1)->val[9] = r0;
                        r0 = ((object*) lenv) [2];
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2161:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_3124_i1950_i4685_i4766; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                  r2 = ((pxll_vector*)r2)->val[9];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2167; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_3124_i1950_i4685_i4766;
                  L2167:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object******) lenv) [1][1][1][1][1][4];
                  r1[2] = r2;
                  r2 = top[135];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2168; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
                  L2168:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [5];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object*) lenv) [4];
                  r1[2] = r2;
                  r2 = top[22];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2169; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                  L2169:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [6];
                  r1[2] = r2;
                  // def lambda_19202_i1947_i4685_i4766
                  goto L2170;
                  FUN_lambda_19202_i1947_i4685_i4766:
                    check_heap (0);
                    r0 = allocate (TC_TUPLE, 8);
                    r1 = (object *) 1;
                    r0[2] = r1;
                    r1 = (object *) 1;
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][4];
                    r0[4] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[5] = r1;
                    r1 = ((object**) lenv) [1][6];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                    r0[7] = r1;
                    r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                    r0[8] = r1;
                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][16];
                    r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2720_i4685_i4766;
                  L2170:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_19202_i1947_i4685_i4766; r2[2] = lenv;
                  r1[3] = r2;
                  r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2171; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                  L2171:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = ((object*) lenv) [8];
                  r1 = ((object*) lenv) [9];
                  r2 = ((object*) lenv) [7];
                  t = alloc_no_clear (UOTAG(11),3);
                  t[1] = r2;
                  t[2] = r0;
                  t[3] = r1;
                  r0 = t;
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_63;
                }
                PXLL_RETURN(0);
                goto fatbar_63_over;
                fatbar_63:
                r0 = (object *) constructed_488[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][2];
                      r1 = ((pxll_vector*)r1)->val[3];
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (UOTAG(1), 2);
                                  r2 = ((object****) lenv) [1][1][1][2];
                                  r1[1] = r2;
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r0[2] = r1;
                                  r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  r1 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r1;
                                  t[2] = r0;
                                  r0 = t;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  lenv[2] = r1;
                                  lenv[3] = r0;
                                  goto FUN_loop_3087_i1947_i4685_i4766;
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_64;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_64;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_64;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_64_over;
                      fatbar_64:
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_486;
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][2];
                      r0[3] = r1;
                      r1 = top[14];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
                      fatbar_64_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_62;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_62;
                }
                PXLL_RETURN(0);
                fatbar_63_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_62;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_62_over;
            fatbar_62:
            r0 = (object*) &constructed_73;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_489;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_489;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
            fatbar_62_over: ;
            PXLL_RETURN(0);
          L2155:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3087_i1947_i4685_i4766; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = (object *) constructed_483[0];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3087_i1947_i4685_i4766;
        } else {
          goto fatbar_61;
        }
        PXLL_RETURN(0);
        goto fatbar_61_over;
        fatbar_61:
        r0 = (object *) constructed_493[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 4);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 4);
                              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                              r2 = ((pxll_vector*)r2)->val[14];
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][2];
                              r1[3] = r2;
                              r2 = (object*) &constructed_490;
                              r1[4] = r2;
                              r2 = top[67];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2172; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
                              L2172:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object******) lenv) [1][1][1][1][1][4];
                              r1[2] = r2;
                              r2 = top[135];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2173; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
                              L2173:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object******) lenv) [1][1][1][1][1][5];
                              r1[2] = r2;
                              r2 = top[22];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2174; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                              L2174:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[4] = r1;
                              r0 = (object *) 1;
                              r1 = ((object*) lenv) [4];
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][38];
                                r1[2] = r2;
                                r2 = top[19];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2175; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
                                L2175:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = top[155];
                                r0[4] = r1;
                                r1 = top[6];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L2176; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
                                L2176:
                                ; lenv = k[2]; k = k[1];
                                r0 = result;
                              } else {
                                r0 = (object *) 14;
                              }
                              r0 = (object *) 1;
                              r1 = ((object*) lenv) [4];
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r2 = ((object**) lenv) [1][3];
                                r1[2] = r2;
                                // def lambda_19090_i1962_i4685_i4766
                                goto L2177;
                                FUN_lambda_19090_i1962_i4685_i4766:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 8);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = (object *) 1;
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                  r0[4] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[5] = r1;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r2 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  r0[6] = r1;
                                  r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                                  r0[7] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                                  r0[8] = r1;
                                  r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][16];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2720_i4685_i4766;
                                L2177:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_lambda_19090_i1962_i4685_i4766; r2[2] = lenv;
                                r1[3] = r2;
                                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2178; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
                                L2178:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r0 = ((object**) lenv) [1][4];
                                r1 = ((object*) lenv) [3];
                                r2 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              } else {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r0 = (object *) 1;
                                r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                r2 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_66;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_66;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_66;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_66;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_66;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_66_over;
          fatbar_66:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_491;
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[14];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          fatbar_66_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_65;
        }
        PXLL_RETURN(0);
        goto fatbar_65_over;
        fatbar_65:
        r0 = (object *) constructed_326[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2179; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L2179:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*****) lenv) [1][1][1][1][38];
            r1[2] = r2;
            r2 = top[19];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2180; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
            L2180:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = top[155];
            r0[4] = r1;
            r1 = top[6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2181; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
            L2181:
            ; lenv = k[2]; k = k[1];
            r0 = result;
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[6] = r1;
          r1 = ((object*) lenv) [4];
          r0[7] = r1;
          r1 = ((object****) lenv) [1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2714_i4685_i4766;
        } else {
          goto fatbar_67;
        }
        PXLL_RETURN(0);
        goto fatbar_67_over;
        fatbar_67:
        r0 = (object *) constructed_495[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][22];
          r1 = ((pxll_vector*)r1)->val[1];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2182; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L2182:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(3),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[135];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2183; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
          L2183:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[136];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2184; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_529;
          L2184:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = (object *) 1;
          r2[3] = r3;
          r3 = top[27];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2185; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
          L2185:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [4];
          r2[2] = r3;
          // def lambda_18958_i1975_i4685_i4766
          goto L2186;
          FUN_lambda_18958_i1975_i4685_i4766:
            check_heap (0);
            r0 = ((object**) lenv) [1][5];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2186:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_18958_i1975_i4685_i4766; r3[2] = lenv;
          r2[3] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2187; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
          L2187:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2188; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
          L2188:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = (object *) 3;
          r2[3] = r3;
          r3 = top[27];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2189; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
          L2189:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [4];
          r2[2] = r3;
          // def lambda_18975_i1975_i4685_i4766
          goto L2190;
          FUN_lambda_18975_i1975_i4685_i4766:
            check_heap (0);
            r0 = ((object**) lenv) [1][5];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2190:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_18975_i1975_i4685_i4766; r3[2] = lenv;
          r2[3] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2191; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
          L2191:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2192; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
          L2192:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = ((object**) lenv) [1][4];
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [7];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(20),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          goto fatbar_68;
        }
        PXLL_RETURN(0);
        goto fatbar_68_over;
        fatbar_68:
        r0 = (object *) constructed_498[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3065_i1981_i4685_i4766
          goto L2193;
          FUN_loop_3065_i1981_i4685_i4766:
            check_heap (0);
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UITAG(0)): {
                r0 = (object*) &constructed_73;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_73;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_496;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_496;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[2] = r1;
                r0 = (object *) 3;
                r1 = ((object**) lenv) [1][2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                r1 = ((object*) lenv) [2];
                lenv = ((object *)lenv)[1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_3065_i1981_i4685_i4766;
              } break;
              case (UOTAG(2)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,2);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                lenv = ((object *)lenv)[1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_3065_i1981_i4685_i4766;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(21),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L2193:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3065_i1981_i4685_i4766; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3065_i1981_i4685_i4766;
        } else {
          goto fatbar_69;
        }
        PXLL_RETURN(0);
        goto fatbar_69_over;
        fatbar_69:
        r0 = allocate (TC_TUPLE, 7);
        r1 = ((object*) lenv) [5];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[5];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[6] = r1;
        r1 = ((object*) lenv) [4];
        r0[7] = r1;
        r1 = ((object****) lenv) [1][1][1][14];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2714_i4685_i4766;
        fatbar_69_over: ;
        PXLL_RETURN(0);
        fatbar_68_over: ;
        PXLL_RETURN(0);
        fatbar_67_over: ;
        PXLL_RETURN(0);
        fatbar_65_over: ;
        PXLL_RETURN(0);
        fatbar_61_over: ;
        PXLL_RETURN(0);
        fatbar_60_over: ;
        PXLL_RETURN(0);
        fatbar_59_over: ;
        PXLL_RETURN(0);
        fatbar_57_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_54[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[135];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2194; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
          L2194:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2195; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2195:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2196; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2196:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[20];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2197; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_320;
          L2197:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = top[20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2198; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
          L2198:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def finish_3042_i1986_i4685_i4766
          goto L2199;
          FUN_finish_3042_i1986_i4685_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][4];
            r1[2] = r2;
            // def lambda_18852_i1986_i4685_i4766
            goto L2200;
            FUN_lambda_18852_i1986_i4685_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object******) lenv) [1][1][1][1][1][3];
              r1[2] = r2;
              r2 = top[136];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2201; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_529;
              L2201:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(6),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2200:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18852_i1986_i4685_i4766; r2[2] = lenv;
            r1[3] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2202; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
            L2202:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_18862_i1986_i4685_i4766
            goto L2203;
            FUN_lambda_18862_i1986_i4685_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 5);
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
              r0[4] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[5] = r1;
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
            L2203:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18862_i1986_i4685_i4766; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][7];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2204; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L2204:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][6];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            switch (get_case (r1)) {
              case (UOTAG(12)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][4];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = (object *) constructed_500[0];
                r2 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = (object *) 6;
                  r1=r1;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_71;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                goto fatbar_71;
              }
            }
            r1=r1;
            goto fatbar_71_over;
            fatbar_71:
            r1 = (object *) 262;
            r1=r1;
            fatbar_71_over: ;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 5);
              r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r2[2] = r3;
              r3 = ((object*****) lenv) [1][1][1][1][6];
              r2[3] = r3;
              r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
              r2[4] = r3;
              r3 = ((object**) lenv) [1][2];
              r2[5] = r3;
              r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2205; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_2695_i4685_i4766;
              L2205:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } else {
              r1 = (object*)UITAG(1);
              r1=r1;
            }
            r0[6] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object****) lenv) [1][1][1][3];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r3 = ((object*****) lenv) [1][1][1][1][4];
            r4 = ((object*) lenv) [6];
            r5 = ((object**) lenv) [1][2];
            t = alloc_no_clear (UOTAG(23),6);
            t[1] = r5;
            t[2] = r2;
            t[3] = r3;
            t[4] = r0;
            t[5] = r4;
            t[6] = r1;
            r0 = t;
            PXLL_RETURN(0);
          L2199:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_finish_3042_i1986_i4685_i4766; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = (object *) 6;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2206; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
          L2206:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
        } else {
          goto fatbar_70;
        }
        PXLL_RETURN(0);
        goto fatbar_70_over;
        fatbar_70:
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][5];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[135];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2207; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
        L2207:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[66];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2208; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L2208:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_501;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[14];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2209; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L2209:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = (object *) 3;
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2210; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L2210:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[20];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2211; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_320;
            L2211:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[20];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2212; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
            L2212:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def finish_3023_i1992_i4685_i4766
            goto L2213;
            FUN_finish_3023_i1992_i4685_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[2] = r2;
              // def lambda_18735_i1992_i4685_i4766
              goto L2214;
              FUN_lambda_18735_i1992_i4685_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = top[136];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2215; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_529;
                L2215:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(6),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              L2214:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18735_i1992_i4685_i4766; r2[2] = lenv;
              r1[3] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2216; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
              L2216:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_18745_i1992_i4685_i4766
              goto L2217;
              FUN_lambda_18745_i1992_i4685_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                r0[4] = r1;
                r1 = ((object**) lenv) [1][2];
                r0[5] = r1;
                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
              L2217:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18745_i1992_i4685_i4766; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][5];
              r1[3] = r2;
              r2 = top[32];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2218; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
              L2218:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2219; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L2219:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][3];
              r2[2] = r3;
              r3 = top[22];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2220; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
              L2220:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(unbox(r3)==unbox(r2));
              r1[4] = r2;
              r1 = (object *) 6;
              r2 = ((object*) lenv) [4];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r2 = ((pxll_vector*)r2)->val[4];
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                switch (get_case (r1)) {
                  case (UOTAG(12)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = ((object**) lenv) [1][2];
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = (object *) constructed_500[0];
                    r2 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_502;
                      r1[2] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                      r1[3] = r2;
                      r2 = top[14];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2221; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                      L2221:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_72;
                    }
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } break;
                  default: {
                    goto fatbar_72;
                  }
                }
                r1=r1;
                goto fatbar_72_over;
                fatbar_72:
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 5);
                r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                r2[2] = r3;
                r3 = ((object******) lenv) [1][1][1][1][1][4];
                r2[3] = r3;
                r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r2[4] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r2[5] = r3;
                r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2222; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_compile_2695_i4685_i4766;
                L2222:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                fatbar_72_over: ;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = (object*)UITAG(1);
                r1=r1;
              }
              r0[4] = r1;
              r0 = ((object*) lenv) [3];
              r1 = ((object*****) lenv) [1][1][1][1][3];
              r2 = ((object******) lenv) [1][1][1][1][1][2];
              r3 = ((object******) lenv) [1][1][1][1][1][3];
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(22),6);
              t[1] = r5;
              t[2] = r2;
              t[3] = r3;
              t[4] = r0;
              t[5] = r4;
              t[6] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2213:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_finish_3023_i1992_i4685_i4766; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 5);
            r1 = (object *) 6;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[3] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][4];
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][4];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2223; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
            L2223:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
          } break;
        }
        PXLL_RETURN(0);
        fatbar_70_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 6);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[6] = r1;
        r1 = ((object****) lenv) [1][1][1][17];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2722_i4685_i4766;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][3];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = top[191];
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2224; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L2224:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 11;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)<unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_18266_i2000_i4685_i4766
            goto L2225;
            FUN_lambda_18266_i2000_i4685_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2226; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_257;
              L2226:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[1];
              r0[3] = r1;
              r0 = top[153];
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
              PXLL_RETURN(0);
            L2225:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18266_i2000_i4685_i4766; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[39];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2227; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_some_question_343;
            L2227:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } else {
            r0 = (object *) 6;
            r0=r0;
          }
          r0=r0;
        } else {
          r0 = (object *) 6;
          r0=r0;
        }
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][5];
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_2992_i2005_i4685_i4766
          goto L2228;
          FUN_loop_2992_i2005_i4685_i4766:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2229; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L2229:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = (object *) 1;
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 5);
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*) lenv) [3];
              r1[2] = r2;
              r2 = top[19];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2230; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
              L2230:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 5);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,2);
                  r1[4] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = allocate (TC_TUPLE, 3);
                  r4 = ((object*) lenv) [3];
                  r3[2] = r4;
                  r4 = (object *) constructed_41[0];
                  r3[3] = r4;
                  r4 = top[21];
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2231; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
                  L2231:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = ((object**) lenv) [1][5];
                  r2[3] = r3;
                  r3 = top[21];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2232; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
                  L2232:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[5] = r2;
                  r1 = ((object*) lenv) [5];
                  r2 = ((object*) lenv) [4];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(0),3);
                  t[1] = r3;
                  t[2] = r1;
                  t[3] = r2;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  r1 = (object*) &constructed_73;
                  r1 = box((pxll_int)((pxll_string*)(r1))->len);
                  r2 = (object*) &constructed_73;
                  (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
                  r1 = (object*) &constructed_504;
                  dump_object (r1, 0); fprintf (stdout, "\n");
                  r1 = (object*) &constructed_504;
                  PXLL_UNDEFINED; result=r1; goto Lreturn;
                  r1=r1;
                } break;
              }
              r0[5] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
            } else {
              r0 = allocate (TC_TUPLE, 5);
              r1 = (object *) 6;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*) lenv) [3];
              r1[2] = r2;
              r2 = top[19];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2233; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
              L2233:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][3];
              r3[2] = r4;
              r4 = top[135];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2234; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_528;
              L2234:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = ((object**) lenv) [1][5];
              r3[2] = r4;
              r4 = (object *) constructed_41[0];
              r3[3] = r4;
              r4 = top[21];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2235; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
              L2235:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r2[3] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2236; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
              L2236:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              // def lambda_18606_i2005_i4685_i4766
              goto L2237;
              FUN_lambda_18606_i2005_i4685_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = top[20];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2238; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
                L2238:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][3];
                r1[2] = r2;
                r2 = top[20];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2239; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
                L2239:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object***) lenv) [1][1][2];
                r2[2] = r3;
                r3 = top[19];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2240; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_319;
                L2240:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][4];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r3;
                t[2] = r1;
                t[3] = r2;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[4] = r1;
                r1 = ((object**) lenv) [1][5];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[5] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto FUN_loop_2992_i2005_i4685_i4766;
              L2237:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18606_i2005_i4685_i4766; r2[2] = lenv;
              r1[3] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2241; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
              L2241:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
            }
            PXLL_RETURN(0);
          L2228:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_2992_i2005_i4685_i4766; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          r0[4] = r1;
          r1 = (object *) constructed_503[0];
          r0[5] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_2992_i2005_i4685_i4766;
        } else {
          r0 = allocate (TC_TUPLE, 6);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][5];
          r0[6] = r1;
          r1 = ((object****) lenv) [1][1][1][17];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2722_i4685_i4766;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_72;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_72;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2083:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_2695_i4685_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def add-literal_2696_i4685_i4766
  goto L2242;
  FUN_add_literal_2696_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[6];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2243; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L2243:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object*****) lenv) [1][1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[6];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object***) lenv) [1][1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    r1 = ((object****) lenv) [1][1][1][2];
    ((pxll_vector*)r1)->val[6] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L2242:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_literal_2696_i4685_i4766; r2[2] = lenv;
  r1[4] = r2;
  // def get-literal-index_2697_i4685_i4766
  goto L2244;
  FUN_get_literal_index_2697_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[5];
    r1[2] = r2;
    r2 = top[11];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[72];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2245; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L2245:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2246; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2696_i4685_i4766;
        L2246:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[5];
        r0[2] = r1;
        r1 = top[11];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[4] = r1;
        r1 = ((object*) lenv) [2];
        r0[5] = r1;
        r1 = top[71];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2247; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L2247:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        ((pxll_vector*)r1)->val[5] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2244:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_literal_index_2697_i4685_i4766; r2[2] = lenv;
  r1[5] = r2;
  // def get-symbol-index_2698_i4685_i4766
  goto L2248;
  FUN_get_symbol_index_2698_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[13];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[66];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2249; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L2249:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object****) lenv) [1][1][1][2];
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = ((object*****) lenv) [1][1][1][1][2];
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3 = r3;
        r3=r3;
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2250; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2696_i4685_i4766;
        L2250:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2251; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2696_i4685_i4766;
        L2251:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[13];
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        t = alloc_no_clear (UOTAG(1),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        ((pxll_vector*)r1)->val[13] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2248:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_symbol_index_2698_i4685_i4766; r2[2] = lenv;
  r1[6] = r2;
  // def scan-literals_2699_i4685_i4766
  goto L2252;
  FUN_scan_literals_2699_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2253; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_get_symbol_index_2698_i4685_i4766;
            L2253:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2254; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_add_literal_2696_i4685_i4766;
            L2254:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2255; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2699_i4685_i4766;
            L2255:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2256; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2699_i4685_i4766;
            L2256:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          default: {
            goto fatbar_48;
          }
        }
        goto fatbar_48_over;
        fatbar_48:
        r0 = (object *) 1;
        fatbar_48_over: ;
        r0 = ((object*) lenv) [3];
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_scan_literals_2699_i4685_i4766;
      } break;
    }
    PXLL_RETURN(0);
  L2252:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_scan_literals_2699_i4685_i4766; r2[2] = lenv;
  r1[7] = r2;
  // def c-sequence_2701_i4685_i4766
  goto L2257;
  FUN_c_sequence_2701_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_73;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_73;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_467;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_467;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 5);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object**) lenv) [1][4];
            r0[4] = r1;
            r1 = ((object**) lenv) [1][5];
            r0[5] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
          } break;
          default: {
            goto fatbar_47;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_47_over;
        fatbar_47:
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object***) lenv) [1][1][5];
        r2[2] = r3;
        r3 = top[135];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2258; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_528;
        L2258:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 5);
        r3 = ((object***) lenv) [1][1][2];
        r2[2] = r3;
        r3 = ((object**) lenv) [1][3];
        r2[3] = r3;
        r3 = ((object***) lenv) [1][1][4];
        r2[4] = r3;
        r3 = ((object***) lenv) [1][1][5];
        r2[5] = r3;
        r3 = ((object****) lenv) [1][1][1][8];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2259; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_c_sequence_2701_i4685_i4766;
        L2259:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object*) lenv) [3];
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
        fatbar_47_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2257:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_sequence_2701_i4685_i4766; r2[2] = lenv;
  r1[8] = r2;
  // def extend-lenv_2704_i4685_i4766
  goto L2260;
  FUN_extend_lenv_2704_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_46;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_46_over;
    fatbar_46:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_46_over: ;
    PXLL_RETURN(0);
  L2260:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_extend_lenv_2704_i4685_i4766; r2[2] = lenv;
  r1[9] = r2;
  // def search-rib_2706_i4685_i4766
  goto L2261;
  FUN_search_rib_2706_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_search_rib_2706_i4685_i4766;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2261:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_rib_2706_i4685_i4766; r2[2] = lenv;
  r1[10] = r2;
  // def lexical-address_2707_i4685_i4766
  goto L2262;
  FUN_lexical_address_2707_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_466;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[14];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        r1[4] = r2;
        r2 = ((object***) lenv) [1][1][10];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2263; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_search_rib_2706_i4685_i4766;
        L2263:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = (object*)UITAG(0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object***) lenv) [1][1][3];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (UOTAG(6), 1);
              r1 = ((object*) lenv) [2];
              r0[1] = r1;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object***) lenv) [1][1][3];
              r0[1] = r1;
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object *) 3;
            r1 = ((object**) lenv) [1][3];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            r1 = ((object*) lenv) [3];
            r2 = ((object**) lenv) [1][2];
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_lexical_address_2707_i4685_i4766;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][2];
        lenv = ((object *)lenv)[1];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_lexical_address_2707_i4685_i4766;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (UOTAG(7), 1);
          r1 = ((object*) lenv) [3];
          r0[1] = r1;
          PXLL_RETURN(0);
        } else {
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [4];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_lexical_address_2707_i4685_i4766;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2262:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lexical_address_2707_i4685_i4766; r2[2] = lenv;
  r1[11] = r2;
  // def collect-primargs_2712_i4685_i4766
  goto L2264;
  FUN_collect_primargs_2712_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2265; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L2265:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2909_i4685_i4766
    goto L2266;
    FUN__24loop_2909_i4685_i4766:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_41[0];
        r0[3] = r1;
        r1 = top[21];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (UOTAG(1), 2);
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*****) lenv) [1][1][1][1][2];
        r2[2] = r3;
        r3 = ((object**) lenv) [1][2];
        r2[3] = r3;
        r3 = top[27];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2267; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
        L2267:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2909_i4685_i4766;
      }
      PXLL_RETURN(0);
    L2266:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2909_i4685_i4766; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2268; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2909_i4685_i4766;
    L2268:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_18124_i4685_i4766
    goto L2269;
    FUN_lambda_18124_i4685_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object**) lenv) [1][3];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[2];
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2269:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18124_i4685_i4766; r2[2] = lenv;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[44];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2270; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_sort_350;
    L2270:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[18];
    r1[2] = r2;
    r2 = ((object*) lenv) [4];
    r1[3] = r2;
    r2 = top[32];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2271; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
    L2271:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[17];
    r1[2] = r2;
    r2 = ((object*) lenv) [4];
    r1[3] = r2;
    r2 = top[32];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2272; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
    L2272:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 7);
    r1 = ((object*) lenv) [6];
    r0[2] = r1;
    r1 = (object *) constructed_465[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [5];
    r0[4] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[5] = r1;
    r1 = ((object**) lenv) [1][4];
    r0[6] = r1;
    r1 = ((object**) lenv) [1][5];
    r0[7] = r1;
    r1 = ((object***) lenv) [1][1][13];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2713_i4685_i4766;
  L2264:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_2712_i4685_i4766; r2[2] = lenv;
  r1[12] = r2;
  // def collect-primargs*_2713_i4685_i4766
  goto L2273;
  FUN_collect_primargs_splat_2713_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = (object *) constructed_41[0];
        r1[3] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2274; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
        L2274:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][4];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2275; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L2275:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_2928_i4685_i4766
        goto L2276;
        FUN__24loop_2928_i4685_i4766:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [3];
            r0[2] = r1;
            r1 = (object *) constructed_41[0];
            r0[3] = r1;
            r1 = top[21];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object*****) lenv) [1][1][1][1][4];
            r2[3] = r3;
            r3 = top[28];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2277; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_index_eq_332;
            L2277:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2278; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
            L2278:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_2928_i4685_i4766;
          }
          PXLL_RETURN(0);
        L2276:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_2928_i4685_i4766; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2279; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2928_i4685_i4766;
        L2279:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][7];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][5];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][6];
        r3[2] = r4;
        r4 = top[135];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2280; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_528;
        L2280:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object*) lenv) [2];
        r3[2] = r4;
        r4 = (object *) constructed_41[0];
        r3[3] = r4;
        r4 = top[21];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2281; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_321;
        L2281:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object***) lenv) [1][1][3];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2282; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L2282:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        // def lambda_18221_i4685_i4766
        goto L2283;
        FUN_lambda_18221_i4685_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][5];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][6];
          r0[6] = r1;
          r1 = ((object***) lenv) [1][1][7];
          r0[7] = r1;
          r1 = ((object****) lenv) [1][1][1][13];
          r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2713_i4685_i4766;
        L2283:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_18221_i4685_i4766; r2[2] = lenv;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2284; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
        L2284:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
      } break;
    }
    PXLL_RETURN(0);
  L2273:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_splat_2713_i4685_i4766; r2[2] = lenv;
  r1[13] = r2;
  // def c-primargs_2714_i4685_i4766
  goto L2285;
  FUN_c_primargs_2714_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [6];
    r0[3] = r1;
    r1 = ((object*) lenv) [7];
    r0[4] = r1;
    // def lambda_18244_i4685_i4766
    goto L2286;
    FUN_lambda_18244_i4685_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][4];
      r2 = ((object**) lenv) [1][5];
      r3 = ((object**) lenv) [1][7];
      r4 = ((object**) lenv) [1][3];
      t = alloc_no_clear (UOTAG(18),5);
      t[1] = r4;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      t[5] = r3;
      r0 = t;
      PXLL_RETURN(0);
    L2286:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_18244_i4685_i4766; r1[2] = lenv;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][12];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
  L2285:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_primargs_2714_i4685_i4766; r2[2] = lenv;
  r1[14] = r2;
  // def c-trcall_2717_i4685_i4766
  goto L2287;
  FUN_c_trcall_2717_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object*) lenv) [4];
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[3] = r1;
    r1 = ((object*) lenv) [6];
    r0[4] = r1;
    // def lambda_18313_i4685_i4766
    goto L2288;
    FUN_lambda_18313_i4685_i4766:
      check_heap (0);
      r0 = ((object**) lenv) [1][3];
      r1 = ((object*) lenv) [2];
      r2 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(15),3);
      t[1] = r2;
      t[2] = r0;
      t[3] = r1;
      r0 = t;
      PXLL_RETURN(0);
    L2288:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_18313_i4685_i4766; r1[2] = lenv;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][12];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2712_i4685_i4766;
  L2287:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_trcall_2717_i4685_i4766; r2[2] = lenv;
  r1[15] = r2;
  // def compile-store-args_2720_i4685_i4766
  goto L2289;
  FUN_compile_store_args_2720_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) 6;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = top[19];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2290; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
    L2290:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [7];
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [6];
    r1[2] = r2;
    // def lambda_18551_i4685_i4766
    goto L2291;
    FUN_lambda_18551_i4685_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r3 = top[20];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2292; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_cdr_320;
      L2292:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object *) 262;
          r1=r1;
        } break;
        default: {
          goto fatbar_45;
        }
      }
      r1=r1;
      goto fatbar_45_over;
      fatbar_45:
      r1 = (object *) 6;
      r1=r1;
      fatbar_45_over: ;
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][8];
        r1=r1;
      } else {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 8);
        r3 = (object *) 3;
        r4 = ((object****) lenv) [1][1][1][2];
        r3 = box((pxll_int)unbox(r4)+unbox(r3));
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][3];
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object****) lenv) [1][1][1][4];
        r3[2] = r4;
        r4 = top[20];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2293; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_320;
        L2293:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = ((object****) lenv) [1][1][1][5];
        r2[5] = r3;
        r3 = ((object****) lenv) [1][1][1][6];
        r2[6] = r3;
        r3 = ((object****) lenv) [1][1][1][7];
        r2[7] = r3;
        r3 = ((object****) lenv) [1][1][1][8];
        r2[8] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][16];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2294; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_compile_store_args_2720_i4685_i4766;
        L2294:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object****) lenv) [1][1][1][6];
        r2 = ((object*) lenv) [2];
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      }
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object**) lenv) [1][2];
      r2 = ((object***) lenv) [1][1][5];
      r3 = ((object*) lenv) [2];
      r4 = ((object***) lenv) [1][1][3];
      t = alloc_no_clear (UOTAG(12),5);
      t[1] = r4;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      t[5] = r3;
      r0 = t;
      PXLL_RETURN(0);
    L2291:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18551_i4685_i4766; r2[2] = lenv;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2295; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
    L2295:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_compile_2695_i4685_i4766;
  L2289:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_store_args_2720_i4685_i4766; r2[2] = lenv;
  r1[16] = r2;
  // def c-let-splat_2722_i4685_i4766
  goto L2296;
  FUN_c_let_splat_2722_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 9);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][4];
    r1[2] = r2;
    r2 = (object *) constructed_41[0];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2297; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L2297:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[19];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2298; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
    L2298:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[20];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2299; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_320;
    L2299:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = (object *) constructed_41[0];
    r1[3] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2300; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
    L2300:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2301; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
    L2301:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][6];
    r1[2] = r2;
    r2 = top[135];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2302; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_528;
    L2302:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    switch (get_case (r2)) {
      case (TC_NIL): {
        r2 = ((object**) lenv) [1][5];
        r2=r2;
      } break;
      default: {
        goto fatbar_44;
      }
    }
    r2=r2;
    goto fatbar_44_over;
    fatbar_44:
    r2 = ((object**) lenv) [1][5];
    r3 = ((object**) lenv) [1][3];
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r2=r2;
    fatbar_44_over: ;
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][6];
    r3[2] = r4;
    r4 = top[135];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L2303; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_528;
    L2303:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    // def lambda_18657_i4685_i4766
    goto L2304;
    FUN_lambda_18657_i4685_i4766:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][6];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (UOTAG(17),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2304:
    r3 = allocate (TC_CLOSURE, 2);
    r3[1] = &&FUN_lambda_18657_i4685_i4766; r3[2] = lenv;
    r2[3] = r3;
    r3 = ((object***) lenv) [1][1][2];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2305; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
    L2305:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2306; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
    L2306:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[8] = r1;
    r1 = ((object*) lenv) [7];
    r2 = ((object*) lenv) [8];
    r3 = (object *) -1;
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[9] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object****) lenv) [1][1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][38];
    r1[2] = r2;
    r2 = top[19];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2307; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
    L2307:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[155];
    r0[4] = r1;
    r1 = top[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2308; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
    L2308:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][7];
    r1[2] = r2;
    // def lambda_18690_i4685_i4766
    goto L2309;
    FUN_lambda_18690_i4685_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 8);
      r2 = (object *) 1;
      r1[2] = r2;
      r2 = (object *) 3;
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][5];
      r1[4] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[5] = r2;
      r2 = ((object****) lenv) [1][1][1][7];
      r3 = ((object**) lenv) [1][2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      r1[6] = r2;
      r2 = ((object*****) lenv) [1][1][1][1][3];
      switch (get_case (r2)) {
        case (TC_NIL): {
          r2 = ((object*****) lenv) [1][1][1][1][5];
          r2=r2;
        } break;
        default: {
          goto fatbar_43;
        }
      }
      r2=r2;
      goto fatbar_43_over;
      fatbar_43:
      r2 = ((object*****) lenv) [1][1][1][1][5];
      r3 = ((object*****) lenv) [1][1][1][1][3];
      t = alloc_no_clear (UOTAG(1),2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      r2=r2;
      fatbar_43_over: ;
      r1[7] = r2;
      r2 = ((object****) lenv) [1][1][1][9];
      r1[8] = r2;
      r2 = ((object******) lenv) [1][1][1][1][1][16];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2310; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_compile_store_args_2720_i4685_i4766;
      L2310:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][7];
      r2 = ((object*) lenv) [2];
      r3 = (object *) -1;
      t = alloc_no_clear (UOTAG(0),3);
      t[1] = r3;
      t[2] = r1;
      t[3] = r2;
      r1 = t;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(16),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2309:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18690_i4685_i4766; r2[2] = lenv;
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2311; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2693_i4685_i4766;
    L2311:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][6];
    t = alloc_no_clear (UOTAG(10),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2296:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_let_splat_2722_i4685_i4766; r2[2] = lenv;
  r1[17] = r2;
  // def record-label-tag_2730_i4685_i4766
  goto L2312;
  FUN_record_label_tag_2730_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3114_i4685_i4766
    goto L2313;
    FUN_loop_3114_i4685_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_3114_i4685_i4766;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[4];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2314; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L2314:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(1), 2);
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[1] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          ((pxll_vector*)r1)->val[4] = r0;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2313:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3114_i4685_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3114_i4685_i4766;
  L2312:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_record_label_tag_2730_i4685_i4766; r2[2] = lenv;
  r1[18] = r2;
  // def gen-return_2733_i4685_i4766
  goto L2315;
  FUN_gen_return_2733_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2315:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_return_2733_i4685_i4766; r2[2] = lenv;
  r1[19] = r2;
  // def gen-invoke_2734_i4685_i4766
  goto L2316;
  FUN_gen_invoke_2734_i4685_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object***) lenv) [1][1][38];
    r1[2] = r2;
    r2 = top[19];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2317; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_319;
    L2317:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[155];
    r0[4] = r1;
    r1 = top[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2318; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_259;
    L2318:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [5];
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(13),4);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    t[4] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2316:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_invoke_2734_i4685_i4766; r2[2] = lenv;
  r1[20] = r2;
  // def gen-tail_2735_i4685_i4766
  goto L2319;
  FUN_gen_tail_2735_i4685_i4766:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [4];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(14),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2319:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_tail_2735_i4685_i4766; r2[2] = lenv;
  r1[21] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = top[112];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2320; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_478;
  L2320:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[22] = r2;
  r1 = allocate (TC_TUPLE, 5);
  r2 = (object *) 262;
  r1[2] = r2;
  r2 = ((object**) lenv) [1][24];
  r1[3] = r2;
  r2 = (object*)UITAG(0);
  r1[4] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = (object *) constructed_464[0];
  r2[2] = r3;
  r3 = ((object*) lenv) [19];
  r2[3] = r3;
  r3 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2321; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_cont_2693_i4685_i4766;
  L2321:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[5] = r2;
  r2 = ((object*) lenv) [3];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2322; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_compile_2695_i4685_i4766;
  L2322:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[39] = r1;
  r1 = allocate (UOTAG(2), 3);
  r2 = (object *) 32769;
  r2 = box((pxll_int)string_tuple_length (unbox(r2)));
  ensure_heap (2, unbox(r2));
  r2 = (object *) 32769;
  r2 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r2))), ((pxll_string*)(t))->len = unbox(r2), t);
  r1[1] = r2;
  r2 = allocate (TC_TUPLE, 4);
  r3 = ((object*) lenv) [12];
  r2[2] = r3;
  r3 = allocate (TC_TUPLE, 2);
  r3[1] = lenv; lenv = r3;
  r4 = top[160];
  r5 = top[159];
  r4 = box((pxll_int)unbox(r5)|unbox(r4));
  r3[2] = r4;
  r3 = ((object*) lenv) [2];
  r4 = top[161];
  r3 = box((pxll_int)unbox(r4)|unbox(r3));
  lenv = lenv[1];
  r3 = r3;
  r2[3] = r3;
  r3 = (object *) 841;
  r2[4] = r3;
  r3 = top[61];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2323; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_open_383;
  L2323:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) 1;
  r1[3] = r2;
  r0[40] = r1;
  r1 = (object *) 3;
  r0[41] = r1;
  r1 = allocate (TC_TUPLE, 7);
  r1[1] = lenv; lenv = r1;
  // def write-indent_4200_i4687_i4766
  goto L2324;
  FUN_write_indent_4200_i4687_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4206_i4687_i4766
    goto L2325;
    FUN_loop_4206_i4687_i4766:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][40];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
        r0[2] = r1;
        r0 = (object*) &constructed_463;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_463;
        r2 = ((object*) lenv) [2];
        r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)-unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_4206_i4687_i4766;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L2325:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4206_i4687_i4766; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][41];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4206_i4687_i4766;
  L2324:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_indent_4200_i4687_i4766; r2[2] = lenv;
  r1[2] = r2;
  // def write-string_4201_i4687_i4766
  goto L2326;
  FUN_write_string_4201_i4687_i4766:
    check_heap (0);
    r0 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2327; ; k = t;
    lenv = r0[2]; goto FUN_write_indent_4200_i4687_i4766;
    L2327:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][40];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][40];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = (object*) &constructed_462;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_462;
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = (object *) 14;
    PXLL_RETURN(0);
  L2326:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_string_4201_i4687_i4766; r2[2] = lenv;
  r1[3] = r2;
  // def copy_4202_i4687_i4766
  goto L2328;
  FUN_copy_4202_i4687_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][40];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    PXLL_RETURN(0);
  L2328:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_copy_4202_i4687_i4766; r2[2] = lenv;
  r1[4] = r2;
  // def indent_4203_i4687_i4766
  goto L2329;
  FUN_indent_4203_i4687_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][41];
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    ((object**) lenv) [1][41] = r0;
    PXLL_RETURN(0);
  L2329:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_indent_4203_i4687_i4766; r2[2] = lenv;
  r1[5] = r2;
  // def dedent_4204_i4687_i4766
  goto L2330;
  FUN_dedent_4204_i4687_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][41];
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)-unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    ((object**) lenv) [1][41] = r0;
    PXLL_RETURN(0);
  L2330:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_dedent_4204_i4687_i4766; r2[2] = lenv;
  r1[6] = r2;
  // def close-file_4205_i4687_i4766
  goto L2331;
  FUN_close_file_4205_i4687_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][40];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)close (unbox(r0)));
    PXLL_RETURN(0);
  L2331:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_close_file_4205_i4687_i4766; r2[2] = lenv;
  r1[7] = r2;
  r1 = allocate (UOTAG(1), 5);
  r2 = ((object*) lenv) [7];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  r2 = ((object*) lenv) [6];
  r1[3] = r2;
  r2 = ((object*) lenv) [5];
  r1[4] = r2;
  r2 = ((object*) lenv) [3];
  r1[5] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[42] = r1;
  r0 = ((object*) lenv) [2];
  r0 = ((pxll_vector*)r0)->val[8];
  r0 = ((pxll_vector*)r0)->val[3];
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_461;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_461;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [39];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = top[137];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2332; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_532;
    L2332:
    ; lenv = k[2]; k = k[1];
    r0 = (object *) 2562;
    box((pxll_int)fputc (GET_CHAR(r0), stdout));
    r0 = (object*) &constructed_460;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_460;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_34211_i4766
    goto L2333;
    FUN_lambda_34211_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = top[116];
      r0[1] = r1[2]; lenv = r0; goto FUN_print_datatype_487;
    L2333:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_34211_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r1 = top[68];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2334; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
    L2334:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_459;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_459;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = (object*) &constructed_458;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_458;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[9];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = (object*) &constructed_457;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_457;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_34259_i4766
    goto L2335;
    FUN_lambda_34259_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2336; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L2336:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r3 = r3;
      r3=r3;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_456;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_455;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_454;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2337; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L2337:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L2335:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_34259_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[13];
    r0[3] = r1;
    r1 = top[68];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2338; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
    L2338:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_453;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_453;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_34293_i4766
    goto L2339;
    FUN_lambda_34293_i4766:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2340; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L2340:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r3 = r3;
      r3=r3;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_452;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_451;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_450;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2341; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L2341:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L2339:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_34293_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[14];
    r0[3] = r1;
    r1 = top[68];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2342; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
    L2342:
    ; lenv = k[2]; k = k[1];
    r0 = (object *) 14;
  } else {
    r0 = (object *) 14;
  }
  r0 = (object*) &constructed_449;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_449;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = (object*) &constructed_448;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_448;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = ((object*) lenv) [12];
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = ((object*) lenv) [12];
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = (object *) 2562;
  box((pxll_int)fputc (GET_CHAR(r0), stdout));
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_34330_i4766
  goto L2343;
  FUN_lambda_34330_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = (object*) &constructed_447;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_446;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2344; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2344:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][42];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L2343:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_34330_i4766; r1[2] = lenv;
  r0[2] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[0];
  r0[3] = r1;
  r1 = top[35];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2345; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
  L2345:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 6);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_445;
  r1[2] = r2;
  r2 = top[62];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2346; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_390;
  L2346:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def loop_4711_i4618_i4721_i4766
  goto L2347;
  FUN_loop_4711_i4618_i4721_i4766:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = (object *) constructed_41[0];
      r1[3] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2348; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
      L2348:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = top[47];
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    } else {
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][2];
      r1[2] = r2;
      r2 = top[64];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2349; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2fread_buffer_396;
      L2349:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv[2] = r1;
      lenv[3] = r0;
      goto FUN_loop_4711_i4618_i4721_i4766;
    }
    PXLL_RETURN(0);
  L2347:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_loop_4711_i4618_i4721_i4766; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][2];
  r2[2] = r3;
  r3 = top[64];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2350; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_file_2fread_buffer_396;
  L2350:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) constructed_444[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2351; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_loop_4711_i4618_i4721_i4766;
  L2351:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[3] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = top[203];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  r2 = top[51];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2352; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_366;
  L2352:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[4] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = top[204];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  r2 = top[51];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2353; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_366;
  L2353:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[5] = r1;
  r1 = (object *) -1;
  r2 = ((object*) lenv) [4];
  if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
    r1 = (object *) 262;
    r1=r1;
  } else {
    r1 = (object *) -1;
    r2 = ((object*) lenv) [5];
    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
    r1=r1;
  }
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_443;
    r1[2] = r2;
    r2 = allocate (UOTAG(1), 2);
    r3 = ((object*) lenv) [4];
    r2[1] = r3;
    r3 = ((object*) lenv) [5];
    r2[2] = r3;
    r1[3] = r2;
    r2 = top[14];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2354; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
    L2354:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  } else {
    r1 = allocate (TC_TUPLE, 8);
    r1[1] = lenv; lenv = r1;
    r2 = top[203];
    r2 = box((pxll_int)((pxll_string*)(r2))->len);
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r3 = ((object**) lenv) [1][4];
    r2 = box((pxll_int)unbox(r3)+unbox(r2));
    r1[3] = r2;
    r2 = top[204];
    r2 = box((pxll_int)((pxll_string*)(r2))->len);
    r1[4] = r2;
    r2 = ((object*) lenv) [4];
    r3 = ((object**) lenv) [1][5];
    r2 = box((pxll_int)unbox(r3)+unbox(r2));
    r1[5] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) 1;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r2[4] = r3;
    r3 = top[45];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2355; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2355:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[6] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = ((object*) lenv) [3];
    r2[3] = r3;
    r3 = ((object*) lenv) [5];
    r2[4] = r3;
    r3 = top[45];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2356; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2356:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[7] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = ((object*) lenv) [5];
    r2[3] = r3;
    r3 = ((object**) lenv) [1][3];
    r3 = box((pxll_int)((pxll_string*)(r3))->len);
    r2[4] = r3;
    r3 = top[45];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2357; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2357:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[8] = r2;
    r1 = allocate (UOTAG(8), 3);
    r2 = ((object*) lenv) [6];
    r1[1] = r2;
    r2 = ((object*) lenv) [7];
    r1[2] = r2;
    r2 = ((object*) lenv) [8];
    r1[3] = r2;
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
  }
  r0[6] = r1;
  r0 = ((object*) lenv) [6];
  switch (get_case_noint (r0)) {
    default: {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,2);
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][42];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2358; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2358:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 8);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[6];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_41[0];
      r1[3] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2359; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
      L2359:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = top[22];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2360; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
      L2360:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = (object*)UITAG(0);
      r0[5] = r1;
      r1 = (object *) constructed_442[0];
      r0[6] = r1;
      r1 = (object *) 1;
      r0[7] = r1;
      r1 = (object *) 1;
      r0[8] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      // def uohead_4648_i4722_i4766
      goto L2361;
      FUN_uohead_4648_i4722_i4766:
        check_heap (0);
        r0 = (object *) constructed_56[0];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_66[0];
          r1 = ((object*) lenv) [4];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_438;
            PXLL_RETURN(0);
          } else {
            goto fatbar_42;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_42;
        }
        PXLL_RETURN(0);
        goto fatbar_42_over;
        fatbar_42:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 8);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2362; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2362:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][5];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2363; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2363:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = (object*) &constructed_441;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = (object*) &constructed_440;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = ((object*) lenv) [7];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r1 = ((object*) lenv) [8];
        r2 = (object*) &constructed_439;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_42_over: ;
        PXLL_RETURN(0);
      L2361:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uohead_4648_i4722_i4766; r1[2] = lenv;
      r0[2] = r1;
      // def uitag_4649_i4722_i4766
      goto L2364;
      FUN_uitag_4649_i4722_i4766:
        check_heap (0);
        r0 = (object *) constructed_56[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_54[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_435;
            PXLL_RETURN(0);
          } else {
            goto fatbar_41;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_41;
        }
        PXLL_RETURN(0);
        goto fatbar_41_over;
        fatbar_41:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2365; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2365:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_437;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_436;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_41_over: ;
        PXLL_RETURN(0);
      L2364:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uitag_4649_i4722_i4766; r1[2] = lenv;
      r0[3] = r1;
      // def walk_4650_i4722_i4766
      goto L2366;
      FUN_walk_4650_i4722_i4766:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 7);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[1];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = (object*) &constructed_423;
            r1[4] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2367; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
            L2367:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object*) lenv) [5];
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2368; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2368:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2369; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L2369:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r0 = (object *) 1;
            r1 = ((object*) lenv) [7];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object****) lenv) [1][1][1][4];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][4];
              r1[3] = r2;
              r2 = top[32];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2370; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
              L2370:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*****) lenv) [1][1][1][1][6];
              r1[2] = r2;
              r2 = top[22];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2371; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
              L2371:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3;
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 5);
              r2 = ((object***) lenv) [1][1][7];
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = ((object***) lenv) [1][1][3];
              r1[4] = r2;
              r2 = ((object***) lenv) [1][1][6];
              r2 = ((pxll_vector*)r2)->val[1];
              r1[5] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2372; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_uohead_4648_i4722_i4766;
              L2372:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][6];
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              ((object*****) lenv) [1][1][1][1][6] = r0;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_32967_i4722_i4766
              goto L2373;
              FUN_lambda_32967_i4722_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][6];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object******) lenv) [1][1][1][1][1][6] = r0;
                PXLL_RETURN(0);
              L2373:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_32967_i4722_i4766; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[35];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2374; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
              L2374:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 8);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object******) lenv) [1][1][1][1][1][7];
              r2[2] = r3;
              r3 = top[56];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2375; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
              L2375:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = top[56];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2376; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
              L2376:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = (object*) &constructed_422;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = ((object*) lenv) [6];
              r3 = (object*) &constructed_421;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = ((object*) lenv) [7];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r1 = ((object*) lenv) [8];
              r2 = (object*) &constructed_420;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = top[47];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = ((object*) lenv) [6];
              r1 = ((pxll_vector*)r1)->val[1];
              r0[4] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_uitag_4649_i4722_i4766;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][4];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[32];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2377; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
            L2377:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2378; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L2378:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object****) lenv) [1][1][1][6];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2379; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
            L2379:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = (object *) 3;
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 5);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object***) lenv) [1][1][4];
            r3[2] = r4;
            r4 = top[56];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2380; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
            L2380:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [3];
            r4 = (object*) &constructed_428;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r3 = ((object*) lenv) [4];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[5] = r3;
            r2 = ((object*) lenv) [5];
            r3 = (object*) &constructed_427;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = top[47];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2381; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
            L2381:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][6];
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            ((object****) lenv) [1][1][1][6] = r0;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_33051_i4722_i4766
            goto L2382;
            FUN_lambda_33051_i4722_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][6];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              ((object*****) lenv) [1][1][1][1][6] = r0;
              PXLL_RETURN(0);
            L2382:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_33051_i4722_i4766; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[35];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2383; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
            L2383:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*****) lenv) [1][1][1][1][7];
            r2[2] = r3;
            r3 = top[56];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2384; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2384:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r3 = top[56];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2385; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2385:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_426;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = (object*) &constructed_425;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = ((object*) lenv) [8];
            r2 = (object*) &constructed_424;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = top[47];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[13];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = (object*) &constructed_431;
            r1[4] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2386; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
            L2386:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[56];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2387; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2387:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object*)TC_NIL;
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            r3 = (object*) &constructed_430;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r1 = ((object*) lenv) [5];
            r2 = (object*) &constructed_429;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = top[47];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][5];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[66];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2388; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L2388:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 5);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[56];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2389; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                L2389:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = (object*)TC_NIL;
                r1[3] = r2;
                r2 = ((object*) lenv) [3];
                r3 = (object*) &constructed_433;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[4] = r2;
                r2 = ((object*) lenv) [4];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[5] = r2;
                r1 = ((object*) lenv) [5];
                r2 = (object*) &constructed_432;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[2] = r1;
                r1 = top[47];
                r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
              } break;
              default: {
                r0 = (object*) &constructed_73;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_73;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_434;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_434;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_40;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_40_over;
        fatbar_40:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[146];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2390; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_encode_immediate_564;
        L2390:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = top[56];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
        fatbar_40_over: ;
        PXLL_RETURN(0);
      L2366:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_4650_i4722_i4766; r1[2] = lenv;
      r0[4] = r1;
      r0 = ((object*****) lenv) [1][1][1][1][42];
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2391; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2391:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4679_i4722_i4766
      goto L2392;
      FUN__24loop_4679_i4722_i4766:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) constructed_419[0];
          ((object*****) lenv) [1][1][1][1][6] = r0;
          r0 = ((object*) lenv) [2];
          ((object*****) lenv) [1][1][1][1][7] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2393; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2393:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = box((pxll_int)((pxll_string*)(r1))->len);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
              r0[2] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(1),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              ((object*******) lenv) [1][1][1][1][1][1][5] = r0;
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 14);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2394; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2394:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2395; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2395:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2396; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2396:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              // def loop_4694_i4523_i4722_i4766
              goto L2397;
              FUN_loop_4694_i4523_i4722_i4766:
                check_heap (0);
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*) lenv) [2];
                    r1[2] = r2;
                    r2 = (object *) constructed_41[0];
                    r1[3] = r2;
                    r2 = top[21];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2398; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
                    L2398:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = top[47];
                    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = (object *) 8706;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_399;
                      r1=r1;
                    } else {
                      goto fatbar_32;
                    }
                    r1=r1;
                    goto fatbar_32_over;
                    fatbar_32:
                    r1 = (object *) 23554;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_400;
                      r1=r1;
                    } else {
                      goto fatbar_33;
                    }
                    r1=r1;
                    goto fatbar_33_over;
                    fatbar_33:
                    r1 = (object *) 2306;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_401;
                      r1=r1;
                    } else {
                      goto fatbar_34;
                    }
                    r1=r1;
                    goto fatbar_34_over;
                    fatbar_34:
                    r1 = (object *) 2562;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_402;
                      r1=r1;
                    } else {
                      goto fatbar_35;
                    }
                    r1=r1;
                    goto fatbar_35_over;
                    fatbar_35:
                    r1 = (object *) 3330;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_403;
                      r1=r1;
                    } else {
                      goto fatbar_36;
                    }
                    r1=r1;
                    goto fatbar_36_over;
                    fatbar_36:
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = top[202];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2399; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L2399:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    if PXLL_IS_TRUE(r1) {
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[46];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2400; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_358;
                      L2400:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } else {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object***) lenv) [1][1][2];
                      r2 = box((pxll_int)GET_CHAR(r2));
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      // def loop_1047_i4532_i4722_i4766
                      goto L2401;
                      FUN_loop_1047_i4532_i4722_i4766:
                        check_heap (0);
                        r0 = ((object*) lenv) [2];
                        r1 = (object *) 1;
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = (object *) 1;
                          r2 = ((object***) lenv) [1][1][2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
                            r1 = ((object*) lenv) [3];
                            r2 = (object *) 11522;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                            r1=r1;
                          } else {
                            r1 = ((object*) lenv) [3];
                            r1=r1;
                          }
                          r0[2] = r1;
                          r1 = top[54];
                          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = (object *) 15;
                          r2 = ((object**) lenv) [1][2];
                          r1 = box((pxll_int)unbox(r2)&unbox(r1));
                          r2 = top[157];
                          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                          r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r1;
                          t[2] = r0;
                          r0 = t;
                          lenv = lenv[1];
                          r0 = r0;
                          r1 = (object *) 7;
                          r2 = ((object*) lenv) [2];
                          r1 = box((pxll_int)unbox(r2)>>unbox(r1));
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_loop_1047_i4532_i4722_i4766;
                        }
                        PXLL_RETURN(0);
                      L2401:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_loop_1047_i4532_i4722_i4766; r3[2] = lenv;
                      r2[2] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = (object *) 1;
                      r4 = ((object**) lenv) [1][2];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)<unbox(r3))) {
                        r3 = ((object**) lenv) [1][2];
                        r4 = (object *) 1;
                        r3 = box((pxll_int)unbox(r4)-unbox(r3));
                        r3=r3;
                      } else {
                        r3 = ((object**) lenv) [1][2];
                        r3=r3;
                      }
                      r2[2] = r3;
                      r3 = (object *) constructed_408[0];
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2402; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_loop_1047_i4532_i4722_i4766;
                      L2402:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[3] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = ((object**) lenv) [1][3];
                      r3 = box((pxll_int)((pxll_string*)(r3))->len);
                      r2[2] = r3;
                      r3 = (object *) 5;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_404;
                        r3=r3;
                      } else {
                        goto fatbar_37;
                      }
                      r3=r3;
                      goto fatbar_37_over;
                      fatbar_37:
                      r3 = (object *) 3;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_405;
                        r3=r3;
                      } else {
                        goto fatbar_38;
                      }
                      r3=r3;
                      goto fatbar_38_over;
                      fatbar_38:
                      r3 = (object *) 1;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_406;
                        r3=r3;
                      } else {
                        goto fatbar_39;
                      }
                      r3=r3;
                      goto fatbar_39_over;
                      fatbar_39:
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = (object*) &constructed_407;
                      r3[2] = r4;
                      r4 = ((object****) lenv) [1][1][1][2];
                      r3[3] = r4;
                      r4 = top[14];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2403; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_error1_304;
                      L2403:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r3=r3;
                      fatbar_39_over: ;
                      r3=r3;
                      fatbar_38_over: ;
                      r3=r3;
                      fatbar_37_over: ;
                      r2[3] = r3;
                      r3 = (object*)TC_NIL;
                      r2[4] = r3;
                      r3 = ((object*) lenv) [4];
                      r4 = ((object**) lenv) [1][3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      r2[5] = r3;
                      r2 = ((object*) lenv) [5];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[2] = r2;
                      r2 = top[47];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2404; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                      L2404:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    }
                    r1=r1;
                    fatbar_36_over: ;
                    r1=r1;
                    fatbar_35_over: ;
                    r1=r1;
                    fatbar_34_over: ;
                    r1=r1;
                    fatbar_33_over: ;
                    r1=r1;
                    fatbar_32_over: ;
                    r0[2] = r1;
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = ((object*) lenv) [3];
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_4694_i4523_i4722_i4766;
                  } break;
                }
                PXLL_RETURN(0);
              L2397:
              r4 = allocate (TC_CLOSURE, 2);
              r4[1] = &&FUN_loop_4694_i4523_i4722_i4766; r4[2] = lenv;
              r3[2] = r4;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_398[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[55];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2405; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string__3elist_372;
              L2405:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2406; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_loop_4694_i4523_i4722_i4766;
              L2406:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              lenv = lenv[1];
              r3 = r3;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_397;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_396;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = ((object*) lenv) [9];
              r4 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_395;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r3 = ((object*) lenv) [11];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[12] = r3;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_394;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[13] = r3;
              r3 = ((object*) lenv) [13];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[14] = r3;
              r2 = ((object*) lenv) [14];
              r3 = (object*) &constructed_393;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2407; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2407:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2408; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2408:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            case (UOTAG(4)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = ((object**) lenv) [1][2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object***) lenv) [1][1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = (object*) &constructed_414;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2409; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2409:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2410; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2410:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 14);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2411; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2411:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2412; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2412:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][7];
              r4[2] = r5;
              r4 = (object *) 3;
              r5 = ((object*) lenv) [2];
              r4 = box((pxll_int)unbox(r5)-unbox(r4));
              lenv = lenv[1];
              r4 = r4;
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2413; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2413:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object********) lenv) [1][1][1][1][1][1][1][8];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2414; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2414:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_413;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_412;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = ((object*) lenv) [9];
              r4 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_411;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r3 = ((object*) lenv) [11];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[12] = r3;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_410;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[13] = r3;
              r3 = ((object*) lenv) [13];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[14] = r3;
              r2 = ((object*) lenv) [14];
              r3 = (object*) &constructed_409;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2415; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2415:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2416; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2416:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][8];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = (object *) 3;
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv = lenv[1];
              r0 = r0;
              ((object*******) lenv) [1][1][1][1][1][1][8] = r0;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_31;
            }
          }
          r0=r0;
          goto fatbar_31_over;
          fatbar_31:
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
          r2[2] = r3;
          r3 = ((object***) lenv) [1][1][2];
          r2[3] = r3;
          r3 = top[27];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2417; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
          L2417:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2418; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_4650_i4722_i4766;
          L2418:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][6];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_41[0];
          r1[3] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2419; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
          L2419:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object****) lenv) [1][1][1][2];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2420; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2420:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[15];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][5];
          r4[3] = r5;
          r5 = top[32];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L2421; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
          L2421:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_418;
          r3[3] = r4;
          r4 = top[48];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2422; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L2422:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_417;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_416;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = ((object*) lenv) [8];
          r3 = (object*) &constructed_415;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2423; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2423:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2424; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2424:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_31_over: ;
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4679_i4722_i4766;
        }
        PXLL_RETURN(0);
      L2392:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4679_i4722_i4766; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2425; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4679_i4722_i4766;
      L2425:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_392[0];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_33394_i4722_i4766
      goto L2426;
      FUN_lambda_33394_i4722_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 5);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][3];
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2427; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2427:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*)TC_NIL;
        r2[3] = r3;
        r3 = ((object*) lenv) [3];
        r4 = (object*) &constructed_391;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[4] = r3;
        r3 = ((object*) lenv) [4];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[5] = r3;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_390;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2428; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2428:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        ((object**) lenv) [1][2] = r0;
        PXLL_RETURN(0);
      L2426:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_33394_i4722_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[13];
      r0[3] = r1;
      r1 = top[68];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2429; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      L2429:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = allocate (TC_TUPLE, 2);
      r5 = ((object**) lenv) [1][2];
      r4[2] = r5;
      r5 = top[22];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2430; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_length_324;
      L2430:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = top[56];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2431; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L2431:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = top[15];
      r4[2] = r5;
      r5 = ((object**) lenv) [1][2];
      r4[3] = r5;
      r5 = top[32];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2432; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_336;
      L2432:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_389;
      r3[3] = r4;
      r4 = top[48];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2433; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
      L2433:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_388;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_387;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_386;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2434; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L2434:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2435; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2435:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = ((object*****) lenv) [1][1][1][1][42];
      r0 = ((pxll_vector*)r0)->val[3];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2436; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2436:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][42];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2437; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2437:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[10];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2438; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L2438:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r2 = (object *) 3;
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4636_i4723_i4766
      goto L2439;
      FUN__24loop_4636_i4723_i4766:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2440; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2440:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = (object*) &constructed_385;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_384;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2441; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2441:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][42];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2442; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2442:
          ; lenv = k[2]; k = k[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4636_i4723_i4766;
        }
        PXLL_RETURN(0);
      L2439:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4636_i4723_i4766; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2443; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4636_i4723_i4766;
      L2443:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_383;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2444; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2444:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_382;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2445; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2445:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_32756_i4723_i4766
      goto L2446;
      FUN_lambda_32756_i4723_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2447; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2447:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2448; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2448:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2449; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2449:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = ((object*) lenv) [5];
        r4 = (object*) &constructed_381;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = ((object*) lenv) [7];
        r4 = (object*) &constructed_380;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = ((object*) lenv) [8];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = ((object*) lenv) [9];
        r4 = (object*) &constructed_379;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = ((object*) lenv) [10];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = ((object*) lenv) [11];
        r3 = (object*) &constructed_378;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2450; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2450:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][42];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2446:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_32756_i4723_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[30];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2451; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_334;
      L2451:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_41[0];
      r1[3] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2452; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
      L2452:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r1 = r1;
      r0[3] = r1;
      r1 = top[35];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2453; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      L2453:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_377;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2454; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2454:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_376;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2455; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2455:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_375;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2456; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2456:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_32817_i4723_i4766
      goto L2457;
      FUN_lambda_32817_i4723_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2458; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2458:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2459; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2459:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[56];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2460; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2460:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = ((object*) lenv) [5];
        r4 = (object*) &constructed_374;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = ((object*) lenv) [7];
        r4 = (object*) &constructed_373;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = ((object*) lenv) [8];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = ((object*) lenv) [9];
        r4 = (object*) &constructed_372;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = ((object*) lenv) [10];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = ((object*) lenv) [11];
        r3 = (object*) &constructed_371;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2461; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2461:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][42];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2457:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_32817_i4723_i4766; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[30];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2462; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_334;
      L2462:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_41[0];
      r1[3] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2463; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_321;
      L2463:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r1 = r1;
      r0[3] = r1;
      r1 = top[35];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2464; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
      L2464:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_370;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2465; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2465:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [4];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][42];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2466; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2466:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 7);
      r0[1] = lenv; lenv = r0;
      // def emit_4261_i4724_i4766
      goto L2467;
      FUN_emit_4261_i4724_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2468; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2468:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_76;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_75;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2469; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2469:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2470; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2470:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2471; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2471:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[146];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2472; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_encode_immediate_564;
            L2472:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object *) -1;
            r3 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
              r2 = (object*) &constructed_79;
              r2=r2;
            } else {
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2473; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2473:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_80;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2474; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2474:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r2=r2;
            }
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 6);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2475; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2475:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_78;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_77;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r3 = ((object*) lenv) [6];
            r4 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2476; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2476:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2477; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2477:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(2)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2478; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2478:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = (object *) constructed_88[0];
              r2 = ((object**) lenv) [1][3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2479; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2479:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2480; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2480:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_83;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_82;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_81;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2481; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2481:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2482; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2482:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2483; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2483:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2484; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2484:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_86;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_85;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_84;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2485; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2485:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2486; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2486:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              }
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(4)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2487; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2487:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_92;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_91;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2488; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2488:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2489; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2489:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2490; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2490:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2491; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
            L2491:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2492; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2492:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_90;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2493; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2493:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2494; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2494:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2495; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
            L2495:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2496; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2496:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_89;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2497; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2497:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(5)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,1);
                r1[3] = r2;
                r1 = (object *) constructed_99[0];
                r2 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 6);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      // def lambda_29060_i3268_i4724_i4766
                      goto L2498;
                      FUN_lambda_29060_i3268_i4724_i4766:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][2];
                        r2[2] = r3;
                        r3 = top[56];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2499; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                        L2499:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_97;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[2] = r1;
                        r1 = top[47];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                      L2498:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_lambda_29060_i3268_i4724_i4766; r3[2] = lenv;
                      r2[2] = r3;
                      r3 = ((object***) lenv) [1][1][2];
                      r2[3] = r3;
                      r3 = top[32];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2500; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_map_336;
                      L2500:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[4] = r2;
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = top[147];
                      r2[2] = r3;
                      r3 = ((object*) lenv) [3];
                      r2[3] = r3;
                      r3 = ((object*) lenv) [4];
                      r2[4] = r3;
                      r3 = top[33];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2501; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_map2_337;
                      L2501:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[5] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object*) lenv) [2];
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = ((object***) lenv) [1][1][4];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [5];
                      r3[3] = r4;
                      r4 = top[150];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2502; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_568;
                      L2502:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = top[149];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2503; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_567;
                      L2503:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[6] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = allocate (TC_TUPLE, 4);
                      r3[1] = lenv; lenv = r3;
                      r4 = (object*)TC_NIL;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [2];
                      r5 = (object*) &constructed_96;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[3] = r4;
                      r4 = ((object*) lenv) [3];
                      r5 = ((object**) lenv) [1][6];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[4] = r4;
                      r3 = ((object*) lenv) [4];
                      r4 = (object*) &constructed_95;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      lenv = lenv[1];
                      r3 = r3;
                      r2[2] = r3;
                      r3 = top[47];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2504; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                      L2504:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2505; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2505:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2506; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2506:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object***) lenv) [1][1][5];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2507; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
                      L2507:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2508; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2508:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_94;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2509; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2509:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2510; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2510:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object***) lenv) [1][1][6];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2511; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
                      L2511:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2512; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2512:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_93;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2513; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2513:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_6;
                    }
                  }
                  r1=r1;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_6;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                goto fatbar_6;
              }
            }
            goto fatbar_6_over;
            fatbar_6:
            r1 = (object*) &constructed_73;
            r1 = box((pxll_int)((pxll_string*)(r1))->len);
            r2 = (object*) &constructed_73;
            (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
            r1 = (object*) &constructed_72;
            dump_object (r1, 0); fprintf (stdout, "\n");
            r1 = (object*) &constructed_72;
            PXLL_UNDEFINED; result=r1; goto Lreturn;
            fatbar_6_over: ;
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(6)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2514; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2514:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2515; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2515:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_102;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_101;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_100;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2516; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2516:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2517; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2517:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(3)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2518; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2518:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UOTAG(1)): {
                r2 = allocate (TC_TUPLE, 3);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,1);
                r2[3] = r3;
                r2 = (object *) constructed_99[0];
                r3 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = ((object*) lenv) [3];
                  switch (get_case (r2)) {
                    case (TC_PAIR): {
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = ((object**) lenv) [1][3];
                      r3 = UOBJ_GET(r3,0);
                      r2[2] = r3;
                      r3 = ((object**) lenv) [1][3];
                      r3 = UOBJ_GET(r3,1);
                      r2[3] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      // def lambda_29199_i3287_i4724_i4766
                      goto L2519;
                      FUN_lambda_29199_i3287_i4724_i4766:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][2];
                        r2[2] = r3;
                        r3 = top[56];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2520; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                        L2520:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_107;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[2] = r1;
                        r1 = top[47];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                      L2519:
                      r4 = allocate (TC_CLOSURE, 2);
                      r4[1] = &&FUN_lambda_29199_i3287_i4724_i4766; r4[2] = lenv;
                      r3[2] = r4;
                      r4 = ((object****) lenv) [1][1][1][5];
                      r3[3] = r4;
                      r4 = top[32];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2521; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_map_336;
                      L2521:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[4] = r3;
                      r3 = allocate (TC_TUPLE, 4);
                      r4 = top[147];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = ((object*) lenv) [4];
                      r3[4] = r4;
                      r4 = top[33];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2522; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_map2_337;
                      L2522:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[5] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object****) lenv) [1][1][1][3];
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = ((object****) lenv) [1][1][1][4];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [5];
                      r3[3] = r4;
                      r4 = top[150];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2523; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_568;
                      L2523:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = top[149];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2524; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_567;
                      L2524:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                      r2 = r2;
                      r2=r2;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_7;
                    }
                  }
                  r2=r2;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_7;
                }
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
              default: {
                goto fatbar_7;
              }
            }
            r2=r2;
            goto fatbar_7_over;
            fatbar_7:
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][4];
            r2[3] = r3;
            r3 = top[149];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2525; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_567;
            L2525:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r2=r2;
            fatbar_7_over: ;
            r1[3] = r2;
            r1 = (object *) -1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 3);
              r3[1] = lenv; lenv = r3;
              r4 = (object*)TC_NIL;
              r3[2] = r4;
              r4 = ((object*) lenv) [2];
              r5 = (object*) &constructed_103;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[3] = r4;
              r3 = ((object*) lenv) [3];
              r4 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2526; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2526:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2527; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2527:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2528; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2528:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_106;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = (object*) &constructed_105;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = ((object*) lenv) [7];
              r4 = (object*) &constructed_104;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2529; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2529:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2530; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2530:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(7)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2531; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2531:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object*****) lenv) [1][1][1][1][3];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2532; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_gen_function_label_4268_i4724_i4766;
            L2532:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[199];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2533; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2533:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = ((object***) lenv) [1][1][2];
            r4 = allocate (TC_TUPLE, 2);
            r4[1] = lenv; lenv = r4;
            r5 = ((object****) lenv) [1][1][1][2];
            r5 = UOBJ_GET(r5,0);
            r4[2] = r5;
            r4 = ((object*) lenv) [2];
            lenv = lenv[1];
            r4 = r4;
            r4=r4;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = (object*) &constructed_119;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2534; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2534:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2535; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2535:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_118;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = (object*) &constructed_117;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2536; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2536:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2537; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2537:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_116;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2538; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2538:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2539; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2539:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2540; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2540:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            r2[2] = r3;
            r3 = ((object***) lenv) [1][1][2];
            r2[3] = r3;
            r3 = top[5];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2541; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_257;
            L2541:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r2 = ((pxll_vector*)r2)->val[1];
            r1[3] = r2;
            r1 = top[155];
            r2 = ((object*) lenv) [3];
            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object*) &constructed_115;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2542; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2542:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2543; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
            L2543:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2544; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2544:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_114;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2545; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2545:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2546; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2546:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2547; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2547:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_113;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_112;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2548; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2548:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2549; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2549:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 10);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2550; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2550:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2551; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2551:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_111;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_110;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = ((object*) lenv) [8];
            r5 = (object*) &constructed_109;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = ((object*) lenv) [9];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r3 = ((object*) lenv) [10];
            r4 = (object*) &constructed_108;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2552; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2552:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2553; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2553:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(8)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2554; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2554:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) -1;
              r3 = ((object***) lenv) [1][1][2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object****) lenv) [1][1][1][3];
                r6 = (object *) 5;
                r5 = box((pxll_int)unbox(r6)+unbox(r5));
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2555; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2555:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_123;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_122;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2556; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2556:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } else {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 11);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 3);
                r6 = ((object****) lenv) [1][1][1][2];
                r5[2] = r6;
                r6 = (object*) &constructed_129;
                r5[3] = r6;
                r6 = top[31];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2557; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
                L2557:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[47];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2558; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
                L2558:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 3);
                r6 = ((object****) lenv) [1][1][1][2];
                r5[2] = r6;
                r6 = (object*) &constructed_128;
                r5[3] = r6;
                r6 = top[31];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2559; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
                L2559:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[47];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2560; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
                L2560:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = (object *) 5;
                r6 = ((object****) lenv) [1][1][1][3];
                r5 = box((pxll_int)unbox(r6)+unbox(r5));
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2561; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2561:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[4] = r4;
                r4 = (object*)TC_NIL;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = (object*) &constructed_127;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = (object*) &constructed_126;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r4 = ((object*) lenv) [8];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[9] = r4;
                r4 = ((object*) lenv) [9];
                r5 = (object*) &constructed_125;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[10] = r4;
                r4 = ((object*) lenv) [10];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[11] = r4;
                r3 = ((object*) lenv) [11];
                r4 = (object*) &constructed_124;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2562; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2562:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              }
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2563; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2563:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_121;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_120;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2564; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2564:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2565; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2565:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(9)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = (object *) -1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][3];
              r6 = (object *) 5;
              r5 = box((pxll_int)unbox(r6)+unbox(r5));
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2566; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2566:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2567; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2567:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_132;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_131;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_130;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2568; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2568:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2569; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2569:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 14);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][2];
              r5[2] = r6;
              r6 = (object*) &constructed_139;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2570; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2570:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2571; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2571:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][2];
              r5[2] = r6;
              r6 = (object*) &constructed_138;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2572; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2572:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2573; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2573:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = (object *) 5;
              r6 = ((object**) lenv) [1][3];
              r5 = box((pxll_int)unbox(r6)+unbox(r5));
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2574; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2574:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2575; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2575:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[5] = r4;
              r4 = (object*)TC_NIL;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_137;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_136;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_135;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r4 = ((object*) lenv) [12];
              r5 = (object*) &constructed_134;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[13] = r4;
              r4 = ((object*) lenv) [13];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[14] = r4;
              r3 = ((object*) lenv) [14];
              r4 = (object*) &constructed_133;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2576; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2576:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2577; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2577:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(10)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2578; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2578:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2579; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2579:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = (object *) 3;
            r6 = ((object***) lenv) [1][1][2];
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2580; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2580:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_144;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_143;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = ((object*) lenv) [8];
            r4 = (object*) &constructed_142;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2581; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2581:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2582; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2582:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = top[201];
            if PXLL_IS_TRUE(r1) {
              r1 = (object *) 6;
              top[201] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2583; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2583:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_141;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_140;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2584; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2584:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2585; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2585:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(11)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2586; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2586:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = top[56];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2587; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                L2587:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 6);
                r3[1] = lenv; lenv = r3;
                r4 = (object *) 1;
                r5 = ((object****) lenv) [1][1][1][3];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)==unbox(r4))) {
                  r4 = (object*) &constructed_153;
                  r4=r4;
                } else {
                  r4 = (object*) &constructed_154;
                  r4=r4;
                }
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2588; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2588:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_152;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r3 = ((object*) lenv) [6];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2589; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2589:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2590; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2590:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_147;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = (object*) &constructed_146;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = ((object*) lenv) [7];
              r4 = (object*) &constructed_145;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2591; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2591:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2592; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2592:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 10);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2593; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2593:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2594; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2594:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_151;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_150;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_149;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_148;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2595; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2595:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2596; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2596:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(12)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 11);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][4];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2597; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2597:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = allocate (TC_TUPLE, 2);
            r5[1] = lenv; lenv = r5;
            r6 = ((object***) lenv) [1][1][2];
            r7 = ((object***) lenv) [1][1][5];
            r6 = box((pxll_int)unbox(r7)+unbox(r6));
            r5[2] = r6;
            r5 = ((object*) lenv) [2];
            r6 = (object *) 3;
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            lenv = lenv[1];
            r5 = r5;
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2598; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2598:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2599; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2599:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[4] = r4;
            r4 = (object*)TC_NIL;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_158;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = (object*) &constructed_157;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = ((object*) lenv) [8];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = ((object*) lenv) [9];
            r5 = (object*) &constructed_156;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r4 = ((object*) lenv) [10];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[11] = r4;
            r3 = ((object*) lenv) [11];
            r4 = (object*) &constructed_155;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2600; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2600:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2601; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2601:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(13)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = top[11];
            r2[2] = r3;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object**) lenv) [1][5];
            r3[2] = r4;
            r4 = top[135];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2602; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_528;
            L2602:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[3] = r3;
            r3 = top[44];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2603; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_sort_350;
            L2603:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[199];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2604; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2604:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2605; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
            L2605:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][5];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2606; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2606:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][4];
            r6 = (object *) 7;
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2607; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2607:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_184;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_183;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2608; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2608:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2609; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2609:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4456_i3416_i4724_i4766
            goto L2610;
            FUN__24loop_4456_i3416_i4724_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_41[0];
                r0[3] = r1;
                r1 = top[21];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 7);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = ((object***) lenv) [1][1][2];
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2611; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2611:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][2];
                r4[2] = r5;
                r5 = ((object***) lenv) [1][1][2];
                r4[3] = r5;
                r5 = top[27];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2612; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_331;
                L2612:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2613; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2613:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_182;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r2 = ((object*) lenv) [7];
                r3 = (object*) &constructed_181;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2614; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2614:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4456_i3416_i4724_i4766;
              }
              PXLL_RETURN(0);
            L2610:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4456_i3416_i4724_i4766; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2615; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4456_i3416_i4724_i4766;
            L2615:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 7);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = (object*) &constructed_180;
            r4[3] = r5;
            r5 = top[48];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2616; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_363;
            L2616:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_179;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_178;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = ((object***) lenv) [1][1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r3 = ((object*) lenv) [7];
            r4 = (object*) &constructed_177;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2617; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2617:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2618; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2618:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object****) lenv) [1][1][1][3];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2619; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2619:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_174;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_173;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2620; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2620:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object****) lenv) [1][1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2621; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4268_i4724_i4766;
                L2621:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_176;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_175;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2622; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2622:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object***) lenv) [1][1][4];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2623; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2623:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2624; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2624:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2625; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2625:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_170;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_169;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_168;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_167;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2626; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2626:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2627; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2627:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2628; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2628:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_172;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_171;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2629; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2629:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2630; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2630:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_166;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2631; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2631:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2632; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2632:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4463_i3416_i4724_i4766
            goto L2633;
            FUN__24loop_4463_i3416_i4724_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_41[0];
                r0[3] = r1;
                r1 = top[21];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_321;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][2];
                r4[2] = r5;
                r5 = ((object***) lenv) [1][1][2];
                r4[3] = r5;
                r5 = top[27];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2634; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_331;
                L2634:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2635; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2635:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = ((object***) lenv) [1][1][2];
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2636; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2636:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_165;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = (object*) &constructed_164;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = ((object*) lenv) [7];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = ((object*) lenv) [8];
                r3 = (object*) &constructed_163;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2637; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2637:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4463_i3416_i4724_i4766;
              }
              PXLL_RETURN(0);
            L2633:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4463_i3416_i4724_i4766; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2638; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4463_i3416_i4724_i4766;
            L2638:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = (object*) &constructed_162;
            r4[3] = r5;
            r5 = top[48];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2639; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_363;
            L2639:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_161;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2640; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2640:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2641; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2641:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object *) 1;
            r2 = ((object*) lenv) [5];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][5];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2642; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2642:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_160;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_159;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2643; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2643:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2644; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2644:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(14)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][3];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2645; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2645:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_192;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_191;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2646; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2646:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = ((object*******) lenv) [1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2647; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4268_i4724_i4766;
                L2647:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_194;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_193;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2648; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2648:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][4];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2649; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2649:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2650; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2650:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][4];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2651; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2651:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_188;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_187;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_186;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_185;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2652; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2652:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2653; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2653:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2654; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2654:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_190;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_189;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2655; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2655:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2656; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2656:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(15)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2657; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
            L2657:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object *) 3;
            r3 = ((object**) lenv) [1][2];
            r2 = box((pxll_int)unbox(r3)-unbox(r2));
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              ((object*) lenv) [3] = r1;
            } else {
              r1 = (object *) 14;
            }
            r1 = (object *) 1;
            r2 = ((object*) lenv) [3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_204;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2658; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2658:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2659; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2659:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_203;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2660; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2660:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2661; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2661:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_202;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_201;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_200;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2662; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2662:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2663; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2663:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4473_i3510_i4724_i4766
            goto L2664;
            FUN__24loop_4473_i3510_i4724_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object**) lenv) [1][2];
                r5 = (object *) 5;
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2665; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2665:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][4];
                r4[2] = r5;
                r5 = ((object**) lenv) [1][2];
                r4[3] = r5;
                r5 = top[27];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2666; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_331;
                L2666:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2667; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2667:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_199;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = (object*) &constructed_198;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = ((object*) lenv) [7];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = ((object*) lenv) [8];
                r3 = (object*) &constructed_197;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2668; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2668:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2669; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2669:
                ; lenv = k[2]; k = k[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4473_i3510_i4724_i4766;
              }
              PXLL_RETURN(0);
            L2664:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4473_i3510_i4724_i4766; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2670; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4473_i3510_i4724_i4766;
            L2670:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object***) lenv) [1][1][3];
            r4[2] = r5;
            r5 = ((object******) lenv) [1][1][1][1][1][3];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2671; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4268_i4724_i4766;
            L2671:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_196;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_195;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2672; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2672:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2673; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2673:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(16)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2674; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2674:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2675; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2675:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_207;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_206;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = ((object*) lenv) [8];
            r4 = (object*) &constructed_205;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2676; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2676:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2677; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2677:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(17)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2678; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2678:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_211;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2679; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2679:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2680; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2680:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2681; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2681:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_210;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_209;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_208;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2682; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2682:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2683; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2683:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(18)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def primop-error_4502_i3550_i4724_i4766
            goto L2684;
            FUN_primop_error_4502_i3550_i4724_i4766:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_226;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[14];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_304;
            L2684:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_primop_error_4502_i3550_i4724_i4766; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object***) lenv) [1][1][6];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2685; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2685:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object***) lenv) [1][1][5];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2686; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
            L2686:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = (object *) constructed_228[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [3];
                          switch (get_case (r1)) {
                            case (TC_NIL): {
                              r1 = ((object******) lenv) [1][1][1][1][1][4];
                              switch (get_case (r1)) {
                                case (UOTAG(1)): {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[3] = r2;
                                  r1 = (object *) constructed_99[0];
                                  r2 = ((object*) lenv) [2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = ((object*) lenv) [3];
                                    switch (get_case (r1)) {
                                      case (TC_PAIR): {
                                        r1 = allocate (TC_TUPLE, 3);
                                        r1[1] = lenv; lenv = r1;
                                        r2 = ((object**) lenv) [1][3];
                                        r2 = UOBJ_GET(r2,0);
                                        r1[2] = r2;
                                        r2 = ((object**) lenv) [1][3];
                                        r2 = UOBJ_GET(r2,1);
                                        r1[3] = r2;
                                        r1 = ((object*) lenv) [3];
                                        switch (get_case (r1)) {
                                          case (TC_PAIR): {
                                            r1 = allocate (TC_TUPLE, 3);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = ((object**) lenv) [1][3];
                                            r2 = UOBJ_GET(r2,0);
                                            r1[2] = r2;
                                            r2 = ((object**) lenv) [1][3];
                                            r2 = UOBJ_GET(r2,1);
                                            r1[3] = r2;
                                            r1 = ((object*) lenv) [3];
                                            switch (get_case (r1)) {
                                              case (TC_NIL): {
                                                r1 = allocate (TC_TUPLE, 4);
                                                r1[1] = lenv; lenv = r1;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 4);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object******) lenv) [1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[56];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2687; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                L2687:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[2] = r4;
                                                r4 = (object*)TC_NIL;
                                                r3[3] = r4;
                                                r4 = ((object*) lenv) [3];
                                                r5 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[4] = r4;
                                                r3 = ((object*) lenv) [4];
                                                r4 = (object*) &constructed_225;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r3 = r3;
                                                r2[2] = r3;
                                                r3 = top[47];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2688; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                L2688:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[2] = r2;
                                                r2 = ((object***) lenv) [1][1][2];
                                                switch (get_case (r2)) {
                                                  case (UOTAG(1)): {
                                                    r2 = allocate (TC_TUPLE, 2);
                                                    r2[1] = lenv; lenv = r2;
                                                    r3 = ((object****) lenv) [1][1][1][2];
                                                    r3 = UOBJ_GET(r3,0);
                                                    r2[2] = r3;
                                                    r2 = ((object***) lenv) [1][1][2];
                                                    switch (get_case (r2)) {
                                                      case (UOTAG(1)): {
                                                        r2 = allocate (TC_TUPLE, 2);
                                                        r2[1] = lenv; lenv = r2;
                                                        r3 = ((object****) lenv) [1][1][1][2];
                                                        r3 = UOBJ_GET(r3,0);
                                                        r2[2] = r3;
                                                        r2 = (object *) constructed_223[0];
                                                        r3 = ((object*) lenv) [2];
                                                        if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                                                          r2 = allocate (TC_TUPLE, 3);
                                                          r3 = ((object**) lenv) [1][2];
                                                          r2[2] = r3;
                                                          r3 = top[200];
                                                          r2[3] = r3;
                                                          r3 = top[25];
                                                          t = allocate (TC_SAVE, 5);
                                                          t[1] = k; t[2] = lenv; t[3] = &&L2689; t[4] = r0; t[5] = r1; k = t;
                                                          r2[1] = r3[2]; lenv = r2; goto FUN_member_eq_question_329;
                                                          L2689:
                                                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                          r2 = result;
                                                          if PXLL_IS_TRUE(r2) {
                                                            r2 = allocate (TC_TUPLE, 2);
                                                            r3 = allocate (TC_TUPLE, 7);
                                                            r3[1] = lenv; lenv = r3;
                                                            r4 = ((object***) lenv) [1][1][2];
                                                            r4 = allocate (TC_TUPLE, 2);
                                                            r4[1] = lenv; lenv = r4;
                                                            r5 = ((object****) lenv) [1][1][1][2];
                                                            r5 = UOBJ_GET(r5,0);
                                                            r4[2] = r5;
                                                            r4 = ((object*) lenv) [2];
                                                            lenv = lenv[1];
                                                            r4 = r4;
                                                            r4=r4;
                                                            r3[2] = r4;
                                                            r4 = (object*)TC_NIL;
                                                            r3[3] = r4;
                                                            r4 = ((object*) lenv) [3];
                                                            r5 = (object*) &constructed_220;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[4] = r4;
                                                            r4 = ((object*) lenv) [4];
                                                            r5 = ((object****) lenv) [1][1][1][2];
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[5] = r4;
                                                            r4 = ((object*) lenv) [5];
                                                            r5 = (object*) &constructed_219;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[6] = r4;
                                                            r4 = ((object*) lenv) [6];
                                                            r5 = ((object*) lenv) [2];
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[7] = r4;
                                                            r3 = ((object*) lenv) [7];
                                                            r4 = (object*) &constructed_218;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r4;
                                                            t[2] = r3;
                                                            r3 = t;
                                                            lenv = lenv[1];
                                                            r3 = r3;
                                                            r2[2] = r3;
                                                            r3 = top[47];
                                                            t = allocate (TC_SAVE, 5);
                                                            t[1] = k; t[2] = lenv; t[3] = &&L2690; t[4] = r0; t[5] = r1; k = t;
                                                            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                            L2690:
                                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                            r2 = result;
                                                            r2=r2;
                                                          } else {
                                                            r2 = allocate (TC_TUPLE, 3);
                                                            r3 = (object*) &constructed_221;
                                                            r2[2] = r3;
                                                            r3 = ((object**) lenv) [1][2];
                                                            r2[3] = r3;
                                                            r3 = top[14];
                                                            t = allocate (TC_SAVE, 5);
                                                            t[1] = k; t[2] = lenv; t[3] = &&L2691; t[4] = r0; t[5] = r1; k = t;
                                                            r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                                                            L2691:
                                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                            r2 = result;
                                                            r2=r2;
                                                          }
                                                          r2=r2;
                                                        } else {
                                                          lenv = ((object **)lenv)[1][1];
                                                          goto fatbar_10;
                                                        }
                                                        lenv = lenv[1];
                                                        r2 = r2;
                                                        r2=r2;
                                                      } break;
                                                      default: {
                                                        lenv = ((object *)lenv)[1];
                                                        goto fatbar_10;
                                                      }
                                                    }
                                                    lenv = lenv[1];
                                                    r2 = r2;
                                                    r2=r2;
                                                  } break;
                                                  default: {
                                                    goto fatbar_10;
                                                  }
                                                }
                                                r2=r2;
                                                goto fatbar_10_over;
                                                fatbar_10:
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = (object*) &constructed_224;
                                                r2[2] = r3;
                                                r3 = allocate (UOTAG(1), 2);
                                                r4 = ((object***) lenv) [1][1][2];
                                                r3[1] = r4;
                                                r4 = ((object**) lenv) [1][2];
                                                r3[2] = r4;
                                                r2[3] = r3;
                                                r3 = top[14];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2692; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_error1_304;
                                                L2692:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r2=r2;
                                                fatbar_10_over: ;
                                                r1[3] = r2;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 11);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object****) lenv) [1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[106];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2693; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_type_repr_468;
                                                L2693:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[2] = r4;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[56];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2694; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                L2694:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[3] = r4;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[56];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2695; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                L2695:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[4] = r4;
                                                r4 = (object*)TC_NIL;
                                                r3[5] = r4;
                                                r4 = ((object*) lenv) [5];
                                                r5 = (object*) &constructed_217;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[6] = r4;
                                                r4 = ((object*) lenv) [6];
                                                r5 = ((object*) lenv) [4];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[7] = r4;
                                                r4 = ((object*) lenv) [7];
                                                r5 = (object*) &constructed_216;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[8] = r4;
                                                r4 = ((object*) lenv) [8];
                                                r5 = ((object*) lenv) [3];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[9] = r4;
                                                r4 = ((object*) lenv) [9];
                                                r5 = (object*) &constructed_215;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[10] = r4;
                                                r4 = ((object*) lenv) [10];
                                                r5 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[11] = r4;
                                                r3 = ((object*) lenv) [11];
                                                r4 = (object*) &constructed_214;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r3 = r3;
                                                r2[2] = r3;
                                                r3 = top[47];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2696; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                L2696:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[4] = r2;
                                                r1 = allocate (TC_TUPLE, 2);
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 5);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = (object*)TC_NIL;
                                                r3[2] = r4;
                                                r4 = ((object*) lenv) [2];
                                                r5 = (object*) &constructed_213;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[3] = r4;
                                                r4 = ((object*) lenv) [3];
                                                r5 = ((object**) lenv) [1][3];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[4] = r4;
                                                r4 = ((object*) lenv) [4];
                                                r5 = (object*) &constructed_212;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[5] = r4;
                                                r3 = ((object*) lenv) [5];
                                                r4 = ((object**) lenv) [1][4];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r3 = r3;
                                                r2[2] = r3;
                                                r3 = top[47];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2697; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                L2697:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[2] = r2;
                                                r2 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                                r2 = ((pxll_vector*)r2)->val[4];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2698; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                L2698:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                lenv = lenv[1];
                                                r1 = r1;
                                                r1=r1;
                                              } break;
                                              default: {
                                                lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                goto fatbar_9;
                                              }
                                            }
                                            lenv = lenv[1];
                                            r1 = r1;
                                            r1=r1;
                                          } break;
                                          default: {
                                            lenv = ((object *****)lenv)[1][1][1][1][1];
                                            goto fatbar_9;
                                          }
                                        }
                                        lenv = lenv[1];
                                        r1 = r1;
                                        r1=r1;
                                      } break;
                                      default: {
                                        lenv = ((object ****)lenv)[1][1][1][1];
                                        goto fatbar_9;
                                      }
                                    }
                                    r1=r1;
                                  } else {
                                    lenv = ((object ****)lenv)[1][1][1][1];
                                    goto fatbar_9;
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_9;
                                }
                              }
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_9;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_9;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_9;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_9;
                }
              }
              r1=r1;
              goto fatbar_9_over;
              fatbar_9:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2699; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2699:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_9_over: ;
              r1=r1;
            } else {
              goto fatbar_8;
            }
            r1=r1;
            goto fatbar_8_over;
            fatbar_8:
            r1 = (object *) constructed_237[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 11);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r4[2] = r5;
                          r5 = top[106];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2700; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_type_repr_468;
                          L2700:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2701; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2701:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2702; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2702:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = (object*)TC_NIL;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = (object*) &constructed_235;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = ((object*) lenv) [4];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = (object*) &constructed_234;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r4 = ((object*) lenv) [8];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[9] = r4;
                          r4 = ((object*) lenv) [9];
                          r5 = (object*) &constructed_233;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[10] = r4;
                          r4 = ((object*) lenv) [10];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[11] = r4;
                          r3 = ((object*) lenv) [11];
                          r4 = (object*) &constructed_232;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2703; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2703:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2704; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2704:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r4[2] = r5;
                          r5 = ((object**) lenv) [1][2];
                          r4[3] = r5;
                          r5 = top[149];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2705; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_wrap_out_567;
                          L2705:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_231;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_230;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_229;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2706; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2706:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2707; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2707:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_12;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_12;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_12;
                }
              }
              r1=r1;
              goto fatbar_12_over;
              fatbar_12:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2708; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2708:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_12_over: ;
              r1=r1;
            } else {
              goto fatbar_11;
            }
            r1=r1;
            goto fatbar_11_over;
            fatbar_11:
            r1 = (object *) constructed_241[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = ((object****) lenv) [1][1][1][5];
              r5[2] = r6;
              r6 = top[19];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2709; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_car_319;
              L2709:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2710; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2710:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_239;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_238;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2711; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2711:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2712; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2712:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              goto fatbar_13;
            }
            r1=r1;
            goto fatbar_13_over;
            fatbar_13:
            r1 = (object *) constructed_248[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object****) lenv) [1][1][1][3];
              r2[2] = r3;
              r3 = top[194];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2713; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              lenv = r3[2]; goto *r3[1];
              L2713:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = top[110];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2714; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_parse_type_splat_473;
              L2714:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object**) lenv) [1][2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 11);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2715; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2715:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[148];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2716; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_irken_type__3ec_type_566;
                L2716:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 2);
                r6 = ((object*****) lenv) [1][1][1][1][5];
                r5[2] = r6;
                r6 = top[19];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2717; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_car_319;
                L2717:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2718; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2718:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[4] = r4;
                r4 = (object*)TC_NIL;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = (object*) &constructed_245;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = (object*) &constructed_244;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r4 = ((object*) lenv) [8];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[9] = r4;
                r4 = ((object*) lenv) [9];
                r5 = (object*) &constructed_243;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[10] = r4;
                r4 = ((object*) lenv) [10];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[11] = r4;
                r3 = ((object*) lenv) [11];
                r4 = (object*) &constructed_242;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2719; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2719:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2720; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2720:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 3);
                r2 = (object*) &constructed_246;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[14];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2721; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                L2721:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } else {
              goto fatbar_14;
            }
            r1=r1;
            goto fatbar_14_over;
            fatbar_14:
            r1 = (object *) constructed_253[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = allocate (TC_TUPLE, 2);
              r7 = ((object****) lenv) [1][1][1][6];
              r6[2] = r7;
              r7 = top[135];
              t = allocate (TC_SAVE, 9);
              t[1] = k; t[2] = lenv; t[3] = &&L2722; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; t[9] = r5; k = t;
              r6[1] = r7[2]; lenv = r6; goto FUN_k_2ffree_528;
              L2722:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; r5 = k[9]; lenv = k[2]; k = k[1];
              r6 = result;
              r5[2] = r6;
              r6 = top[22];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2723; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_length_324;
              L2723:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2724; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2724:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = ((object****) lenv) [1][1][1][5];
              r5[2] = r6;
              r6 = top[19];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2725; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_car_319;
              L2725:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2726; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2726:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_251;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_250;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_249;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2727; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2727:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2728; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2728:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              goto fatbar_15;
            }
            r1=r1;
            goto fatbar_15_over;
            fatbar_15:
            r1 = (object *) constructed_264[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = ((object**) lenv) [1][3];
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = ((object*) lenv) [2];
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object**) lenv) [1][2];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = ((object**) lenv) [1][3];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_PAIR): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = ((object**) lenv) [1][3];
                                              r2 = UOBJ_GET(r2,0);
                                              r1[2] = r2;
                                              r2 = ((object**) lenv) [1][3];
                                              r2 = UOBJ_GET(r2,1);
                                              r1[3] = r2;
                                              r1 = ((object*) lenv) [3];
                                              switch (get_case (r1)) {
                                                case (TC_NIL): {
                                                  r1 = allocate (TC_TUPLE, 3);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = allocate (TC_TUPLE, 3);
                                                  r3 = ((object******) lenv) [1][1][1][1][1][2];
                                                  r2[2] = r3;
                                                  r3 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                                  r2[3] = r3;
                                                  r3 = top[9];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2729; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_264;
                                                  L2729:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = ((object****) lenv) [1][1][1][2];
                                                  r2[2] = r3;
                                                  r3 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][4];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2730; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4281_i4724_i4766;
                                                  L2730:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[3] = r2;
                                                  r1 = ((object*) lenv) [3];
                                                  switch (get_case (r1)) {
                                                    case (UOTAG(0)): {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = ((object**) lenv) [1][3];
                                                      r2 = UOBJ_GET(r2,0);
                                                      r1[2] = r2;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 11);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object*****) lenv) [1][1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2731; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2731:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = allocate (TC_TUPLE, 3);
                                                      r6 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                      r5[2] = r6;
                                                      r6 = ((object**) lenv) [1][2];
                                                      r5[3] = r6;
                                                      r6 = top[28];
                                                      t = allocate (TC_SAVE, 8);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2732; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                      r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_332;
                                                      L2732:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                      r5 = result;
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2733; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2733:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2734; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2734:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[5] = r4;
                                                      r4 = ((object*) lenv) [5];
                                                      r5 = (object*) &constructed_257;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[6] = r4;
                                                      r4 = ((object*) lenv) [6];
                                                      r5 = ((object*) lenv) [4];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = ((object*) lenv) [7];
                                                      r5 = (object*) &constructed_256;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = ((object*) lenv) [8];
                                                      r5 = ((object*) lenv) [3];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = ((object*) lenv) [9];
                                                      r5 = (object*) &constructed_255;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = ((object*) lenv) [10];
                                                      r5 = ((object*) lenv) [2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r3 = ((object*) lenv) [11];
                                                      r4 = (object*) &constructed_254;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r3 = r3;
                                                      r2[2] = r3;
                                                      r3 = top[47];
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2735; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                      L2735:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = ((object******************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2736; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2736:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      lenv = lenv[1];
                                                      r1 = r1;
                                                      r1=r1;
                                                    } break;
                                                    default: {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 14);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2737; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2737:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2738; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2738:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object**) lenv) [1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2739; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2739:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object***) lenv) [1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[56];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2740; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2740:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[5] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[6] = r4;
                                                      r4 = ((object*) lenv) [6];
                                                      r5 = (object*) &constructed_262;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = ((object*) lenv) [7];
                                                      r5 = ((object*) lenv) [5];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = ((object*) lenv) [8];
                                                      r5 = (object*) &constructed_261;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = ((object*) lenv) [9];
                                                      r5 = ((object*) lenv) [4];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = ((object*) lenv) [10];
                                                      r5 = (object*) &constructed_260;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r4 = ((object*) lenv) [11];
                                                      r5 = ((object*) lenv) [3];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[12] = r4;
                                                      r4 = ((object*) lenv) [12];
                                                      r5 = (object*) &constructed_259;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[13] = r4;
                                                      r4 = ((object*) lenv) [13];
                                                      r5 = ((object*) lenv) [2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[14] = r4;
                                                      r3 = ((object*) lenv) [14];
                                                      r4 = (object*) &constructed_258;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r3 = r3;
                                                      r2[2] = r3;
                                                      r3 = top[47];
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2741; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                      L2741:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2742; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2742:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      r1=r1;
                                                    } break;
                                                  }
                                                  lenv = lenv[1];
                                                  r1 = r1;
                                                  r1=r1;
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_17;
                                                }
                                              }
                                              lenv = lenv[1];
                                              r1 = r1;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_17;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_17;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_17;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_17;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_17;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_17;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_17;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_17;
                }
              }
              r1=r1;
              goto fatbar_17_over;
              fatbar_17:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2743; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2743:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_17_over: ;
              r1=r1;
            } else {
              goto fatbar_16;
            }
            r1=r1;
            goto fatbar_16_over;
            fatbar_16:
            r1 = (object *) constructed_275[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = ((object**) lenv) [1][3];
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = ((object*) lenv) [2];
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object**) lenv) [1][2];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = ((object**) lenv) [1][3];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = ((object*****) lenv) [1][1][1][1][2];
                                              r2[2] = r3;
                                              r3 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                              r2[3] = r3;
                                              r3 = top[9];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2744; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_264;
                                              L2744:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = ((object***) lenv) [1][1][2];
                                              r2[2] = r3;
                                              r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][4];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2745; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4281_i4724_i4766;
                                              L2745:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r1 = ((object*) lenv) [3];
                                              switch (get_case (r1)) {
                                                case (UOTAG(0)): {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = ((object**) lenv) [1][3];
                                                  r2 = UOBJ_GET(r2,0);
                                                  r1[2] = r2;
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 11);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2746; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2746:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object****) lenv) [1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2747; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2747:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = allocate (TC_TUPLE, 3);
                                                  r6 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                  r5[2] = r6;
                                                  r6 = ((object**) lenv) [1][2];
                                                  r5[3] = r6;
                                                  r6 = top[28];
                                                  t = allocate (TC_SAVE, 8);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2748; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                  r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_332;
                                                  L2748:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                  r5 = result;
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2749; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2749:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[5] = r4;
                                                  r4 = ((object*) lenv) [5];
                                                  r5 = (object*) &constructed_268;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[6] = r4;
                                                  r4 = ((object*) lenv) [6];
                                                  r5 = ((object*) lenv) [4];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = ((object*) lenv) [7];
                                                  r5 = (object*) &constructed_267;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = ((object*) lenv) [8];
                                                  r5 = ((object*) lenv) [3];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = ((object*) lenv) [9];
                                                  r5 = (object*) &constructed_266;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = ((object*) lenv) [10];
                                                  r5 = ((object*) lenv) [2];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r3 = ((object*) lenv) [11];
                                                  r4 = (object*) &constructed_265;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r3 = r3;
                                                  r2[2] = r3;
                                                  r3 = top[47];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2750; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                  L2750:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2751; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2751:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                  lenv = lenv[1];
                                                  r1 = r1;
                                                  r1=r1;
                                                } break;
                                                default: {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 14);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2752; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2752:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object***) lenv) [1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2753; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2753:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object***) lenv) [1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2754; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2754:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object**) lenv) [1][2];
                                                  r4[2] = r5;
                                                  r5 = top[56];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2755; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2755:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[5] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[6] = r4;
                                                  r4 = ((object*) lenv) [6];
                                                  r5 = (object*) &constructed_273;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = ((object*) lenv) [7];
                                                  r5 = ((object*) lenv) [5];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = ((object*) lenv) [8];
                                                  r5 = (object*) &constructed_272;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = ((object*) lenv) [9];
                                                  r5 = ((object*) lenv) [4];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = ((object*) lenv) [10];
                                                  r5 = (object*) &constructed_271;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r4 = ((object*) lenv) [11];
                                                  r5 = ((object*) lenv) [3];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[12] = r4;
                                                  r4 = ((object*) lenv) [12];
                                                  r5 = (object*) &constructed_270;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[13] = r4;
                                                  r4 = ((object*) lenv) [13];
                                                  r5 = ((object*) lenv) [2];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[14] = r4;
                                                  r3 = ((object*) lenv) [14];
                                                  r4 = (object*) &constructed_269;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r3 = r3;
                                                  r2[2] = r3;
                                                  r3 = top[47];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2756; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                  L2756:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2757; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2757:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                  r1=r1;
                                                } break;
                                              }
                                              lenv = lenv[1];
                                              r1 = r1;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_19;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_19;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_19;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_19;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_19;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_19;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_19;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_19;
                }
              }
              r1=r1;
              goto fatbar_19_over;
              fatbar_19:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2758; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2758:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_19_over: ;
              r1=r1;
            } else {
              goto fatbar_18;
            }
            r1=r1;
            goto fatbar_18_over;
            fatbar_18:
            r1 = (object *) constructed_284[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [3];
                          switch (get_case (r1)) {
                            case (TC_NIL): {
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 8);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object****) lenv) [1][1][1][2];
                              r4[2] = r5;
                              r5 = top[56];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2759; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2759:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object***) lenv) [1][1][2];
                              r4[2] = r5;
                              r5 = top[56];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2760; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2760:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = (object*)TC_NIL;
                              r3[4] = r4;
                              r4 = ((object*) lenv) [4];
                              r5 = (object*) &constructed_282;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[5] = r4;
                              r4 = ((object*) lenv) [5];
                              r5 = ((object*) lenv) [3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = ((object*) lenv) [6];
                              r5 = (object*) &constructed_281;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = ((object*) lenv) [7];
                              r5 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r3 = ((object*) lenv) [8];
                              r4 = (object*) &constructed_280;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r3 = r3;
                              r2[2] = r3;
                              r3 = top[47];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2761; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                              L2761:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2762; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2762:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 11);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object****) lenv) [1][1][1][2];
                              r4[2] = r5;
                              r5 = top[56];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2763; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2763:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object***) lenv) [1][1][2];
                              r4[2] = r5;
                              r5 = top[56];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2764; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2764:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object**) lenv) [1][2];
                              r4[2] = r5;
                              r5 = top[56];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2765; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2765:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[4] = r4;
                              r4 = (object*)TC_NIL;
                              r3[5] = r4;
                              r4 = ((object*) lenv) [5];
                              r5 = (object*) &constructed_279;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = ((object*) lenv) [6];
                              r5 = ((object*) lenv) [4];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = ((object*) lenv) [7];
                              r5 = (object*) &constructed_278;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r4 = ((object*) lenv) [8];
                              r5 = ((object*) lenv) [3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[9] = r4;
                              r4 = ((object*) lenv) [9];
                              r5 = (object*) &constructed_277;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[10] = r4;
                              r4 = ((object*) lenv) [10];
                              r5 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[11] = r4;
                              r3 = ((object*) lenv) [11];
                              r4 = (object*) &constructed_276;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r3 = r3;
                              r2[2] = r3;
                              r3 = top[47];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2766; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                              L2766:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2767; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2767:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_21;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_21;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_21;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_21;
                }
              }
              r1=r1;
              goto fatbar_21_over;
              fatbar_21:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2768; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2768:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_21_over: ;
              r1=r1;
            } else {
              goto fatbar_20;
            }
            r1=r1;
            goto fatbar_20_over;
            fatbar_20:
            r1 = (object *) constructed_293[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2769; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2769:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2770; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2770:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_291;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_290;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_289;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2771; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2771:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2772; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2772:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 11);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2773; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2773:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2774; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2774:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2775; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2775:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = (object*)TC_NIL;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = (object*) &constructed_288;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = ((object*) lenv) [4];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = (object*) &constructed_287;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r4 = ((object*) lenv) [8];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[9] = r4;
                          r4 = ((object*) lenv) [9];
                          r5 = (object*) &constructed_286;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[10] = r4;
                          r4 = ((object*) lenv) [10];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[11] = r4;
                          r3 = ((object*) lenv) [11];
                          r4 = (object*) &constructed_285;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2776; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2776:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2777; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2777:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_23;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_23;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_23;
                }
              }
              r1=r1;
              goto fatbar_23_over;
              fatbar_23:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2778; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2778:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_23_over: ;
              r1=r1;
            } else {
              goto fatbar_22;
            }
            r1=r1;
            goto fatbar_22_over;
            fatbar_22:
            r1 = (object *) constructed_306[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2779; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2779:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2780; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2780:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_304;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_303;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_302;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2781; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2781:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2782; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2782:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2783; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2783:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = ((object*) lenv) [3];
                          r5 = (object*) &constructed_301;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = ((object*) lenv) [5];
                          r4 = (object*) &constructed_300;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2784; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2784:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2785; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2785:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2786; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2786:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2787; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2787:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_299;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_298;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_297;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2788; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2788:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2789; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2789:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[56];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2790; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2790:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = ((object*) lenv) [3];
                          r5 = (object*) &constructed_296;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = ((object*) lenv) [5];
                          r4 = (object*) &constructed_295;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = top[47];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2791; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2791:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2792; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2792:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = (object*) &constructed_294;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2793; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2793:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_25;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_25;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_25;
                }
              }
              r1=r1;
              goto fatbar_25_over;
              fatbar_25:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2794; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2794:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_25_over: ;
              r1=r1;
            } else {
              goto fatbar_24;
            }
            r1=r1;
            goto fatbar_24_over;
            fatbar_24:
            r1 = (object *) constructed_312[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[2] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = allocate (TC_TUPLE, 11);
                                              r3[1] = lenv; lenv = r3;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                              r4[2] = r5;
                                              r5 = top[56];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2795; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2795:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[2] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object**) lenv) [1][2];
                                              r4[2] = r5;
                                              r5 = top[56];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2796; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2796:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[3] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object****) lenv) [1][1][1][2];
                                              r4[2] = r5;
                                              r5 = top[56];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2797; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2797:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[4] = r4;
                                              r4 = (object*)TC_NIL;
                                              r3[5] = r4;
                                              r4 = ((object*) lenv) [5];
                                              r5 = (object*) &constructed_310;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[6] = r4;
                                              r4 = ((object*) lenv) [6];
                                              r5 = ((object*) lenv) [4];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[7] = r4;
                                              r4 = ((object*) lenv) [7];
                                              r5 = (object*) &constructed_309;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[8] = r4;
                                              r4 = ((object*) lenv) [8];
                                              r5 = ((object*) lenv) [3];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[9] = r4;
                                              r4 = ((object*) lenv) [9];
                                              r5 = (object*) &constructed_308;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[10] = r4;
                                              r4 = ((object*) lenv) [10];
                                              r5 = ((object*) lenv) [2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[11] = r4;
                                              r3 = ((object*) lenv) [11];
                                              r4 = (object*) &constructed_307;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r4;
                                              t[2] = r3;
                                              r3 = t;
                                              lenv = lenv[1];
                                              r3 = r3;
                                              r2[2] = r3;
                                              r3 = top[47];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2798; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                              L2798:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = ((object***************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                                              r2 = ((pxll_vector*)r2)->val[4];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2799; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                              L2799:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_27;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_27;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_27;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_27;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_27;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_27;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_27;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_27;
                }
              }
              r1=r1;
              goto fatbar_27_over;
              fatbar_27:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2800; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2800:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_27_over: ;
              r1=r1;
            } else {
              goto fatbar_26;
            }
            r1=r1;
            goto fatbar_26_over;
            fatbar_26:
            r1 = (object *) constructed_326[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(9)): {
                  r1 = allocate (TC_TUPLE, 4);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                  r3 = ((pxll_vector*)r3)->val[1];
                  r2[2] = r3;
                  r3 = ((object*) lenv) [2];
                  r2[3] = r3;
                  r3 = top[66];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2801; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                  L2801:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[4] = r2;
                  r1 = ((object*) lenv) [4];
                  switch (get_case (r1)) {
                    case (UITAG(1)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_313;
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[14];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2802; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                      L2802:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } break;
                    default: {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][4];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object**) lenv) [1][3];
                      r2[2] = r3;
                      r3 = ((object*) lenv) [2];
                      r3 = ((pxll_vector*)r3)->val[1];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2803; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto *r3[1];
                      L2803:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r1 = (object *) 1;
                      r2 = ((object***) lenv) [1][1][3];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][2];
                        r4[2] = r5;
                        r5 = top[56];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2804; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2804:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = ((object***) lenv) [1][1][2];
                        r4[2] = r5;
                        r5 = ((object***) lenv) [1][1][3];
                        r4[3] = r5;
                        r5 = ((object**) lenv) [1][3];
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][6];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2805; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uitag_4283_i4724_i4766;
                        L2805:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = (object*) &constructed_316;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = ((object*) lenv) [5];
                        r5 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = ((object*) lenv) [6];
                        r5 = (object*) &constructed_315;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = ((object*) lenv) [7];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = ((object*) lenv) [8];
                        r4 = (object*) &constructed_314;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = top[47];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2806; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2806:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2807; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2807:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      } else {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = ((object***) lenv) [1][1][2];
                        r4[2] = r5;
                        r5 = ((object***) lenv) [1][1][3];
                        r4[3] = r5;
                        r5 = ((object**) lenv) [1][3];
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2808; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uotag_4282_i4724_i4766;
                        L2808:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][3];
                        r4[2] = r5;
                        r5 = top[56];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2809; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2809:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = (object*) &constructed_324;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = ((object*) lenv) [5];
                        r5 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = ((object*) lenv) [6];
                        r5 = (object*) &constructed_323;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = ((object*) lenv) [7];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = ((object*) lenv) [8];
                        r4 = (object*) &constructed_322;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = top[47];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2810; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2810:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2811; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2811:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        r2 = ((object****) lenv) [1][1][1][3];
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_4579_i3550_i4724_i4766
                        goto L2812;
                        FUN__24loop_4579_i3550_i4724_i4766:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][2];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = allocate (TC_TUPLE, 8);
                            r2[1] = lenv; lenv = r2;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = (object *) 3;
                            r5 = ((object**) lenv) [1][2];
                            r4 = box((pxll_int)unbox(r5)+unbox(r4));
                            r3[2] = r4;
                            r4 = top[56];
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2813; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                            L2813:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[2] = r3;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = allocate (TC_TUPLE, 3);
                            r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                            r4[2] = r5;
                            r5 = ((object**) lenv) [1][2];
                            r4[3] = r5;
                            r5 = top[27];
                            t = allocate (TC_SAVE, 7);
                            t[1] = k; t[2] = lenv; t[3] = &&L2814; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                            r4[1] = r5[2]; lenv = r4; goto FUN_nth_331;
                            L2814:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                            r4 = result;
                            r3[2] = r4;
                            r4 = top[56];
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2815; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                            L2815:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[3] = r3;
                            r3 = (object*)TC_NIL;
                            r2[4] = r3;
                            r3 = ((object*) lenv) [4];
                            r4 = (object*) &constructed_321;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[5] = r3;
                            r3 = ((object*) lenv) [5];
                            r4 = ((object*) lenv) [3];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[6] = r3;
                            r3 = ((object*) lenv) [6];
                            r4 = (object*) &constructed_320;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[7] = r3;
                            r3 = ((object*) lenv) [7];
                            r4 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[8] = r3;
                            r2 = ((object*) lenv) [8];
                            r3 = (object*) &constructed_319;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r2 = r2;
                            r1[2] = r2;
                            r2 = top[47];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2816; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                            L2816:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                            r1 = ((pxll_vector*)r1)->val[4];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L2817; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                            L2817:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = ((object*) lenv) [2];
                            r0 = box((pxll_int)unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_4579_i3550_i4724_i4766;
                          }
                          PXLL_RETURN(0);
                        L2812:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_4579_i3550_i4724_i4766; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2818; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4579_i3550_i4724_i4766;
                        L2818:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        r1 = r1;
                        lenv = lenv[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 5);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][2];
                        r4[2] = r5;
                        r5 = top[56];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2819; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2819:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = (object*)TC_NIL;
                        r3[3] = r4;
                        r4 = ((object*) lenv) [3];
                        r5 = (object*) &constructed_318;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r3 = ((object*) lenv) [5];
                        r4 = (object*) &constructed_317;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = top[47];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2820; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2820:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2821; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2821:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_29;
                }
              }
              r1=r1;
              goto fatbar_29_over;
              fatbar_29:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_226;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[14];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2822; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
              L2822:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_29_over: ;
              r1=r1;
            } else {
              goto fatbar_28;
            }
            r1=r1;
            goto fatbar_28_over;
            fatbar_28:
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object*) &constructed_226;
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[14];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2823; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
            L2823:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r1=r1;
            fatbar_28_over: ;
            r1=r1;
            fatbar_26_over: ;
            r1=r1;
            fatbar_24_over: ;
            r1=r1;
            fatbar_22_over: ;
            r1=r1;
            fatbar_20_over: ;
            r1=r1;
            fatbar_18_over: ;
            r1=r1;
            fatbar_16_over: ;
            r1=r1;
            fatbar_15_over: ;
            r1=r1;
            fatbar_14_over: ;
            r1=r1;
            fatbar_13_over: ;
            r1=r1;
            fatbar_11_over: ;
            r1=r1;
            fatbar_8_over: ;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(19)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[136];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2824; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_529;
            L2824:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r3 = ((object***) lenv) [1][1][3];
              r2 = PXLL_TEST(unbox(r3)==unbox(r2));
              r1[2] = r2;
              r1 = (object *) 6;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } else {
              r1 = (object *) 6;
              r1=r1;
            }
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2825; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2825:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[56];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2826; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2826:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_329;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_328;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_327;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2827; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2827:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2828; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2828:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r3 = ((object**) lenv) [1][2];
                r2 = PXLL_TEST(unbox(r3)==unbox(r2));
                r1[2] = r2;
                r1 = (object *) 6;
                r2 = ((object*) lenv) [2];
                r1 = PXLL_TEST(r2==r1);
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = (object *) 6;
                r1=r1;
              }
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2829; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2829:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[56];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2830; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2830:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_332;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_331;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_330;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = top[47];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2831; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2831:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2832; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2832:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } else {
                r1 = (object *) 14;
                r1=r1;
              }
              r1=r1;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(20)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2833; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
            L2833:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2834; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2834:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_338;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_337;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2835; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2835:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2836; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2836:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2837; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2837:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_336;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_335;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2838; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2838:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2839; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2839:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2840; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
            L2840:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2841; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2841:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_334;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_333;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2842; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2842:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2843; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2843:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(21)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_345;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2844; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2844:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2845; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2845:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_344;
              r5[3] = r6;
              r6 = top[31];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2846; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_335;
              L2846:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[47];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2847; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2847:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_343;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_342;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_341;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = top[47];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2848; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2848:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2849; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2849:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2850; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2850:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_340;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_339;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2851; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2851:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2852; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2852:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(22)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][6];
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = (object *) 262;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 6;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r3 = ((pxll_vector*)r3)->val[1];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][3];
            r2[3] = r3;
            r3 = top[66];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2853; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
            L2853:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UITAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r2 = (object*) &constructed_346;
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = top[14];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2854; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                L2854:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } break;
              default: {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object****) lenv) [1][1][1][5];
                r2[2] = r3;
                r3 = top[22];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2855; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
                L2855:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                lenv = lenv[1];
                r1 = r1;
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = ((pxll_vector*)r2)->val[3];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2856; t[4] = r0; t[5] = r1; k = t;
                  lenv = r2[2]; goto *r2[1];
                  L2856:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = (object *) 3;
                  r2 = ((object*) lenv) [2];
                  r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } else {
                  r1 = (object *) 6;
                  r1=r1;
                }
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object***) lenv) [1][1][5];
                  r2[2] = r3;
                  r3 = (object *) 1;
                  r2[3] = r3;
                  r3 = top[27];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2857; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_nth_331;
                  L2857:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2858; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
                  L2858:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } else {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = (object*) &constructed_357;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = allocate (TC_TUPLE, 7);
                  r3[1] = lenv; lenv = r3;
                  r4 = allocate (TC_TUPLE, 2);
                  r5 = ((object*****) lenv) [1][1][1][1][2];
                  r4[2] = r5;
                  r5 = top[56];
                  t = allocate (TC_SAVE, 7);
                  t[1] = k; t[2] = lenv; t[3] = &&L2859; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                  L2859:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                  r4 = result;
                  r3[2] = r4;
                  r4 = (object*)TC_NIL;
                  r3[3] = r4;
                  r4 = ((object*) lenv) [3];
                  r5 = (object*) &constructed_356;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[4] = r4;
                  r4 = ((object*) lenv) [4];
                  r5 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[5] = r4;
                  r4 = ((object*) lenv) [5];
                  r5 = (object*) &constructed_355;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[6] = r4;
                  r4 = ((object*) lenv) [6];
                  r5 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[7] = r4;
                  r3 = ((object*) lenv) [7];
                  r4 = (object*) &constructed_354;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  lenv = lenv[1];
                  r3 = r3;
                  r2[2] = r3;
                  r3 = top[47];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2860; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                  L2860:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2861; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2861:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*****) lenv) [1][1][1][1][4];
                  r2[2] = r3;
                  r3 = top[22];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2862; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
                  L2862:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def $loop_4605_i3786_i4724_i4766
                  goto L2863;
                  FUN__24loop_4605_i3786_i4724_i4766:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[27];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2864; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                      L2864:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[27];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2865; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                      L2865:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      r2 = ((pxll_vector*)r2)->val[1];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2866; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2866:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = ((object*) lenv) [4];
                      r1 = ((pxll_vector*)r1)->val[0];
                      r0[5] = r1;
                      r1 = (object *) 6;
                      r0[6] = r1;
                      r1 = (object *) 1;
                      r2 = ((object*) lenv) [5];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r1[3] = r2;
                        r2 = ((object*) lenv) [4];
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][6];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2867; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uitag_4283_i4724_i4766;
                        L2867:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      } else {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r1[3] = r2;
                        r2 = ((object*) lenv) [4];
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][5];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2868; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uotag_4282_i4724_i4766;
                        L2868:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      }
                      r0[7] = r1;
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2869; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2869:
                      ; lenv = k[2]; k = k[1];
                      r0 = (object *) 6;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                        r1[2] = r2;
                        r2 = top[22];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2870; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
                        L2870:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = (object *) 3;
                        r2 = ((object*) lenv) [2];
                        r1 = box((pxll_int)unbox(r2)-unbox(r1));
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object***) lenv) [1][1][2];
                        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } else {
                        r0 = (object *) 6;
                        r0=r0;
                      }
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object*) &constructed_351;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2871; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2871:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 4);
                        r2[1] = lenv; lenv = r2;
                        r3 = (object*)TC_NIL;
                        r2[2] = r3;
                        r3 = ((object*) lenv) [2];
                        r4 = (object*) &constructed_353;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[3] = r3;
                        r3 = ((object*) lenv) [3];
                        r4 = ((object**) lenv) [1][7];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[4] = r3;
                        r2 = ((object*) lenv) [4];
                        r3 = (object*) &constructed_352;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        lenv = lenv[1];
                        r2 = r2;
                        r1[2] = r2;
                        r2 = top[47];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2872; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                        L2872:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2873; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2873:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      }
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2874; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2874:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = ((object*) lenv) [3];
                      r0[2] = r1;
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2875; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4261_i4724_i4766;
                      L2875:
                      ; lenv = k[2]; k = k[1];
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2876; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2876:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object*) &constructed_350;
                      r0[2] = r1;
                      r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[4];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2877; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L2877:
                      ; lenv = k[2]; k = k[1];
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][42];
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2878; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2878:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_4605_i3786_i4724_i4766;
                    }
                    PXLL_RETURN(0);
                  L2863:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN__24loop_4605_i3786_i4724_i4766; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object *) 1;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2879; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4605_i3786_i4724_i4766;
                  L2879:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  lenv = lenv[1];
                  r1 = ((object****) lenv) [1][1][1][6];
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object*****) lenv) [1][1][1][1][6];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2880; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2880:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_349;
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2881; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2881:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2882; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2882:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2883; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4261_i4724_i4766;
                      L2883:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2884; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2884:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_348;
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2885; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2885:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][42];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2886; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2886:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_30;
                    }
                  }
                  goto fatbar_30_over;
                  fatbar_30:
                  r1 = (object *) 14;
                  fatbar_30_over: ;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object*) &constructed_347;
                  r1[2] = r2;
                  r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][42];
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2887; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2887:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = ((object*) lenv) [6];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = (object*) &constructed_73;
                r1 = box((pxll_int)((pxll_string*)(r1))->len);
                r2 = (object*) &constructed_73;
                (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
                r1 = (object*) &constructed_369;
                dump_object (r1, 0); fprintf (stdout, "\n");
                r1 = (object*) &constructed_369;
                PXLL_UNDEFINED; result=r1; goto Lreturn;
              } break;
              default: {
                r1 = (object *) 14;
              } break;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[56];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2888; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2888:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_368;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_367;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = top[47];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2889; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2889:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2890; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2890:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][5];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2891; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_324;
            L2891:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4621_i3807_i4724_i4766
            goto L2892;
            FUN__24loop_4621_i3807_i4724_i4766:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 9);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2893; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L2893:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][4];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2894; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L2894:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][5];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2895; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
                L2895:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[14];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[66];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2896; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                L2896:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = ((object*) lenv) [5];
                switch (get_case (r1)) {
                  case (UOTAG(0)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = ((object**) lenv) [1][5];
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = ((object*) lenv) [2];
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } break;
                  default: {
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object*) &constructed_366;
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = top[14];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2897; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_304;
                    L2897:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r1=r1;
                  } break;
                }
                r0[6] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 6);
                r2[1] = lenv; lenv = r2;
                r3 = (object *) 1;
                r4 = ((object**) lenv) [1][3];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)==unbox(r3))) {
                  r3 = (object*) &constructed_364;
                  r3=r3;
                } else {
                  r3 = (object*) &constructed_365;
                  r3=r3;
                }
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object**) lenv) [1][6];
                r3[2] = r4;
                r4 = top[56];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2898; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2898:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_363;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r2 = ((object*) lenv) [6];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2899; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2899:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[7] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 4);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r4 = (object*) &constructed_362;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[3] = r3;
                r3 = ((object*) lenv) [3];
                r4 = ((object**) lenv) [1][7];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[4] = r3;
                r2 = ((object*) lenv) [4];
                r3 = (object*) &constructed_361;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2900; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2900:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[8] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 3;
                r3 = ((object******) lenv) [1][1][1][1][1][2];
                r2 = box((pxll_int)unbox(r3)-unbox(r2));
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                r2 = ((object***) lenv) [1][1][2];
                r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                lenv = lenv[1];
                r1 = r1;
                if PXLL_IS_TRUE(r1) {
                  r1 = (object*) &constructed_360;
                  r1=r1;
                } else {
                  r1 = ((object*) lenv) [8];
                  r1=r1;
                }
                r0[9] = r1;
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2901; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2901:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object*) lenv) [9];
                r0[2] = r1;
                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2902; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2902:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2903; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2903:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object*) lenv) [4];
                r0[2] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2904; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_emit_4261_i4724_i4766;
                L2904:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2905; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2905:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object*) &constructed_359;
                r0[2] = r1;
                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2906; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2906:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][42];
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2907; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2907:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4621_i3807_i4724_i4766;
              }
              PXLL_RETURN(0);
            L2892:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4621_i3807_i4724_i4766; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2908; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4621_i3807_i4724_i4766;
            L2908:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_358;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][42];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2909; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2909:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r0;
            goto FUN_emit_4261_i4724_i4766;
          } break;
          default: {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L2467:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_emit_4261_i4724_i4766; r1[2] = lenv;
      r0[2] = r1;
      // def gen-function-label_4268_i4724_i4766
      goto L2910;
      FUN_gen_function_label_4268_i4724_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = ((object***) lenv) [1][1][2];
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3 = r3;
        r3=r3;
        r2[2] = r3;
        r3 = ((object***) lenv) [1][1][7];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2911; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto *r3[1];
        L2911:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_74;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      L2910:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_gen_function_label_4268_i4724_i4766; r1[2] = lenv;
      r0[3] = r1;
      // def guess-record-type_4281_i4724_i4766
      goto L2912;
      FUN_guess_record_type_4281_i4724_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_30484_i4724_i4766
        goto L2913;
        FUN_lambda_30484_i4724_i4766:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_5;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_5_over;
          fatbar_5:
          r0 = (object*) &constructed_73;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_73;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_72;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_72;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
          fatbar_5_over: ;
          PXLL_RETURN(0);
        L2913:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_30484_i4724_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2914; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_336;
        L2914:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_30495_i4724_i4766
        goto L2915;
        FUN_lambda_30495_i4724_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_71[0];
          r2 = ((object**) lenv) [1][2];
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          PXLL_RETURN(0);
        L2915:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_30495_i4724_i4766; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2916; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_filter_338;
        L2916:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object *) constructed_69[0];
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_30523_i4724_i4766
        goto L2917;
        FUN_lambda_30523_i4724_i4766:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_30465_i4125_i4724_i4766
              goto L2918;
              FUN_lambda_30465_i4125_i4724_i4766:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r0[3] = r1;
                r1 = top[25];
                r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_329;
              L2918:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_30465_i4125_i4724_i4766; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r0[3] = r1;
              r1 = top[40];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2919; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_every_question_344;
              L2919:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][4];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                ((object***) lenv) [1][1][4] = r0;
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L2917:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_30523_i4724_i4766; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[9];
        r0[3] = r1;
        r1 = top[35];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2920; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
        L2920:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][4];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2921; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
        L2921:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = (object *) 3;
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[27];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2922; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_331;
          L2922:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2912:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_guess_record_type_4281_i4724_i4766; r1[2] = lenv;
      r0[4] = r1;
      // def get-uotag_4282_i4724_i4766
      goto L2923;
      FUN_get_uotag_4282_i4724_i4766:
        check_heap (0);
        r0 = (object *) constructed_63[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_61[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_59;
            PXLL_RETURN(0);
          } else {
            goto fatbar_3;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_3;
        }
        PXLL_RETURN(0);
        goto fatbar_3_over;
        fatbar_3:
        r0 = (object *) constructed_56[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_66[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_64;
            PXLL_RETURN(0);
          } else {
            goto fatbar_4;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_4;
        }
        PXLL_RETURN(0);
        goto fatbar_4_over;
        fatbar_4:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2924; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2924:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_68;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_67;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_4_over: ;
        PXLL_RETURN(0);
        fatbar_3_over: ;
        PXLL_RETURN(0);
      L2923:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uotag_4282_i4724_i4766; r1[2] = lenv;
      r0[5] = r1;
      // def get-uitag_4283_i4724_i4766
      goto L2925;
      FUN_get_uitag_4283_i4724_i4766:
        check_heap (0);
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_46[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_44;
            PXLL_RETURN(0);
          } else {
            goto fatbar_1;
          }
          PXLL_RETURN(0);
          goto fatbar_1_over;
          fatbar_1:
          r0 = (object *) constructed_49[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_47;
            PXLL_RETURN(0);
          } else {
            goto fatbar_0;
          }
          PXLL_RETURN(0);
          fatbar_1_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_0;
        }
        PXLL_RETURN(0);
        goto fatbar_0_over;
        fatbar_0:
        r0 = (object *) constructed_56[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_54[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_52;
            PXLL_RETURN(0);
          } else {
            goto fatbar_2;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_2;
        }
        PXLL_RETURN(0);
        goto fatbar_2_over;
        fatbar_2:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2926; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2926:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_58;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_57;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = top[47];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_2_over: ;
        PXLL_RETURN(0);
        fatbar_0_over: ;
        PXLL_RETURN(0);
      L2925:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uitag_4283_i4724_i4766; r1[2] = lenv;
      r0[6] = r1;
      r1 = allocate (TC_TUPLE, 4);
      r1[1] = lenv; lenv = r1;
      // def frob-name_4210_i4434_i4724_i4766
      goto L2927;
      FUN_frob_name_4210_i4434_i4724_i4766:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        // def loop_4215_i3143_i4434_i4724_i4766
        goto L2928;
        FUN_loop_4215_i3143_i4434_i4724_i4766:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [3];
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][2];
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2929; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2929:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = top[46];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2930; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_358;
              L2930:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r2[2] = r3;
              r3 = ((object***) lenv) [1][1][2];
              r2[3] = r3;
              r3 = top[66];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2931; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
              L2931:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 4);
                  r2[1] = lenv; lenv = r2;
                  r3 = allocate (TC_TUPLE, 2);
                  r4 = ((object****) lenv) [1][1][1][2];
                  r4 = box((pxll_int)GET_CHAR(r4));
                  r3[2] = r4;
                  r4 = top[57];
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2932; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_int__3ehex_string_375;
                  L2932:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = (object*)TC_NIL;
                  r2[3] = r3;
                  r3 = ((object*) lenv) [3];
                  r4 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  r2[4] = r3;
                  r2 = ((object*) lenv) [4];
                  r3 = (object*) &constructed_43;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r2 = r2;
                  r1[2] = r2;
                  r2 = top[47];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2933; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                  L2933:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } break;
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            }
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = ((object**) lenv) [1][2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = ((object *)lenv)[1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_4215_i3143_i4434_i4724_i4766;
          }
          PXLL_RETURN(0);
        L2928:
        r4 = allocate (TC_CLOSURE, 2);
        r4[1] = &&FUN_loop_4215_i3143_i4434_i4724_i4766; r4[2] = lenv;
        r3[2] = r4;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 1;
        r3[2] = r4;
        r4 = (object *) constructed_42[0];
        r3[3] = r4;
        r4 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2934; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_loop_4215_i3143_i4434_i4724_i4766;
        L2934:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [2];
        r2[2] = r3;
        r3 = (object *) constructed_41[0];
        r2[3] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2935; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_321;
        L2935:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2936; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2936:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = (object*) &constructed_40;
        r1[3] = r2;
        r2 = top[50];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2937; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
        L2937:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = (object*) &constructed_39;
          PXLL_RETURN(0);
        } else {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2927:
      r2 = allocate (TC_CLOSURE, 2);
      r2[1] = &&FUN_frob_name_4210_i4434_i4724_i4766; r2[2] = lenv;
      r1[2] = r2;
      r2 = (object *) constructed_38[0];
      r1[3] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r3 = allocate (TC_TUPLE, 2);
      r4 = (object*) &constructed_31;
      r3[2] = r4;
      r4 = top[55];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2938; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string__3elist_372;
      L2938:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = top[82];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2939; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_char_class_429;
      L2939:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[4] = r2;
      r1 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1 = r1;
      r0[7] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object****) lenv) [1][1][1][39];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2940; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4261_i4724_i4766;
      L2940:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_30;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2941; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2941:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_29;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2942; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2942:
      ; lenv = k[2]; k = k[1];
      r0 = ((object****) lenv) [1][1][1][42];
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2943; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2943:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_28;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][42];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2944; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2944:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = r0;
      r0=r0;
    } break;
  }
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object**) lenv) [1][2];
  r2 = ((pxll_vector*)r2)->val[9];
  r1[2] = r2;
  r2 = top[22];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2945; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
  L2945:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r0 = (object *) 1;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(unbox(r1)>unbox(r0));
  lenv = lenv[1];
  r0 = r0;
  if PXLL_IS_TRUE(r0) {
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_27;
    r0[2] = r1;
    r1 = ((object*) lenv) [42];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2946; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2946:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_26;
    r0[2] = r1;
    r1 = ((object*) lenv) [42];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2947; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2947:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_33695_i4725_i4766
    goto L2948;
    FUN_lambda_33695_i4725_i4766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[56];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2949; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2949:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = (object*) &constructed_25;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_24;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2950; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2950:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][42];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2951; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2951:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_23;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][42];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2952; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2952:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2953; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_324;
          L2953:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_4705_i4725_i4766
          goto L2954;
          FUN__24loop_4705_i4725_i4766:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 3);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object*****) lenv) [1][1][1][1][2];
              r5[2] = r6;
              r6 = ((object**) lenv) [1][2];
              r5[3] = r6;
              r6 = top[27];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2955; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_nth_331;
              L2955:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r4[3] = r5;
              r5 = top[9];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2956; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_lookup_label_code_264;
              L2956:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2957; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2957:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][2];
              r3[2] = r4;
              r4 = top[56];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2958; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2958:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_22;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_21;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = ((object*) lenv) [8];
              r3 = (object*) &constructed_20;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2959; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2959:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][42];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2960; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2960:
              ; lenv = k[2]; k = k[1];
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4705_i4725_i4766;
            }
            PXLL_RETURN(0);
          L2954:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_4705_i4725_i4766; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2961; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4705_i4725_i4766;
          L2961:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_19;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][42];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L2948:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_33695_i4725_i4766; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[9];
    r0[3] = r1;
    r1 = top[35];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2962; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_339;
    L2962:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_18;
    r0[2] = r1;
    r1 = ((object*) lenv) [42];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2963; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2963:
    ; lenv = k[2]; k = k[1];
    r0 = result;
  } else {
    r0 = (object *) 14;
  }
  r0 = (object*) &constructed_17;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_17;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = ((object*) lenv) [42];
  r0 = ((pxll_vector*)r0)->val[0];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2964; ; k = t;
  lenv = r0[2]; goto *r0[1];
  L2964:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = ((object**) lenv) [1][2];
  r1 = ((pxll_vector*)r1)->val[8];
  r1 = ((pxll_vector*)r1)->val[1];
  r0[2] = r1;
  r0 = (object *) 6;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(r1==r0);
  lenv = lenv[1];
  r0 = r0;
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_16;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_16;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 9);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[8];
    r0[2] = r1;
    r1 = (object *) 3;
    r1 = alloc_no_clear (TC_BUFFER, HOW_MANY (sizeof (struct utsname) * unbox(r1), sizeof (object)));
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    box((pxll_int)uname (((struct utsname*)(((pxll_vector*)r1)+1))));
    r1 = allocate (UOTAG(0), 5);
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object*) lenv) [3];
    r3 = (object*)((struct utsname*)(((pxll_vector*)r3)+1))->machine;
    r2[2] = r3;
    r3 = top[60];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2965; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
    L2965:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[1] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object*) lenv) [3];
    r3 = (object*)((struct utsname*)(((pxll_vector*)r3)+1))->nodename;
    r2[2] = r3;
    r3 = top[60];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2966; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
    L2966:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object*) lenv) [3];
    r3 = (object*)((struct utsname*)(((pxll_vector*)r3)+1))->release;
    r2[2] = r3;
    r3 = top[60];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2967; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
    L2967:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object*) lenv) [3];
    r3 = (object*)((struct utsname*)(((pxll_vector*)r3)+1))->sysname;
    r2[2] = r3;
    r3 = top[60];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2968; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
    L2968:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object*) lenv) [3];
    r3 = (object*)((struct utsname*)(((pxll_vector*)r3)+1))->version;
    r2[2] = r3;
    r3 = top[60];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2969; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
    L2969:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_15;
    r1[2] = r2;
    r2 = (object*) &constructed_14;
    r1[3] = r2;
    r2 = top[151];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2970; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_578;
    L2970:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_13;
    r1[2] = r2;
    r2 = (object*) &constructed_12;
    r1[3] = r2;
    r2 = top[151];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2971; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_578;
    L2971:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][5];
    r2[2] = r3;
    r3 = (object*) &constructed_11;
    r2[3] = r3;
    r3 = top[50];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2972; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
    L2972:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r1 = (object *) 1;
    r2 = ((object*) lenv) [2];
    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
    lenv = lenv[1];
    r1 = r1;
    if PXLL_IS_TRUE(r1) {
      r1 = allocate (TC_TUPLE, 3);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][4];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 3);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = (object*) &constructed_10;
      r2[3] = r3;
      r3 = top[50];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2973; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
      L2973:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[3] = r2;
      r1 = (object *) 1;
      r2 = ((object*) lenv) [3];
      r1 = PXLL_TEST(unbox(r2)==unbox(r1));
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
    } else {
      r1 = (object *) 6;
      r1=r1;
    }
    if PXLL_IS_TRUE(r1) {
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 3);
      r2[1] = lenv; lenv = r2;
      r3 = (object*)TC_NIL;
      r2[2] = r3;
      r3 = ((object*) lenv) [2];
      r4 = (object*) &constructed_9;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[3] = r3;
      r2 = ((object*) lenv) [3];
      r3 = ((object**) lenv) [1][6];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = top[47];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2974; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L2974:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r1=r1;
    } else {
      r1 = ((object*) lenv) [6];
      r1=r1;
    }
    r0[7] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[2];
    if PXLL_IS_TRUE(r3) {
      r3 = (object*) &constructed_7;
      r3=r3;
    } else {
      r3 = (object*) &constructed_8;
      r3=r3;
    }
    r2[2] = r3;
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[0];
    r2[3] = r3;
    r3 = (object*)TC_NIL;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = ((object*) lenv) [5];
    r4 = (object*) &constructed_6;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = ((object*) lenv) [7];
    r4 = (object*) &constructed_5;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = ((object*) lenv) [8];
    r3 = ((object**) lenv) [1][7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2975; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2975:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[8] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = ((object***) lenv) [1][1][11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_4;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object***) lenv) [1][1][11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = ((object*) lenv) [5];
    r4 = (object*) &constructed_3;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = ((object*) lenv) [6];
    r4 = ((object**) lenv) [1][8];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = ((object*) lenv) [7];
    r4 = (object*) &constructed_2;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = ((object*) lenv) [8];
    r3 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2976; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2976:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[9] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = (object*) &constructed_1;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object***) lenv) [1][1][9];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_0;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = top[47];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2977; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2977:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [9];
    r0[2] = r1;
    r1 = top[53];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2978; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_zero_terminate_370;
    L2978:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r0 = box((pxll_int)system (((pxll_string*)(r0))->data));
    lenv = lenv[1];
    r0 = (object *) 14;
    PXLL_RETURN(0);
  } else {
    r0 = (object *) 14;
    PXLL_RETURN(0);
  }
  PXLL_RETURN(0);
  Lreturn:
  return (pxll_int) result;
}
static int lookup_field (int tag, int label)
{ switch (tag) {
  case 25:
  switch (label) {
     case 84: return 0; break;
     case 70: return 1; break;
     case 85: return 2; break;
     case 68: return 3; break;
     case 86: return 4; break;
  } break;
  case 24:
  switch (label) {
     case 10: return 0; break;
     case 83: return 1; break;
     case 11: return 2; break;
     case 12: return 3; break;
  } break;
  case 23:
  switch (label) {
     case 80: return 0; break;
     case 81: return 1; break;
     case 82: return 2; break;
  } break;
  case 22:
  switch (label) {
     case 16: return 0; break;
     case 79: return 1; break;
  } break;
  case 21:
  switch (label) {
     case 16: return 0; break;
     case 75: return 1; break;
     case 76: return 2; break;
     case 77: return 3; break;
     case 78: return 4; break;
  } break;
  case 20:
  switch (label) {
     case 70: return 0; break;
     case 71: return 1; break;
     case 72: return 2; break;
     case 73: return 3; break;
     case 54: return 4; break;
     case 74: return 5; break;
  } break;
  case 19:
  switch (label) {
     case 66: return 0; break;
     case 21: return 1; break;
     case 67: return 2; break;
     case 68: return 3; break;
     case 69: return 4; break;
  } break;
  case 18:
  switch (label) {
     case 64: return 0; break;
     case 65: return 1; break;
  } break;
  case 17:
  switch (label) {
     case 63: return 0; break;
     case 53: return 1; break;
  } break;
  case 16:
  switch (label) {
     case 62: return 0; break;
     case 53: return 1; break;
  } break;
  case 15:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 57: return 2; break;
     case 58: return 3; break;
     case 30: return 4; break;
     case 59: return 5; break;
     case 60: return 6; break;
     case 61: return 7; break;
  } break;
  case 14:
  switch (label) {
     case 56: return 0; break;
     case 53: return 1; break;
     case 54: return 2; break;
  } break;
  case 13:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 55: return 2; break;
     case 30: return 3; break;
  } break;
  case 12:
  switch (label) {
     case 53: return 0; break;
     case 54: return 1; break;
  } break;
  case 11:
  switch (label) {
     case 49: return 0; break;
     case 50: return 1; break;
     case 51: return 2; break;
     case 52: return 3; break;
  } break;
  case 10:
  switch (label) {
     case 47: return 0; break;
     case 48: return 1; break;
  } break;
  case 9:
  switch (label) {
     case 31: return 0; break;
     case 32: return 1; break;
     case 33: return 2; break;
     case 34: return 3; break;
     case 35: return 4; break;
     case 36: return 5; break;
     case 37: return 6; break;
     case 38: return 7; break;
     case 39: return 8; break;
     case 40: return 9; break;
     case 41: return 10; break;
     case 42: return 11; break;
     case 43: return 12; break;
     case 44: return 13; break;
     case 45: return 14; break;
     case 46: return 15; break;
  } break;
  case 8:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 26: return 2; break;
     case 27: return 3; break;
     case 28: return 4; break;
     case 29: return 5; break;
     case 30: return 6; break;
     case 21: return 7; break;
  } break;
  case 7:
  switch (label) {
     case 23: return 0; break;
     case 21: return 1; break;
     case 24: return 2; break;
     case 25: return 3; break;
  } break;
  case 6:
  switch (label) {
     case 20: return 0; break;
     case 14: return 1; break;
     case 21: return 2; break;
     case 22: return 3; break;
  } break;
  case 5:
  switch (label) {
     case 18: return 0; break;
     case 19: return 1; break;
  } break;
  case 4:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 17: return 2; break;
  } break;
  case 3:
  switch (label) {
     case 13: return 0; break;
     case 14: return 1; break;
  } break;
  case 2:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 12: return 2; break;
  } break;
  case 1:
  switch (label) {
     case 5: return 0; break;
     case 6: return 1; break;
     case 7: return 2; break;
     case 8: return 3; break;
     case 9: return 4; break;
  } break;
  case 0:
  switch (label) {
     case 0: return 0; break;
     case 1: return 1; break;
     case 2: return 2; break;
     case 3: return 3; break;
     case 4: return 4; break;
  } break;
}}
